/*!
 * jQuery JavaScript Library v1.7.2
 * http://jquery.com/
 *
 * Copyright 2011, John Resig
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 * Copyright 2011, The Dojo Foundation
 * Released under the MIT, BSD, and GPL Licenses.
 *
 * Date: Wed Mar 21 12:46:34 2012 -0700
 */
(function( window, undefined ) {

// Use the correct document accordingly with window argument (sandbox)
var document = window.document,
	navigator = window.navigator,
	location = window.location;
var jQuery = (function() {

// Define a local copy of jQuery
var jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		return new jQuery.fn.init( selector, context, rootjQuery );
	},

	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$,

	// A central reference to the root jQuery(document)
	rootjQuery,

	// A simple way to check for HTML strings or ID strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	quickExpr = /^(?:[^#<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,

	// Check if a string has a non-whitespace character in it
	rnotwhite = /\S/,

	// Used for trimming whitespace
	trimLeft = /^\s+/,
	trimRight = /\s+$/,

	// Match a standalone tag
	rsingleTag = /^<(\w+)\s*\/?>(?:<\/\1>)?$/,

	// JSON RegExp
	rvalidchars = /^[\],:{}\s]*$/,
	rvalidescape = /\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,
	rvalidtokens = /"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,
	rvalidbraces = /(?:^|:|,)(?:\s*\[)+/g,

	// Useragent RegExp
	rwebkit = /(webkit)[ \/]([\w.]+)/,
	ropera = /(opera)(?:.*version)?[ \/]([\w.]+)/,
	rmsie = /(msie) ([\w.]+)/,
	rmozilla = /(mozilla)(?:.*? rv:([\w.]+))?/,

	// Matches dashed string for camelizing
	rdashAlpha = /-([a-z]|[0-9])/ig,
	rmsPrefix = /^-ms-/,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return ( letter + "" ).toUpperCase();
	},

	// Keep a UserAgent string for use with jQuery.browser
	userAgent = navigator.userAgent,

	// For matching the engine and version of the browser
	browserMatch,

	// The deferred used on DOM ready
	readyList,

	// The ready event handler
	DOMContentLoaded,

	// Save a reference to some core methods
	toString = Object.prototype.toString,
	hasOwn = Object.prototype.hasOwnProperty,
	push = Array.prototype.push,
	slice = Array.prototype.slice,
	trim = String.prototype.trim,
	indexOf = Array.prototype.indexOf,

	// [[Class]] -> type pairs
	class2type = {};

jQuery.fn = jQuery.prototype = {
	constructor: jQuery,
	init: function( selector, context, rootjQuery ) {
		var match, elem, ret, doc;

		// Handle $(""), $(null), or $(undefined)
		if ( !selector ) {
			return this;
		}

		// Handle $(DOMElement)
		if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;
		}

		// The body element only exists once, optimize finding it
		if ( selector === "body" && !context && document.body ) {
			this.context = document;
			this[0] = document.body;
			this.selector = selector;
			this.length = 1;
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			// Are we dealing with HTML string or an ID?
			if ( selector.charAt(0) === "<" && selector.charAt( selector.length - 1 ) === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = quickExpr.exec( selector );
			}

			// Verify a match, and that no context was specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;
					doc = ( context ? context.ownerDocument || context : document );

					// If a single string is passed in and it's a single tag
					// just do a createElement and skip the rest
					ret = rsingleTag.exec( selector );

					if ( ret ) {
						if ( jQuery.isPlainObject( context ) ) {
							selector = [ document.createElement( ret[1] ) ];
							jQuery.fn.attr.call( selector, context, true );

						} else {
							selector = [ doc.createElement( ret[1] ) ];
						}

					} else {
						ret = jQuery.buildFragment( [ match[1] ], [ doc ] );
						selector = ( ret.cacheable ? jQuery.clone(ret.fragment) : ret.fragment ).childNodes;
					}

					return jQuery.merge( this, selector );

				// HANDLE: $("#id")
				} else {
					elem = document.getElementById( match[2] );

					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document #6963
					if ( elem && elem.parentNode ) {
						// Handle the case where IE and Opera return items
						// by name instead of ID
						if ( elem.id !== match[2] ) {
							return rootjQuery.find( selector );
						}

						// Otherwise, we inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return rootjQuery.ready( selector );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	},

	// Start with an empty selector
	selector: "",

	// The current version of jQuery being used
	jquery: "1.7.2",

	// The default length of a jQuery object is 0
	length: 0,

	// The number of elements contained in the matched element set
	size: function() {
		return this.length;
	},

	toArray: function() {
		return slice.call( this, 0 );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num == null ?

			// Return a 'clean' array
			this.toArray() :

			// Return just the object
			( num < 0 ? this[ this.length + num ] : this[ num ] );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems, name, selector ) {
		// Build a new jQuery matched element set
		var ret = this.constructor();

		if ( jQuery.isArray( elems ) ) {
			push.apply( ret, elems );

		} else {
			jQuery.merge( ret, elems );
		}

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;

		ret.context = this.context;

		if ( name === "find" ) {
			ret.selector = this.selector + ( this.selector ? " " : "" ) + selector;
		} else if ( name ) {
			ret.selector = this.selector + "." + name + "(" + selector + ")";
		}

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	ready: function( fn ) {
		// Attach the listeners
		jQuery.bindReady();

		// Add the callback
		readyList.add( fn );

		return this;
	},

	eq: function( i ) {
		i = +i;
		return i === -1 ?
			this.slice( i ) :
			this.slice( i, i + 1 );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ),
			"slice", slice.call(arguments).join(",") );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: [].sort,
	splice: [].splice
};

// Give the init function the jQuery prototype for later instantiation
jQuery.fn.init.prototype = jQuery.fn;

jQuery.extend = jQuery.fn.extend = function() {
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;
		target = arguments[1] || {};
		// skip the boolean and the target
		i = 2;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// extend jQuery itself if only one argument is passed
	if ( length === i ) {
		target = this;
		--i;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	noConflict: function( deep ) {
		if ( window.$ === jQuery ) {
			window.$ = _$;
		}

		if ( deep && window.jQuery === jQuery ) {
			window.jQuery = _jQuery;
		}

		return jQuery;
	},

	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {
		// Either a released hold or an DOMready/load event and not yet ready
		if ( (wait === true && !--jQuery.readyWait) || (wait !== true && !jQuery.isReady) ) {
			// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
			if ( !document.body ) {
				return setTimeout( jQuery.ready, 1 );
			}

			// Remember that the DOM is ready
			jQuery.isReady = true;

			// If a normal DOM Ready event fired, decrement, and wait if need be
			if ( wait !== true && --jQuery.readyWait > 0 ) {
				return;
			}

			// If there are functions bound, to execute
			readyList.fireWith( document, [ jQuery ] );

			// Trigger any bound ready events
			if ( jQuery.fn.trigger ) {
				jQuery( document ).trigger( "ready" ).off( "ready" );
			}
		}
	},

	bindReady: function() {
		if ( readyList ) {
			return;
		}

		readyList = jQuery.Callbacks( "once memory" );

		// Catch cases where $(document).ready() is called after the
		// browser event has already occurred.
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			return setTimeout( jQuery.ready, 1 );
		}

		// Mozilla, Opera and webkit nightlies currently support this event
		if ( document.addEventListener ) {
			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", DOMContentLoaded, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", jQuery.ready, false );

		// If IE event model is used
		} else if ( document.attachEvent ) {
			// ensure firing before onload,
			// maybe late but safe also for iframes
			document.attachEvent( "onreadystatechange", DOMContentLoaded );

			// A fallback to window.onload, that will always work
			window.attachEvent( "onload", jQuery.ready );

			// If IE and not a frame
			// continually check to see if the document is ready
			var toplevel = false;

			try {
				toplevel = window.frameElement == null;
			} catch(e) {}

			if ( document.documentElement.doScroll && toplevel ) {
				doScrollCheck();
			}
		}
	},

	// See test/unit/core.js for details concerning isFunction.
	// Since version 1.3, DOM methods and functions like alert
	// aren't supported. They return false on IE (#2968).
	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray || function( obj ) {
		return jQuery.type(obj) === "array";
	},

	isWindow: function( obj ) {
		return obj != null && obj == obj.window;
	},

	isNumeric: function( obj ) {
		return !isNaN( parseFloat(obj) ) && isFinite( obj );
	},

	type: function( obj ) {
		return obj == null ?
			String( obj ) :
			class2type[ toString.call(obj) ] || "object";
	},

	isPlainObject: function( obj ) {
		// Must be an Object.
		// Because of IE, we also have to check the presence of the constructor property.
		// Make sure that DOM nodes and window objects don't pass through, as well
		if ( !obj || jQuery.type(obj) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		try {
			// Not own constructor property must be Object
			if ( obj.constructor &&
				!hasOwn.call(obj, "constructor") &&
				!hasOwn.call(obj.constructor.prototype, "isPrototypeOf") ) {
				return false;
			}
		} catch ( e ) {
			// IE8,9 Will throw exceptions on certain host objects #9897
			return false;
		}

		// Own properties are enumerated firstly, so to speed up,
		// if last one is own, then all properties are own.

		var key;
		for ( key in obj ) {}

		return key === undefined || hasOwn.call( obj, key );
	},

	isEmptyObject: function( obj ) {
		for ( var name in obj ) {
			return false;
		}
		return true;
	},

	error: function( msg ) {
		throw new Error( msg );
	},

	parseJSON: function( data ) {
		if ( typeof data !== "string" || !data ) {
			return null;
		}

		// Make sure leading/trailing whitespace is removed (IE can't handle it)
		data = jQuery.trim( data );

		// Attempt to parse using the native JSON parser first
		if ( window.JSON && window.JSON.parse ) {
			return window.JSON.parse( data );
		}

		// Make sure the incoming data is actual JSON
		// Logic borrowed from http://json.org/json2.js
		if ( rvalidchars.test( data.replace( rvalidescape, "@" )
			.replace( rvalidtokens, "]" )
			.replace( rvalidbraces, "")) ) {

			return ( new Function( "return " + data ) )();

		}
		jQuery.error( "Invalid JSON: " + data );
	},

	// Cross-browser xml parsing
	parseXML: function( data ) {
		if ( typeof data !== "string" || !data ) {
			return null;
		}
		var xml, tmp;
		try {
			if ( window.DOMParser ) { // Standard
				tmp = new DOMParser();
				xml = tmp.parseFromString( data , "text/xml" );
			} else { // IE
				xml = new ActiveXObject( "Microsoft.XMLDOM" );
				xml.async = "false";
				xml.loadXML( data );
			}
		} catch( e ) {
			xml = undefined;
		}
		if ( !xml || !xml.documentElement || xml.getElementsByTagName( "parsererror" ).length ) {
			jQuery.error( "Invalid XML: " + data );
		}
		return xml;
	},

	noop: function() {},

	// Evaluates a script in a global context
	// Workarounds based on findings by Jim Driscoll
	// http://weblogs.java.net/blog/driscoll/archive/2009/09/08/eval-javascript-global-context
	globalEval: function( data ) {
		if ( data && rnotwhite.test( data ) ) {
			// We use execScript on Internet Explorer
			// We use an anonymous function so that context is window
			// rather than jQuery in Firefox
			( window.execScript || function( data ) {
				window[ "eval" ].call( window, data );
			} )( data );
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toUpperCase() === name.toUpperCase();
	},

	// args is for internal usage only
	each: function( object, callback, args ) {
		var name, i = 0,
			length = object.length,
			isObj = length === undefined || jQuery.isFunction( object );

		if ( args ) {
			if ( isObj ) {
				for ( name in object ) {
					if ( callback.apply( object[ name ], args ) === false ) {
						break;
					}
				}
			} else {
				for ( ; i < length; ) {
					if ( callback.apply( object[ i++ ], args ) === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isObj ) {
				for ( name in object ) {
					if ( callback.call( object[ name ], name, object[ name ] ) === false ) {
						break;
					}
				}
			} else {
				for ( ; i < length; ) {
					if ( callback.call( object[ i ], i, object[ i++ ] ) === false ) {
						break;
					}
				}
			}
		}

		return object;
	},

	// Use native String.trim function wherever possible
	trim: trim ?
		function( text ) {
			return text == null ?
				"" :
				trim.call( text );
		} :

		// Otherwise use our own trimming functionality
		function( text ) {
			return text == null ?
				"" :
				text.toString().replace( trimLeft, "" ).replace( trimRight, "" );
		},

	// results is for internal usage only
	makeArray: function( array, results ) {
		var ret = results || [];

		if ( array != null ) {
			// The window, strings (and functions) also have 'length'
			// Tweaked logic slightly to handle Blackberry 4.7 RegExp issues #6930
			var type = jQuery.type( array );

			if ( array.length == null || type === "string" || type === "function" || type === "regexp" || jQuery.isWindow( array ) ) {
				push.call( ret, array );
			} else {
				jQuery.merge( ret, array );
			}
		}

		return ret;
	},

	inArray: function( elem, array, i ) {
		var len;

		if ( array ) {
			if ( indexOf ) {
				return indexOf.call( array, elem, i );
			}

			len = array.length;
			i = i ? i < 0 ? Math.max( 0, len + i ) : i : 0;

			for ( ; i < len; i++ ) {
				// Skip accessing in sparse arrays
				if ( i in array && array[ i ] === elem ) {
					return i;
				}
			}
		}

		return -1;
	},

	merge: function( first, second ) {
		var i = first.length,
			j = 0;

		if ( typeof second.length === "number" ) {
			for ( var l = second.length; j < l; j++ ) {
				first[ i++ ] = second[ j ];
			}

		} else {
			while ( second[j] !== undefined ) {
				first[ i++ ] = second[ j++ ];
			}
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, inv ) {
		var ret = [], retVal;
		inv = !!inv;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( var i = 0, length = elems.length; i < length; i++ ) {
			retVal = !!callback( elems[ i ], i );
			if ( inv !== retVal ) {
				ret.push( elems[ i ] );
			}
		}

		return ret;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value, key, ret = [],
			i = 0,
			length = elems.length,
			// jquery objects are treated as arrays
			isArray = elems instanceof jQuery || length !== undefined && typeof length === "number" && ( ( length > 0 && elems[ 0 ] && elems[ length -1 ] ) || length === 0 || jQuery.isArray( elems ) ) ;

		// Go through the array, translating each of the items to their
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret[ ret.length ] = value;
				}
			}

		// Go through every key on the object,
		} else {
			for ( key in elems ) {
				value = callback( elems[ key ], key, arg );

				if ( value != null ) {
					ret[ ret.length ] = value;
				}
			}
		}

		// Flatten any nested arrays
		return ret.concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		if ( typeof context === "string" ) {
			var tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		var args = slice.call( arguments, 2 ),
			proxy = function() {
				return fn.apply( context, args.concat( slice.call( arguments ) ) );
			};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || proxy.guid || jQuery.guid++;

		return proxy;
	},

	// Mutifunctional method to get and set values to a collection
	// The value/s can optionally be executed if it's a function
	access: function( elems, fn, key, value, chainable, emptyGet, pass ) {
		var exec,
			bulk = key == null,
			i = 0,
			length = elems.length;

		// Sets many values
		if ( key && typeof key === "object" ) {
			for ( i in key ) {
				jQuery.access( elems, fn, i, key[i], 1, emptyGet, value );
			}
			chainable = 1;

		// Sets one value
		} else if ( value !== undefined ) {
			// Optionally, function values get executed if exec is true
			exec = pass === undefined && jQuery.isFunction( value );

			if ( bulk ) {
				// Bulk operations only iterate when executing function values
				if ( exec ) {
					exec = fn;
					fn = function( elem, key, value ) {
						return exec.call( jQuery( elem ), value );
					};

				// Otherwise they run against the entire set
				} else {
					fn.call( elems, value );
					fn = null;
				}
			}

			if ( fn ) {
				for (; i < length; i++ ) {
					fn( elems[i], key, exec ? value.call( elems[i], i, fn( elems[i], key ) ) : value, pass );
				}
			}

			chainable = 1;
		}

		return chainable ?
			elems :

			// Gets
			bulk ?
				fn.call( elems ) :
				length ? fn( elems[0], key ) : emptyGet;
	},

	now: function() {
		return ( new Date() ).getTime();
	},

	// Use of jQuery.browser is frowned upon.
	// More details: http://docs.jquery.com/Utilities/jQuery.browser
	uaMatch: function( ua ) {
		ua = ua.toLowerCase();

		var match = rwebkit.exec( ua ) ||
			ropera.exec( ua ) ||
			rmsie.exec( ua ) ||
			ua.indexOf("compatible") < 0 && rmozilla.exec( ua ) ||
			[];

		return { browser: match[1] || "", version: match[2] || "0" };
	},

	sub: function() {
		function jQuerySub( selector, context ) {
			return new jQuerySub.fn.init( selector, context );
		}
		jQuery.extend( true, jQuerySub, this );
		jQuerySub.superclass = this;
		jQuerySub.fn = jQuerySub.prototype = this();
		jQuerySub.fn.constructor = jQuerySub;
		jQuerySub.sub = this.sub;
		jQuerySub.fn.init = function init( selector, context ) {
			if ( context && context instanceof jQuery && !(context instanceof jQuerySub) ) {
				context = jQuerySub( context );
			}

			return jQuery.fn.init.call( this, selector, context, rootjQuerySub );
		};
		jQuerySub.fn.init.prototype = jQuerySub.fn;
		var rootjQuerySub = jQuerySub(document);
		return jQuerySub;
	},

	browser: {}
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

browserMatch = jQuery.uaMatch( userAgent );
if ( browserMatch.browser ) {
	jQuery.browser[ browserMatch.browser ] = true;
	jQuery.browser.version = browserMatch.version;
}

// Deprecated, use jQuery.browser.webkit instead
if ( jQuery.browser.webkit ) {
	jQuery.browser.safari = true;
}

// IE doesn't match non-breaking spaces with \s
if ( rnotwhite.test( "\xA0" ) ) {
	trimLeft = /^[\s\xA0]+/;
	trimRight = /[\s\xA0]+$/;
}

// All jQuery objects should point back to these
rootjQuery = jQuery(document);

// Cleanup functions for the document ready method
if ( document.addEventListener ) {
	DOMContentLoaded = function() {
		document.removeEventListener( "DOMContentLoaded", DOMContentLoaded, false );
		jQuery.ready();
	};

} else if ( document.attachEvent ) {
	DOMContentLoaded = function() {
		// Make sure body exists, at least, in case IE gets a little overzealous (ticket #5443).
		if ( document.readyState === "complete" ) {
			document.detachEvent( "onreadystatechange", DOMContentLoaded );
			jQuery.ready();
		}
	};
}

// The DOM ready check for Internet Explorer
function doScrollCheck() {
	if ( jQuery.isReady ) {
		return;
	}

	try {
		// If IE is used, use the trick by Diego Perini
		// http://javascript.nwbox.com/IEContentLoaded/
		document.documentElement.doScroll("left");
	} catch(e) {
		setTimeout( doScrollCheck, 1 );
		return;
	}

	// and execute any waiting functions
	jQuery.ready();
}

return jQuery;

})();


// String to Object flags format cache
var flagsCache = {};

// Convert String-formatted flags into Object-formatted ones and store in cache
function createFlags( flags ) {
	var object = flagsCache[ flags ] = {},
		i, length;
	flags = flags.split( /\s+/ );
	for ( i = 0, length = flags.length; i < length; i++ ) {
		object[ flags[i] ] = true;
	}
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	flags:	an optional list of space-separated flags that will change how
 *			the callback list behaves
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible flags:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( flags ) {

	// Convert flags from String-formatted to Object-formatted
	// (we check in cache first)
	flags = flags ? ( flagsCache[ flags ] || createFlags( flags ) ) : {};

	var // Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = [],
		// Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// Flag to know if list is currently firing
		firing,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// Add one or several callbacks to the list
		add = function( args ) {
			var i,
				length,
				elem,
				type,
				actual;
			for ( i = 0, length = args.length; i < length; i++ ) {
				elem = args[ i ];
				type = jQuery.type( elem );
				if ( type === "array" ) {
					// Inspect recursively
					add( elem );
				} else if ( type === "function" ) {
					// Add if not in unique mode and callback is not in
					if ( !flags.unique || !self.has( elem ) ) {
						list.push( elem );
					}
				}
			}
		},
		// Fire callbacks
		fire = function( context, args ) {
			args = args || [];
			memory = !flags.memory || [ context, args ];
			fired = true;
			firing = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( context, args ) === false && flags.stopOnFalse ) {
					memory = true; // Mark as halted
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( !flags.once ) {
					if ( stack && stack.length ) {
						memory = stack.shift();
						self.fireWith( memory[ 0 ], memory[ 1 ] );
					}
				} else if ( memory === true ) {
					self.disable();
				} else {
					list = [];
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					var length = list.length;
					add( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away, unless previous
					// firing was halted (stopOnFalse)
					} else if ( memory && memory !== true ) {
						firingStart = length;
						fire( memory[ 0 ], memory[ 1 ] );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					var args = arguments,
						argIndex = 0,
						argLength = args.length;
					for ( ; argIndex < argLength ; argIndex++ ) {
						for ( var i = 0; i < list.length; i++ ) {
							if ( args[ argIndex ] === list[ i ] ) {
								// Handle firingIndex and firingLength
								if ( firing ) {
									if ( i <= firingLength ) {
										firingLength--;
										if ( i <= firingIndex ) {
											firingIndex--;
										}
									}
								}
								// Remove the element
								list.splice( i--, 1 );
								// If we have some unicity property then
								// we only need to do this once
								if ( flags.unique ) {
									break;
								}
							}
						}
					}
				}
				return this;
			},
			// Control if a given callback is in the list
			has: function( fn ) {
				if ( list ) {
					var i = 0,
						length = list.length;
					for ( ; i < length; i++ ) {
						if ( fn === list[ i ] ) {
							return true;
						}
					}
				}
				return false;
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory || memory === true ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( stack ) {
					if ( firing ) {
						if ( !flags.once ) {
							stack.push( [ context, args ] );
						}
					} else if ( !( flags.once && memory ) ) {
						fire( context, args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};




var // Static reference to slice
	sliceDeferred = [].slice;

jQuery.extend({

	Deferred: function( func ) {
		var doneList = jQuery.Callbacks( "once memory" ),
			failList = jQuery.Callbacks( "once memory" ),
			progressList = jQuery.Callbacks( "memory" ),
			state = "pending",
			lists = {
				resolve: doneList,
				reject: failList,
				notify: progressList
			},
			promise = {
				done: doneList.add,
				fail: failList.add,
				progress: progressList.add,

				state: function() {
					return state;
				},

				// Deprecated
				isResolved: doneList.fired,
				isRejected: failList.fired,

				then: function( doneCallbacks, failCallbacks, progressCallbacks ) {
					deferred.done( doneCallbacks ).fail( failCallbacks ).progress( progressCallbacks );
					return this;
				},
				always: function() {
					deferred.done.apply( deferred, arguments ).fail.apply( deferred, arguments );
					return this;
				},
				pipe: function( fnDone, fnFail, fnProgress ) {
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( {
							done: [ fnDone, "resolve" ],
							fail: [ fnFail, "reject" ],
							progress: [ fnProgress, "notify" ]
						}, function( handler, data ) {
							var fn = data[ 0 ],
								action = data[ 1 ],
								returned;
							if ( jQuery.isFunction( fn ) ) {
								deferred[ handler ](function() {
									returned = fn.apply( this, arguments );
									if ( returned && jQuery.isFunction( returned.promise ) ) {
										returned.promise().then( newDefer.resolve, newDefer.reject, newDefer.notify );
									} else {
										newDefer[ action + "With" ]( this === deferred ? newDefer : this, [ returned ] );
									}
								});
							} else {
								deferred[ handler ]( newDefer[ action ] );
							}
						});
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					if ( obj == null ) {
						obj = promise;
					} else {
						for ( var key in promise ) {
							obj[ key ] = promise[ key ];
						}
					}
					return obj;
				}
			},
			deferred = promise.promise({}),
			key;

		for ( key in lists ) {
			deferred[ key ] = lists[ key ].fire;
			deferred[ key + "With" ] = lists[ key ].fireWith;
		}

		// Handle state
		deferred.done( function() {
			state = "resolved";
		}, failList.disable, progressList.lock ).fail( function() {
			state = "rejected";
		}, doneList.disable, progressList.lock );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( firstParam ) {
		var args = sliceDeferred.call( arguments, 0 ),
			i = 0,
			length = args.length,
			pValues = new Array( length ),
			count = length,
			pCount = length,
			deferred = length <= 1 && firstParam && jQuery.isFunction( firstParam.promise ) ?
				firstParam :
				jQuery.Deferred(),
			promise = deferred.promise();
		function resolveFunc( i ) {
			return function( value ) {
				args[ i ] = arguments.length > 1 ? sliceDeferred.call( arguments, 0 ) : value;
				if ( !( --count ) ) {
					deferred.resolveWith( deferred, args );
				}
			};
		}
		function progressFunc( i ) {
			return function( value ) {
				pValues[ i ] = arguments.length > 1 ? sliceDeferred.call( arguments, 0 ) : value;
				deferred.notifyWith( promise, pValues );
			};
		}
		if ( length > 1 ) {
			for ( ; i < length; i++ ) {
				if ( args[ i ] && args[ i ].promise && jQuery.isFunction( args[ i ].promise ) ) {
					args[ i ].promise().then( resolveFunc(i), deferred.reject, progressFunc(i) );
				} else {
					--count;
				}
			}
			if ( !count ) {
				deferred.resolveWith( deferred, args );
			}
		} else if ( deferred !== firstParam ) {
			deferred.resolveWith( deferred, length ? [ firstParam ] : [] );
		}
		return promise;
	}
});




jQuery.support = (function() {

	var support,
		all,
		a,
		select,
		opt,
		input,
		fragment,
		tds,
		events,
		eventName,
		i,
		isSupported,
		div = document.createElement( "div" ),
		documentElement = document.documentElement;

	// Preliminary tests
	div.setAttribute("className", "t");
	div.innerHTML = "   <link/><table></table><a href='/a' style='top:1px;float:left;opacity:.55;'>a</a><input type='checkbox'/>";

	all = div.getElementsByTagName( "*" );
	a = div.getElementsByTagName( "a" )[ 0 ];

	// Can't get basic test support
	if ( !all || !all.length || !a ) {
		return {};
	}

	// First batch of supports tests
	select = document.createElement( "select" );
	opt = select.appendChild( document.createElement("option") );
	input = div.getElementsByTagName( "input" )[ 0 ];

	support = {
		// IE strips leading whitespace when .innerHTML is used
		leadingWhitespace: ( div.firstChild.nodeType === 3 ),

		// Make sure that tbody elements aren't automatically inserted
		// IE will insert them into empty tables
		tbody: !div.getElementsByTagName("tbody").length,

		// Make sure that link elements get serialized correctly by innerHTML
		// This requires a wrapper element in IE
		htmlSerialize: !!div.getElementsByTagName("link").length,

		// Get the style information from getAttribute
		// (IE uses .cssText instead)
		style: /top/.test( a.getAttribute("style") ),

		// Make sure that URLs aren't manipulated
		// (IE normalizes it by default)
		hrefNormalized: ( a.getAttribute("href") === "/a" ),

		// Make sure that element opacity exists
		// (IE uses filter instead)
		// Use a regex to work around a WebKit issue. See #5145
		opacity: /^0.55/.test( a.style.opacity ),

		// Verify style float existence
		// (IE uses styleFloat instead of cssFloat)
		cssFloat: !!a.style.cssFloat,

		// Make sure that if no value is specified for a checkbox
		// that it defaults to "on".
		// (WebKit defaults to "" instead)
		checkOn: ( input.value === "on" ),

		// Make sure that a selected-by-default option has a working selected property.
		// (WebKit defaults to false instead of true, IE too, if it's in an optgroup)
		optSelected: opt.selected,

		// Test setAttribute on camelCase class. If it works, we need attrFixes when doing get/setAttribute (ie6/7)
		getSetAttribute: div.className !== "t",

		// Tests for enctype support on a form(#6743)
		enctype: !!document.createElement("form").enctype,

		// Makes sure cloning an html5 element does not cause problems
		// Where outerHTML is undefined, this still works
		html5Clone: document.createElement("nav").cloneNode( true ).outerHTML !== "<:nav></:nav>",

		// Will be defined later
		submitBubbles: true,
		changeBubbles: true,
		focusinBubbles: false,
		deleteExpando: true,
		noCloneEvent: true,
		inlineBlockNeedsLayout: false,
		shrinkWrapBlocks: false,
		reliableMarginRight: true,
		pixelMargin: true
	};

	// jQuery.boxModel DEPRECATED in 1.3, use jQuery.support.boxModel instead
	jQuery.boxModel = support.boxModel = (document.compatMode === "CSS1Compat");

	// Make sure checked status is properly cloned
	input.checked = true;
	support.noCloneChecked = input.cloneNode( true ).checked;

	// Make sure that the options inside disabled selects aren't marked as disabled
	// (WebKit marks them as disabled)
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Test to see if it's possible to delete an expando from an element
	// Fails in Internet Explorer
	try {
		delete div.test;
	} catch( e ) {
		support.deleteExpando = false;
	}

	if ( !div.addEventListener && div.attachEvent && div.fireEvent ) {
		div.attachEvent( "onclick", function() {
			// Cloning a node shouldn't copy over any
			// bound event handlers (IE does this)
			support.noCloneEvent = false;
		});
		div.cloneNode( true ).fireEvent( "onclick" );
	}

	// Check if a radio maintains its value
	// after being appended to the DOM
	input = document.createElement("input");
	input.value = "t";
	input.setAttribute("type", "radio");
	support.radioValue = input.value === "t";

	input.setAttribute("checked", "checked");

	// #11217 - WebKit loses check when the name is after the checked attribute
	input.setAttribute( "name", "t" );

	div.appendChild( input );
	fragment = document.createDocumentFragment();
	fragment.appendChild( div.lastChild );

	// WebKit doesn't clone checked state correctly in fragments
	support.checkClone = fragment.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Check if a disconnected checkbox will retain its checked
	// value of true after appended to the DOM (IE6/7)
	support.appendChecked = input.checked;

	fragment.removeChild( input );
	fragment.appendChild( div );

	// Technique from Juriy Zaytsev
	// http://perfectionkills.com/detecting-event-support-without-browser-sniffing/
	// We only care about the case where non-standard event systems
	// are used, namely in IE. Short-circuiting here helps us to
	// avoid an eval call (in setAttribute) which can cause CSP
	// to go haywire. See: https://developer.mozilla.org/en/Security/CSP
	if ( div.attachEvent ) {
		for ( i in {
			submit: 1,
			change: 1,
			focusin: 1
		}) {
			eventName = "on" + i;
			isSupported = ( eventName in div );
			if ( !isSupported ) {
				div.setAttribute( eventName, "return;" );
				isSupported = ( typeof div[ eventName ] === "function" );
			}
			support[ i + "Bubbles" ] = isSupported;
		}
	}

	fragment.removeChild( div );

	// Null elements to avoid leaks in IE
	fragment = select = opt = div = input = null;

	// Run tests that need a body at doc ready
	jQuery(function() {
		var container, outer, inner, table, td, offsetSupport,
			marginDiv, conMarginTop, style, html, positionTopLeftWidthHeight,
			paddingMarginBorderVisibility, paddingMarginBorder,
			body = document.getElementsByTagName("body")[0];

		if ( !body ) {
			// Return for frameset docs that don't have a body
			return;
		}

		conMarginTop = 1;
		paddingMarginBorder = "padding:0;margin:0;border:";
		positionTopLeftWidthHeight = "position:absolute;top:0;left:0;width:1px;height:1px;";
		paddingMarginBorderVisibility = paddingMarginBorder + "0;visibility:hidden;";
		style = "style='" + positionTopLeftWidthHeight + paddingMarginBorder + "5px solid #000;";
		html = "<div " + style + "display:block;'><div style='" + paddingMarginBorder + "0;display:block;overflow:hidden;'></div></div>" +
			"<table " + style + "' cellpadding='0' cellspacing='0'>" +
			"<tr><td></td></tr></table>";

		container = document.createElement("div");
		container.style.cssText = paddingMarginBorderVisibility + "width:0;height:0;position:static;top:0;margin-top:" + conMarginTop + "px";
		body.insertBefore( container, body.firstChild );

		// Construct the test element
		div = document.createElement("div");
		container.appendChild( div );

		// Check if table cells still have offsetWidth/Height when they are set
		// to display:none and there are still other visible table cells in a
		// table row; if so, offsetWidth/Height are not reliable for use when
		// determining if an element has been hidden directly using
		// display:none (it is still safe to use offsets if a parent element is
		// hidden; don safety goggles and see bug #4512 for more information).
		// (only IE 8 fails this test)
    div.innerHTML = "<table><tr><td style='" + paddingMarginBorder + "0;display:none'></td><td>t</td></tr></table>"

		tds = div.getElementsByTagName( "td" );
		isSupported = ( tds[ 0 ].offsetHeight === 0 );

		tds[ 0 ].style.display = "";
		tds[ 1 ].style.display = "none";

		// Check if empty table cells still have offsetWidth/Height
		// (IE <= 8 fail this test)
		support.reliableHiddenOffsets = isSupported && ( tds[ 0 ].offsetHeight === 0 );

		// Check if div with explicit width and no margin-right incorrectly
		// gets computed margin-right based on width of container. For more
		// info see bug #3333
		// Fails in WebKit before Feb 2011 nightlies
		// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
		if ( window.getComputedStyle ) {
			div.innerHTML = "";
			marginDiv = document.createElement( "div" );
			marginDiv.style.width = "0";
			marginDiv.style.marginRight = "0";
			div.style.width = "2px";
			div.appendChild( marginDiv );
			support.reliableMarginRight =
				( parseInt( ( window.getComputedStyle( marginDiv, null ) || { marginRight: 0 } ).marginRight, 10 ) || 0 ) === 0;
		}

		if ( typeof div.style.zoom !== "undefined" ) {
			// Check if natively block-level elements act like inline-block
			// elements when setting their display to 'inline' and giving
			// them layout
			// (IE < 8 does this)
			div.innerHTML = "";
			div.style.width = div.style.padding = "1px";
			div.style.border = 0;
			div.style.overflow = "hidden";
			div.style.display = "inline";
			div.style.zoom = 1;
			support.inlineBlockNeedsLayout = ( div.offsetWidth === 3 );

			// Check if elements with layout shrink-wrap their children
			// (IE 6 does this)
			div.style.display = "block";
			div.style.overflow = "visible";
			div.innerHTML = "<div style='width:5px;'></div>";
			support.shrinkWrapBlocks = ( div.offsetWidth !== 3 );
		}

		div.style.cssText = positionTopLeftWidthHeight + paddingMarginBorderVisibility;
		div.innerHTML = html;

		outer = div.firstChild;
		inner = outer.firstChild;
		td = outer.nextSibling.firstChild.firstChild;

		offsetSupport = {
			doesNotAddBorder: ( inner.offsetTop !== 5 ),
			doesAddBorderForTableAndCells: ( td.offsetTop === 5 )
		};

		inner.style.position = "fixed";
		inner.style.top = "20px";

		// safari subtracts parent border width here which is 5px
		offsetSupport.fixedPosition = ( inner.offsetTop === 20 || inner.offsetTop === 15 );
		inner.style.position = inner.style.top = "";

		outer.style.overflow = "hidden";
		outer.style.position = "relative";

		offsetSupport.subtractsBorderForOverflowNotVisible = ( inner.offsetTop === -5 );
		offsetSupport.doesNotIncludeMarginInBodyOffset = ( body.offsetTop !== conMarginTop );

		if ( window.getComputedStyle ) {
			div.style.marginTop = "1%";
			support.pixelMargin = ( window.getComputedStyle( div, null ) || { marginTop: 0 } ).marginTop !== "1%";
		}

		if ( typeof container.style.zoom !== "undefined" ) {
			container.style.zoom = 1;
		}

		body.removeChild( container );
		marginDiv = div = container = null;

		jQuery.extend( support, offsetSupport );
	});

	return support;
})();




var rbrace = /^(?:\{.*\}|\[.*\])$/,
	rmultiDash = /([A-Z])/g;

jQuery.extend({
	cache: {},

	// Please use with caution
	uuid: 0,

	// Unique for each copy of jQuery on the page
	// Non-digits removed to match rinlinejQuery
	expando: "jQuery" + ( jQuery.fn.jquery + Math.random() ).replace( /\D/g, "" ),

	// The following elements throw uncatchable exceptions if you
	// attempt to add expando properties to them.
	noData: {
		"embed": true,
		// Ban all objects except for Flash (which handle expandos)
		"object": "clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",
		"applet": true
	},

	hasData: function( elem ) {
		elem = elem.nodeType ? jQuery.cache[ elem[jQuery.expando] ] : elem[ jQuery.expando ];
		return !!elem && !isEmptyDataObject( elem );
	},

	data: function( elem, name, data, pvt /* Internal Use Only */ ) {
		if ( !jQuery.acceptData( elem ) ) {
			return;
		}

		var privateCache, thisCache, ret,
			internalKey = jQuery.expando,
			getByName = typeof name === "string",

			// We have to handle DOM nodes and JS objects differently because IE6-7
			// can't GC object references properly across the DOM-JS boundary
			isNode = elem.nodeType,

			// Only DOM nodes need the global jQuery cache; JS object data is
			// attached directly to the object so GC can occur automatically
			cache = isNode ? jQuery.cache : elem,

			// Only defining an ID for JS objects if its cache already exists allows
			// the code to shortcut on the same path as a DOM node with no cache
			id = isNode ? elem[ internalKey ] : elem[ internalKey ] && internalKey,
			isEvents = name === "events";

		// Avoid doing any more work than we need to when trying to get data on an
		// object that has no data at all
		if ( (!id || !cache[id] || (!isEvents && !pvt && !cache[id].data)) && getByName && data === undefined ) {
			return;
		}

		if ( !id ) {
			// Only DOM nodes need a new unique ID for each element since their data
			// ends up in the global cache
			if ( isNode ) {
				elem[ internalKey ] = id = ++jQuery.uuid;
			} else {
				id = internalKey;
			}
		}

		if ( !cache[ id ] ) {
			cache[ id ] = {};

			// Avoids exposing jQuery metadata on plain JS objects when the object
			// is serialized using JSON.stringify
			if ( !isNode ) {
				cache[ id ].toJSON = jQuery.noop;
			}
		}

		// An object can be passed to jQuery.data instead of a key/value pair; this gets
		// shallow copied over onto the existing cache
		if ( typeof name === "object" || typeof name === "function" ) {
			if ( pvt ) {
				cache[ id ] = jQuery.extend( cache[ id ], name );
			} else {
				cache[ id ].data = jQuery.extend( cache[ id ].data, name );
			}
		}

		privateCache = thisCache = cache[ id ];

		// jQuery data() is stored in a separate object inside the object's internal data
		// cache in order to avoid key collisions between internal data and user-defined
		// data.
		if ( !pvt ) {
			if ( !thisCache.data ) {
				thisCache.data = {};
			}

			thisCache = thisCache.data;
		}

		if ( data !== undefined ) {
			thisCache[ jQuery.camelCase( name ) ] = data;
		}

		// Users should not attempt to inspect the internal events object using jQuery.data,
		// it is undocumented and subject to change. But does anyone listen? No.
		if ( isEvents && !thisCache[ name ] ) {
			return privateCache.events;
		}

		// Check for both converted-to-camel and non-converted data property names
		// If a data property was specified
		if ( getByName ) {

			// First Try to find as-is property data
			ret = thisCache[ name ];

			// Test for null|undefined property data
			if ( ret == null ) {

				// Try to find the camelCased property
				ret = thisCache[ jQuery.camelCase( name ) ];
			}
		} else {
			ret = thisCache;
		}

		return ret;
	},

	removeData: function( elem, name, pvt /* Internal Use Only */ ) {
		if ( !jQuery.acceptData( elem ) ) {
			return;
		}

		var thisCache, i, l,

			// Reference to internal data cache key
			internalKey = jQuery.expando,

			isNode = elem.nodeType,

			// See jQuery.data for more information
			cache = isNode ? jQuery.cache : elem,

			// See jQuery.data for more information
			id = isNode ? elem[ internalKey ] : internalKey;

		// If there is already no cache entry for this object, there is no
		// purpose in continuing
		if ( !cache[ id ] ) {
			return;
		}

		if ( name ) {

			thisCache = pvt ? cache[ id ] : cache[ id ].data;

			if ( thisCache ) {

				// Support array or space separated string names for data keys
				if ( !jQuery.isArray( name ) ) {

					// try the string as a key before any manipulation
					if ( name in thisCache ) {
						name = [ name ];
					} else {

						// split the camel cased version by spaces unless a key with the spaces exists
						name = jQuery.camelCase( name );
						if ( name in thisCache ) {
							name = [ name ];
						} else {
							name = name.split( " " );
						}
					}
				}

				for ( i = 0, l = name.length; i < l; i++ ) {
					delete thisCache[ name[i] ];
				}

				// If there is no data left in the cache, we want to continue
				// and let the cache object itself get destroyed
				if ( !( pvt ? isEmptyDataObject : jQuery.isEmptyObject )( thisCache ) ) {
					return;
				}
			}
		}

		// See jQuery.data for more information
		if ( !pvt ) {
			delete cache[ id ].data;

			// Don't destroy the parent cache unless the internal data object
			// had been the only thing left in it
			if ( !isEmptyDataObject(cache[ id ]) ) {
				return;
			}
		}

		// Browsers that fail expando deletion also refuse to delete expandos on
		// the window, but it will allow it on all other JS objects; other browsers
		// don't care
		// Ensure that `cache` is not a window object #10080
		if ( jQuery.support.deleteExpando || !cache.setInterval ) {
			delete cache[ id ];
		} else {
			cache[ id ] = null;
		}

		// We destroyed the cache and need to eliminate the expando on the node to avoid
		// false lookups in the cache for entries that no longer exist
		if ( isNode ) {
			// IE does not allow us to delete expando properties from nodes,
			// nor does it have a removeAttribute function on Document nodes;
			// we must handle all of these cases
			if ( jQuery.support.deleteExpando ) {
				delete elem[ internalKey ];
			} else if ( elem.removeAttribute ) {
				elem.removeAttribute( internalKey );
			} else {
				elem[ internalKey ] = null;
			}
		}
	},

	// For internal use only.
	_data: function( elem, name, data ) {
		return jQuery.data( elem, name, data, true );
	},

	// A method for determining if a DOM node can handle the data expando
	acceptData: function( elem ) {
		if ( elem.nodeName ) {
			var match = jQuery.noData[ elem.nodeName.toLowerCase() ];

			if ( match ) {
				return !(match === true || elem.getAttribute("classid") !== match);
			}
		}

		return true;
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var parts, part, attr, name, l,
			elem = this[0],
			i = 0,
			data = null;

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = jQuery.data( elem );

				if ( elem.nodeType === 1 && !jQuery._data( elem, "parsedAttrs" ) ) {
					attr = elem.attributes;
					for ( l = attr.length; i < l; i++ ) {
						name = attr[i].name;

						if ( name.indexOf( "data-" ) === 0 ) {
							name = jQuery.camelCase( name.substring(5) );

							dataAttr( elem, name, data[ name ] );
						}
					}
					jQuery._data( elem, "parsedAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				jQuery.data( this, key );
			});
		}

		parts = key.split( ".", 2 );
		parts[1] = parts[1] ? "." + parts[1] : "";
		part = parts[1] + "!";

		return jQuery.access( this, function( value ) {

			if ( value === undefined ) {
				data = this.triggerHandler( "getData" + part, [ parts[0] ] );

				// Try to fetch any internally stored data first
				if ( data === undefined && elem ) {
					data = jQuery.data( elem, key );
					data = dataAttr( elem, key, data );
				}

				return data === undefined && parts[1] ?
					this.data( parts[0] ) :
					data;
			}

			parts[1] = value;
			this.each(function() {
				var self = jQuery( this );

				self.triggerHandler( "setData" + part, parts );
				jQuery.data( this, key, value );
				self.triggerHandler( "changeData" + part, parts );
			});
		}, null, value, arguments.length > 1, null, false );
	},

	removeData: function( key ) {
		return this.each(function() {
			jQuery.removeData( this, key );
		});
	}
});

function dataAttr( elem, key, data ) {
	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {

		var name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();

		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
				data === "false" ? false :
				data === "null" ? null :
				jQuery.isNumeric( data ) ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			jQuery.data( elem, key, data );

		} else {
			data = undefined;
		}
	}

	return data;
}

// checks a cache object for emptiness
function isEmptyDataObject( obj ) {
	for ( var name in obj ) {

		// if the public data object is empty, the private is still empty
		if ( name === "data" && jQuery.isEmptyObject( obj[name] ) ) {
			continue;
		}
		if ( name !== "toJSON" ) {
			return false;
		}
	}

	return true;
}




function handleQueueMarkDefer( elem, type, src ) {
	var deferDataKey = type + "defer",
		queueDataKey = type + "queue",
		markDataKey = type + "mark",
		defer = jQuery._data( elem, deferDataKey );
	if ( defer &&
		( src === "queue" || !jQuery._data(elem, queueDataKey) ) &&
		( src === "mark" || !jQuery._data(elem, markDataKey) ) ) {
		// Give room for hard-coded callbacks to fire first
		// and eventually mark/queue something else on the element
		setTimeout( function() {
			if ( !jQuery._data( elem, queueDataKey ) &&
				!jQuery._data( elem, markDataKey ) ) {
				jQuery.removeData( elem, deferDataKey, true );
				defer.fire();
			}
		}, 0 );
	}
}

jQuery.extend({

	_mark: function( elem, type ) {
		if ( elem ) {
			type = ( type || "fx" ) + "mark";
			jQuery._data( elem, type, (jQuery._data( elem, type ) || 0) + 1 );
		}
	},

	_unmark: function( force, elem, type ) {
		if ( force !== true ) {
			type = elem;
			elem = force;
			force = false;
		}
		if ( elem ) {
			type = type || "fx";
			var key = type + "mark",
				count = force ? 0 : ( (jQuery._data( elem, key ) || 1) - 1 );
			if ( count ) {
				jQuery._data( elem, key, count );
			} else {
				jQuery.removeData( elem, key, true );
				handleQueueMarkDefer( elem, type, "mark" );
			}
		}
	},

	queue: function( elem, type, data ) {
		var q;
		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			q = jQuery._data( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !q || jQuery.isArray(data) ) {
					q = jQuery._data( elem, type, jQuery.makeArray(data) );
				} else {
					q.push( data );
				}
			}
			return q || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			fn = queue.shift(),
			hooks = {};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
		}

		if ( fn ) {
			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			jQuery._data( elem, type + ".run", hooks );
			fn.call( elem, function() {
				jQuery.dequeue( elem, type );
			}, hooks );
		}

		if ( !queue.length ) {
			jQuery.removeData( elem, type + "queue " + type + ".run", true );
			handleQueueMarkDefer( elem, type, "queue" );
		}
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	// Based off of the plugin by Clint Helfers, with permission.
	// http://blindsignals.com/index.php/2009/07/jquery-delay/
	delay: function( time, type ) {
		time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
		type = type || "fx";

		return this.queue( type, function( next, hooks ) {
			var timeout = setTimeout( next, time );
			hooks.stop = function() {
				clearTimeout( timeout );
			};
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, object ) {
		if ( typeof type !== "string" ) {
			object = type;
			type = undefined;
		}
		type = type || "fx";
		var defer = jQuery.Deferred(),
			elements = this,
			i = elements.length,
			count = 1,
			deferDataKey = type + "defer",
			queueDataKey = type + "queue",
			markDataKey = type + "mark",
			tmp;
		function resolve() {
			if ( !( --count ) ) {
				defer.resolveWith( elements, [ elements ] );
			}
		}
		while( i-- ) {
			if (( tmp = jQuery.data( elements[ i ], deferDataKey, undefined, true ) ||
					( jQuery.data( elements[ i ], queueDataKey, undefined, true ) ||
						jQuery.data( elements[ i ], markDataKey, undefined, true ) ) &&
					jQuery.data( elements[ i ], deferDataKey, jQuery.Callbacks( "once memory" ), true ) )) {
				count++;
				tmp.add( resolve );
			}
		}
		resolve();
		return defer.promise( object );
	}
});




var rclass = /[\n\t\r]/g,
	rspace = /\s+/,
	rreturn = /\r/g,
	rtype = /^(?:button|input)$/i,
	rfocusable = /^(?:button|input|object|select|textarea)$/i,
	rclickable = /^a(?:rea)?$/i,
	rboolean = /^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,
	getSetAttribute = jQuery.support.getSetAttribute,
	nodeHook, boolHook, fixSpecified;

jQuery.fn.extend({
	attr: function( name, value ) {
		return jQuery.access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	},

	prop: function( name, value ) {
		return jQuery.access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		name = jQuery.propFix[ name ] || name;
		return this.each(function() {
			// try/catch handles cases where IE balks (such as removing a property on window)
			try {
				this[ name ] = undefined;
				delete this[ name ];
			} catch( e ) {}
		});
	},

	addClass: function( value ) {
		var classNames, i, l, elem,
			setClass, c, cl;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call(this, j, this.className) );
			});
		}

		if ( value && typeof value === "string" ) {
			classNames = value.split( rspace );

			for ( i = 0, l = this.length; i < l; i++ ) {
				elem = this[ i ];

				if ( elem.nodeType === 1 ) {
					if ( !elem.className && classNames.length === 1 ) {
						elem.className = value;

					} else {
						setClass = " " + elem.className + " ";

						for ( c = 0, cl = classNames.length; c < cl; c++ ) {
							if ( !~setClass.indexOf( " " + classNames[ c ] + " " ) ) {
								setClass += classNames[ c ] + " ";
							}
						}
						elem.className = jQuery.trim( setClass );
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classNames, i, l, elem, className, c, cl;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call(this, j, this.className) );
			});
		}

		if ( (value && typeof value === "string") || value === undefined ) {
			classNames = ( value || "" ).split( rspace );

			for ( i = 0, l = this.length; i < l; i++ ) {
				elem = this[ i ];

				if ( elem.nodeType === 1 && elem.className ) {
					if ( value ) {
						className = (" " + elem.className + " ").replace( rclass, " " );
						for ( c = 0, cl = classNames.length; c < cl; c++ ) {
							className = className.replace(" " + classNames[ c ] + " ", " ");
						}
						elem.className = jQuery.trim( className );

					} else {
						elem.className = "";
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value,
			isBool = typeof stateVal === "boolean";

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					state = stateVal,
					classNames = value.split( rspace );

				while ( (className = classNames[ i++ ]) ) {
					// check each className given, space seperated list
					state = isBool ? state : !self.hasClass( className );
					self[ state ? "addClass" : "removeClass" ]( className );
				}

			} else if ( type === "undefined" || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					jQuery._data( this, "__className__", this.className );
				}

				// toggle whole className
				this.className = this.className || value === false ? "" : jQuery._data( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) > -1 ) {
				return true;
			}
		}

		return false;
	},

	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// handle most common string cases
					ret.replace(rreturn, "") :
					// handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var self = jQuery(this), val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, self.val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";
			} else if ( typeof val === "number" ) {
				val += "";
			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map(val, function ( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				// attributes.value is undefined in Blackberry 4.7 but
				// uses .value. See #6932
				var val = elem.attributes.value;
				return !val || val.specified ? elem.value : elem.text;
			}
		},
		select: {
			get: function( elem ) {
				var value, i, max, option,
					index = elem.selectedIndex,
					values = [],
					options = elem.options,
					one = elem.type === "select-one";

				// Nothing was selected
				if ( index < 0 ) {
					return null;
				}

				// Loop through all the selected options
				i = one ? index : 0;
				max = one ? index + 1 : options.length;
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// Don't return options that are disabled or in a disabled optgroup
					if ( option.selected && (jQuery.support.optDisabled ? !option.disabled : option.getAttribute("disabled") === null) &&
							(!option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" )) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				// Fixes Bug #2551 -- select.val() broken in IE after form.reset()
				if ( one && !values.length && options.length ) {
					return jQuery( options[ index ] ).val();
				}

				return values;
			},

			set: function( elem, value ) {
				var values = jQuery.makeArray( value );

				jQuery(elem).find("option").each(function() {
					this.selected = jQuery.inArray( jQuery(this).val(), values ) >= 0;
				});

				if ( !values.length ) {
					elem.selectedIndex = -1;
				}
				return values;
			}
		}
	},

	attrFn: {
		val: true,
		css: true,
		html: true,
		text: true,
		data: true,
		width: true,
		height: true,
		offset: true
	},

	attr: function( elem, name, value, pass ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		if ( pass && name in jQuery.attrFn ) {
			return jQuery( elem )[ name ]( value );
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === "undefined" ) {
			return jQuery.prop( elem, name, value );
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( notxml ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] || ( rboolean.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );
				return;

			} else if ( hooks && "set" in hooks && notxml && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, "" + value );
				return value;
			}

		} else if ( hooks && "get" in hooks && notxml && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {

			ret = elem.getAttribute( name );

			// Non-existent attributes return null, we normalize to undefined
			return ret === null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var propName, attrNames, name, l, isBool,
			i = 0;

		if ( value && elem.nodeType === 1 ) {
			attrNames = value.toLowerCase().split( rspace );
			l = attrNames.length;

			for ( ; i < l; i++ ) {
				name = attrNames[ i ];

				if ( name ) {
					propName = jQuery.propFix[ name ] || name;
					isBool = rboolean.test( name );

					// See #9699 for explanation of this approach (setting first, then removal)
					// Do not do this for boolean attributes (see #10870)
					if ( !isBool ) {
						jQuery.attr( elem, name, "" );
					}
					elem.removeAttribute( getSetAttribute ? name : propName );

					// Set corresponding property to false for boolean attributes
					if ( isBool && propName in elem ) {
						elem[ propName ] = false;
					}
				}
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				// We can't allow the type property to be changed (since it causes problems in IE)
				if ( rtype.test( elem.nodeName ) && elem.parentNode ) {
					jQuery.error( "type property can't be changed" );
				} else if ( !jQuery.support.radioValue && value === "radio" && jQuery.nodeName(elem, "input") ) {
					// Setting the type on a radio button after the value resets the value in IE6-9
					// Reset value to it's default in case type is set after value
					// This is for element creation
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		},
		// Use the value property for back compat
		// Use the nodeHook for button elements in IE6/7 (#1954)
		value: {
			get: function( elem, name ) {
				if ( nodeHook && jQuery.nodeName( elem, "button" ) ) {
					return nodeHook.get( elem, name );
				}
				return name in elem ?
					elem.value :
					null;
			},
			set: function( elem, value, name ) {
				if ( nodeHook && jQuery.nodeName( elem, "button" ) ) {
					return nodeHook.set( elem, value, name );
				}
				// Does not return so that setAttribute is also used
				elem.value = value;
			}
		}
	},

	propFix: {
		tabindex: "tabIndex",
		readonly: "readOnly",
		"for": "htmlFor",
		"class": "className",
		maxlength: "maxLength",
		cellspacing: "cellSpacing",
		cellpadding: "cellPadding",
		rowspan: "rowSpan",
		colspan: "colSpan",
		usemap: "useMap",
		frameborder: "frameBorder",
		contenteditable: "contentEditable"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				return ( elem[ name ] = value );
			}

		} else {
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
				return ret;

			} else {
				return elem[ name ];
			}
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				// elem.tabIndex doesn't always return the correct value when it hasn't been explicitly set
				// http://fluidproject.org/blog/2008/01/09/getting-setting-and-removing-tabindex-values-with-javascript/
				var attributeNode = elem.getAttributeNode("tabindex");

				return attributeNode && attributeNode.specified ?
					parseInt( attributeNode.value, 10 ) :
					rfocusable.test( elem.nodeName ) || rclickable.test( elem.nodeName ) && elem.href ?
						0 :
						undefined;
			}
		}
	}
});

// Add the tabIndex propHook to attrHooks for back-compat (different case is intentional)
jQuery.attrHooks.tabindex = jQuery.propHooks.tabIndex;

// Hook for boolean attributes
boolHook = {
	get: function( elem, name ) {
		// Align boolean attributes with corresponding properties
		// Fall back to attribute presence where some booleans are not supported
		var attrNode,
			property = jQuery.prop( elem, name );
		return property === true || typeof property !== "boolean" && ( attrNode = elem.getAttributeNode(name) ) && attrNode.nodeValue !== false ?
			name.toLowerCase() :
			undefined;
	},
	set: function( elem, value, name ) {
		var propName;
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else {
			// value is true since we know at this point it's type boolean and not false
			// Set boolean attributes to the same name and set the DOM property
			propName = jQuery.propFix[ name ] || name;
			if ( propName in elem ) {
				// Only set the IDL specifically if it already exists on the element
				elem[ propName ] = true;
			}

			elem.setAttribute( name, name.toLowerCase() );
		}
		return name;
	}
};

// IE6/7 do not support getting/setting some attributes with get/setAttribute
if ( !getSetAttribute ) {

	fixSpecified = {
		name: true,
		id: true,
		coords: true
	};

	// Use this for any attribute in IE6/7
	// This fixes almost every IE6/7 issue
	nodeHook = jQuery.valHooks.button = {
		get: function( elem, name ) {
			var ret;
			ret = elem.getAttributeNode( name );
			return ret && ( fixSpecified[ name ] ? ret.nodeValue !== "" : ret.specified ) ?
				ret.nodeValue :
				undefined;
		},
		set: function( elem, value, name ) {
			// Set the existing or create a new attribute node
			var ret = elem.getAttributeNode( name );
			if ( !ret ) {
				ret = document.createAttribute( name );
				elem.setAttributeNode( ret );
			}
			return ( ret.nodeValue = value + "" );
		}
	};

	// Apply the nodeHook to tabindex
	jQuery.attrHooks.tabindex.set = nodeHook.set;

	// Set width and height to auto instead of 0 on empty string( Bug #8150 )
	// This is for removals
	jQuery.each([ "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
			set: function( elem, value ) {
				if ( value === "" ) {
					elem.setAttribute( name, "auto" );
					return value;
				}
			}
		});
	});

	// Set contenteditable to false on removals(#10429)
	// Setting to empty string throws an error as an invalid value
	jQuery.attrHooks.contenteditable = {
		get: nodeHook.get,
		set: function( elem, value, name ) {
			if ( value === "" ) {
				value = "false";
			}
			nodeHook.set( elem, value, name );
		}
	};
}


// Some attributes require a special call on IE
if ( !jQuery.support.hrefNormalized ) {
	jQuery.each([ "href", "src", "width", "height" ], function( i, name ) {
		jQuery.attrHooks[ name ] = jQuery.extend( jQuery.attrHooks[ name ], {
			get: function( elem ) {
				var ret = elem.getAttribute( name, 2 );
				return ret === null ? undefined : ret;
			}
		});
	});
}

if ( !jQuery.support.style ) {
	jQuery.attrHooks.style = {
		get: function( elem ) {
			// Return undefined in the case of empty string
			// Normalize to lowercase since IE uppercases css property names
			return elem.style.cssText.toLowerCase() || undefined;
		},
		set: function( elem, value ) {
			return ( elem.style.cssText = "" + value );
		}
	};
}

// Safari mis-reports the default selected property of an option
// Accessing the parent's selectedIndex property fixes it
if ( !jQuery.support.optSelected ) {
	jQuery.propHooks.selected = jQuery.extend( jQuery.propHooks.selected, {
		get: function( elem ) {
			var parent = elem.parentNode;

			if ( parent ) {
				parent.selectedIndex;

				// Make sure that it also works with optgroups, see #5701
				if ( parent.parentNode ) {
					parent.parentNode.selectedIndex;
				}
			}
			return null;
		}
	});
}

// IE6/7 call enctype encoding
if ( !jQuery.support.enctype ) {
	jQuery.propFix.enctype = "encoding";
}

// Radios and checkboxes getter/setter
if ( !jQuery.support.checkOn ) {
	jQuery.each([ "radio", "checkbox" ], function() {
		jQuery.valHooks[ this ] = {
			get: function( elem ) {
				// Handle the case where in Webkit "" is returned instead of "on" if a value isn't specified
				return elem.getAttribute("value") === null ? "on" : elem.value;
			}
		};
	});
}
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = jQuery.extend( jQuery.valHooks[ this ], {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	});
});




var rformElems = /^(?:textarea|input|select)$/i,
	rtypenamespace = /^([^\.]*)?(?:\.(.+))?$/,
	rhoverHack = /(?:^|\s)hover(\.\S+)?\b/,
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rquickIs = /^(\w*)(?:#([\w\-]+))?(?:\.([\w\-]+))?$/,
	quickParse = function( selector ) {
		var quick = rquickIs.exec( selector );
		if ( quick ) {
			//   0  1    2   3
			// [ _, tag, id, class ]
			quick[1] = ( quick[1] || "" ).toLowerCase();
			quick[3] = quick[3] && new RegExp( "(?:^|\\s)" + quick[3] + "(?:\\s|$)" );
		}
		return quick;
	},
	quickIs = function( elem, m ) {
		var attrs = elem.attributes || {};
		return (
			(!m[1] || elem.nodeName.toLowerCase() === m[1]) &&
			(!m[2] || (attrs.id || {}).value === m[2]) &&
			(!m[3] || m[3].test( (attrs[ "class" ] || {}).value ))
		);
	},
	hoverHack = function( events ) {
		return jQuery.event.special.hover ? events : events.replace( rhoverHack, "mouseenter$1 mouseleave$1" );
	};

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	add: function( elem, types, handler, data, selector ) {

		var elemData, eventHandle, events,
			t, tns, type, namespaces, handleObj,
			handleObjIn, quick, handlers, special;

		// Don't attach events to noData or text/comment nodes (allow plain objects tho)
		if ( elem.nodeType === 3 || elem.nodeType === 8 || !types || !handler || !(elemData = jQuery._data( elem )) ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		events = elemData.events;
		if ( !events ) {
			elemData.events = events = {};
		}
		eventHandle = elemData.handle;
		if ( !eventHandle ) {
			elemData.handle = eventHandle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== "undefined" && (!e || jQuery.event.triggered !== e.type) ?
					jQuery.event.dispatch.apply( eventHandle.elem, arguments ) :
					undefined;
			};
			// Add elem as a property of the handle fn to prevent a memory leak with IE non-native events
			eventHandle.elem = elem;
		}

		// Handle multiple events separated by a space
		// jQuery(...).bind("mouseover mouseout", fn);
		types = jQuery.trim( hoverHack(types) ).split( " " );
		for ( t = 0; t < types.length; t++ ) {

			tns = rtypenamespace.exec( types[t] ) || [];
			type = tns[1];
			namespaces = ( tns[2] || "" ).split( "." ).sort();

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: tns[1],
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				quick: selector && quickParse( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			handlers = events[ type ];
			if ( !handlers ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener/attachEvent if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					// Bind the global event handler to the element
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );

					} else if ( elem.attachEvent ) {
						elem.attachEvent( "on" + type, eventHandle );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

		// Nullify elem to prevent memory leaks in IE
		elem = null;
	},

	global: {},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {

		var elemData = jQuery.hasData( elem ) && jQuery._data( elem ),
			t, tns, type, origType, namespaces, origCount,
			j, events, special, handle, eventType, handleObj;

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = jQuery.trim( hoverHack( types || "" ) ).split(" ");
		for ( t = 0; t < types.length; t++ ) {
			tns = rtypenamespace.exec( types[t] ) || [];
			type = origType = tns[1];
			namespaces = tns[2];

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector? special.delegateType : special.bindType ) || type;
			eventType = events[ type ] || [];
			origCount = eventType.length;
			namespaces = namespaces ? new RegExp("(^|\\.)" + namespaces.split(".").sort().join("\\.(?:.*\\.)?") + "(\\.|$)") : null;

			// Remove matching events
			for ( j = 0; j < eventType.length; j++ ) {
				handleObj = eventType[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					 ( !handler || handler.guid === handleObj.guid ) &&
					 ( !namespaces || namespaces.test( handleObj.namespace ) ) &&
					 ( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					eventType.splice( j--, 1 );

					if ( handleObj.selector ) {
						eventType.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( eventType.length === 0 && origCount !== eventType.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			handle = elemData.handle;
			if ( handle ) {
				handle.elem = null;
			}

			// removeData also checks for emptiness and clears the expando if empty
			// so use it instead of delete
			jQuery.removeData( elem, [ "events", "handle" ], true );
		}
	},

	// Events that are safe to short-circuit if no handlers are attached.
	// Native DOM events should not be added, they may have inline handlers.
	customEvent: {
		"getData": true,
		"setData": true,
		"changeData": true
	},

	trigger: function( event, data, elem, onlyHandlers ) {
		// Don't do events on text and comment nodes
		if ( elem && (elem.nodeType === 3 || elem.nodeType === 8) ) {
			return;
		}

		// Event object or event type
		var type = event.type || event,
			namespaces = [],
			cache, exclusive, i, cur, old, ontype, special, handle, eventPath, bubbleType;

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf( "!" ) >= 0 ) {
			// Exclusive events trigger only for the exact event (no namespaces)
			type = type.slice(0, -1);
			exclusive = true;
		}

		if ( type.indexOf( "." ) >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}

		if ( (!elem || jQuery.event.customEvent[ type ]) && !jQuery.event.global[ type ] ) {
			// No jQuery handlers for this event type, and it can't have inline handlers
			return;
		}

		// Caller can pass in an Event, Object, or just an event type string
		event = typeof event === "object" ?
			// jQuery.Event object
			event[ jQuery.expando ] ? event :
			// Object literal
			new jQuery.Event( type, event ) :
			// Just the event type (string)
			new jQuery.Event( type );

		event.type = type;
		event.isTrigger = true;
		event.exclusive = exclusive;
		event.namespace = namespaces.join( "." );
		event.namespace_re = event.namespace? new RegExp("(^|\\.)" + namespaces.join("\\.(?:.*\\.)?") + "(\\.|$)") : null;
		ontype = type.indexOf( ":" ) < 0 ? "on" + type : "";

		// Handle a global trigger
		if ( !elem ) {

			// TODO: Stop taunting the data cache; remove global events and always attach to document
			cache = jQuery.cache;
			for ( i in cache ) {
				if ( cache[ i ].events && cache[ i ].events[ type ] ) {
					jQuery.event.trigger( event, data, cache[ i ].handle.elem, true );
				}
			}
			return;
		}

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data != null ? jQuery.makeArray( data ) : [];
		data.unshift( event );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		eventPath = [[ elem, special.bindType || type ]];
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			cur = rfocusMorph.test( bubbleType + type ) ? elem : elem.parentNode;
			old = null;
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push([ cur, bubbleType ]);
				old = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( old && old === elem.ownerDocument ) {
				eventPath.push([ old.defaultView || old.parentWindow || window, bubbleType ]);
			}
		}

		// Fire handlers on the event path
		for ( i = 0; i < eventPath.length && !event.isPropagationStopped(); i++ ) {

			cur = eventPath[i][0];
			event.type = eventPath[i][1];

			handle = ( jQuery._data( cur, "events" ) || {} )[ event.type ] && jQuery._data( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}
			// Note that this is a bare JS function and not a jQuery handler
			handle = ontype && cur[ ontype ];
			if ( handle && jQuery.acceptData( cur ) && handle.apply( cur, data ) === false ) {
				event.preventDefault();
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( elem.ownerDocument, data ) === false) &&
				!(type === "click" && jQuery.nodeName( elem, "a" )) && jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Can't use an .isFunction() check here because IE6/7 fails that test.
				// Don't do default actions on window, that's where global variables be (#6170)
				// IE<9 dies on focus/blur to hidden element (#1486)
				if ( ontype && elem[ type ] && ((type !== "focus" && type !== "blur") || event.target.offsetWidth !== 0) && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					old = elem[ ontype ];

					if ( old ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					elem[ type ]();
					jQuery.event.triggered = undefined;

					if ( old ) {
						elem[ ontype ] = old;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event || window.event );

		var handlers = ( (jQuery._data( this, "events" ) || {} )[ event.type ] || []),
			delegateCount = handlers.delegateCount,
			args = [].slice.call( arguments, 0 ),
			run_all = !event.exclusive && !event.namespace,
			special = jQuery.event.special[ event.type ] || {},
			handlerQueue = [],
			i, j, cur, jqcur, ret, selMatch, matched, matches, handleObj, sel, related;

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers that should run if there are delegated events
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && !(event.button && event.type === "click") ) {

			// Pregenerate a single jQuery object for reuse with .is()
			jqcur = jQuery(this);
			jqcur.context = this.ownerDocument || this;

			for ( cur = event.target; cur != this; cur = cur.parentNode || this ) {

				// Don't process events on disabled elements (#6911, #8165)
				if ( cur.disabled !== true ) {
					selMatch = {};
					matches = [];
					jqcur[0] = cur;
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];
						sel = handleObj.selector;

						if ( selMatch[ sel ] === undefined ) {
							selMatch[ sel ] = (
								handleObj.quick ? quickIs( cur, handleObj.quick ) : jqcur.is( sel )
							);
						}
						if ( selMatch[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, matches: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( handlers.length > delegateCount ) {
			handlerQueue.push({ elem: this, matches: handlers.slice( delegateCount ) });
		}

		// Run delegates first; they may want to stop propagation beneath us
		for ( i = 0; i < handlerQueue.length && !event.isPropagationStopped(); i++ ) {
			matched = handlerQueue[ i ];
			event.currentTarget = matched.elem;

			for ( j = 0; j < matched.matches.length && !event.isImmediatePropagationStopped(); j++ ) {
				handleObj = matched.matches[ j ];

				// Triggered event must either 1) be non-exclusive and have no namespace, or
				// 2) have namespace(s) a subset or equal to those in the bound event (both can have no namespace).
				if ( run_all || (!event.namespace && !handleObj.namespace) || event.namespace_re && event.namespace_re.test( handleObj.namespace ) ) {

					event.data = handleObj.data;
					event.handleObj = handleObj;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						event.result = ret;
						if ( ret === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	// *** attrChange attrName relatedNode srcElement  are not normalized, non-W3C, deprecated, will be removed in 1.8 ***
	props: "attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var eventDoc, doc, body,
				button = original.button,
				fromElement = original.fromElement;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add relatedTarget, if necessary
			if ( !event.relatedTarget && fromElement ) {
				event.relatedTarget = fromElement === event.target ? original.toElement : fromElement;
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop,
			originalEvent = event,
			fixHook = jQuery.event.fixHooks[ event.type ] || {},
			copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = jQuery.Event( originalEvent );

		for ( i = copy.length; i; ) {
			prop = copy[ --i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Fix target property, if necessary (#1925, IE 6/7/8 & Safari2)
		if ( !event.target ) {
			event.target = originalEvent.srcElement || document;
		}

		// Target should not be a text node (#504, Safari)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		// For mouse/key events; add metaKey if it's not there (#3368, IE6/7/8)
		if ( event.metaKey === undefined ) {
			event.metaKey = event.ctrlKey;
		}

		return fixHook.filter? fixHook.filter( event, originalEvent ) : event;
	},

	special: {
		ready: {
			// Make sure the ready event is setup
			setup: jQuery.bindReady
		},

		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},

		focus: {
			delegateType: "focusin"
		},
		blur: {
			delegateType: "focusout"
		},

		beforeunload: {
			setup: function( data, namespaces, eventHandle ) {
				// We only want to do this special case on windows
				if ( jQuery.isWindow( this ) ) {
					this.onbeforeunload = eventHandle;
				}
			},

			teardown: function( namespaces, eventHandle ) {
				if ( this.onbeforeunload === eventHandle ) {
					this.onbeforeunload = null;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{ type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

// Some plugins are using, but it's undocumented/deprecated and will be removed.
// The 1.7 special event interface should provide all the hooks needed now.
jQuery.event.handle = jQuery.event.dispatch;

jQuery.removeEvent = document.removeEventListener ?
	function( elem, type, handle ) {
		if ( elem.removeEventListener ) {
			elem.removeEventListener( type, handle, false );
		}
	} :
	function( elem, type, handle ) {
		if ( elem.detachEvent ) {
			elem.detachEvent( "on" + type, handle );
		}
	};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = ( src.defaultPrevented || src.returnValue === false ||
			src.getPreventDefault && src.getPreventDefault() ) ? returnTrue : returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

function returnFalse() {
	return false;
}
function returnTrue() {
	return true;
}

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	preventDefault: function() {
		this.isDefaultPrevented = returnTrue;

		var e = this.originalEvent;
		if ( !e ) {
			return;
		}

		// if preventDefault exists run it on the original event
		if ( e.preventDefault ) {
			e.preventDefault();

		// otherwise set the returnValue property of the original event to false (IE)
		} else {
			e.returnValue = false;
		}
	},
	stopPropagation: function() {
		this.isPropagationStopped = returnTrue;

		var e = this.originalEvent;
		if ( !e ) {
			return;
		}
		// if stopPropagation exists run it on the original event
		if ( e.stopPropagation ) {
			e.stopPropagation();
		}
		// otherwise set the cancelBubble property of the original event to true (IE)
		e.cancelBubble = true;
	},
	stopImmediatePropagation: function() {
		this.isImmediatePropagationStopped = returnTrue;
		this.stopPropagation();
	},
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse
};

// Create mouseenter/leave events using mouseover/out and event-time checks
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj,
				selector = handleObj.selector,
				ret;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// IE submit delegation
if ( !jQuery.support.submitBubbles ) {

	jQuery.event.special.submit = {
		setup: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Lazy-add a submit handler when a descendant form may potentially be submitted
			jQuery.event.add( this, "click._submit keypress._submit", function( e ) {
				// Node name check avoids a VML-related crash in IE (#9807)
				var elem = e.target,
					form = jQuery.nodeName( elem, "input" ) || jQuery.nodeName( elem, "button" ) ? elem.form : undefined;
				if ( form && !form._submit_attached ) {
					jQuery.event.add( form, "submit._submit", function( event ) {
						event._submit_bubble = true;
					});
					form._submit_attached = true;
				}
			});
			// return undefined since we don't need an event listener
		},
		
		postDispatch: function( event ) {
			// If form was submitted by the user, bubble the event up the tree
			if ( event._submit_bubble ) {
				delete event._submit_bubble;
				if ( this.parentNode && !event.isTrigger ) {
					jQuery.event.simulate( "submit", this.parentNode, event, true );
				}
			}
		},

		teardown: function() {
			// Only need this for delegated form submit events
			if ( jQuery.nodeName( this, "form" ) ) {
				return false;
			}

			// Remove delegated handlers; cleanData eventually reaps submit handlers attached above
			jQuery.event.remove( this, "._submit" );
		}
	};
}

// IE change delegation and checkbox/radio fix
if ( !jQuery.support.changeBubbles ) {

	jQuery.event.special.change = {

		setup: function() {

			if ( rformElems.test( this.nodeName ) ) {
				// IE doesn't fire change on a check/radio until blur; trigger it on click
				// after a propertychange. Eat the blur-change in special.change.handle.
				// This still fires onchange a second time for check/radio after blur.
				if ( this.type === "checkbox" || this.type === "radio" ) {
					jQuery.event.add( this, "propertychange._change", function( event ) {
						if ( event.originalEvent.propertyName === "checked" ) {
							this._just_changed = true;
						}
					});
					jQuery.event.add( this, "click._change", function( event ) {
						if ( this._just_changed && !event.isTrigger ) {
							this._just_changed = false;
							jQuery.event.simulate( "change", this, event, true );
						}
					});
				}
				return false;
			}
			// Delegated event; lazy-add a change handler on descendant inputs
			jQuery.event.add( this, "beforeactivate._change", function( e ) {
				var elem = e.target;

				if ( rformElems.test( elem.nodeName ) && !elem._change_attached ) {
					jQuery.event.add( elem, "change._change", function( event ) {
						if ( this.parentNode && !event.isSimulated && !event.isTrigger ) {
							jQuery.event.simulate( "change", this.parentNode, event, true );
						}
					});
					elem._change_attached = true;
				}
			});
		},

		handle: function( event ) {
			var elem = event.target;

			// Swallow native change events from checkbox/radio, we already triggered them above
			if ( this !== elem || event.isSimulated || event.isTrigger || (elem.type !== "radio" && elem.type !== "checkbox") ) {
				return event.handleObj.handler.apply( this, arguments );
			}
		},

		teardown: function() {
			jQuery.event.remove( this, "._change" );

			return rformElems.test( this.nodeName );
		}
	};
}

// Create "bubbling" focus and blur events
if ( !jQuery.support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler while someone wants focusin/focusout
		var attaches = 0,
			handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				if ( attaches++ === 0 ) {
					document.addEventListener( orig, handler, true );
				}
			},
			teardown: function() {
				if ( --attaches === 0 ) {
					document.removeEventListener( orig, handler, true );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var origFn, type;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) { // && selector != null
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			var handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( var type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	live: function( types, data, fn ) {
		jQuery( this.context ).on( types, this.selector, data, fn );
		return this;
	},
	die: function( types, fn ) {
		jQuery( this.context ).off( types, this.selector || "**", fn );
		return this;
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length == 1? this.off( selector, "**" ) : this.off( types, selector, fn );
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		if ( this[0] ) {
			return jQuery.event.trigger( type, data, this[0], true );
		}
	},

	toggle: function( fn ) {
		// Save reference to arguments for access in closure
		var args = arguments,
			guid = fn.guid || jQuery.guid++,
			i = 0,
			toggler = function( event ) {
				// Figure out which function to execute
				var lastToggle = ( jQuery._data( this, "lastToggle" + fn.guid ) || 0 ) % i;
				jQuery._data( this, "lastToggle" + fn.guid, lastToggle + 1 );

				// Make sure that clicks stop
				event.preventDefault();

				// and execute the function
				return args[ lastToggle ].apply( this, arguments ) || false;
			};

		// link all the functions, so any of them can unbind this click handler
		toggler.guid = guid;
		while ( i < args.length ) {
			args[ i++ ].guid = guid;
		}

		return this.click( toggler );
	},

	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	}
});

jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		if ( fn == null ) {
			fn = data;
			data = null;
		}

		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};

	if ( jQuery.attrFn ) {
		jQuery.attrFn[ name ] = true;
	}

	if ( rkeyEvent.test( name ) ) {
		jQuery.event.fixHooks[ name ] = jQuery.event.keyHooks;
	}

	if ( rmouseEvent.test( name ) ) {
		jQuery.event.fixHooks[ name ] = jQuery.event.mouseHooks;
	}
});



/*!
 * Sizzle CSS Selector Engine
 *  Copyright 2011, The Dojo Foundation
 *  Released under the MIT, BSD, and GPL Licenses.
 *  More information: http://sizzlejs.com/
 */
(function(){

var chunker = /((?:\((?:\([^()]+\)|[^()]+)+\)|\[(?:\[[^\[\]]*\]|['"][^'"]*['"]|[^\[\]'"]+)+\]|\\.|[^ >+~,(\[\\]+)+|[>+~])(\s*,\s*)?((?:.|\r|\n)*)/g,
	expando = "sizcache" + (Math.random() + '').replace('.', ''),
	done = 0,
	toString = Object.prototype.toString,
	hasDuplicate = false,
	baseHasDuplicate = true,
	rBackslash = /\\/g,
	rReturn = /\r\n/g,
	rNonWord = /\W/;

// Here we check if the JavaScript engine is using some sort of
// optimization where it does not always call our comparision
// function. If that is the case, discard the hasDuplicate value.
//   Thus far that includes Google Chrome.
[0, 0].sort(function() {
	baseHasDuplicate = false;
	return 0;
});

var Sizzle = function( selector, context, results, seed ) {
	results = results || [];
	context = context || document;

	var origContext = context;

	if ( context.nodeType !== 1 && context.nodeType !== 9 ) {
		return [];
	}

	if ( !selector || typeof selector !== "string" ) {
		return results;
	}

	var m, set, checkSet, extra, ret, cur, pop, i,
		prune = true,
		contextXML = Sizzle.isXML( context ),
		parts = [],
		soFar = selector;

	// Reset the position of the chunker regexp (start from head)
	do {
		chunker.exec( "" );
		m = chunker.exec( soFar );

		if ( m ) {
			soFar = m[3];

			parts.push( m[1] );

			if ( m[2] ) {
				extra = m[3];
				break;
			}
		}
	} while ( m );

	if ( parts.length > 1 && origPOS.exec( selector ) ) {

		if ( parts.length === 2 && Expr.relative[ parts[0] ] ) {
			set = posProcess( parts[0] + parts[1], context, seed );

		} else {
			set = Expr.relative[ parts[0] ] ?
				[ context ] :
				Sizzle( parts.shift(), context );

			while ( parts.length ) {
				selector = parts.shift();

				if ( Expr.relative[ selector ] ) {
					selector += parts.shift();
				}

				set = posProcess( selector, set, seed );
			}
		}

	} else {
		// Take a shortcut and set the context if the root selector is an ID
		// (but not if it'll be faster if the inner selector is an ID)
		if ( !seed && parts.length > 1 && context.nodeType === 9 && !contextXML &&
				Expr.match.ID.test(parts[0]) && !Expr.match.ID.test(parts[parts.length - 1]) ) {

			ret = Sizzle.find( parts.shift(), context, contextXML );
			context = ret.expr ?
				Sizzle.filter( ret.expr, ret.set )[0] :
				ret.set[0];
		}

		if ( context ) {
			ret = seed ?
				{ expr: parts.pop(), set: makeArray(seed) } :
				Sizzle.find( parts.pop(), parts.length === 1 && (parts[0] === "~" || parts[0] === "+") && context.parentNode ? context.parentNode : context, contextXML );

			set = ret.expr ?
				Sizzle.filter( ret.expr, ret.set ) :
				ret.set;

			if ( parts.length > 0 ) {
				checkSet = makeArray( set );

			} else {
				prune = false;
			}

			while ( parts.length ) {
				cur = parts.pop();
				pop = cur;

				if ( !Expr.relative[ cur ] ) {
					cur = "";
				} else {
					pop = parts.pop();
				}

				if ( pop == null ) {
					pop = context;
				}

				Expr.relative[ cur ]( checkSet, pop, contextXML );
			}

		} else {
			checkSet = parts = [];
		}
	}

	if ( !checkSet ) {
		checkSet = set;
	}

	if ( !checkSet ) {
		Sizzle.error( cur || selector );
	}

	if ( toString.call(checkSet) === "[object Array]" ) {
		if ( !prune ) {
			results.push.apply( results, checkSet );

		} else if ( context && context.nodeType === 1 ) {
			for ( i = 0; checkSet[i] != null; i++ ) {
				if ( checkSet[i] && (checkSet[i] === true || checkSet[i].nodeType === 1 && Sizzle.contains(context, checkSet[i])) ) {
					results.push( set[i] );
				}
			}

		} else {
			for ( i = 0; checkSet[i] != null; i++ ) {
				if ( checkSet[i] && checkSet[i].nodeType === 1 ) {
					results.push( set[i] );
				}
			}
		}

	} else {
		makeArray( checkSet, results );
	}

	if ( extra ) {
		Sizzle( extra, origContext, results, seed );
		Sizzle.uniqueSort( results );
	}

	return results;
};

Sizzle.uniqueSort = function( results ) {
	if ( sortOrder ) {
		hasDuplicate = baseHasDuplicate;
		results.sort( sortOrder );

		if ( hasDuplicate ) {
			for ( var i = 1; i < results.length; i++ ) {
				if ( results[i] === results[ i - 1 ] ) {
					results.splice( i--, 1 );
				}
			}
		}
	}

	return results;
};

Sizzle.matches = function( expr, set ) {
	return Sizzle( expr, null, null, set );
};

Sizzle.matchesSelector = function( node, expr ) {
	return Sizzle( expr, null, null, [node] ).length > 0;
};

Sizzle.find = function( expr, context, isXML ) {
	var set, i, len, match, type, left;

	if ( !expr ) {
		return [];
	}

	for ( i = 0, len = Expr.order.length; i < len; i++ ) {
		type = Expr.order[i];

		if ( (match = Expr.leftMatch[ type ].exec( expr )) ) {
			left = match[1];
			match.splice( 1, 1 );

			if ( left.substr( left.length - 1 ) !== "\\" ) {
				match[1] = (match[1] || "").replace( rBackslash, "" );
				set = Expr.find[ type ]( match, context, isXML );

				if ( set != null ) {
					expr = expr.replace( Expr.match[ type ], "" );
					break;
				}
			}
		}
	}

	if ( !set ) {
		set = typeof context.getElementsByTagName !== "undefined" ?
			context.getElementsByTagName( "*" ) :
			[];
	}

	return { set: set, expr: expr };
};

Sizzle.filter = function( expr, set, inplace, not ) {
	var match, anyFound,
		type, found, item, filter, left,
		i, pass,
		old = expr,
		result = [],
		curLoop = set,
		isXMLFilter = set && set[0] && Sizzle.isXML( set[0] );

	while ( expr && set.length ) {
		for ( type in Expr.filter ) {
			if ( (match = Expr.leftMatch[ type ].exec( expr )) != null && match[2] ) {
				filter = Expr.filter[ type ];
				left = match[1];

				anyFound = false;

				match.splice(1,1);

				if ( left.substr( left.length - 1 ) === "\\" ) {
					continue;
				}

				if ( curLoop === result ) {
					result = [];
				}

				if ( Expr.preFilter[ type ] ) {
					match = Expr.preFilter[ type ]( match, curLoop, inplace, result, not, isXMLFilter );

					if ( !match ) {
						anyFound = found = true;

					} else if ( match === true ) {
						continue;
					}
				}

				if ( match ) {
					for ( i = 0; (item = curLoop[i]) != null; i++ ) {
						if ( item ) {
							found = filter( item, match, i, curLoop );
							pass = not ^ found;

							if ( inplace && found != null ) {
								if ( pass ) {
									anyFound = true;

								} else {
									curLoop[i] = false;
								}

							} else if ( pass ) {
								result.push( item );
								anyFound = true;
							}
						}
					}
				}

				if ( found !== undefined ) {
					if ( !inplace ) {
						curLoop = result;
					}

					expr = expr.replace( Expr.match[ type ], "" );

					if ( !anyFound ) {
						return [];
					}

					break;
				}
			}
		}

		// Improper expression
		if ( expr === old ) {
			if ( anyFound == null ) {
				Sizzle.error( expr );

			} else {
				break;
			}
		}

		old = expr;
	}

	return curLoop;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Utility function for retreiving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
var getText = Sizzle.getText = function( elem ) {
    var i, node,
		nodeType = elem.nodeType,
		ret = "";

	if ( nodeType ) {
		if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
			// Use textContent || innerText for elements
			if ( typeof elem.textContent === 'string' ) {
				return elem.textContent;
			} else if ( typeof elem.innerText === 'string' ) {
				// Replace IE's carriage returns
				return elem.innerText.replace( rReturn, '' );
			} else {
				// Traverse it's children
				for ( elem = elem.firstChild; elem; elem = elem.nextSibling) {
					ret += getText( elem );
				}
			}
		} else if ( nodeType === 3 || nodeType === 4 ) {
			return elem.nodeValue;
		}
	} else {

		// If no nodeType, this is expected to be an array
		for ( i = 0; (node = elem[i]); i++ ) {
			// Do not traverse comment nodes
			if ( node.nodeType !== 8 ) {
				ret += getText( node );
			}
		}
	}
	return ret;
};

var Expr = Sizzle.selectors = {
	order: [ "ID", "NAME", "TAG" ],

	match: {
		ID: /#((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,
		CLASS: /\.((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,
		NAME: /\[name=['"]*((?:[\w\u00c0-\uFFFF\-]|\\.)+)['"]*\]/,
		ATTR: /\[\s*((?:[\w\u00c0-\uFFFF\-]|\\.)+)\s*(?:(\S?=)\s*(?:(['"])(.*?)\3|(#?(?:[\w\u00c0-\uFFFF\-]|\\.)*)|)|)\s*\]/,
		TAG: /^((?:[\w\u00c0-\uFFFF\*\-]|\\.)+)/,
		CHILD: /:(only|nth|last|first)-child(?:\(\s*(even|odd|(?:[+\-]?\d+|(?:[+\-]?\d*)?n\s*(?:[+\-]\s*\d+)?))\s*\))?/,
		POS: /:(nth|eq|gt|lt|first|last|even|odd)(?:\((\d*)\))?(?=[^\-]|$)/,
		PSEUDO: /:((?:[\w\u00c0-\uFFFF\-]|\\.)+)(?:\((['"]?)((?:\([^\)]+\)|[^\(\)]*)+)\2\))?/
	},

	leftMatch: {},

	attrMap: {
		"class": "className",
		"for": "htmlFor"
	},

	attrHandle: {
		href: function( elem ) {
			return elem.getAttribute( "href" );
		},
		type: function( elem ) {
			return elem.getAttribute( "type" );
		}
	},

	relative: {
		"+": function(checkSet, part){
			var isPartStr = typeof part === "string",
				isTag = isPartStr && !rNonWord.test( part ),
				isPartStrNotTag = isPartStr && !isTag;

			if ( isTag ) {
				part = part.toLowerCase();
			}

			for ( var i = 0, l = checkSet.length, elem; i < l; i++ ) {
				if ( (elem = checkSet[i]) ) {
					while ( (elem = elem.previousSibling) && elem.nodeType !== 1 ) {}

					checkSet[i] = isPartStrNotTag || elem && elem.nodeName.toLowerCase() === part ?
						elem || false :
						elem === part;
				}
			}

			if ( isPartStrNotTag ) {
				Sizzle.filter( part, checkSet, true );
			}
		},

		">": function( checkSet, part ) {
			var elem,
				isPartStr = typeof part === "string",
				i = 0,
				l = checkSet.length;

			if ( isPartStr && !rNonWord.test( part ) ) {
				part = part.toLowerCase();

				for ( ; i < l; i++ ) {
					elem = checkSet[i];

					if ( elem ) {
						var parent = elem.parentNode;
						checkSet[i] = parent.nodeName.toLowerCase() === part ? parent : false;
					}
				}

			} else {
				for ( ; i < l; i++ ) {
					elem = checkSet[i];

					if ( elem ) {
						checkSet[i] = isPartStr ?
							elem.parentNode :
							elem.parentNode === part;
					}
				}

				if ( isPartStr ) {
					Sizzle.filter( part, checkSet, true );
				}
			}
		},

		"": function(checkSet, part, isXML){
			var nodeCheck,
				doneName = done++,
				checkFn = dirCheck;

			if ( typeof part === "string" && !rNonWord.test( part ) ) {
				part = part.toLowerCase();
				nodeCheck = part;
				checkFn = dirNodeCheck;
			}

			checkFn( "parentNode", part, doneName, checkSet, nodeCheck, isXML );
		},

		"~": function( checkSet, part, isXML ) {
			var nodeCheck,
				doneName = done++,
				checkFn = dirCheck;

			if ( typeof part === "string" && !rNonWord.test( part ) ) {
				part = part.toLowerCase();
				nodeCheck = part;
				checkFn = dirNodeCheck;
			}

			checkFn( "previousSibling", part, doneName, checkSet, nodeCheck, isXML );
		}
	},

	find: {
		ID: function( match, context, isXML ) {
			if ( typeof context.getElementById !== "undefined" && !isXML ) {
				var m = context.getElementById(match[1]);
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [m] : [];
			}
		},

		NAME: function( match, context ) {
			if ( typeof context.getElementsByName !== "undefined" ) {
				var ret = [],
					results = context.getElementsByName( match[1] );

				for ( var i = 0, l = results.length; i < l; i++ ) {
					if ( results[i].getAttribute("name") === match[1] ) {
						ret.push( results[i] );
					}
				}

				return ret.length === 0 ? null : ret;
			}
		},

		TAG: function( match, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( match[1] );
			}
		}
	},
	preFilter: {
		CLASS: function( match, curLoop, inplace, result, not, isXML ) {
			match = " " + match[1].replace( rBackslash, "" ) + " ";

			if ( isXML ) {
				return match;
			}

			for ( var i = 0, elem; (elem = curLoop[i]) != null; i++ ) {
				if ( elem ) {
					if ( not ^ (elem.className && (" " + elem.className + " ").replace(/[\t\n\r]/g, " ").indexOf(match) >= 0) ) {
						if ( !inplace ) {
							result.push( elem );
						}

					} else if ( inplace ) {
						curLoop[i] = false;
					}
				}
			}

			return false;
		},

		ID: function( match ) {
			return match[1].replace( rBackslash, "" );
		},

		TAG: function( match, curLoop ) {
			return match[1].replace( rBackslash, "" ).toLowerCase();
		},

		CHILD: function( match ) {
			if ( match[1] === "nth" ) {
				if ( !match[2] ) {
					Sizzle.error( match[0] );
				}

				match[2] = match[2].replace(/^\+|\s*/g, '');

				// parse equations like 'even', 'odd', '5', '2n', '3n+2', '4n-1', '-n+6'
				var test = /(-?)(\d*)(?:n([+\-]?\d*))?/.exec(
					match[2] === "even" && "2n" || match[2] === "odd" && "2n+1" ||
					!/\D/.test( match[2] ) && "0n+" + match[2] || match[2]);

				// calculate the numbers (first)n+(last) including if they are negative
				match[2] = (test[1] + (test[2] || 1)) - 0;
				match[3] = test[3] - 0;
			}
			else if ( match[2] ) {
				Sizzle.error( match[0] );
			}

			// TODO: Move to normal caching system
			match[0] = done++;

			return match;
		},

		ATTR: function( match, curLoop, inplace, result, not, isXML ) {
			var name = match[1] = match[1].replace( rBackslash, "" );

			if ( !isXML && Expr.attrMap[name] ) {
				match[1] = Expr.attrMap[name];
			}

			// Handle if an un-quoted value was used
			match[4] = ( match[4] || match[5] || "" ).replace( rBackslash, "" );

			if ( match[2] === "~=" ) {
				match[4] = " " + match[4] + " ";
			}

			return match;
		},

		PSEUDO: function( match, curLoop, inplace, result, not ) {
			if ( match[1] === "not" ) {
				// If we're dealing with a complex expression, or a simple one
				if ( ( chunker.exec(match[3]) || "" ).length > 1 || /^\w/.test(match[3]) ) {
					match[3] = Sizzle(match[3], null, null, curLoop);

				} else {
					var ret = Sizzle.filter(match[3], curLoop, inplace, true ^ not);

					if ( !inplace ) {
						result.push.apply( result, ret );
					}

					return false;
				}

			} else if ( Expr.match.POS.test( match[0] ) || Expr.match.CHILD.test( match[0] ) ) {
				return true;
			}

			return match;
		},

		POS: function( match ) {
			match.unshift( true );

			return match;
		}
	},

	filters: {
		enabled: function( elem ) {
			return elem.disabled === false && elem.type !== "hidden";
		},

		disabled: function( elem ) {
			return elem.disabled === true;
		},

		checked: function( elem ) {
			return elem.checked === true;
		},

		selected: function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		parent: function( elem ) {
			return !!elem.firstChild;
		},

		empty: function( elem ) {
			return !elem.firstChild;
		},

		has: function( elem, i, match ) {
			return !!Sizzle( match[3], elem ).length;
		},

		header: function( elem ) {
			return (/h\d/i).test( elem.nodeName );
		},

		text: function( elem ) {
			var attr = elem.getAttribute( "type" ), type = elem.type;
			// IE6 and 7 will map elem.type to 'text' for new HTML5 types (search, etc)
			// use getAttribute instead to test this case
			return elem.nodeName.toLowerCase() === "input" && "text" === type && ( attr === type || attr === null );
		},

		radio: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "radio" === elem.type;
		},

		checkbox: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "checkbox" === elem.type;
		},

		file: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "file" === elem.type;
		},

		password: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "password" === elem.type;
		},

		submit: function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return (name === "input" || name === "button") && "submit" === elem.type;
		},

		image: function( elem ) {
			return elem.nodeName.toLowerCase() === "input" && "image" === elem.type;
		},

		reset: function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return (name === "input" || name === "button") && "reset" === elem.type;
		},

		button: function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && "button" === elem.type || name === "button";
		},

		input: function( elem ) {
			return (/input|select|textarea|button/i).test( elem.nodeName );
		},

		focus: function( elem ) {
			return elem === elem.ownerDocument.activeElement;
		}
	},
	setFilters: {
		first: function( elem, i ) {
			return i === 0;
		},

		last: function( elem, i, match, array ) {
			return i === array.length - 1;
		},

		even: function( elem, i ) {
			return i % 2 === 0;
		},

		odd: function( elem, i ) {
			return i % 2 === 1;
		},

		lt: function( elem, i, match ) {
			return i < match[3] - 0;
		},

		gt: function( elem, i, match ) {
			return i > match[3] - 0;
		},

		nth: function( elem, i, match ) {
			return match[3] - 0 === i;
		},

		eq: function( elem, i, match ) {
			return match[3] - 0 === i;
		}
	},
	filter: {
		PSEUDO: function( elem, match, i, array ) {
			var name = match[1],
				filter = Expr.filters[ name ];

			if ( filter ) {
				return filter( elem, i, match, array );

			} else if ( name === "contains" ) {
				return (elem.textContent || elem.innerText || getText([ elem ]) || "").indexOf(match[3]) >= 0;

			} else if ( name === "not" ) {
				var not = match[3];

				for ( var j = 0, l = not.length; j < l; j++ ) {
					if ( not[j] === elem ) {
						return false;
					}
				}

				return true;

			} else {
				Sizzle.error( name );
			}
		},

		CHILD: function( elem, match ) {
			var first, last,
				doneName, parent, cache,
				count, diff,
				type = match[1],
				node = elem;

			switch ( type ) {
				case "only":
				case "first":
					while ( (node = node.previousSibling) ) {
						if ( node.nodeType === 1 ) {
							return false;
						}
					}

					if ( type === "first" ) {
						return true;
					}

					node = elem;

					/* falls through */
				case "last":
					while ( (node = node.nextSibling) ) {
						if ( node.nodeType === 1 ) {
							return false;
						}
					}

					return true;

				case "nth":
					first = match[2];
					last = match[3];

					if ( first === 1 && last === 0 ) {
						return true;
					}

					doneName = match[0];
					parent = elem.parentNode;

					if ( parent && (parent[ expando ] !== doneName || !elem.nodeIndex) ) {
						count = 0;

						for ( node = parent.firstChild; node; node = node.nextSibling ) {
							if ( node.nodeType === 1 ) {
								node.nodeIndex = ++count;
							}
						}

						parent[ expando ] = doneName;
					}

					diff = elem.nodeIndex - last;

					if ( first === 0 ) {
						return diff === 0;

					} else {
						return ( diff % first === 0 && diff / first >= 0 );
					}
			}
		},

		ID: function( elem, match ) {
			return elem.nodeType === 1 && elem.getAttribute("id") === match;
		},

		TAG: function( elem, match ) {
			return (match === "*" && elem.nodeType === 1) || !!elem.nodeName && elem.nodeName.toLowerCase() === match;
		},

		CLASS: function( elem, match ) {
			return (" " + (elem.className || elem.getAttribute("class")) + " ")
				.indexOf( match ) > -1;
		},

		ATTR: function( elem, match ) {
			var name = match[1],
				result = Sizzle.attr ?
					Sizzle.attr( elem, name ) :
					Expr.attrHandle[ name ] ?
					Expr.attrHandle[ name ]( elem ) :
					elem[ name ] != null ?
						elem[ name ] :
						elem.getAttribute( name ),
				value = result + "",
				type = match[2],
				check = match[4];

			return result == null ?
				type === "!=" :
				!type && Sizzle.attr ?
				result != null :
				type === "=" ?
				value === check :
				type === "*=" ?
				value.indexOf(check) >= 0 :
				type === "~=" ?
				(" " + value + " ").indexOf(check) >= 0 :
				!check ?
				value && result !== false :
				type === "!=" ?
				value !== check :
				type === "^=" ?
				value.indexOf(check) === 0 :
				type === "$=" ?
				value.substr(value.length - check.length) === check :
				type === "|=" ?
				value === check || value.substr(0, check.length + 1) === check + "-" :
				false;
		},

		POS: function( elem, match, i, array ) {
			var name = match[2],
				filter = Expr.setFilters[ name ];

			if ( filter ) {
				return filter( elem, i, match, array );
			}
		}
	}
};

var origPOS = Expr.match.POS,
	fescape = function(all, num){
		return "\\" + (num - 0 + 1);
	};

for ( var type in Expr.match ) {
	Expr.match[ type ] = new RegExp( Expr.match[ type ].source + (/(?![^\[]*\])(?![^\(]*\))/.source) );
	Expr.leftMatch[ type ] = new RegExp( /(^(?:.|\r|\n)*?)/.source + Expr.match[ type ].source.replace(/\\(\d+)/g, fescape) );
}
// Expose origPOS
// "global" as in regardless of relation to brackets/parens
Expr.match.globalPOS = origPOS;

var makeArray = function( array, results ) {
	array = Array.prototype.slice.call( array, 0 );

	if ( results ) {
		results.push.apply( results, array );
		return results;
	}

	return array;
};

// Perform a simple check to determine if the browser is capable of
// converting a NodeList to an array using builtin methods.
// Also verifies that the returned array holds DOM nodes
// (which is not the case in the Blackberry browser)
try {
	Array.prototype.slice.call( document.documentElement.childNodes, 0 )[0].nodeType;

// Provide a fallback method if it does not work
} catch( e ) {
	makeArray = function( array, results ) {
		var i = 0,
			ret = results || [];

		if ( toString.call(array) === "[object Array]" ) {
			Array.prototype.push.apply( ret, array );

		} else {
			if ( typeof array.length === "number" ) {
				for ( var l = array.length; i < l; i++ ) {
					ret.push( array[i] );
				}

			} else {
				for ( ; array[i]; i++ ) {
					ret.push( array[i] );
				}
			}
		}

		return ret;
	};
}

var sortOrder, siblingCheck;

if ( document.documentElement.compareDocumentPosition ) {
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		if ( !a.compareDocumentPosition || !b.compareDocumentPosition ) {
			return a.compareDocumentPosition ? -1 : 1;
		}

		return a.compareDocumentPosition(b) & 4 ? -1 : 1;
	};

} else {
	sortOrder = function( a, b ) {
		// The nodes are identical, we can exit early
		if ( a === b ) {
			hasDuplicate = true;
			return 0;

		// Fallback to using sourceIndex (in IE) if it's available on both nodes
		} else if ( a.sourceIndex && b.sourceIndex ) {
			return a.sourceIndex - b.sourceIndex;
		}

		var al, bl,
			ap = [],
			bp = [],
			aup = a.parentNode,
			bup = b.parentNode,
			cur = aup;

		// If the nodes are siblings (or identical) we can do a quick check
		if ( aup === bup ) {
			return siblingCheck( a, b );

		// If no parents were found then the nodes are disconnected
		} else if ( !aup ) {
			return -1;

		} else if ( !bup ) {
			return 1;
		}

		// Otherwise they're somewhere else in the tree so we need
		// to build up a full list of the parentNodes for comparison
		while ( cur ) {
			ap.unshift( cur );
			cur = cur.parentNode;
		}

		cur = bup;

		while ( cur ) {
			bp.unshift( cur );
			cur = cur.parentNode;
		}

		al = ap.length;
		bl = bp.length;

		// Start walking down the tree looking for a discrepancy
		for ( var i = 0; i < al && i < bl; i++ ) {
			if ( ap[i] !== bp[i] ) {
				return siblingCheck( ap[i], bp[i] );
			}
		}

		// We ended someplace up the tree so do a sibling check
		return i === al ?
			siblingCheck( a, bp[i], -1 ) :
			siblingCheck( ap[i], b, 1 );
	};

	siblingCheck = function( a, b, ret ) {
		if ( a === b ) {
			return ret;
		}

		var cur = a.nextSibling;

		while ( cur ) {
			if ( cur === b ) {
				return -1;
			}

			cur = cur.nextSibling;
		}

		return 1;
	};
}

// Check to see if the browser returns elements by name when
// querying by getElementById (and provide a workaround)
(function(){
	// We're going to inject a fake input element with a specified name
	var form = document.createElement("div"),
		id = "script" + (new Date()).getTime(),
		root = document.documentElement;

	form.innerHTML = "<a name='" + id + "'/>";

	// Inject it into the root element, check its status, and remove it quickly
	root.insertBefore( form, root.firstChild );

	// The workaround has to do additional checks after a getElementById
	// Which slows things down for other browsers (hence the branching)
	if ( document.getElementById( id ) ) {
		Expr.find.ID = function( match, context, isXML ) {
			if ( typeof context.getElementById !== "undefined" && !isXML ) {
				var m = context.getElementById(match[1]);

				return m ?
					m.id === match[1] || typeof m.getAttributeNode !== "undefined" && m.getAttributeNode("id").nodeValue === match[1] ?
						[m] :
						undefined :
					[];
			}
		};

		Expr.filter.ID = function( elem, match ) {
			var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");

			return elem.nodeType === 1 && node && node.nodeValue === match;
		};
	}

	root.removeChild( form );

	// release memory in IE
	root = form = null;
})();

(function(){
	// Check to see if the browser returns only elements
	// when doing getElementsByTagName("*")

	// Create a fake element
	var div = document.createElement("div");
	div.appendChild( document.createComment("") );

	// Make sure no comments are found
	if ( div.getElementsByTagName("*").length > 0 ) {
		Expr.find.TAG = function( match, context ) {
			var results = context.getElementsByTagName( match[1] );

			// Filter out possible comments
			if ( match[1] === "*" ) {
				var tmp = [];

				for ( var i = 0; results[i]; i++ ) {
					if ( results[i].nodeType === 1 ) {
						tmp.push( results[i] );
					}
				}

				results = tmp;
			}

			return results;
		};
	}

	// Check to see if an attribute returns normalized href attributes
	div.innerHTML = "<a href='#'></a>";

	if ( div.firstChild && typeof div.firstChild.getAttribute !== "undefined" &&
			div.firstChild.getAttribute("href") !== "#" ) {

		Expr.attrHandle.href = function( elem ) {
			return elem.getAttribute( "href", 2 );
		};
	}

	// release memory in IE
	div = null;
})();

if ( document.querySelectorAll ) {
	(function(){
		var oldSizzle = Sizzle,
			div = document.createElement("div"),
			id = "__sizzle__";

		div.innerHTML = "<p class='TEST'></p>";

		// Safari can't handle uppercase or unicode characters when
		// in quirks mode.
		if ( div.querySelectorAll && div.querySelectorAll(".TEST").length === 0 ) {
			return;
		}

		Sizzle = function( query, context, extra, seed ) {
			context = context || document;

			// Only use querySelectorAll on non-XML documents
			// (ID selectors don't work in non-HTML documents)
			if ( !seed && !Sizzle.isXML(context) ) {
				// See if we find a selector to speed up
				var match = /^(\w+$)|^\.([\w\-]+$)|^#([\w\-]+$)/.exec( query );

				if ( match && (context.nodeType === 1 || context.nodeType === 9) ) {
					// Speed-up: Sizzle("TAG")
					if ( match[1] ) {
						return makeArray( context.getElementsByTagName( query ), extra );

					// Speed-up: Sizzle(".CLASS")
					} else if ( match[2] && Expr.find.CLASS && context.getElementsByClassName ) {
						return makeArray( context.getElementsByClassName( match[2] ), extra );
					}
				}

				if ( context.nodeType === 9 ) {
					// Speed-up: Sizzle("body")
					// The body element only exists once, optimize finding it
					if ( query === "body" && context.body ) {
						return makeArray( [ context.body ], extra );

					// Speed-up: Sizzle("#ID")
					} else if ( match && match[3] ) {
						var elem = context.getElementById( match[3] );

						// Check parentNode to catch when Blackberry 4.6 returns
						// nodes that are no longer in the document #6963
						if ( elem && elem.parentNode ) {
							// Handle the case where IE and Opera return items
							// by name instead of ID
							if ( elem.id === match[3] ) {
								return makeArray( [ elem ], extra );
							}

						} else {
							return makeArray( [], extra );
						}
					}

					try {
						return makeArray( context.querySelectorAll(query), extra );
					} catch(qsaError) {}

				// qSA works strangely on Element-rooted queries
				// We can work around this by specifying an extra ID on the root
				// and working up from there (Thanks to Andrew Dupont for the technique)
				// IE 8 doesn't work on object elements
				} else if ( context.nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
					var oldContext = context,
						old = context.getAttribute( "id" ),
						nid = old || id,
						hasParent = context.parentNode,
						relativeHierarchySelector = /^\s*[+~]/.test( query );

					if ( !old ) {
						context.setAttribute( "id", nid );
					} else {
						nid = nid.replace( /'/g, "\\$&" );
					}
					if ( relativeHierarchySelector && hasParent ) {
						context = context.parentNode;
					}

					try {
						if ( !relativeHierarchySelector || hasParent ) {
							return makeArray( context.querySelectorAll( "[id='" + nid + "'] " + query ), extra );
						}

					} catch(pseudoError) {
					} finally {
						if ( !old ) {
							oldContext.removeAttribute( "id" );
						}
					}
				}
			}

			return oldSizzle(query, context, extra, seed);
		};

		for ( var prop in oldSizzle ) {
			Sizzle[ prop ] = oldSizzle[ prop ];
		}

		// release memory in IE
		div = null;
	})();
}

(function(){
	var html = document.documentElement,
		matches = html.matchesSelector || html.mozMatchesSelector || html.webkitMatchesSelector || html.msMatchesSelector;

	if ( matches ) {
		// Check to see if it's possible to do matchesSelector
		// on a disconnected node (IE 9 fails this)
		var disconnectedMatch = !matches.call( document.createElement( "div" ), "div" ),
			pseudoWorks = false;

		try {
			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( document.documentElement, "[test!='']:sizzle" );

		} catch( pseudoError ) {
			pseudoWorks = true;
		}

		Sizzle.matchesSelector = function( node, expr ) {
			// Make sure that attribute selectors are quoted
			expr = expr.replace(/\=\s*([^'"\]]*)\s*\]/g, "='$1']");

			if ( !Sizzle.isXML( node ) ) {
				try {
					if ( pseudoWorks || !Expr.match.PSEUDO.test( expr ) && !/!=/.test( expr ) ) {
						var ret = matches.call( node, expr );

						// IE 9's matchesSelector returns false on disconnected nodes
						if ( ret || !disconnectedMatch ||
								// As well, disconnected nodes are said to be in a document
								// fragment in IE 9, so check for that
								node.document && node.document.nodeType !== 11 ) {
							return ret;
						}
					}
				} catch(e) {}
			}

			return Sizzle(expr, null, null, [node]).length > 0;
		};
	}
})();

(function(){
	var div = document.createElement("div");

	div.innerHTML = "<div class='test e'></div><div class='test'></div>";

	// Opera can't find a second classname (in 9.6)
	// Also, make sure that getElementsByClassName actually exists
	if ( !div.getElementsByClassName || div.getElementsByClassName("e").length === 0 ) {
		return;
	}

	// Safari caches class attributes, doesn't catch changes (in 3.2)
	div.lastChild.className = "e";

	if ( div.getElementsByClassName("e").length === 1 ) {
		return;
	}

	Expr.order.splice(1, 0, "CLASS");
	Expr.find.CLASS = function( match, context, isXML ) {
		if ( typeof context.getElementsByClassName !== "undefined" && !isXML ) {
			return context.getElementsByClassName(match[1]);
		}
	};

	// release memory in IE
	div = null;
})();

function dirNodeCheck( dir, cur, doneName, checkSet, nodeCheck, isXML ) {
	for ( var i = 0, l = checkSet.length; i < l; i++ ) {
		var elem = checkSet[i];

		if ( elem ) {
			var match = false;

			elem = elem[dir];

			while ( elem ) {
				if ( elem[ expando ] === doneName ) {
					match = checkSet[elem.sizset];
					break;
				}

				if ( elem.nodeType === 1 && !isXML ){
					elem[ expando ] = doneName;
					elem.sizset = i;
				}

				if ( elem.nodeName.toLowerCase() === cur ) {
					match = elem;
					break;
				}

				elem = elem[dir];
			}

			checkSet[i] = match;
		}
	}
}

function dirCheck( dir, cur, doneName, checkSet, nodeCheck, isXML ) {
	for ( var i = 0, l = checkSet.length; i < l; i++ ) {
		var elem = checkSet[i];

		if ( elem ) {
			var match = false;

			elem = elem[dir];

			while ( elem ) {
				if ( elem[ expando ] === doneName ) {
					match = checkSet[elem.sizset];
					break;
				}

				if ( elem.nodeType === 1 ) {
					if ( !isXML ) {
						elem[ expando ] = doneName;
						elem.sizset = i;
					}

					if ( typeof cur !== "string" ) {
						if ( elem === cur ) {
							match = true;
							break;
						}

					} else if ( Sizzle.filter( cur, [elem] ).length > 0 ) {
						match = elem;
						break;
					}
				}

				elem = elem[dir];
			}

			checkSet[i] = match;
		}
	}
}

if ( document.documentElement.contains ) {
	Sizzle.contains = function( a, b ) {
		return a !== b && (a.contains ? a.contains(b) : true);
	};

} else if ( document.documentElement.compareDocumentPosition ) {
	Sizzle.contains = function( a, b ) {
		return !!(a.compareDocumentPosition(b) & 16);
	};

} else {
	Sizzle.contains = function() {
		return false;
	};
}

Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = (elem ? elem.ownerDocument || elem : 0).documentElement;

	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

var posProcess = function( selector, context, seed ) {
	var match,
		tmpSet = [],
		later = "",
		root = context.nodeType ? [context] : context;

	// Position selectors must be done after the filter
	// And so must :not(positional) so we move all PSEUDOs to the end
	while ( (match = Expr.match.PSEUDO.exec( selector )) ) {
		later += match[0];
		selector = selector.replace( Expr.match.PSEUDO, "" );
	}

	selector = Expr.relative[selector] ? selector + "*" : selector;

	for ( var i = 0, l = root.length; i < l; i++ ) {
		Sizzle( selector, root[i], tmpSet, seed );
	}

	return Sizzle.filter( later, tmpSet );
};

// EXPOSE
// Override sizzle attribute retrieval
Sizzle.attr = jQuery.attr;
Sizzle.selectors.attrMap = {};
jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.filters;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;


})();


var runtil = /Until$/,
	rparentsprev = /^(?:parents|prevUntil|prevAll)/,
	// Note: This RegExp should be improved, or likely pulled from Sizzle
	rmultiselector = /,/,
	isSimple = /^.[^:#\[\.,]*$/,
	slice = Array.prototype.slice,
	POS = jQuery.expr.match.globalPOS,
	// methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.fn.extend({
	find: function( selector ) {
		var self = this,
			i, l;

		if ( typeof selector !== "string" ) {
			return jQuery( selector ).filter(function() {
				for ( i = 0, l = self.length; i < l; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			});
		}

		var ret = this.pushStack( "", "find", selector ),
			length, n, r;

		for ( i = 0, l = this.length; i < l; i++ ) {
			length = ret.length;
			jQuery.find( selector, this[i], ret );

			if ( i > 0 ) {
				// Make sure that the results are unique
				for ( n = length; n < ret.length; n++ ) {
					for ( r = 0; r < length; r++ ) {
						if ( ret[r] === ret[n] ) {
							ret.splice(n--, 1);
							break;
						}
					}
				}
			}
		}

		return ret;
	},

	has: function( target ) {
		var targets = jQuery( target );
		return this.filter(function() {
			for ( var i = 0, l = targets.length; i < l; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	not: function( selector ) {
		return this.pushStack( winnow(this, selector, false), "not", selector);
	},

	filter: function( selector ) {
		return this.pushStack( winnow(this, selector, true), "filter", selector );
	},

	is: function( selector ) {
		return !!selector && (
			typeof selector === "string" ?
				// If this is a positional selector, check membership in the returned set
				// so $("p:first").is("p:last") won't return true for a doc with two "p".
				POS.test( selector ) ?
					jQuery( selector, this.context ).index( this[0] ) >= 0 :
					jQuery.filter( selector, this ).length > 0 :
				this.filter( selector ).length > 0 );
	},

	closest: function( selectors, context ) {
		var ret = [], i, l, cur = this[0];

		// Array (deprecated as of jQuery 1.7)
		if ( jQuery.isArray( selectors ) ) {
			var level = 1;

			while ( cur && cur.ownerDocument && cur !== context ) {
				for ( i = 0; i < selectors.length; i++ ) {

					if ( jQuery( cur ).is( selectors[ i ] ) ) {
						ret.push({ selector: selectors[ i ], elem: cur, level: level });
					}
				}

				cur = cur.parentNode;
				level++;
			}

			return ret;
		}

		// String
		var pos = POS.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( i = 0, l = this.length; i < l; i++ ) {
			cur = this[i];

			while ( cur ) {
				if ( pos ? pos.index(cur) > -1 : jQuery.find.matchesSelector(cur, selectors) ) {
					ret.push( cur );
					break;

				} else {
					cur = cur.parentNode;
					if ( !cur || !cur.ownerDocument || cur === context || cur.nodeType === 11 ) {
						break;
					}
				}
			}
		}

		ret = ret.length > 1 ? jQuery.unique( ret ) : ret;

		return this.pushStack( ret, "closest", selectors );
	},

	// Determine the position of an element within
	// the matched set of elements
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[0] && this[0].parentNode ) ? this.prevAll().length : -1;
		}

		// index in selector
		if ( typeof elem === "string" ) {
			return jQuery.inArray( this[0], jQuery( elem ) );
		}

		// Locate the position of the desired element
		return jQuery.inArray(
			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[0] : elem, this );
	},

	add: function( selector, context ) {
		var set = typeof selector === "string" ?
				jQuery( selector, context ) :
				jQuery.makeArray( selector && selector.nodeType ? [ selector ] : selector ),
			all = jQuery.merge( this.get(), set );

		return this.pushStack( isDisconnected( set[0] ) || isDisconnected( all[0] ) ?
			all :
			jQuery.unique( all ) );
	},

	andSelf: function() {
		return this.add( this.prevObject );
	}
});

// A painfully simple check to see if an element is disconnected
// from a document (should be improved, where feasible).
function isDisconnected( node ) {
	return !node || !node.parentNode || node.parentNode.nodeType === 11;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return jQuery.nth( elem, 2, "nextSibling" );
	},
	prev: function( elem ) {
		return jQuery.nth( elem, 2, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return jQuery.nodeName( elem, "iframe" ) ?
			elem.contentDocument || elem.contentWindow.document :
			jQuery.makeArray( elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var ret = jQuery.map( this, fn, until );

		if ( !runtil.test( name ) ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			ret = jQuery.filter( selector, ret );
		}

		ret = this.length > 1 && !guaranteedUnique[ name ] ? jQuery.unique( ret ) : ret;

		if ( (this.length > 1 || rmultiselector.test( selector )) && rparentsprev.test( name ) ) {
			ret = ret.reverse();
		}

		return this.pushStack( ret, name, slice.call( arguments ).join(",") );
	};
});

jQuery.extend({
	filter: function( expr, elems, not ) {
		if ( not ) {
			expr = ":not(" + expr + ")";
		}

		return elems.length === 1 ?
			jQuery.find.matchesSelector(elems[0], expr) ? [ elems[0] ] : [] :
			jQuery.find.matches(expr, elems);
	},

	dir: function( elem, dir, until ) {
		var matched = [],
			cur = elem[ dir ];

		while ( cur && cur.nodeType !== 9 && (until === undefined || cur.nodeType !== 1 || !jQuery( cur ).is( until )) ) {
			if ( cur.nodeType === 1 ) {
				matched.push( cur );
			}
			cur = cur[dir];
		}
		return matched;
	},

	nth: function( cur, result, dir, elem ) {
		result = result || 1;
		var num = 0;

		for ( ; cur; cur = cur[dir] ) {
			if ( cur.nodeType === 1 && ++num === result ) {
				break;
			}
		}

		return cur;
	},

	sibling: function( n, elem ) {
		var r = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				r.push( n );
			}
		}

		return r;
	}
});

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, keep ) {

	// Can't pass null or undefined to indexOf in Firefox 4
	// Set to 0 to skip string check
	qualifier = qualifier || 0;

	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep(elements, function( elem, i ) {
			var retVal = !!qualifier.call( elem, i, elem );
			return retVal === keep;
		});

	} else if ( qualifier.nodeType ) {
		return jQuery.grep(elements, function( elem, i ) {
			return ( elem === qualifier ) === keep;
		});

	} else if ( typeof qualifier === "string" ) {
		var filtered = jQuery.grep(elements, function( elem ) {
			return elem.nodeType === 1;
		});

		if ( isSimple.test( qualifier ) ) {
			return jQuery.filter(qualifier, filtered, !keep);
		} else {
			qualifier = jQuery.filter( qualifier, filtered );
		}
	}

	return jQuery.grep(elements, function( elem, i ) {
		return ( jQuery.inArray( elem, qualifier ) >= 0 ) === keep;
	});
}




function createSafeFragment( document ) {
	var list = nodeNames.split( "|" ),
	safeFrag = document.createDocumentFragment();

	if ( safeFrag.createElement ) {
		while ( list.length ) {
			safeFrag.createElement(
				list.pop()
			);
		}
	}
	return safeFrag;
}

var nodeNames = "abbr|article|aside|audio|bdi|canvas|data|datalist|details|figcaption|figure|footer|" +
		"header|hgroup|mark|meter|nav|output|progress|section|summary|time|video",
	rinlinejQuery = / jQuery\d+="(?:\d+|null)"/g,
	rleadingWhitespace = /^\s+/,
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/ig,
	rtagName = /<([\w:]+)/,
	rtbody = /<tbody/i,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style)/i,
	rnocache = /<(?:script|object|embed|option|style)/i,
	rnoshimcache = new RegExp("<(?:" + nodeNames + ")[\\s/>]", "i"),
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /\/(java|ecma)script/i,
	rcleanScript = /^\s*<!(?:\[CDATA\[|\-\-)/,
	wrapMap = {
		option: [ 1, "<select multiple='multiple'>", "</select>" ],
		legend: [ 1, "<fieldset>", "</fieldset>" ],
		thead: [ 1, "<table>", "</table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],
		col: [ 2, "<table><tbody></tbody><colgroup>", "</colgroup></table>" ],
		area: [ 1, "<map>", "</map>" ],
		_default: [ 0, "", "" ]
	},
	safeFragment = createSafeFragment( document );

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

// IE can't serialize <link> and <script> tags normally
if ( !jQuery.support.htmlSerialize ) {
	wrapMap._default = [ 1, "div<div>", "</div>" ];
}

jQuery.fn.extend({
	text: function( value ) {
		return jQuery.access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().append( ( this[0] && this[0].ownerDocument || document ).createTextNode( value ) );
		}, null, value, arguments.length );
	},

	wrapAll: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapAll( html.call(this, i) );
			});
		}

		if ( this[0] ) {
			// The elements to wrap the target around
			var wrap = jQuery( html, this[0].ownerDocument ).eq(0).clone(true);

			if ( this[0].parentNode ) {
				wrap.insertBefore( this[0] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstChild && elem.firstChild.nodeType === 1 ) {
					elem = elem.firstChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function(i) {
				jQuery(this).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function(i) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	},

	append: function() {
		return this.domManip(arguments, true, function( elem ) {
			if ( this.nodeType === 1 ) {
				this.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip(arguments, true, function( elem ) {
			if ( this.nodeType === 1 ) {
				this.insertBefore( elem, this.firstChild );
			}
		});
	},

	before: function() {
		if ( this[0] && this[0].parentNode ) {
			return this.domManip(arguments, false, function( elem ) {
				this.parentNode.insertBefore( elem, this );
			});
		} else if ( arguments.length ) {
			var set = jQuery.clean( arguments );
			set.push.apply( set, this.toArray() );
			return this.pushStack( set, "before", arguments );
		}
	},

	after: function() {
		if ( this[0] && this[0].parentNode ) {
			return this.domManip(arguments, false, function( elem ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			});
		} else if ( arguments.length ) {
			var set = this.pushStack( this, "after", arguments );
			set.push.apply( set, jQuery.clean(arguments) );
			return set;
		}
	},

	// keepData is for internal use only--do not document
	remove: function( selector, keepData ) {
		for ( var i = 0, elem; (elem = this[i]) != null; i++ ) {
			if ( !selector || jQuery.filter( selector, [ elem ] ).length ) {
				if ( !keepData && elem.nodeType === 1 ) {
					jQuery.cleanData( elem.getElementsByTagName("*") );
					jQuery.cleanData( [ elem ] );
				}

				if ( elem.parentNode ) {
					elem.parentNode.removeChild( elem );
				}
			}
		}

		return this;
	},

	empty: function() {
		for ( var i = 0, elem; (elem = this[i]) != null; i++ ) {
			// Remove element nodes and prevent memory leaks
			if ( elem.nodeType === 1 ) {
				jQuery.cleanData( elem.getElementsByTagName("*") );
			}

			// Remove any remaining nodes
			while ( elem.firstChild ) {
				elem.removeChild( elem.firstChild );
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map( function () {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return jQuery.access( this, function( value ) {
			var elem = this[0] || {},
				i = 0,
				l = this.length;

			if ( value === undefined ) {
				return elem.nodeType === 1 ?
					elem.innerHTML.replace( rinlinejQuery, "" ) :
					null;
			}


			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				( jQuery.support.leadingWhitespace || !rleadingWhitespace.test( value ) ) &&
				!wrapMap[ ( rtagName.exec( value ) || ["", ""] )[1].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for (; i < l; i++ ) {
						// Remove element nodes and prevent memory leaks
						elem = this[i] || {};
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( elem.getElementsByTagName( "*" ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch(e) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function( value ) {
		if ( this[0] && this[0].parentNode ) {
			// Make sure that the elements are removed from the DOM before they are inserted
			// this can help fix replacing a parent with child elements
			if ( jQuery.isFunction( value ) ) {
				return this.each(function(i) {
					var self = jQuery(this), old = self.html();
					self.replaceWith( value.call( this, i, old ) );
				});
			}

			if ( typeof value !== "string" ) {
				value = jQuery( value ).detach();
			}

			return this.each(function() {
				var next = this.nextSibling,
					parent = this.parentNode;

				jQuery( this ).remove();

				if ( next ) {
					jQuery(next).before( value );
				} else {
					jQuery(parent).append( value );
				}
			});
		} else {
			return this.length ?
				this.pushStack( jQuery(jQuery.isFunction(value) ? value() : value), "replaceWith", value ) :
				this;
		}
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, table, callback ) {
		var results, first, fragment, parent,
			value = args[0],
			scripts = [];

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( !jQuery.support.checkClone && arguments.length === 3 && typeof value === "string" && rchecked.test( value ) ) {
			return this.each(function() {
				jQuery(this).domManip( args, table, callback, true );
			});
		}

		if ( jQuery.isFunction(value) ) {
			return this.each(function(i) {
				var self = jQuery(this);
				args[0] = value.call(this, i, table ? self.html() : undefined);
				self.domManip( args, table, callback );
			});
		}

		if ( this[0] ) {
			parent = value && value.parentNode;

			// If we're in a fragment, just use that instead of building a new one
			if ( jQuery.support.parentNode && parent && parent.nodeType === 11 && parent.childNodes.length === this.length ) {
				results = { fragment: parent };

			} else {
				results = jQuery.buildFragment( args, this, scripts );
			}

			fragment = results.fragment;

			if ( fragment.childNodes.length === 1 ) {
				first = fragment = fragment.firstChild;
			} else {
				first = fragment.firstChild;
			}

			if ( first ) {
				table = table && jQuery.nodeName( first, "tr" );

				for ( var i = 0, l = this.length, lastIndex = l - 1; i < l; i++ ) {
					callback.call(
						table ?
							root(this[i], first) :
							this[i],
						// Make sure that we do not leak memory by inadvertently discarding
						// the original fragment (which might have attached data) instead of
						// using it; in addition, use the original fragment object for the last
						// item instead of first because it can end up being emptied incorrectly
						// in certain situations (Bug #8070).
						// Fragments from the fragment cache must always be cloned and never used
						// in place.
						results.cacheable || ( l > 1 && i < lastIndex ) ?
							jQuery.clone( fragment, true, true ) :
							fragment
					);
				}
			}

			if ( scripts.length ) {
				jQuery.each( scripts, function( i, elem ) {
					if ( elem.src ) {
						jQuery.ajax({
							type: "GET",
							global: false,
							url: elem.src,
							async: false,
							dataType: "script"
						});
					} else {
						jQuery.globalEval( ( elem.text || elem.textContent || elem.innerHTML || "" ).replace( rcleanScript, "/*$0*/" ) );
					}

					if ( elem.parentNode ) {
						elem.parentNode.removeChild( elem );
					}
				});
			}
		}

		return this;
	}
});

function root( elem, cur ) {
	return jQuery.nodeName(elem, "table") ?
		(elem.getElementsByTagName("tbody")[0] ||
		elem.appendChild(elem.ownerDocument.createElement("tbody"))) :
		elem;
}

function cloneCopyEvent( src, dest ) {

	if ( dest.nodeType !== 1 || !jQuery.hasData( src ) ) {
		return;
	}

	var type, i, l,
		oldData = jQuery._data( src ),
		curData = jQuery._data( dest, oldData ),
		events = oldData.events;

	if ( events ) {
		delete curData.handle;
		curData.events = {};

		for ( type in events ) {
			for ( i = 0, l = events[ type ].length; i < l; i++ ) {
				jQuery.event.add( dest, type, events[ type ][ i ] );
			}
		}
	}

	// make the cloned public data object a copy from the original
	if ( curData.data ) {
		curData.data = jQuery.extend( {}, curData.data );
	}
}

function cloneFixAttributes( src, dest ) {
	var nodeName;

	// We do not need to do anything for non-Elements
	if ( dest.nodeType !== 1 ) {
		return;
	}

	// clearAttributes removes the attributes, which we don't want,
	// but also removes the attachEvent events, which we *do* want
	if ( dest.clearAttributes ) {
		dest.clearAttributes();
	}

	// mergeAttributes, in contrast, only merges back on the
	// original attributes, not the events
	if ( dest.mergeAttributes ) {
		dest.mergeAttributes( src );
	}

	nodeName = dest.nodeName.toLowerCase();

	// IE6-8 fail to clone children inside object elements that use
	// the proprietary classid attribute value (rather than the type
	// attribute) to identify the type of content to display
	if ( nodeName === "object" ) {
		dest.outerHTML = src.outerHTML;

	} else if ( nodeName === "input" && (src.type === "checkbox" || src.type === "radio") ) {
		// IE6-8 fails to persist the checked state of a cloned checkbox
		// or radio button. Worse, IE6-7 fail to give the cloned element
		// a checked appearance if the defaultChecked value isn't also set
		if ( src.checked ) {
			dest.defaultChecked = dest.checked = src.checked;
		}

		// IE6-7 get confused and end up setting the value of a cloned
		// checkbox/radio button to an empty string instead of "on"
		if ( dest.value !== src.value ) {
			dest.value = src.value;
		}

	// IE6-8 fails to return the selected option to the default selected
	// state when cloning options
	} else if ( nodeName === "option" ) {
		dest.selected = src.defaultSelected;

	// IE6-8 fails to set the defaultValue to the correct value when
	// cloning other types of input fields
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;

	// IE blanks contents when cloning scripts
	} else if ( nodeName === "script" && dest.text !== src.text ) {
		dest.text = src.text;
	}

	// Event data gets referenced instead of copied if the expando
	// gets copied too
	dest.removeAttribute( jQuery.expando );

	// Clear flags for bubbling special change/submit events, they must
	// be reattached when the newly cloned events are first activated
	dest.removeAttribute( "_submit_attached" );
	dest.removeAttribute( "_change_attached" );
}

jQuery.buildFragment = function( args, nodes, scripts ) {
	var fragment, cacheable, cacheresults, doc,
	first = args[ 0 ];

	// nodes may contain either an explicit document object,
	// a jQuery collection or context object.
	// If nodes[0] contains a valid object to assign to doc
	if ( nodes && nodes[0] ) {
		doc = nodes[0].ownerDocument || nodes[0];
	}

	// Ensure that an attr object doesn't incorrectly stand in as a document object
	// Chrome and Firefox seem to allow this to occur and will throw exception
	// Fixes #8950
	if ( !doc.createDocumentFragment ) {
		doc = document;
	}

	// Only cache "small" (1/2 KB) HTML strings that are associated with the main document
	// Cloning options loses the selected state, so don't cache them
	// IE 6 doesn't like it when you put <object> or <embed> elements in a fragment
	// Also, WebKit does not clone 'checked' attributes on cloneNode, so don't cache
	// Lastly, IE6,7,8 will not correctly reuse cached fragments that were created from unknown elems #10501
	if ( args.length === 1 && typeof first === "string" && first.length < 512 && doc === document &&
		first.charAt(0) === "<" && !rnocache.test( first ) &&
		(jQuery.support.checkClone || !rchecked.test( first )) &&
		(jQuery.support.html5Clone || !rnoshimcache.test( first )) ) {

		cacheable = true;

		cacheresults = jQuery.fragments[ first ];
		if ( cacheresults && cacheresults !== 1 ) {
			fragment = cacheresults;
		}
	}

	if ( !fragment ) {
		fragment = doc.createDocumentFragment();
		jQuery.clean( args, doc, fragment, scripts );
	}

	if ( cacheable ) {
		jQuery.fragments[ first ] = cacheresults ? fragment : 1;
	}

	return { fragment: fragment, cacheable: cacheable };
};

jQuery.fragments = {};

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var ret = [],
			insert = jQuery( selector ),
			parent = this.length === 1 && this[0].parentNode;

		if ( parent && parent.nodeType === 11 && parent.childNodes.length === 1 && insert.length === 1 ) {
			insert[ original ]( this[0] );
			return this;

		} else {
			for ( var i = 0, l = insert.length; i < l; i++ ) {
				var elems = ( i > 0 ? this.clone(true) : this ).get();
				jQuery( insert[i] )[ original ]( elems );
				ret = ret.concat( elems );
			}

			return this.pushStack( ret, name, insert.selector );
		}
	};
});

function getAll( elem ) {
	if ( typeof elem.getElementsByTagName !== "undefined" ) {
		return elem.getElementsByTagName( "*" );

	} else if ( typeof elem.querySelectorAll !== "undefined" ) {
		return elem.querySelectorAll( "*" );

	} else {
		return [];
	}
}

// Used in clean, fixes the defaultChecked property
function fixDefaultChecked( elem ) {
	if ( elem.type === "checkbox" || elem.type === "radio" ) {
		elem.defaultChecked = elem.checked;
	}
}
// Finds all inputs and passes them to fixDefaultChecked
function findInputs( elem ) {
	var nodeName = ( elem.nodeName || "" ).toLowerCase();
	if ( nodeName === "input" ) {
		fixDefaultChecked( elem );
	// Skip scripts, get other children
	} else if ( nodeName !== "script" && typeof elem.getElementsByTagName !== "undefined" ) {
		jQuery.grep( elem.getElementsByTagName("input"), fixDefaultChecked );
	}
}

// Derived From: http://www.iecss.com/shimprove/javascript/shimprove.1-0-1.js
function shimCloneNode( elem ) {
	var div = document.createElement( "div" );
	safeFragment.appendChild( div );

	div.innerHTML = elem.outerHTML;
	return div.firstChild;
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var srcElements,
			destElements,
			i,
			// IE<=8 does not properly clone detached, unknown element nodes
			clone = jQuery.support.html5Clone || jQuery.isXMLDoc(elem) || !rnoshimcache.test( "<" + elem.nodeName + ">" ) ?
				elem.cloneNode( true ) :
				shimCloneNode( elem );

		if ( (!jQuery.support.noCloneEvent || !jQuery.support.noCloneChecked) &&
				(elem.nodeType === 1 || elem.nodeType === 11) && !jQuery.isXMLDoc(elem) ) {
			// IE copies events bound via attachEvent when using cloneNode.
			// Calling detachEvent on the clone will also remove the events
			// from the original. In order to get around this, we use some
			// proprietary methods to clear the events. Thanks to MooTools
			// guys for this hotness.

			cloneFixAttributes( elem, clone );

			// Using Sizzle here is crazy slow, so we use getElementsByTagName instead
			srcElements = getAll( elem );
			destElements = getAll( clone );

			// Weird iteration because IE will replace the length property
			// with an element if you are cloning the body and one of the
			// elements on the page has a name or id of "length"
			for ( i = 0; srcElements[i]; ++i ) {
				// Ensure that the destination node is not null; Fixes #9587
				if ( destElements[i] ) {
					cloneFixAttributes( srcElements[i], destElements[i] );
				}
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			cloneCopyEvent( elem, clone );

			if ( deepDataAndEvents ) {
				srcElements = getAll( elem );
				destElements = getAll( clone );

				for ( i = 0; srcElements[i]; ++i ) {
					cloneCopyEvent( srcElements[i], destElements[i] );
				}
			}
		}

		srcElements = destElements = null;

		// Return the cloned set
		return clone;
	},

	clean: function( elems, context, fragment, scripts ) {
		var checkScriptType, script, j,
				ret = [];

		context = context || document;

		// !context.createElement fails in IE with an error but returns typeof 'object'
		if ( typeof context.createElement === "undefined" ) {
			context = context.ownerDocument || context[0] && context[0].ownerDocument || document;
		}

		for ( var i = 0, elem; (elem = elems[i]) != null; i++ ) {
			if ( typeof elem === "number" ) {
				elem += "";
			}

			if ( !elem ) {
				continue;
			}

			// Convert html string into DOM nodes
			if ( typeof elem === "string" ) {
				if ( !rhtml.test( elem ) ) {
					elem = context.createTextNode( elem );
				} else {
					// Fix "XHTML"-style tags in all browsers
					elem = elem.replace(rxhtmlTag, "<$1></$2>");

					// Trim whitespace, otherwise indexOf won't work as expected
					var tag = ( rtagName.exec( elem ) || ["", ""] )[1].toLowerCase(),
						wrap = wrapMap[ tag ] || wrapMap._default,
						depth = wrap[0],
						div = context.createElement("div"),
						safeChildNodes = safeFragment.childNodes,
						remove;

					// Append wrapper element to unknown element safe doc fragment
					if ( context === document ) {
						// Use the fragment we've already created for this document
						safeFragment.appendChild( div );
					} else {
						// Use a fragment created with the owner document
						createSafeFragment( context ).appendChild( div );
					}

					// Go to html and back, then peel off extra wrappers
					div.innerHTML = wrap[1] + elem + wrap[2];

					// Move to the right depth
					while ( depth-- ) {
						div = div.lastChild;
					}

					// Remove IE's autoinserted <tbody> from table fragments
					if ( !jQuery.support.tbody ) {

						// String was a <table>, *may* have spurious <tbody>
						var hasBody = rtbody.test(elem),
							tbody = tag === "table" && !hasBody ?
								div.firstChild && div.firstChild.childNodes :

								// String was a bare <thead> or <tfoot>
								wrap[1] === "<table>" && !hasBody ?
									div.childNodes :
									[];

						for ( j = tbody.length - 1; j >= 0 ; --j ) {
							if ( jQuery.nodeName( tbody[ j ], "tbody" ) && !tbody[ j ].childNodes.length ) {
								tbody[ j ].parentNode.removeChild( tbody[ j ] );
							}
						}
					}

					// IE completely kills leading whitespace when innerHTML is used
					if ( !jQuery.support.leadingWhitespace && rleadingWhitespace.test( elem ) ) {
						div.insertBefore( context.createTextNode( rleadingWhitespace.exec(elem)[0] ), div.firstChild );
					}

					elem = div.childNodes;

					// Clear elements from DocumentFragment (safeFragment or otherwise)
					// to avoid hoarding elements. Fixes #11356
					if ( div ) {
						div.parentNode.removeChild( div );

						// Guard against -1 index exceptions in FF3.6
						if ( safeChildNodes.length > 0 ) {
							remove = safeChildNodes[ safeChildNodes.length - 1 ];

							if ( remove && remove.parentNode ) {
								remove.parentNode.removeChild( remove );
							}
						}
					}
				}
			}

			// Resets defaultChecked for any radios and checkboxes
			// about to be appended to the DOM in IE 6/7 (#8060)
			var len;
			if ( !jQuery.support.appendChecked ) {
				if ( elem[0] && typeof (len = elem.length) === "number" ) {
					for ( j = 0; j < len; j++ ) {
						findInputs( elem[j] );
					}
				} else {
					findInputs( elem );
				}
			}

			if ( elem.nodeType ) {
				ret.push( elem );
			} else {
				ret = jQuery.merge( ret, elem );
			}
		}

		if ( fragment ) {
			checkScriptType = function( elem ) {
				return !elem.type || rscriptType.test( elem.type );
			};
			for ( i = 0; ret[i]; i++ ) {
				script = ret[i];
				if ( scripts && jQuery.nodeName( script, "script" ) && (!script.type || rscriptType.test( script.type )) ) {
					scripts.push( script.parentNode ? script.parentNode.removeChild( script ) : script );

				} else {
					if ( script.nodeType === 1 ) {
						var jsTags = jQuery.grep( script.getElementsByTagName( "script" ), checkScriptType );

						ret.splice.apply( ret, [i + 1, 0].concat( jsTags ) );
					}
					fragment.appendChild( script );
				}
			}
		}

		return ret;
	},

	cleanData: function( elems ) {
		var data, id,
			cache = jQuery.cache,
			special = jQuery.event.special,
			deleteExpando = jQuery.support.deleteExpando;

		for ( var i = 0, elem; (elem = elems[i]) != null; i++ ) {
			if ( elem.nodeName && jQuery.noData[elem.nodeName.toLowerCase()] ) {
				continue;
			}

			id = elem[ jQuery.expando ];

			if ( id ) {
				data = cache[ id ];

				if ( data && data.events ) {
					for ( var type in data.events ) {
						if ( special[ type ] ) {
							jQuery.event.remove( elem, type );

						// This is a shortcut to avoid jQuery.event.remove's overhead
						} else {
							jQuery.removeEvent( elem, type, data.handle );
						}
					}

					// Null the DOM reference to avoid IE6/7/8 leak (#7054)
					if ( data.handle ) {
						data.handle.elem = null;
					}
				}

				if ( deleteExpando ) {
					delete elem[ jQuery.expando ];

				} else if ( elem.removeAttribute ) {
					elem.removeAttribute( jQuery.expando );
				}

				delete cache[ id ];
			}
		}
	}
});




var ralpha = /alpha\([^)]*\)/i,
	ropacity = /opacity=([^)]*)/,
	// fixed for IE9, see #8346
	rupper = /([A-Z]|^ms)/g,
	rnum = /^[\-+]?(?:\d*\.)?\d+$/i,
	rnumnonpx = /^-?(?:\d*\.)?\d+(?!px)[^\d\s]+$/i,
	rrelNum = /^([\-+])=([\-+.\de]+)/,
	rmargin = /^margin/,

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },

	// order is important!
	cssExpand = [ "Top", "Right", "Bottom", "Left" ],

	curCSS,

	getComputedStyle,
	currentStyle;

jQuery.fn.css = function( name, value ) {
	return jQuery.access( this, function( elem, name, value ) {
		return value !== undefined ?
			jQuery.style( elem, name, value ) :
			jQuery.css( elem, name );
	}, name, value, arguments.length > 1 );
};

jQuery.extend({
	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {
					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;

				} else {
					return elem.style.opacity;
				}
			}
		}
	},

	// Exclude the following css properties to add px
	cssNumber: {
		"fillOpacity": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		// normalize float css property
		"float": jQuery.support.cssFloat ? "cssFloat" : "styleFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {
		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, origName = jQuery.camelCase( name ),
			style = elem.style, hooks = jQuery.cssHooks[ origName ];

		name = jQuery.cssProps[ origName ] || origName;

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// convert relative number strings (+= or -=) to relative numbers. #7345
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( +( ret[1] + 1) * +ret[2] ) + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that NaN and null values aren't set. See: #7116
			if ( value == null || type === "number" && isNaN( value ) ) {
				return;
			}

			// If a number was passed in, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value )) !== undefined ) {
				// Wrapped to prevent IE from throwing errors when 'invalid' values are provided
				// Fixes bug #5509
				try {
					style[ name ] = value;
				} catch(e) {}
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra ) {
		var ret, hooks;

		// Make sure that we're working with the right name
		name = jQuery.camelCase( name );
		hooks = jQuery.cssHooks[ name ];
		name = jQuery.cssProps[ name ] || name;

		// cssFloat needs a special treatment
		if ( name === "cssFloat" ) {
			name = "float";
		}

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks && (ret = hooks.get( elem, true, extra )) !== undefined ) {
			return ret;

		// Otherwise, if a way to get the computed value exists, use that
		} else if ( curCSS ) {
			return curCSS( elem, name );
		}
	},

	// A method for quickly swapping in/out CSS properties to get correct calculations
	swap: function( elem, options, callback ) {
		var old = {},
			ret, name;

		// Remember the old values, and insert the new ones
		for ( name in options ) {
			old[ name ] = elem.style[ name ];
			elem.style[ name ] = options[ name ];
		}

		ret = callback.call( elem );

		// Revert the old values
		for ( name in options ) {
			elem.style[ name ] = old[ name ];
		}

		return ret;
	}
});

// DEPRECATED in 1.3, Use jQuery.css() instead
jQuery.curCSS = jQuery.css;

if ( document.defaultView && document.defaultView.getComputedStyle ) {
	getComputedStyle = function( elem, name ) {
		var ret, defaultView, computedStyle, width,
			style = elem.style;

		name = name.replace( rupper, "-$1" ).toLowerCase();

		if ( (defaultView = elem.ownerDocument.defaultView) &&
				(computedStyle = defaultView.getComputedStyle( elem, null )) ) {

			ret = computedStyle.getPropertyValue( name );
			if ( ret === "" && !jQuery.contains( elem.ownerDocument.documentElement, elem ) ) {
				ret = jQuery.style( elem, name );
			}
		}

		// A tribute to the "awesome hack by Dean Edwards"
		// WebKit uses "computed value (percentage if specified)" instead of "used value" for margins
		// which is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
		if ( !jQuery.support.pixelMargin && computedStyle && rmargin.test( name ) && rnumnonpx.test( ret ) ) {
			width = style.width;
			style.width = ret;
			ret = computedStyle.width;
			style.width = width;
		}

		return ret;
	};
}

if ( document.documentElement.currentStyle ) {
	currentStyle = function( elem, name ) {
		var left, rsLeft, uncomputed,
			ret = elem.currentStyle && elem.currentStyle[ name ],
			style = elem.style;

		// Avoid setting ret to empty string here
		// so we don't default to auto
		if ( ret == null && style && (uncomputed = style[ name ]) ) {
			ret = uncomputed;
		}

		// From the awesome hack by Dean Edwards
		// http://erik.eae.net/archives/2007/07/27/18.54.15/#comment-102291

		// If we're not dealing with a regular pixel number
		// but a number that has a weird ending, we need to convert it to pixels
		if ( rnumnonpx.test( ret ) ) {

			// Remember the original values
			left = style.left;
			rsLeft = elem.runtimeStyle && elem.runtimeStyle.left;

			// Put in the new values to get a computed value out
			if ( rsLeft ) {
				elem.runtimeStyle.left = elem.currentStyle.left;
			}
			style.left = name === "fontSize" ? "1em" : ret;
			ret = style.pixelLeft + "px";

			// Revert the changed values
			style.left = left;
			if ( rsLeft ) {
				elem.runtimeStyle.left = rsLeft;
			}
		}

		return ret === "" ? "auto" : ret;
	};
}

curCSS = getComputedStyle || currentStyle;

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property
	var val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		i = name === "width" ? 1 : 0,
		len = 4;

	if ( val > 0 ) {
		if ( extra !== "border" ) {
			for ( ; i < len; i += 2 ) {
				if ( !extra ) {
					val -= parseFloat( jQuery.css( elem, "padding" + cssExpand[ i ] ) ) || 0;
				}
				if ( extra === "margin" ) {
					val += parseFloat( jQuery.css( elem, extra + cssExpand[ i ] ) ) || 0;
				} else {
					val -= parseFloat( jQuery.css( elem, "border" + cssExpand[ i ] + "Width" ) ) || 0;
				}
			}
		}

		return val + "px";
	}

	// Fall back to computed then uncomputed css if necessary
	val = curCSS( elem, name );
	if ( val < 0 || val == null ) {
		val = elem.style[ name ];
	}

	// Computed unit is not pixels. Stop here and return.
	if ( rnumnonpx.test(val) ) {
		return val;
	}

	// Normalize "", auto, and prepare for extra
	val = parseFloat( val ) || 0;

	// Add padding, border, margin
	if ( extra ) {
		for ( ; i < len; i += 2 ) {
			val += parseFloat( jQuery.css( elem, "padding" + cssExpand[ i ] ) ) || 0;
			if ( extra !== "padding" ) {
				val += parseFloat( jQuery.css( elem, "border" + cssExpand[ i ] + "Width" ) ) || 0;
			}
			if ( extra === "margin" ) {
				val += parseFloat( jQuery.css( elem, extra + cssExpand[ i ]) ) || 0;
			}
		}
	}

	return val + "px";
}

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {
				if ( elem.offsetWidth !== 0 ) {
					return getWidthOrHeight( elem, name, extra );
				} else {
					return jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					});
				}
			}
		},

		set: function( elem, value ) {
			return rnum.test( value ) ?
				value + "px" :
				value;
		}
	};
});

if ( !jQuery.support.opacity ) {
	jQuery.cssHooks.opacity = {
		get: function( elem, computed ) {
			// IE uses filters for opacity
			return ropacity.test( (computed && elem.currentStyle ? elem.currentStyle.filter : elem.style.filter) || "" ) ?
				( parseFloat( RegExp.$1 ) / 100 ) + "" :
				computed ? "1" : "";
		},

		set: function( elem, value ) {
			var style = elem.style,
				currentStyle = elem.currentStyle,
				opacity = jQuery.isNumeric( value ) ? "alpha(opacity=" + value * 100 + ")" : "",
				filter = currentStyle && currentStyle.filter || style.filter || "";

			// IE has trouble with opacity if it does not have layout
			// Force it by setting the zoom level
			style.zoom = 1;

			// if setting opacity to 1, and no other filters exist - attempt to remove filter attribute #6652
			if ( value >= 1 && jQuery.trim( filter.replace( ralpha, "" ) ) === "" ) {

				// Setting style.filter to null, "" & " " still leave "filter:" in the cssText
				// if "filter:" is present at all, clearType is disabled, we want to avoid this
				// style.removeAttribute is IE Only, but so apparently is this code path...
				style.removeAttribute( "filter" );

				// if there there is no filter style applied in a css rule, we are done
				if ( currentStyle && !currentStyle.filter ) {
					return;
				}
			}

			// otherwise, set new filter values
			style.filter = ralpha.test( filter ) ?
				filter.replace( ralpha, opacity ) :
				filter + " " + opacity;
		}
	};
}

jQuery(function() {
	// This hook cannot be added until DOM ready because the support test
	// for it is not run until after DOM ready
	if ( !jQuery.support.reliableMarginRight ) {
		jQuery.cssHooks.marginRight = {
			get: function( elem, computed ) {
				// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
				// Work around by temporarily setting element display to inline-block
				return jQuery.swap( elem, { "display": "inline-block" }, function() {
					if ( computed ) {
						return curCSS( elem, "margin-right" );
					} else {
						return elem.style.marginRight;
					}
				});
			}
		};
	}
});

if ( jQuery.expr && jQuery.expr.filters ) {
	jQuery.expr.filters.hidden = function( elem ) {
		var width = elem.offsetWidth,
			height = elem.offsetHeight;

		return ( width === 0 && height === 0 ) || (!jQuery.support.reliableHiddenOffsets && ((elem.style && elem.style.display) || jQuery.css( elem, "display" )) === "none");
	};

	jQuery.expr.filters.visible = function( elem ) {
		return !jQuery.expr.filters.hidden( elem );
	};
}

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {

	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i,

				// assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ],
				expanded = {};

			for ( i = 0; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};
});




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rhash = /#.*$/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)\r?$/mg, // IE leaves an \r character at EOL
	rinput = /^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app\-storage|.+\-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rquery = /\?/,
	rscript = /<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,
	rselectTextarea = /^(?:select|textarea)/i,
	rspacesAjax = /\s+/,
	rts = /([?&])_=[^&]*/,
	rurl = /^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+))?)?/,

	// Keep a copy of the old load method
	_load = jQuery.fn.load,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Document location
	ajaxLocation,

	// Document location segments
	ajaxLocParts,

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = ["*/"] + ["*"];

// #8138, IE may throw an exception when accessing
// a field from window.location if document.domain has been set
try {
	ajaxLocation = location.href;
} catch( e ) {
	// Use the href attribute of an A element
	// since IE will modify it given document.location
	ajaxLocation = document.createElement( "a" );
	ajaxLocation.href = "";
	ajaxLocation = ajaxLocation.href;
}

// Segment location into parts
ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		if ( jQuery.isFunction( func ) ) {
			var dataTypes = dataTypeExpression.toLowerCase().split( rspacesAjax ),
				i = 0,
				length = dataTypes.length,
				dataType,
				list,
				placeBefore;

			// For each dataType in the dataTypeExpression
			for ( ; i < length; i++ ) {
				dataType = dataTypes[ i ];
				// We control if we're asked to add before
				// any existing element
				placeBefore = /^\+/.test( dataType );
				if ( placeBefore ) {
					dataType = dataType.substr( 1 ) || "*";
				}
				list = structure[ dataType ] = structure[ dataType ] || [];
				// then we add to the structure accordingly
				list[ placeBefore ? "unshift" : "push" ]( func );
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR,
		dataType /* internal */, inspected /* internal */ ) {

	dataType = dataType || options.dataTypes[ 0 ];
	inspected = inspected || {};

	inspected[ dataType ] = true;

	var list = structure[ dataType ],
		i = 0,
		length = list ? list.length : 0,
		executeOnly = ( structure === prefilters ),
		selection;

	for ( ; i < length && ( executeOnly || !selection ); i++ ) {
		selection = list[ i ]( options, originalOptions, jqXHR );
		// If we got redirected to another dataType
		// we try there if executing only and not done already
		if ( typeof selection === "string" ) {
			if ( !executeOnly || inspected[ selection ] ) {
				selection = undefined;
			} else {
				options.dataTypes.unshift( selection );
				selection = inspectPrefiltersOrTransports(
						structure, options, originalOptions, jqXHR, selection, inspected );
			}
		}
	}
	// If we're only executing or nothing was selected
	// we try the catchall dataType if not done already
	if ( ( executeOnly || !selection ) && !inspected[ "*" ] ) {
		selection = inspectPrefiltersOrTransports(
				structure, options, originalOptions, jqXHR, "*", inspected );
	}
	// unnecessary when only executing (prefilters)
	// but it'll be ignored by the caller in that case
	return selection;
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var key, deep,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};
	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || ( deep = {} ) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}
}

jQuery.fn.extend({
	load: function( url, params, callback ) {
		if ( typeof url !== "string" && _load ) {
			return _load.apply( this, arguments );

		// Don't do a request if no elements are being requested
		} else if ( !this.length ) {
			return this;
		}

		var off = url.indexOf( " " );
		if ( off >= 0 ) {
			var selector = url.slice( off, url.length );
			url = url.slice( 0, off );
		}

		// Default to a GET request
		var type = "GET";

		// If the second parameter was provided
		if ( params ) {
			// If it's a function
			if ( jQuery.isFunction( params ) ) {
				// We assume that it's the callback
				callback = params;
				params = undefined;

			// Otherwise, build a param string
			} else if ( typeof params === "object" ) {
				params = jQuery.param( params, jQuery.ajaxSettings.traditional );
				type = "POST";
			}
		}

		var self = this;

		// Request the remote document
		jQuery.ajax({
			url: url,
			type: type,
			dataType: "html",
			data: params,
			// Complete callback (responseText is used internally)
			complete: function( jqXHR, status, responseText ) {
				// Store the response as specified by the jqXHR object
				responseText = jqXHR.responseText;
				// If successful, inject the HTML into all the matched elements
				if ( jqXHR.isResolved() ) {
					// #4825: Get the actual response in case
					// a dataFilter is present in ajaxSettings
					jqXHR.done(function( r ) {
						responseText = r;
					});
					// See if a selector was specified
					self.html( selector ?
						// Create a dummy div to hold the results
						jQuery("<div>")
							// inject the contents of the document in, removing the scripts
							// to avoid any 'Permission Denied' errors in IE
							.append(responseText.replace(rscript, ""))

							// Locate the specified elements
							.find(selector) :

						// If not, just inject the full result
						responseText );
				}

				if ( callback ) {
					self.each( callback, [ responseText, status, jqXHR ] );
				}
			}
		});

		return this;
	},

	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},

	serializeArray: function() {
		return this.map(function(){
			return this.elements ? jQuery.makeArray( this.elements ) : this;
		})
		.filter(function(){
			return this.name && !this.disabled &&
				( this.checked || rselectTextarea.test( this.nodeName ) ||
					rinput.test( this.type ) );
		})
		.map(function( i, elem ){
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val, i ){
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});

// Attach a bunch of functions for handling common AJAX events
jQuery.each( "ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split( " " ), function( i, o ){
	jQuery.fn[ o ] = function( f ){
		return this.on( o, f );
	};
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			type: method,
			url: url,
			data: data,
			success: callback,
			dataType: type
		});
	};
});

jQuery.extend({

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		if ( settings ) {
			// Building a settings object
			ajaxExtend( target, jQuery.ajaxSettings );
		} else {
			// Extending ajaxSettings
			settings = target;
			target = jQuery.ajaxSettings;
		}
		ajaxExtend( target, settings );
		return target;
	},

	ajaxSettings: {
		url: ajaxLocation,
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		type: "GET",
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		processData: true,
		async: true,
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		traditional: false,
		headers: {},
		*/

		accepts: {
			xml: "application/xml, text/xml",
			html: "text/html",
			text: "text/plain",
			json: "application/json, text/javascript",
			"*": allTypes
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText"
		},

		// List of data converters
		// 1) key format is "source_type destination_type" (a single space in-between)
		// 2) the catchall symbol "*" can be used for source_type
		converters: {

			// Convert anything to text
			"* text": window.String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			context: true,
			url: true
		}
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var // Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events
			// It's the callbackContext if one was provided in the options
			// and if it's a DOM node or a jQuery collection
			globalEventContext = callbackContext !== s &&
				( callbackContext.nodeType || callbackContext instanceof jQuery ) ?
						jQuery( callbackContext ) : jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks( "once memory" ),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// ifModified key
			ifModifiedKey,
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// Response headers
			responseHeadersString,
			responseHeaders,
			// transport
			transport,
			// timeout handle
			timeoutTimer,
			// Cross-domain detection vars
			parts,
			// The jqXHR state
			state = 0,
			// To know if global events are to be dispatched
			fireGlobals,
			// Loop variable
			i,
			// Fake xhr
			jqXHR = {

				readyState: 0,

				// Caches the header
				setRequestHeader: function( name, value ) {
					if ( !state ) {
						var lname = name.toLowerCase();
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while( ( match = rheaders.exec( responseHeadersString ) ) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match === undefined ? null : match;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					statusText = statusText || "abort";
					if ( transport ) {
						transport.abort( statusText );
					}
					done( 0, statusText );
					return this;
				}
			};

		// Callback for when everything is done
		// It is defined here because jslint complains if it is declared
		// at the end of the function (which would be more logical and readable)
		function done( status, nativeStatusText, responses, headers ) {

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			var isSuccess,
				success,
				error,
				statusText = nativeStatusText,
				response = responses ? ajaxHandleResponses( s, jqXHR, responses ) : undefined,
				lastModified,
				etag;

			// If successful, handle type chaining
			if ( status >= 200 && status < 300 || status === 304 ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {

					if ( ( lastModified = jqXHR.getResponseHeader( "Last-Modified" ) ) ) {
						jQuery.lastModified[ ifModifiedKey ] = lastModified;
					}
					if ( ( etag = jqXHR.getResponseHeader( "Etag" ) ) ) {
						jQuery.etag[ ifModifiedKey ] = etag;
					}
				}

				// If not modified
				if ( status === 304 ) {

					statusText = "notmodified";
					isSuccess = true;

				// If we have data
				} else {

					try {
						success = ajaxConvert( s, response );
						statusText = "success";
						isSuccess = true;
					} catch(e) {
						// We have a parsererror
						statusText = "parsererror";
						error = e;
					}
				}
			} else {
				// We extract error from statusText
				// then normalize statusText and status for non-aborts
				error = statusText;
				if ( !statusText || status ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = "" + ( nativeStatusText || statusText );

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajax" + ( isSuccess ? "Success" : "Error" ),
						[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger( "ajaxStop" );
				}
			}
		}

		// Attach deferreds
		deferred.promise( jqXHR );
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;
		jqXHR.complete = completeDeferred.add;

		// Status-dependent callbacks
		jqXHR.statusCode = function( map ) {
			if ( map ) {
				var tmp;
				if ( state < 2 ) {
					for ( tmp in map ) {
						statusCode[ tmp ] = [ statusCode[tmp], map[tmp] ];
					}
				} else {
					tmp = map[ jqXHR.status ];
					jqXHR.then( tmp, tmp );
				}
			}
			return this;
		};

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (#5866: IE7 issue with protocol-less urls)
		// We also use the url parameter if available
		s.url = ( ( url || s.url ) + "" ).replace( rhash, "" ).replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().split( rspacesAjax );

		// Determine if a cross-domain request is in order
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] != ajaxLocParts[ 1 ] || parts[ 2 ] != ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? 80 : 443 ) ) !=
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? 80 : 443 ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return false;
		}

		// We can fire global events as of now if asked to
		fireGlobals = s.global;

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger( "ajaxStart" );
		}

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.data;
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Get ifModifiedKey before adding the anti-cache parameter
			ifModifiedKey = s.url;

			// Add anti-cache in url if needed
			if ( s.cache === false ) {

				var ts = jQuery.now(),
					// try replacing _= if it is there
					ret = s.url.replace( rts, "$1_=" + ts );

				// if nothing was replaced, add timestamp to the end
				s.url = ret + ( ( ret === s.url ) ? ( rquery.test( s.url ) ? "&" : "?" ) + "_=" + ts : "" );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			ifModifiedKey = ifModifiedKey || s.url;
			if ( jQuery.lastModified[ ifModifiedKey ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ ifModifiedKey ] );
			}
			if ( jQuery.etag[ ifModifiedKey ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ ifModifiedKey ] );
			}
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
				// Abort if not done already
				jqXHR.abort();
				return false;

		}

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;
			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout( function(){
					jqXHR.abort( "timeout" );
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch (e) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		return jqXHR;
	},

	// Serialize an array of form elements or a set of
	// key/values into a query string
	param: function( a, traditional ) {
		var s = [],
			add = function( key, value ) {
				// If value is a function, invoke it and return its value
				value = jQuery.isFunction( value ) ? value() : value;
				s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
			};

		// Set traditional to true for jQuery <= 1.3.2 behavior.
		if ( traditional === undefined ) {
			traditional = jQuery.ajaxSettings.traditional;
		}

		// If an array was passed in, assume that it is an array of form elements.
		if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
			// Serialize the form elements
			jQuery.each( a, function() {
				add( this.name, this.value );
			});

		} else {
			// If traditional, encode the "old" way (the way 1.3.2 or older
			// did it), otherwise encode params recursively.
			for ( var prefix in a ) {
				buildParams( prefix, a[ prefix ], traditional, add );
			}
		}

		// Return the resulting serialization
		return s.join( "&" ).replace( r20, "+" );
	}
});

function buildParams( prefix, obj, traditional, add ) {
	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// If array item is non-scalar (array or object), encode its
				// numeric index to resolve deserialization ambiguity issues.
				// Note that rack (as of 1.0.0) can't currently deserialize
				// nested arrays properly, and attempting to do so may cause
				// a server error. Possible fixes are to modify rack's
				// deserialization algorithm or to provide an option or flag
				// to force array serialization to be shallow.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( var name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// This is still on the jQuery object... for now
// Want to move this to jQuery.ajax some day
jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {}

});

/* Handles responses to an ajax request:
 * - sets all responseXXX fields accordingly
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {

	var contents = s.contents,
		dataTypes = s.dataTypes,
		responseFields = s.responseFields,
		ct,
		type,
		finalDataType,
		firstDataType;

	// Fill responseXXX fields
	for ( type in responseFields ) {
		if ( type in responses ) {
			jqXHR[ responseFields[type] ] = responses[ type ];
		}
	}

	// Remove auto dataType and get content-type in the process
	while( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader( "content-type" );
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

// Chain conversions given the request and the original response
function ajaxConvert( s, response ) {

	// Apply the dataFilter if provided
	if ( s.dataFilter ) {
		response = s.dataFilter( response, s.dataType );
	}

	var dataTypes = s.dataTypes,
		converters = {},
		i,
		key,
		length = dataTypes.length,
		tmp,
		// Current and previous dataTypes
		current = dataTypes[ 0 ],
		prev,
		// Conversion expression
		conversion,
		// Conversion function
		conv,
		// Conversion functions (transitive conversion)
		conv1,
		conv2;

	// For each dataType in the chain
	for ( i = 1; i < length; i++ ) {

		// Create converters map
		// with lowercased keys
		if ( i === 1 ) {
			for ( key in s.converters ) {
				if ( typeof key === "string" ) {
					converters[ key.toLowerCase() ] = s.converters[ key ];
				}
			}
		}

		// Get the dataTypes
		prev = current;
		current = dataTypes[ i ];

		// If current is auto dataType, update it to prev
		if ( current === "*" ) {
			current = prev;
		// If no auto and dataTypes are actually different
		} else if ( prev !== "*" && prev !== current ) {

			// Get the converter
			conversion = prev + " " + current;
			conv = converters[ conversion ] || converters[ "* " + current ];

			// If there is no direct converter, search transitively
			if ( !conv ) {
				conv2 = undefined;
				for ( conv1 in converters ) {
					tmp = conv1.split( " " );
					if ( tmp[ 0 ] === prev || tmp[ 0 ] === "*" ) {
						conv2 = converters[ tmp[1] + " " + current ];
						if ( conv2 ) {
							conv1 = converters[ conv1 ];
							if ( conv1 === true ) {
								conv = conv2;
							} else if ( conv2 === true ) {
								conv = conv1;
							}
							break;
						}
					}
				}
			}
			// If we found no converter, dispatch an error
			if ( !( conv || conv2 ) ) {
				jQuery.error( "No conversion from " + conversion.replace(" "," to ") );
			}
			// If found converter is not an equivalence
			if ( conv !== true ) {
				// Convert with 1 or 2 converters accordingly
				response = conv ? conv( response ) : conv2( conv1(response) );
			}
		}
	}
	return response;
}




var jsc = jQuery.now(),
	jsre = /(\=)\?(&|$)|\?\?/i;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		return jQuery.expando + "_" + ( jsc++ );
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var inspectData = ( typeof s.data === "string" ) && /^application\/x\-www\-form\-urlencoded/.test( s.contentType );

	if ( s.dataTypes[ 0 ] === "jsonp" ||
		s.jsonp !== false && ( jsre.test( s.url ) ||
				inspectData && jsre.test( s.data ) ) ) {

		var responseContainer,
			jsonpCallback = s.jsonpCallback =
				jQuery.isFunction( s.jsonpCallback ) ? s.jsonpCallback() : s.jsonpCallback,
			previous = window[ jsonpCallback ],
			url = s.url,
			data = s.data,
			replace = "$1" + jsonpCallback + "$2";

		if ( s.jsonp !== false ) {
			url = url.replace( jsre, replace );
			if ( s.url === url ) {
				if ( inspectData ) {
					data = data.replace( jsre, replace );
				}
				if ( s.data === data ) {
					// Add callback manually
					url += (/\?/.test( url ) ? "&" : "?") + s.jsonp + "=" + jsonpCallback;
				}
			}
		}

		s.url = url;
		s.data = data;

		// Install callback
		window[ jsonpCallback ] = function( response ) {
			responseContainer = [ response ];
		};

		// Clean-up function
		jqXHR.always(function() {
			// Set callback back to previous value
			window[ jsonpCallback ] = previous;
			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( previous ) ) {
				window[ jsonpCallback ]( responseContainer[ 0 ] );
			}
		});

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( jsonpCallback + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Delegate to script
		return "script";
	}
});




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /javascript|ecmascript/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and global
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
		s.global = false;
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function(s) {

	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {

		var script,
			head = document.head || document.getElementsByTagName( "head" )[0] || document.documentElement;

		return {

			send: function( _, callback ) {

				script = document.createElement( "script" );

				script.async = "async";

				if ( s.scriptCharset ) {
					script.charset = s.scriptCharset;
				}

				script.src = s.url;

				// Attach handlers for all browsers
				script.onload = script.onreadystatechange = function( _, isAbort ) {

					if ( isAbort || !script.readyState || /loaded|complete/.test( script.readyState ) ) {

						// Handle memory leak in IE
						script.onload = script.onreadystatechange = null;

						// Remove the script
						if ( head && script.parentNode ) {
							head.removeChild( script );
						}

						// Dereference the script
						script = undefined;

						// Callback if not abort
						if ( !isAbort ) {
							callback( 200, "success" );
						}
					}
				};
				// Use insertBefore instead of appendChild  to circumvent an IE6 bug.
				// This arises when a base node is used (#2709 and #4378).
				head.insertBefore( script, head.firstChild );
			},

			abort: function() {
				if ( script ) {
					script.onload( 0, 1 );
				}
			}
		};
	}
});




var // #5280: Internet Explorer will keep connections alive if we don't abort on unload
	xhrOnUnloadAbort = window.ActiveXObject ? function() {
		// Abort all pending requests
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]( 0, 1 );
		}
	} : false,
	xhrId = 0,
	xhrCallbacks;

// Functions to create xhrs
function createStandardXHR() {
	try {
		return new window.XMLHttpRequest();
	} catch( e ) {}
}

function createActiveXHR() {
	try {
		return new window.ActiveXObject( "Microsoft.XMLHTTP" );
	} catch( e ) {}
}

// Create the request object
// (This is still attached to ajaxSettings for backward compatibility)
jQuery.ajaxSettings.xhr = window.ActiveXObject ?
	/* Microsoft failed to properly
	 * implement the XMLHttpRequest in IE7 (can't request local files),
	 * so we use the ActiveXObject when it is available
	 * Additionally XMLHttpRequest can be disabled in IE7/IE8 so
	 * we need a fallback.
	 */
	function() {
		return !this.isLocal && createStandardXHR() || createActiveXHR();
	} :
	// For all other browsers, use the standard XMLHttpRequest object
	createStandardXHR;

// Determine support properties
(function( xhr ) {
	jQuery.extend( jQuery.support, {
		ajax: !!xhr,
		cors: !!xhr && ( "withCredentials" in xhr )
	});
})( jQuery.ajaxSettings.xhr() );

// Create transport if the browser can provide an xhr
if ( jQuery.support.ajax ) {

	jQuery.ajaxTransport(function( s ) {
		// Cross domain only allowed if supported through XMLHttpRequest
		if ( !s.crossDomain || jQuery.support.cors ) {

			var callback;

			return {
				send: function( headers, complete ) {

					// Get a new xhr
					var xhr = s.xhr(),
						handle,
						i;

					// Open the socket
					// Passing null username, generates a login popup on Opera (#2865)
					if ( s.username ) {
						xhr.open( s.type, s.url, s.async, s.username, s.password );
					} else {
						xhr.open( s.type, s.url, s.async );
					}

					// Apply custom fields if provided
					if ( s.xhrFields ) {
						for ( i in s.xhrFields ) {
							xhr[ i ] = s.xhrFields[ i ];
						}
					}

					// Override mime type if needed
					if ( s.mimeType && xhr.overrideMimeType ) {
						xhr.overrideMimeType( s.mimeType );
					}

					// X-Requested-With header
					// For cross-domain requests, seeing as conditions for a preflight are
					// akin to a jigsaw puzzle, we simply never set it to be sure.
					// (it can always be set on a per-request basis or even using ajaxSetup)
					// For same-domain requests, won't change header if already provided.
					if ( !s.crossDomain && !headers["X-Requested-With"] ) {
						headers[ "X-Requested-With" ] = "XMLHttpRequest";
					}

					// Need an extra try/catch for cross domain requests in Firefox 3
					try {
						for ( i in headers ) {
							xhr.setRequestHeader( i, headers[ i ] );
						}
					} catch( _ ) {}

					// Do send the request
					// This may raise an exception which is actually
					// handled in jQuery.ajax (so no try/catch here)
					xhr.send( ( s.hasContent && s.data ) || null );

					// Listener
					callback = function( _, isAbort ) {

						var status,
							statusText,
							responseHeaders,
							responses,
							xml;

						// Firefox throws exceptions when accessing properties
						// of an xhr when a network error occured
						// http://helpful.knobs-dials.com/index.php/Component_returned_failure_code:_0x80040111_(NS_ERROR_NOT_AVAILABLE)
						try {

							// Was never called and is aborted or complete
							if ( callback && ( isAbort || xhr.readyState === 4 ) ) {

								// Only called once
								callback = undefined;

								// Do not keep as active anymore
								if ( handle ) {
									xhr.onreadystatechange = jQuery.noop;
									if ( xhrOnUnloadAbort ) {
										delete xhrCallbacks[ handle ];
									}
								}

								// If it's an abort
								if ( isAbort ) {
									// Abort it manually if needed
									if ( xhr.readyState !== 4 ) {
										xhr.abort();
									}
								} else {
									status = xhr.status;
									responseHeaders = xhr.getAllResponseHeaders();
									responses = {};
									xml = xhr.responseXML;

									// Construct response list
									if ( xml && xml.documentElement /* #4958 */ ) {
										responses.xml = xml;
									}

									// When requesting binary data, IE6-9 will throw an exception
									// on any attempt to access responseText (#11426)
									try {
										responses.text = xhr.responseText;
									} catch( _ ) {
									}

									// Firefox throws an exception when accessing
									// statusText for faulty cross-domain requests
									try {
										statusText = xhr.statusText;
									} catch( e ) {
										// We normalize with Webkit giving an empty statusText
										statusText = "";
									}

									// Filter status for non standard behaviors

									// If the request is local and we have data: assume a success
									// (success with no data won't get notified, that's the best we
									// can do given current implementations)
									if ( !status && s.isLocal && !s.crossDomain ) {
										status = responses.text ? 200 : 404;
									// IE - #1450: sometimes returns 1223 when it should be 204
									} else if ( status === 1223 ) {
										status = 204;
									}
								}
							}
						} catch( firefoxAccessException ) {
							if ( !isAbort ) {
								complete( -1, firefoxAccessException );
							}
						}

						// Call complete if needed
						if ( responses ) {
							complete( status, statusText, responses, responseHeaders );
						}
					};

					// if we're in sync mode or it's in cache
					// and has been retrieved directly (IE6 & IE7)
					// we need to manually fire the callback
					if ( !s.async || xhr.readyState === 4 ) {
						callback();
					} else {
						handle = ++xhrId;
						if ( xhrOnUnloadAbort ) {
							// Create the active xhrs callbacks list if needed
							// and attach the unload handler
							if ( !xhrCallbacks ) {
								xhrCallbacks = {};
								jQuery( window ).unload( xhrOnUnloadAbort );
							}
							// Add to list of active xhrs callbacks
							xhrCallbacks[ handle ] = callback;
						}
						xhr.onreadystatechange = callback;
					}
				},

				abort: function() {
					if ( callback ) {
						callback(0,1);
					}
				}
			};
		}
	});
}




var elemdisplay = {},
	iframe, iframeDoc,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = /^([+\-]=)?([\d+.\-]+)([a-z%]*)$/i,
	timerId,
	fxAttrs = [
		// height animations
		[ "height", "marginTop", "marginBottom", "paddingTop", "paddingBottom" ],
		// width animations
		[ "width", "marginLeft", "marginRight", "paddingLeft", "paddingRight" ],
		// opacity animations
		[ "opacity" ]
	],
	fxNow;

jQuery.fn.extend({
	show: function( speed, easing, callback ) {
		var elem, display;

		if ( speed || speed === 0 ) {
			return this.animate( genFx("show", 3), speed, easing, callback );

		} else {
			for ( var i = 0, j = this.length; i < j; i++ ) {
				elem = this[ i ];

				if ( elem.style ) {
					display = elem.style.display;

					// Reset the inline display of this element to learn if it is
					// being hidden by cascaded rules or not
					if ( !jQuery._data(elem, "olddisplay") && display === "none" ) {
						display = elem.style.display = "";
					}

					// Set elements which have been overridden with display: none
					// in a stylesheet to whatever the default browser style is
					// for such an element
					if ( (display === "" && jQuery.css(elem, "display") === "none") ||
						!jQuery.contains( elem.ownerDocument.documentElement, elem ) ) {
						jQuery._data( elem, "olddisplay", defaultDisplay(elem.nodeName) );
					}
				}
			}

			// Set the display of most of the elements in a second loop
			// to avoid the constant reflow
			for ( i = 0; i < j; i++ ) {
				elem = this[ i ];

				if ( elem.style ) {
					display = elem.style.display;

					if ( display === "" || display === "none" ) {
						elem.style.display = jQuery._data( elem, "olddisplay" ) || "";
					}
				}
			}

			return this;
		}
	},

	hide: function( speed, easing, callback ) {
		if ( speed || speed === 0 ) {
			return this.animate( genFx("hide", 3), speed, easing, callback);

		} else {
			var elem, display,
				i = 0,
				j = this.length;

			for ( ; i < j; i++ ) {
				elem = this[i];
				if ( elem.style ) {
					display = jQuery.css( elem, "display" );

					if ( display !== "none" && !jQuery._data( elem, "olddisplay" ) ) {
						jQuery._data( elem, "olddisplay", display );
					}
				}
			}

			// Set the display of the elements in a second loop
			// to avoid the constant reflow
			for ( i = 0; i < j; i++ ) {
				if ( this[i].style ) {
					this[i].style.display = "none";
				}
			}

			return this;
		}
	},

	// Save the old toggle function
	_toggle: jQuery.fn.toggle,

	toggle: function( fn, fn2, callback ) {
		var bool = typeof fn === "boolean";

		if ( jQuery.isFunction(fn) && jQuery.isFunction(fn2) ) {
			this._toggle.apply( this, arguments );

		} else if ( fn == null || bool ) {
			this.each(function() {
				var state = bool ? fn : jQuery(this).is(":hidden");
				jQuery(this)[ state ? "show" : "hide" ]();
			});

		} else {
			this.animate(genFx("toggle", 3), fn, fn2, callback);
		}

		return this;
	},

	fadeTo: function( speed, to, easing, callback ) {
		return this.filter(":hidden").css("opacity", 0).show().end()
					.animate({opacity: to}, speed, easing, callback);
	},

	animate: function( prop, speed, easing, callback ) {
		var optall = jQuery.speed( speed, easing, callback );

		if ( jQuery.isEmptyObject( prop ) ) {
			return this.each( optall.complete, [ false ] );
		}

		// Do not change referenced properties as per-property easing will be lost
		prop = jQuery.extend( {}, prop );

		function doAnimation() {
			// XXX 'this' does not always have a nodeName when running the
			// test suite

			if ( optall.queue === false ) {
				jQuery._mark( this );
			}

			var opt = jQuery.extend( {}, optall ),
				isElement = this.nodeType === 1,
				hidden = isElement && jQuery(this).is(":hidden"),
				name, val, p, e, hooks, replace,
				parts, start, end, unit,
				method;

			// will store per property easing and be used to determine when an animation is complete
			opt.animatedProperties = {};

			// first pass over propertys to expand / normalize
			for ( p in prop ) {
				name = jQuery.camelCase( p );
				if ( p !== name ) {
					prop[ name ] = prop[ p ];
					delete prop[ p ];
				}

				if ( ( hooks = jQuery.cssHooks[ name ] ) && "expand" in hooks ) {
					replace = hooks.expand( prop[ name ] );
					delete prop[ name ];

					// not quite $.extend, this wont overwrite keys already present.
					// also - reusing 'p' from above because we have the correct "name"
					for ( p in replace ) {
						if ( ! ( p in prop ) ) {
							prop[ p ] = replace[ p ];
						}
					}
				}
			}

			for ( name in prop ) {
				val = prop[ name ];
				// easing resolution: per property > opt.specialEasing > opt.easing > 'swing' (default)
				if ( jQuery.isArray( val ) ) {
					opt.animatedProperties[ name ] = val[ 1 ];
					val = prop[ name ] = val[ 0 ];
				} else {
					opt.animatedProperties[ name ] = opt.specialEasing && opt.specialEasing[ name ] || opt.easing || 'swing';
				}

				if ( val === "hide" && hidden || val === "show" && !hidden ) {
					return opt.complete.call( this );
				}

				if ( isElement && ( name === "height" || name === "width" ) ) {
					// Make sure that nothing sneaks out
					// Record all 3 overflow attributes because IE does not
					// change the overflow attribute when overflowX and
					// overflowY are set to the same value
					opt.overflow = [ this.style.overflow, this.style.overflowX, this.style.overflowY ];

					// Set display property to inline-block for height/width
					// animations on inline elements that are having width/height animated
					if ( jQuery.css( this, "display" ) === "inline" &&
							jQuery.css( this, "float" ) === "none" ) {

						// inline-level elements accept inline-block;
						// block-level elements need to be inline with layout
						if ( !jQuery.support.inlineBlockNeedsLayout || defaultDisplay( this.nodeName ) === "inline" ) {
							this.style.display = "inline-block";

						} else {
							this.style.zoom = 1;
						}
					}
				}
			}

			if ( opt.overflow != null ) {
				this.style.overflow = "hidden";
			}

			for ( p in prop ) {
				e = new jQuery.fx( this, opt, p );
				val = prop[ p ];

				if ( rfxtypes.test( val ) ) {

					// Tracks whether to show or hide based on private
					// data attached to the element
					method = jQuery._data( this, "toggle" + p ) || ( val === "toggle" ? hidden ? "show" : "hide" : 0 );
					if ( method ) {
						jQuery._data( this, "toggle" + p, method === "show" ? "hide" : "show" );
						e[ method ]();
					} else {
						e[ val ]();
					}

				} else {
					parts = rfxnum.exec( val );
					start = e.cur();

					if ( parts ) {
						end = parseFloat( parts[2] );
						unit = parts[3] || ( jQuery.cssNumber[ p ] ? "" : "px" );

						// We need to compute starting value
						if ( unit !== "px" ) {
							jQuery.style( this, p, (end || 1) + unit);
							start = ( (end || 1) / e.cur() ) * start;
							jQuery.style( this, p, start + unit);
						}

						// If a +=/-= token was provided, we're doing a relative animation
						if ( parts[1] ) {
							end = ( (parts[ 1 ] === "-=" ? -1 : 1) * end ) + start;
						}

						e.custom( start, end, unit );

					} else {
						e.custom( start, val, "" );
					}
				}
			}

			// For JS strict compliance
			return true;
		}

		return optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},

	stop: function( type, clearQueue, gotoEnd ) {
		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var index,
				hadTimers = false,
				timers = jQuery.timers,
				data = jQuery._data( this );

			// clear marker counters if we know they won't be
			if ( !gotoEnd ) {
				jQuery._unmark( true, this );
			}

			function stopQueue( elem, data, index ) {
				var hooks = data[ index ];
				jQuery.removeData( elem, index, true );
				hooks.stop( gotoEnd );
			}

			if ( type == null ) {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && index.indexOf(".run") === index.length - 4 ) {
						stopQueue( this, data, index );
					}
				}
			} else if ( data[ index = type + ".run" ] && data[ index ].stop ){
				stopQueue( this, data, index );
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					if ( gotoEnd ) {

						// force the next step to be the last
						timers[ index ]( true );
					} else {
						timers[ index ].saveState();
					}
					hadTimers = true;
					timers.splice( index, 1 );
				}
			}

			// start the next in the queue if the last step wasn't forced
			// timers currently will call their complete callbacks, which will dequeue
			// but only if they were gotoEnd
			if ( !( gotoEnd && hadTimers ) ) {
				jQuery.dequeue( this, type );
			}
		});
	}

});

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout( clearFxNow, 0 );
	return ( fxNow = jQuery.now() );
}

function clearFxNow() {
	fxNow = undefined;
}

// Generate parameters to create a standard animation
function genFx( type, num ) {
	var obj = {};

	jQuery.each( fxAttrs.concat.apply([], fxAttrs.slice( 0, num )), function() {
		obj[ this ] = type;
	});

	return obj;
}

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx( "show", 1 ),
	slideUp: genFx( "hide", 1 ),
	slideToggle: genFx( "toggle", 1 ),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.extend({
	speed: function( speed, easing, fn ) {
		var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
			complete: fn || !fn && easing ||
				jQuery.isFunction( speed ) && speed,
			duration: speed,
			easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
		};

		opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
			opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

		// normalize opt.queue - true/undefined/null -> "fx"
		if ( opt.queue == null || opt.queue === true ) {
			opt.queue = "fx";
		}

		// Queueing
		opt.old = opt.complete;

		opt.complete = function( noUnmark ) {
			if ( jQuery.isFunction( opt.old ) ) {
				opt.old.call( this );
			}

			if ( opt.queue ) {
				jQuery.dequeue( this, opt.queue );
			} else if ( noUnmark !== false ) {
				jQuery._unmark( this );
			}
		};

		return opt;
	},

	easing: {
		linear: function( p ) {
			return p;
		},
		swing: function( p ) {
			return ( -Math.cos( p*Math.PI ) / 2 ) + 0.5;
		}
	},

	timers: [],

	fx: function( elem, options, prop ) {
		this.options = options;
		this.elem = elem;
		this.prop = prop;

		options.orig = options.orig || {};
	}

});

jQuery.fx.prototype = {
	// Simple function for setting a style value
	update: function() {
		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		( jQuery.fx.step[ this.prop ] || jQuery.fx.step._default )( this );
	},

	// Get the current size
	cur: function() {
		if ( this.elem[ this.prop ] != null && (!this.elem.style || this.elem.style[ this.prop ] == null) ) {
			return this.elem[ this.prop ];
		}

		var parsed,
			r = jQuery.css( this.elem, this.prop );
		// Empty strings, null, undefined and "auto" are converted to 0,
		// complex values such as "rotate(1rad)" are returned as is,
		// simple values such as "10px" are parsed to Float.
		return isNaN( parsed = parseFloat( r ) ) ? !r || r === "auto" ? 0 : r : parsed;
	},

	// Start an animation from one number to another
	custom: function( from, to, unit ) {
		var self = this,
			fx = jQuery.fx;

		this.startTime = fxNow || createFxNow();
		this.end = to;
		this.now = this.start = from;
		this.pos = this.state = 0;
		this.unit = unit || this.unit || ( jQuery.cssNumber[ this.prop ] ? "" : "px" );

		function t( gotoEnd ) {
			return self.step( gotoEnd );
		}

		t.queue = this.options.queue;
		t.elem = this.elem;
		t.saveState = function() {
			if ( jQuery._data( self.elem, "fxshow" + self.prop ) === undefined ) {
				if ( self.options.hide ) {
					jQuery._data( self.elem, "fxshow" + self.prop, self.start );
				} else if ( self.options.show ) {
					jQuery._data( self.elem, "fxshow" + self.prop, self.end );
				}
			}
		};

		if ( t() && jQuery.timers.push(t) && !timerId ) {
			timerId = setInterval( fx.tick, fx.interval );
		}
	},

	// Simple 'show' function
	show: function() {
		var dataShow = jQuery._data( this.elem, "fxshow" + this.prop );

		// Remember where we started, so that we can go back to it later
		this.options.orig[ this.prop ] = dataShow || jQuery.style( this.elem, this.prop );
		this.options.show = true;

		// Begin the animation
		// Make sure that we start at a small width/height to avoid any flash of content
		if ( dataShow !== undefined ) {
			// This show is picking up where a previous hide or show left off
			this.custom( this.cur(), dataShow );
		} else {
			this.custom( this.prop === "width" || this.prop === "height" ? 1 : 0, this.cur() );
		}

		// Start by showing the element
		jQuery( this.elem ).show();
	},

	// Simple 'hide' function
	hide: function() {
		// Remember where we started, so that we can go back to it later
		this.options.orig[ this.prop ] = jQuery._data( this.elem, "fxshow" + this.prop ) || jQuery.style( this.elem, this.prop );
		this.options.hide = true;

		// Begin the animation
		this.custom( this.cur(), 0 );
	},

	// Each step of an animation
	step: function( gotoEnd ) {
		var p, n, complete,
			t = fxNow || createFxNow(),
			done = true,
			elem = this.elem,
			options = this.options;

		if ( gotoEnd || t >= options.duration + this.startTime ) {
			this.now = this.end;
			this.pos = this.state = 1;
			this.update();

			options.animatedProperties[ this.prop ] = true;

			for ( p in options.animatedProperties ) {
				if ( options.animatedProperties[ p ] !== true ) {
					done = false;
				}
			}

			if ( done ) {
				// Reset the overflow
				if ( options.overflow != null && !jQuery.support.shrinkWrapBlocks ) {

					jQuery.each( [ "", "X", "Y" ], function( index, value ) {
						elem.style[ "overflow" + value ] = options.overflow[ index ];
					});
				}

				// Hide the element if the "hide" operation was done
				if ( options.hide ) {
					jQuery( elem ).hide();
				}

				// Reset the properties, if the item has been hidden or shown
				if ( options.hide || options.show ) {
					for ( p in options.animatedProperties ) {
						jQuery.style( elem, p, options.orig[ p ] );
						jQuery.removeData( elem, "fxshow" + p, true );
						// Toggle data is no longer needed
						jQuery.removeData( elem, "toggle" + p, true );
					}
				}

				// Execute the complete function
				// in the event that the complete function throws an exception
				// we must ensure it won't be called twice. #5684

				complete = options.complete;
				if ( complete ) {

					options.complete = false;
					complete.call( elem );
				}
			}

			return false;

		} else {
			// classical easing cannot be used with an Infinity duration
			if ( options.duration == Infinity ) {
				this.now = t;
			} else {
				n = t - this.startTime;
				this.state = n / options.duration;

				// Perform the easing function, defaults to swing
				this.pos = jQuery.easing[ options.animatedProperties[this.prop] ]( this.state, n, 0, 1, options.duration );
				this.now = this.start + ( (this.end - this.start) * this.pos );
			}
			// Perform the next step of the animation
			this.update();
		}

		return true;
	}
};

jQuery.extend( jQuery.fx, {
	tick: function() {
		var timer,
			timers = jQuery.timers,
			i = 0;

		for ( ; i < timers.length; i++ ) {
			timer = timers[ i ];
			// Checks the timer has not already been removed
			if ( !timer() && timers[ i ] === timer ) {
				timers.splice( i--, 1 );
			}
		}

		if ( !timers.length ) {
			jQuery.fx.stop();
		}
	},

	interval: 13,

	stop: function() {
		clearInterval( timerId );
		timerId = null;
	},

	speeds: {
		slow: 600,
		fast: 200,
		// Default speed
		_default: 400
	},

	step: {
		opacity: function( fx ) {
			jQuery.style( fx.elem, "opacity", fx.now );
		},

		_default: function( fx ) {
			if ( fx.elem.style && fx.elem.style[ fx.prop ] != null ) {
				fx.elem.style[ fx.prop ] = fx.now + fx.unit;
			} else {
				fx.elem[ fx.prop ] = fx.now;
			}
		}
	}
});

// Ensure props that can't be negative don't go there on undershoot easing
jQuery.each( fxAttrs.concat.apply( [], fxAttrs ), function( i, prop ) {
	// exclude marginTop, marginLeft, marginBottom and marginRight from this list
	if ( prop.indexOf( "margin" ) ) {
		jQuery.fx.step[ prop ] = function( fx ) {
			jQuery.style( fx.elem, prop, Math.max(0, fx.now) + fx.unit );
		};
	}
});

if ( jQuery.expr && jQuery.expr.filters ) {
	jQuery.expr.filters.animated = function( elem ) {
		return jQuery.grep(jQuery.timers, function( fn ) {
			return elem === fn.elem;
		}).length;
	};
}

// Try to restore the default display value of an element
function defaultDisplay( nodeName ) {

	if ( !elemdisplay[ nodeName ] ) {

		var body = document.body,
			elem = jQuery( "<" + nodeName + ">" ).appendTo( body ),
			display = elem.css( "display" );
		elem.remove();

		// If the simple way fails,
		// get element's real default display by attaching it to a temp iframe
		if ( display === "none" || display === "" ) {
			// No iframe to use yet, so create it
			if ( !iframe ) {
				iframe = document.createElement( "iframe" );
				iframe.frameBorder = iframe.width = iframe.height = 0;
			}

			body.appendChild( iframe );

			// Create a cacheable copy of the iframe document on first call.
			// IE and Opera will allow us to reuse the iframeDoc without re-writing the fake HTML
			// document to it; WebKit & Firefox won't allow reusing the iframe document.
			if ( !iframeDoc || !iframe.createElement ) {
				iframeDoc = ( iframe.contentWindow || iframe.contentDocument ).document;
				iframeDoc.write( ( jQuery.support.boxModel ? "<!doctype html>" : "" ) + "<html><body>" );
				iframeDoc.close();
			}

			elem = iframeDoc.createElement( nodeName );

			iframeDoc.body.appendChild( elem );

			display = jQuery.css( elem, "display" );
			body.removeChild( iframe );
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return elemdisplay[ nodeName ];
}




var getOffset,
	rtable = /^t(?:able|d|h)$/i,
	rroot = /^(?:body|html)$/i;

if ( "getBoundingClientRect" in document.documentElement ) {
	getOffset = function( elem, doc, docElem, box ) {
		try {
			box = elem.getBoundingClientRect();
		} catch(e) {}

		// Make sure we're not dealing with a disconnected DOM node
		if ( !box || !jQuery.contains( docElem, elem ) ) {
			return box ? { top: box.top, left: box.left } : { top: 0, left: 0 };
		}

		var body = doc.body,
			win = getWindow( doc ),
			clientTop  = docElem.clientTop  || body.clientTop  || 0,
			clientLeft = docElem.clientLeft || body.clientLeft || 0,
			scrollTop  = win.pageYOffset || jQuery.support.boxModel && docElem.scrollTop  || body.scrollTop,
			scrollLeft = win.pageXOffset || jQuery.support.boxModel && docElem.scrollLeft || body.scrollLeft,
			top  = box.top  + scrollTop  - clientTop,
			left = box.left + scrollLeft - clientLeft;

		return { top: top, left: left };
	};

} else {
	getOffset = function( elem, doc, docElem ) {
		var computedStyle,
			offsetParent = elem.offsetParent,
			prevOffsetParent = elem,
			body = doc.body,
			defaultView = doc.defaultView,
			prevComputedStyle = defaultView ? defaultView.getComputedStyle( elem, null ) : elem.currentStyle,
			top = elem.offsetTop,
			left = elem.offsetLeft;

		while ( (elem = elem.parentNode) && elem !== body && elem !== docElem ) {
			if ( jQuery.support.fixedPosition && prevComputedStyle.position === "fixed" ) {
				break;
			}

			computedStyle = defaultView ? defaultView.getComputedStyle(elem, null) : elem.currentStyle;
			top  -= elem.scrollTop;
			left -= elem.scrollLeft;

			if ( elem === offsetParent ) {
				top  += elem.offsetTop;
				left += elem.offsetLeft;

				if ( jQuery.support.doesNotAddBorder && !(jQuery.support.doesAddBorderForTableAndCells && rtable.test(elem.nodeName)) ) {
					top  += parseFloat( computedStyle.borderTopWidth  ) || 0;
					left += parseFloat( computedStyle.borderLeftWidth ) || 0;
				}

				prevOffsetParent = offsetParent;
				offsetParent = elem.offsetParent;
			}

			if ( jQuery.support.subtractsBorderForOverflowNotVisible && computedStyle.overflow !== "visible" ) {
				top  += parseFloat( computedStyle.borderTopWidth  ) || 0;
				left += parseFloat( computedStyle.borderLeftWidth ) || 0;
			}

			prevComputedStyle = computedStyle;
		}

		if ( prevComputedStyle.position === "relative" || prevComputedStyle.position === "static" ) {
			top  += body.offsetTop;
			left += body.offsetLeft;
		}

		if ( jQuery.support.fixedPosition && prevComputedStyle.position === "fixed" ) {
			top  += Math.max( docElem.scrollTop, body.scrollTop );
			left += Math.max( docElem.scrollLeft, body.scrollLeft );
		}

		return { top: top, left: left };
	};
}

jQuery.fn.offset = function( options ) {
	if ( arguments.length ) {
		return options === undefined ?
			this :
			this.each(function( i ) {
				jQuery.offset.setOffset( this, options, i );
			});
	}

	var elem = this[0],
		doc = elem && elem.ownerDocument;

	if ( !doc ) {
		return null;
	}

	if ( elem === doc.body ) {
		return jQuery.offset.bodyOffset( elem );
	}

	return getOffset( elem, doc, doc.documentElement );
};

jQuery.offset = {

	bodyOffset: function( body ) {
		var top = body.offsetTop,
			left = body.offsetLeft;

		if ( jQuery.support.doesNotIncludeMarginInBodyOffset ) {
			top  += parseFloat( jQuery.css(body, "marginTop") ) || 0;
			left += parseFloat( jQuery.css(body, "marginLeft") ) || 0;
		}

		return { top: top, left: left };
	},

	setOffset: function( elem, options, i ) {
		var position = jQuery.css( elem, "position" );

		// set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		var curElem = jQuery( elem ),
			curOffset = curElem.offset(),
			curCSSTop = jQuery.css( elem, "top" ),
			curCSSLeft = jQuery.css( elem, "left" ),
			calculatePosition = ( position === "absolute" || position === "fixed" ) && jQuery.inArray("auto", [curCSSTop, curCSSLeft]) > -1,
			props = {}, curPosition = {}, curTop, curLeft;

		// need to be able to calculate position if either top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;
		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );
		} else {
			curElem.css( props );
		}
	}
};


jQuery.fn.extend({

	position: function() {
		if ( !this[0] ) {
			return null;
		}

		var elem = this[0],

		// Get *real* offsetParent
		offsetParent = this.offsetParent(),

		// Get correct offsets
		offset       = this.offset(),
		parentOffset = rroot.test(offsetParent[0].nodeName) ? { top: 0, left: 0 } : offsetParent.offset();

		// Subtract element margins
		// note: when an element has margin: auto the offsetLeft and marginLeft
		// are the same in Safari causing offset.left to incorrectly be 0
		offset.top  -= parseFloat( jQuery.css(elem, "marginTop") ) || 0;
		offset.left -= parseFloat( jQuery.css(elem, "marginLeft") ) || 0;

		// Add offsetParent borders
		parentOffset.top  += parseFloat( jQuery.css(offsetParent[0], "borderTopWidth") ) || 0;
		parentOffset.left += parseFloat( jQuery.css(offsetParent[0], "borderLeftWidth") ) || 0;

		// Subtract the two offsets
		return {
			top:  offset.top  - parentOffset.top,
			left: offset.left - parentOffset.left
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || document.body;
			while ( offsetParent && (!rroot.test(offsetParent.nodeName) && jQuery.css(offsetParent, "position") === "static") ) {
				offsetParent = offsetParent.offsetParent;
			}
			return offsetParent;
		});
	}
});


// Create scrollLeft and scrollTop methods
jQuery.each( {scrollLeft: "pageXOffset", scrollTop: "pageYOffset"}, function( method, prop ) {
	var top = /Y/.test( prop );

	jQuery.fn[ method ] = function( val ) {
		return jQuery.access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? (prop in win) ? win[ prop ] :
					jQuery.support.boxModel && win.document.documentElement[ method ] ||
						win.document.body[ method ] :
					elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : jQuery( win ).scrollLeft(),
					 top ? val : jQuery( win ).scrollTop()
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

function getWindow( elem ) {
	return jQuery.isWindow( elem ) ?
		elem :
		elem.nodeType === 9 ?
			elem.defaultView || elem.parentWindow :
			false;
}




// Create width, height, innerHeight, innerWidth, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	var clientProp = "client" + name,
		scrollProp = "scroll" + name,
		offsetProp = "offset" + name;

	// innerHeight and innerWidth
	jQuery.fn[ "inner" + name ] = function() {
		var elem = this[0];
		return elem ?
			elem.style ?
			parseFloat( jQuery.css( elem, type, "padding" ) ) :
			this[ type ]() :
			null;
	};

	// outerHeight and outerWidth
	jQuery.fn[ "outer" + name ] = function( margin ) {
		var elem = this[0];
		return elem ?
			elem.style ?
			parseFloat( jQuery.css( elem, type, margin ? "margin" : "border" ) ) :
			this[ type ]() :
			null;
	};

	jQuery.fn[ type ] = function( value ) {
		return jQuery.access( this, function( elem, type, value ) {
			var doc, docElemProp, orig, ret;

			if ( jQuery.isWindow( elem ) ) {
				// 3rd condition allows Nokia support, as it supports the docElem prop but not CSS1Compat
				doc = elem.document;
				docElemProp = doc.documentElement[ clientProp ];
				return jQuery.support.boxModel && docElemProp ||
					doc.body && doc.body[ clientProp ] || docElemProp;
			}

			// Get document width or height
			if ( elem.nodeType === 9 ) {
				// Either scroll[Width/Height] or offset[Width/Height], whichever is greater
				doc = elem.documentElement;

				// when a window > document, IE6 reports a offset[Width/Height] > client[Width/Height]
				// so we can't use max, as it'll choose the incorrect offset[Width/Height]
				// instead we use the correct client[Width/Height]
				// support:IE6
				if ( doc[ clientProp ] >= doc[ scrollProp ] ) {
					return doc[ clientProp ];
				}

				return Math.max(
					elem.body[ scrollProp ], doc[ scrollProp ],
					elem.body[ offsetProp ], doc[ offsetProp ]
				);
			}

			// Get width or height on the element
			if ( value === undefined ) {
				orig = jQuery.css( elem, type );
				ret = parseFloat( orig );
				return jQuery.isNumeric( ret ) ? ret : orig;
			}

			// Set the width or height on the element
			jQuery( elem ).css( type, value );
		}, type, value, arguments.length, null );
	};
});




// Expose jQuery to the global object
window.jQuery = window.$ = jQuery;

// Expose jQuery as an AMD module, but only for AMD loaders that
// understand the issues with loading multiple versions of jQuery
// in a page that all might call define(). The loader will indicate
// they have special allowances for multiple jQuery versions by
// specifying define.amd.jQuery = true. Register as a named module,
// since jQuery can be concatenated with other files that may use define,
// but not use a proper concatenation script that understands anonymous
// AMD modules. A named AMD is safest and most robust way to register.
// Lowercase jquery is used because AMD module names are derived from
// file names, and jQuery is normally delivered in a lowercase file name.
// Do this after creating the global so that if an AMD module wants to call
// noConflict to hide this version of jQuery, it will work.
if ( typeof define === "function" && define.amd && define.amd.jQuery ) {
	define( "jquery", [], function () { return jQuery; } );
}



})( window );






















$j = jQuery.noConflict();
var cnnCurrDay;
var cnnOmniHour;
var cnnOmniTime;
if (typeof (cnnCurrMin) != "undefined") {
  var cnnOmniMint = "00";
  if (cnnCurrMin >= 15 && cnnCurrMin < 30) {
    cnnOmniMint = "15";
  }
  if (cnnCurrMin >= 30 && cnnCurrMin < 45) {
    cnnOmniMint = "30";
  }
  if (cnnCurrMin >= 45 && cnnCurrMin < 60) {
    cnnOmniMint = "45";
  }
}
if (typeof (cnnCurrHour) != "undefined") {
  if (cnnCurrHour < 10) {
    var cnnOmniHour = "0" + cnnCurrHour;
  } else {
    cnnOmniHour = cnnCurrHour;
  }
}
if (typeof (cnnCurrHour) != "undefined") {
  var cnnOmniTime = cnnOmniHour + ":" + cnnOmniMint;
}






/*  Prototype JavaScript framework, version 1.6.0.3
 *  (c) 2005-2008 Sam Stephenson
 *
 *  Prototype is freely distributable under the terms of an MIT-style license.
 *  For details, see the Prototype web site: http://www.prototypejs.org/
 *
 *--------------------------------------------------------------------------*/

var Prototype = {
  Version: '1.6.0.3',

  Browser: {
    IE:     !!(window.attachEvent &&
      navigator.userAgent.indexOf('Opera') === -1),
    Opera:  navigator.userAgent.indexOf('Opera') > -1,
    WebKit: navigator.userAgent.indexOf('AppleWebKit/') > -1,
    Gecko:  navigator.userAgent.indexOf('Gecko') > -1 &&
      navigator.userAgent.indexOf('KHTML') === -1,
    MobileSafari: !!navigator.userAgent.match(/Apple.*Mobile.*Safari/)
  },

  BrowserFeatures: {
    XPath: !!document.evaluate,
    SelectorsAPI: !!document.querySelector,
    ElementExtensions: !!window.HTMLElement,
    SpecificElementExtensions:
      document.createElement('div')['__proto__'] &&
      document.createElement('div')['__proto__'] !==
        document.createElement('form')['__proto__']
  },

  ScriptFragment: '<script[^>]*>([\\S\\s]*?)<\/script>',
  JSONFilter: /^\/\*-secure-([\s\S]*)\*\/\s*$/,

  emptyFunction: function() { },
  K: function(x) { return x }
};

if (Prototype.Browser.MobileSafari)
  Prototype.BrowserFeatures.SpecificElementExtensions = false;


/* Based on Alex Arnell's inheritance implementation. */
var Class = {
  create: function() {
    var parent = null, properties = $A(arguments);
    if (Object.isFunction(properties[0]))
      parent = properties.shift();

    function klass() {
      this.initialize.apply(this, arguments);
    }

    Object.extend(klass, Class.Methods);
    klass.superclass = parent;
    klass.subclasses = [];

    if (parent) {
      var subclass = function() { };
      subclass.prototype = parent.prototype;
      klass.prototype = new subclass;
      parent.subclasses.push(klass);
    }

    for (var i = 0; i < properties.length; i++)
      klass.addMethods(properties[i]);

    if (!klass.prototype.initialize)
      klass.prototype.initialize = Prototype.emptyFunction;

    klass.prototype.constructor = klass;

    return klass;
  }
};

Class.Methods = {
  addMethods: function(source) {
    var ancestor   = this.superclass && this.superclass.prototype;
    var properties = Object.keys(source);

    if (!Object.keys({ toString: true }).length)
      properties.push("toString", "valueOf");

    for (var i = 0, length = properties.length; i < length; i++) {
      var property = properties[i], value = source[property];
      if (ancestor && Object.isFunction(value) &&
          value.argumentNames().first() == "$super") {
        var method = value;
        value = (function(m) {
          return function() { return ancestor[m].apply(this, arguments) };
        })(property).wrap(method);

        value.valueOf = method.valueOf.bind(method);
        value.toString = method.toString.bind(method);
      }
      this.prototype[property] = value;
    }

    return this;
  }
};

var Abstract = { };

Object.extend = function(destination, source) {
  for (var property in source)
    destination[property] = source[property];
  return destination;
};

Object.extend(Object, {
  inspect: function(object) {
    try {
      if (Object.isUndefined(object)) return 'undefined';
      if (object === null) return 'null';
      return object.inspect ? object.inspect() : String(object);
    } catch (e) {
      if (e instanceof RangeError) return '...';
      throw e;
    }
  },

  toJSON: function(object) {
    var type = typeof object;
    switch (type) {
      case 'undefined':
      case 'function':
      case 'unknown': return;
      case 'boolean': return object.toString();
    }

    if (object === null) return 'null';
    if (object.toJSON) return object.toJSON();
    if (Object.isElement(object)) return;

    var results = [];
    for (var property in object) {
      var value = Object.toJSON(object[property]);
      if (!Object.isUndefined(value))
        results.push(property.toJSON() + ': ' + value);
    }

    return '{' + results.join(', ') + '}';
  },

  toQueryString: function(object) {
    return $H(object).toQueryString();
  },

  toHTML: function(object) {
    return object && object.toHTML ? object.toHTML() : String.interpret(object);
  },

  keys: function(object) {
    var keys = [];
    for (var property in object)
      keys.push(property);
    return keys;
  },

  values: function(object) {
    var values = [];
    for (var property in object)
      values.push(object[property]);
    return values;
  },

  clone: function(object) {
    return Object.extend({ }, object);
  },

  isElement: function(object) {
    return !!(object && object.nodeType == 1);
  },

  isArray: function(object) {
    return object != null && typeof object == "object" &&
      'splice' in object && 'join' in object;
  },

  isHash: function(object) {
    return object instanceof Hash;
  },

  isFunction: function(object) {
    return typeof object == "function";
  },

  isString: function(object) {
    return typeof object == "string";
  },

  isNumber: function(object) {
    return typeof object == "number";
  },

  isUndefined: function(object) {
    return typeof object == "undefined";
  }
});

Object.extend(Function.prototype, {
  argumentNames: function() {
    var names = this.toString().match(/^[\s\(]*function[^(]*\(([^\)]*)\)/)[1]
      .replace(/\s+/g, '').split(',');
    return names.length == 1 && !names[0] ? [] : names;
  },

  bind: function() {
    if (arguments.length < 2 && Object.isUndefined(arguments[0])) return this;
    var __method = this, args = $A(arguments), object = args.shift();
    return function() {
      return __method.apply(object, args.concat($A(arguments)));
    }
  },

  bindAsEventListener: function() {
    var __method = this, args = $A(arguments), object = args.shift();
    return function(event) {
      return __method.apply(object, [event || window.event].concat(args));
    }
  },

  curry: function() {
    if (!arguments.length) return this;
    var __method = this, args = $A(arguments);
    return function() {
      return __method.apply(this, args.concat($A(arguments)));
    }
  },

  delay: function() {
    var __method = this, args = $A(arguments), timeout = args.shift() * 1000;
    return window.setTimeout(function() {
      return __method.apply(__method, args);
    }, timeout);
  },

  defer: function() {
    var args = [0.01].concat($A(arguments));
    return this.delay.apply(this, args);
  },

  wrap: function(wrapper) {
    var __method = this;
    return function() {
      return wrapper.apply(this, [__method.bind(this)].concat($A(arguments)));
    }
  },

  methodize: function() {
    if (this._methodized) return this._methodized;
    var __method = this;
    return this._methodized = function() {
      return __method.apply(null, [this].concat($A(arguments)));
    };
  }
});

Date.prototype.toJSON = function() {
  return '"' + this.getUTCFullYear() + '-' +
    (this.getUTCMonth() + 1).toPaddedString(2) + '-' +
    this.getUTCDate().toPaddedString(2) + 'T' +
    this.getUTCHours().toPaddedString(2) + ':' +
    this.getUTCMinutes().toPaddedString(2) + ':' +
    this.getUTCSeconds().toPaddedString(2) + 'Z"';
};

var Try = {
  these: function() {
    var returnValue;

    for (var i = 0, length = arguments.length; i < length; i++) {
      var lambda = arguments[i];
      try {
        returnValue = lambda();
        break;
      } catch (e) { }
    }

    return returnValue;
  }
};

RegExp.prototype.match = RegExp.prototype.test;

RegExp.escape = function(str) {
  return String(str).replace(/([.*+?^=!:${}()|[\]\/\\])/g, '\\$1');
};

/*--------------------------------------------------------------------------*/

var PeriodicalExecuter = Class.create({
  initialize: function(callback, frequency) {
    this.callback = callback;
    this.frequency = frequency;
    this.currentlyExecuting = false;

    this.registerCallback();
  },

  registerCallback: function() {
    this.timer = setInterval(this.onTimerEvent.bind(this), this.frequency * 1000);
  },

  execute: function() {
    this.callback(this);
  },

  stop: function() {
    if (!this.timer) return;
    clearInterval(this.timer);
    this.timer = null;
  },

  onTimerEvent: function() {
    if (!this.currentlyExecuting) {
      try {
        this.currentlyExecuting = true;
        this.execute();
      } finally {
        this.currentlyExecuting = false;
      }
    }
  }
});
Object.extend(String, {
  interpret: function(value) {
    return value == null ? '' : String(value);
  },
  specialChar: {
    '\b': '\\b',
    '\t': '\\t',
    '\n': '\\n',
    '\f': '\\f',
    '\r': '\\r',
    '\\': '\\\\'
  }
});

Object.extend(String.prototype, {
  gsub: function(pattern, replacement) {
    var result = '', source = this, match;
    replacement = arguments.callee.prepareReplacement(replacement);

    while (source.length > 0) {
      if (match = source.match(pattern)) {
        result += source.slice(0, match.index);
        result += String.interpret(replacement(match));
        source  = source.slice(match.index + match[0].length);
      } else {
        result += source, source = '';
      }
    }
    return result;
  },

  sub: function(pattern, replacement, count) {
    replacement = this.gsub.prepareReplacement(replacement);
    count = Object.isUndefined(count) ? 1 : count;

    return this.gsub(pattern, function(match) {
      if (--count < 0) return match[0];
      return replacement(match);
    });
  },

  scan: function(pattern, iterator) {
    this.gsub(pattern, iterator);
    return String(this);
  },

  truncate: function(length, truncation) {
    length = length || 30;
    truncation = Object.isUndefined(truncation) ? '...' : truncation;
    return this.length > length ?
      this.slice(0, length - truncation.length) + truncation : String(this);
  },

  strip: function() {
    return this.replace(/^\s+/, '').replace(/\s+$/, '');
  },

  stripTags: function() {
    return this.replace(/<\/?[^>]+>/gi, '');
  },

  stripScripts: function() {
    return this.replace(new RegExp(Prototype.ScriptFragment, 'img'), '');
  },

  extractScripts: function() {
    var matchAll = new RegExp(Prototype.ScriptFragment, 'img');
    var matchOne = new RegExp(Prototype.ScriptFragment, 'im');
    return (this.match(matchAll) || []).map(function(scriptTag) {
      return (scriptTag.match(matchOne) || ['', ''])[1];
    });
  },

  evalScripts: function() {
    return this.extractScripts().map(function(script) { return eval(script) });
  },

  escapeHTML: function() {
    var self = arguments.callee;
    self.text.data = this;
    return self.div.innerHTML;
  },

  unescapeHTML: function() {
    var div = new Element('div');
    div.innerHTML = this.stripTags();
    return div.childNodes[0] ? (div.childNodes.length > 1 ?
      $A(div.childNodes).inject('', function(memo, node) { return memo+node.nodeValue }) :
      div.childNodes[0].nodeValue) : '';
  },

  toQueryParams: function(separator) {
    var match = this.strip().match(/([^?#]*)(#.*)?$/);
    if (!match) return { };

    return match[1].split(separator || '&').inject({ }, function(hash, pair) {
      if ((pair = pair.split('='))[0]) {
        var key = decodeURIComponent(pair.shift());
        var value = pair.length > 1 ? pair.join('=') : pair[0];
        if (value != undefined) value = decodeURIComponent(value);

        if (key in hash) {
          if (!Object.isArray(hash[key])) hash[key] = [hash[key]];
          hash[key].push(value);
        }
        else hash[key] = value;
      }
      return hash;
    });
  },

  toArray: function() {
    return this.split('');
  },

  succ: function() {
    return this.slice(0, this.length - 1) +
      String.fromCharCode(this.charCodeAt(this.length - 1) + 1);
  },

  times: function(count) {
    return count < 1 ? '' : new Array(count + 1).join(this);
  },

  camelize: function() {
    var parts = this.split('-'), len = parts.length;
    if (len == 1) return parts[0];

    var camelized = this.charAt(0) == '-'
      ? parts[0].charAt(0).toUpperCase() + parts[0].substring(1)
      : parts[0];

    for (var i = 1; i < len; i++)
      camelized += parts[i].charAt(0).toUpperCase() + parts[i].substring(1);

    return camelized;
  },

  capitalize: function() {
    return this.charAt(0).toUpperCase() + this.substring(1).toLowerCase();
  },

  underscore: function() {
    return this.gsub(/::/, '/').gsub(/([A-Z]+)([A-Z][a-z])/,'#{1}_#{2}').gsub(/([a-z\d])([A-Z])/,'#{1}_#{2}').gsub(/-/,'_').toLowerCase();
  },

  dasherize: function() {
    return this.gsub(/_/,'-');
  },

  inspect: function(useDoubleQuotes) {
    var escapedString = this.gsub(/[\x00-\x1f\\]/, function(match) {
      var character = String.specialChar[match[0]];
      return character ? character : '\\u00' + match[0].charCodeAt().toPaddedString(2, 16);
    });
    if (useDoubleQuotes) return '"' + escapedString.replace(/"/g, '\\"') + '"';
    return "'" + escapedString.replace(/'/g, '\\\'') + "'";
  },

  toJSON: function() {
    return this.inspect(true);
  },

  unfilterJSON: function(filter) {
    return this.sub(filter || Prototype.JSONFilter, '#{1}');
  },

  isJSON: function() {
    var str = this;
    if (str.blank()) return false;
    str = this.replace(/\\./g, '@').replace(/"[^"\\\n\r]*"/g, '');
    return (/^[,:{}\[\]0-9.\-+Eaeflnr-u \n\r\t]*$/).test(str);
  },

  evalJSON: function(sanitize) {
    var json = this.unfilterJSON();
    try {
      if (!sanitize || json.isJSON()) return eval('(' + json + ')');
    } catch (e) { }
    throw new SyntaxError('Badly formed JSON string: ' + this.inspect());
  },

  include: function(pattern) {
    return this.indexOf(pattern) > -1;
  },

  startsWith: function(pattern) {
    return this.indexOf(pattern) === 0;
  },

  endsWith: function(pattern) {
    var d = this.length - pattern.length;
    return d >= 0 && this.lastIndexOf(pattern) === d;
  },

  empty: function() {
    return this == '';
  },

  blank: function() {
    return /^\s*$/.test(this);
  },

  interpolate: function(object, pattern) {
    return new Template(this, pattern).evaluate(object);
  }
});

if (Prototype.Browser.WebKit || Prototype.Browser.IE) Object.extend(String.prototype, {
  escapeHTML: function() {
    return this.replace(/&/g,'&amp;').replace(/</g,'&lt;').replace(/>/g,'&gt;');
  },
  unescapeHTML: function() {
    return this.stripTags().replace(/&amp;/g,'&').replace(/&lt;/g,'<').replace(/&gt;/g,'>');
  }
});

String.prototype.gsub.prepareReplacement = function(replacement) {
  if (Object.isFunction(replacement)) return replacement;
  var template = new Template(replacement);
  return function(match) { return template.evaluate(match) };
};

String.prototype.parseQuery = String.prototype.toQueryParams;

Object.extend(String.prototype.escapeHTML, {
  div:  document.createElement('div'),
  text: document.createTextNode('')
});

String.prototype.escapeHTML.div.appendChild(String.prototype.escapeHTML.text);

var Template = Class.create({
  initialize: function(template, pattern) {
    this.template = template.toString();
    this.pattern = pattern || Template.Pattern;
  },

  evaluate: function(object) {
    if (Object.isFunction(object.toTemplateReplacements))
      object = object.toTemplateReplacements();

    return this.template.gsub(this.pattern, function(match) {
      if (object == null) return '';

      var before = match[1] || '';
      if (before == '\\') return match[2];

      var ctx = object, expr = match[3];
      var pattern = /^([^.[]+|\[((?:.*?[^\\])?)\])(\.|\[|$)/;
      match = pattern.exec(expr);
      if (match == null) return before;

      while (match != null) {
        var comp = match[1].startsWith('[') ? match[2].gsub('\\\\]', ']') : match[1];
        ctx = ctx[comp];
        if (null == ctx || '' == match[3]) break;
        expr = expr.substring('[' == match[3] ? match[1].length : match[0].length);
        match = pattern.exec(expr);
      }

      return before + String.interpret(ctx);
    });
  }
});
Template.Pattern = /(^|.|\r|\n)(#\{(.*?)\})/;

var $break = { };

var Enumerable = {
  each: function(iterator, context) {
    var index = 0;
    try {
      this._each(function(value) {
        iterator.call(context, value, index++);
      });
    } catch (e) {
      if (e != $break) throw e;
    }
    return this;
  },

  eachSlice: function(number, iterator, context) {
    var index = -number, slices = [], array = this.toArray();
    if (number < 1) return array;
    while ((index += number) < array.length)
      slices.push(array.slice(index, index+number));
    return slices.collect(iterator, context);
  },

  all: function(iterator, context) {
    iterator = iterator || Prototype.K;
    var result = true;
    this.each(function(value, index) {
      result = result && !!iterator.call(context, value, index);
      if (!result) throw $break;
    });
    return result;
  },

  any: function(iterator, context) {
    iterator = iterator || Prototype.K;
    var result = false;
    this.each(function(value, index) {
      if (result = !!iterator.call(context, value, index))
        throw $break;
    });
    return result;
  },

  collect: function(iterator, context) {
    iterator = iterator || Prototype.K;
    var results = [];
    this.each(function(value, index) {
      results.push(iterator.call(context, value, index));
    });
    return results;
  },

  detect: function(iterator, context) {
    var result;
    this.each(function(value, index) {
      if (iterator.call(context, value, index)) {
        result = value;
        throw $break;
      }
    });
    return result;
  },

  findAll: function(iterator, context) {
    var results = [];
    this.each(function(value, index) {
      if (iterator.call(context, value, index))
        results.push(value);
    });
    return results;
  },

  grep: function(filter, iterator, context) {
    iterator = iterator || Prototype.K;
    var results = [];

    if (Object.isString(filter))
      filter = new RegExp(filter);

    this.each(function(value, index) {
      if (filter.match(value))
        results.push(iterator.call(context, value, index));
    });
    return results;
  },

  include: function(object) {
    if (Object.isFunction(this.indexOf))
      if (this.indexOf(object) != -1) return true;

    var found = false;
    this.each(function(value) {
      if (value == object) {
        found = true;
        throw $break;
      }
    });
    return found;
  },

  inGroupsOf: function(number, fillWith) {
    fillWith = Object.isUndefined(fillWith) ? null : fillWith;
    return this.eachSlice(number, function(slice) {
      while(slice.length < number) slice.push(fillWith);
      return slice;
    });
  },

  inject: function(memo, iterator, context) {
    this.each(function(value, index) {
      memo = iterator.call(context, memo, value, index);
    });
    return memo;
  },

  invoke: function(method) {
    var args = $A(arguments).slice(1);
    return this.map(function(value) {
      return value[method].apply(value, args);
    });
  },

  max: function(iterator, context) {
    iterator = iterator || Prototype.K;
    var result;
    this.each(function(value, index) {
      value = iterator.call(context, value, index);
      if (result == null || value >= result)
        result = value;
    });
    return result;
  },

  min: function(iterator, context) {
    iterator = iterator || Prototype.K;
    var result;
    this.each(function(value, index) {
      value = iterator.call(context, value, index);
      if (result == null || value < result)
        result = value;
    });
    return result;
  },

  partition: function(iterator, context) {
    iterator = iterator || Prototype.K;
    var trues = [], falses = [];
    this.each(function(value, index) {
      (iterator.call(context, value, index) ?
        trues : falses).push(value);
    });
    return [trues, falses];
  },

  pluck: function(property) {
    var results = [];
    this.each(function(value) {
      results.push(value[property]);
    });
    return results;
  },

  reject: function(iterator, context) {
    var results = [];
    this.each(function(value, index) {
      if (!iterator.call(context, value, index))
        results.push(value);
    });
    return results;
  },

  sortBy: function(iterator, context) {
    return this.map(function(value, index) {
      return {
        value: value,
        criteria: iterator.call(context, value, index)
      };
    }).sort(function(left, right) {
      var a = left.criteria, b = right.criteria;
      return a < b ? -1 : a > b ? 1 : 0;
    }).pluck('value');
  },

  toArray: function() {
    return this.map();
  },

  zip: function() {
    var iterator = Prototype.K, args = $A(arguments);
    if (Object.isFunction(args.last()))
      iterator = args.pop();

    var collections = [this].concat(args).map($A);
    return this.map(function(value, index) {
      return iterator(collections.pluck(index));
    });
  },

  size: function() {
    return this.toArray().length;
  },

  inspect: function() {
    return '#<Enumerable:' + this.toArray().inspect() + '>';
  }
};

Object.extend(Enumerable, {
  map:     Enumerable.collect,
  find:    Enumerable.detect,
  select:  Enumerable.findAll,
  filter:  Enumerable.findAll,
  member:  Enumerable.include,
  entries: Enumerable.toArray,
  every:   Enumerable.all,
  some:    Enumerable.any
});
function $A(iterable) {
  if (!iterable) return [];
  if (iterable.toArray) return iterable.toArray();
  var length = iterable.length || 0, results = new Array(length);
  while (length--) results[length] = iterable[length];
  return results;
}

if (Prototype.Browser.WebKit) {
  $A = function(iterable) {
    if (!iterable) return [];
    // In Safari, only use the `toArray` method if it's not a NodeList.
    // A NodeList is a function, has an function `item` property, and a numeric
    // `length` property. Adapted from Google Doctype.
    if (!(typeof iterable === 'function' && typeof iterable.length ===
        'number' && typeof iterable.item === 'function') && iterable.toArray)
      return iterable.toArray();
    var length = iterable.length || 0, results = new Array(length);
    while (length--) results[length] = iterable[length];
    return results;
  };
}

Array.from = $A;

Object.extend(Array.prototype, Enumerable);

if (!Array.prototype._reverse) Array.prototype._reverse = Array.prototype.reverse;

Object.extend(Array.prototype, {
  _each: function(iterator) {
    for (var i = 0, length = this.length; i < length; i++)
      iterator(this[i]);
  },

  clear: function() {
    this.length = 0;
    return this;
  },

  first: function() {
    return this[0];
  },

  last: function() {
    return this[this.length - 1];
  },

  compact: function() {
    return this.select(function(value) {
      return value != null;
    });
  },

  flatten: function() {
    return this.inject([], function(array, value) {
      return array.concat(Object.isArray(value) ?
        value.flatten() : [value]);
    });
  },

  without: function() {
    var values = $A(arguments);
    return this.select(function(value) {
      return !values.include(value);
    });
  },

  reverse: function(inline) {
    return (inline !== false ? this : this.toArray())._reverse();
  },

  reduce: function() {
    return this.length > 1 ? this : this[0];
  },

  uniq: function(sorted) {
    return this.inject([], function(array, value, index) {
      if (0 == index || (sorted ? array.last() != value : !array.include(value)))
        array.push(value);
      return array;
    });
  },

  intersect: function(array) {
    return this.uniq().findAll(function(item) {
      return array.detect(function(value) { return item === value });
    });
  },

  clone: function() {
    return [].concat(this);
  },

  size: function() {
    return this.length;
  },

  inspect: function() {
    return '[' + this.map(Object.inspect).join(', ') + ']';
  },

  toJSON: function() {
    var results = [];
    this.each(function(object) {
      var value = Object.toJSON(object);
      if (!Object.isUndefined(value)) results.push(value);
    });
    return '[' + results.join(', ') + ']';
  }
});

// use native browser JS 1.6 implementation if available
if (Object.isFunction(Array.prototype.forEach))
  Array.prototype._each = Array.prototype.forEach;

if (!Array.prototype.indexOf) Array.prototype.indexOf = function(item, i) {
  i || (i = 0);
  var length = this.length;
  if (i < 0) i = length + i;
  for (; i < length; i++)
    if (this[i] === item) return i;
  return -1;
};

if (!Array.prototype.lastIndexOf) Array.prototype.lastIndexOf = function(item, i) {
  i = isNaN(i) ? this.length : (i < 0 ? this.length + i : i) + 1;
  var n = this.slice(0, i).reverse().indexOf(item);
  return (n < 0) ? n : i - n - 1;
};

Array.prototype.toArray = Array.prototype.clone;

function $w(string) {
  if (!Object.isString(string)) return [];
  string = string.strip();
  return string ? string.split(/\s+/) : [];
}

if (Prototype.Browser.Opera){
  Array.prototype.concat = function() {
    var array = [];
    for (var i = 0, length = this.length; i < length; i++) array.push(this[i]);
    for (var i = 0, length = arguments.length; i < length; i++) {
      if (Object.isArray(arguments[i])) {
        for (var j = 0, arrayLength = arguments[i].length; j < arrayLength; j++)
          array.push(arguments[i][j]);
      } else {
        array.push(arguments[i]);
      }
    }
    return array;
  };
}
Object.extend(Number.prototype, {
  toColorPart: function() {
    return this.toPaddedString(2, 16);
  },

  succ: function() {
    return this + 1;
  },

  times: function(iterator, context) {
    $R(0, this, true).each(iterator, context);
    return this;
  },

  toPaddedString: function(length, radix) {
    var string = this.toString(radix || 10);
    return '0'.times(length - string.length) + string;
  },

  toJSON: function() {
    return isFinite(this) ? this.toString() : 'null';
  }
});

$w('abs round ceil floor').each(function(method){
  Number.prototype[method] = Math[method].methodize();
});
function $H(object) {
  return new Hash(object);
};

var Hash = Class.create(Enumerable, (function() {

  function toQueryPair(key, value) {
    if (Object.isUndefined(value)) return key;
    return key + '=' + encodeURIComponent(String.interpret(value));
  }

  return {
    initialize: function(object) {
      this._object = Object.isHash(object) ? object.toObject() : Object.clone(object);
    },

    _each: function(iterator) {
      for (var key in this._object) {
        var value = this._object[key], pair = [key, value];
        pair.key = key;
        pair.value = value;
        iterator(pair);
      }
    },

    set: function(key, value) {
      return this._object[key] = value;
    },

    get: function(key) {
      // simulating poorly supported hasOwnProperty
      if (this._object[key] !== Object.prototype[key])
        return this._object[key];
    },

    unset: function(key) {
      var value = this._object[key];
      delete this._object[key];
      return value;
    },

    toObject: function() {
      return Object.clone(this._object);
    },

    keys: function() {
      return this.pluck('key');
    },

    values: function() {
      return this.pluck('value');
    },

    index: function(value) {
      var match = this.detect(function(pair) {
        return pair.value === value;
      });
      return match && match.key;
    },

    merge: function(object) {
      return this.clone().update(object);
    },

    update: function(object) {
      return new Hash(object).inject(this, function(result, pair) {
        result.set(pair.key, pair.value);
        return result;
      });
    },

    toQueryString: function() {
      return this.inject([], function(results, pair) {
        var key = encodeURIComponent(pair.key), values = pair.value;

        if (values && typeof values == 'object') {
          if (Object.isArray(values))
            return results.concat(values.map(toQueryPair.curry(key)));
        } else results.push(toQueryPair(key, values));
        return results;
      }).join('&');
    },

    inspect: function() {
      return '#<Hash:{' + this.map(function(pair) {
        return pair.map(Object.inspect).join(': ');
      }).join(', ') + '}>';
    },

    toJSON: function() {
      return Object.toJSON(this.toObject());
    },

    clone: function() {
      return new Hash(this);
    }
  }
})());

Hash.prototype.toTemplateReplacements = Hash.prototype.toObject;
Hash.from = $H;
var ObjectRange = Class.create(Enumerable, {
  initialize: function(start, end, exclusive) {
    this.start = start;
    this.end = end;
    this.exclusive = exclusive;
  },

  _each: function(iterator) {
    var value = this.start;
    while (this.include(value)) {
      iterator(value);
      value = value.succ();
    }
  },

  include: function(value) {
    if (value < this.start)
      return false;
    if (this.exclusive)
      return value < this.end;
    return value <= this.end;
  }
});

var $R = function(start, end, exclusive) {
  return new ObjectRange(start, end, exclusive);
};

var Ajax = {
  getTransport: function() {
    return Try.these(
      function() {return new XMLHttpRequest()},
      function() {return new ActiveXObject('Msxml2.XMLHTTP')},
      function() {return new ActiveXObject('Microsoft.XMLHTTP')}
    ) || false;
  },

  activeRequestCount: 0
};

Ajax.Responders = {
  responders: [],

  _each: function(iterator) {
    this.responders._each(iterator);
  },

  register: function(responder) {
    if (!this.include(responder))
      this.responders.push(responder);
  },

  unregister: function(responder) {
    this.responders = this.responders.without(responder);
  },

  dispatch: function(callback, request, transport, json) {
    this.each(function(responder) {
      if (Object.isFunction(responder[callback])) {
        try {
          responder[callback].apply(responder, [request, transport, json]);
        } catch (e) { }
      }
    });
  }
};

Object.extend(Ajax.Responders, Enumerable);

Ajax.Responders.register({
  onCreate:   function() { Ajax.activeRequestCount++ },
  onComplete: function() { Ajax.activeRequestCount-- }
});

Ajax.Base = Class.create({
  initialize: function(options) {
    this.options = {
      method:       'post',
      asynchronous: true,
      contentType:  'application/x-www-form-urlencoded',
      encoding:     'UTF-8',
      parameters:   '',
      evalJSON:     true,
      evalJS:       true
    };
    Object.extend(this.options, options || { });

    this.options.method = this.options.method.toLowerCase();

    if (Object.isString(this.options.parameters))
      this.options.parameters = this.options.parameters.toQueryParams();
    else if (Object.isHash(this.options.parameters))
      this.options.parameters = this.options.parameters.toObject();
  }
});

Ajax.Request = Class.create(Ajax.Base, {
  _complete: false,

  initialize: function($super, url, options) {
    $super(options);
    this.transport = Ajax.getTransport();
    this.request(url);
  },

  request: function(url) {
    this.url = url;
    this.method = this.options.method;
    var params = Object.clone(this.options.parameters);

    if (!['get', 'post'].include(this.method)) {
      // simulate other verbs over post
      params['_method'] = this.method;
      this.method = 'post';
    }

    this.parameters = params;

    if (params = Object.toQueryString(params)) {
      // when GET, append parameters to URL
      if (this.method == 'get')
        this.url += (this.url.include('?') ? '&' : '?') + params;
      else if (/Konqueror|Safari|KHTML/.test(navigator.userAgent))
        params += '&_=';
    }

    try {
      var response = new Ajax.Response(this);
      if (this.options.onCreate) this.options.onCreate(response);
      Ajax.Responders.dispatch('onCreate', this, response);

      this.transport.open(this.method.toUpperCase(), this.url,
        this.options.asynchronous);

      if (this.options.asynchronous) this.respondToReadyState.bind(this).defer(1);

      this.transport.onreadystatechange = this.onStateChange.bind(this);
      this.setRequestHeaders();

      this.body = this.method == 'post' ? (this.options.postBody || params) : null;
      this.transport.send(this.body);

      /* Force Firefox to handle ready state 4 for synchronous requests */
      if (!this.options.asynchronous && this.transport.overrideMimeType)
        this.onStateChange();

    }
    catch (e) {
      this.dispatchException(e);
    }
  },

  onStateChange: function() {
    var readyState = this.transport.readyState;
    if (readyState > 1 && !((readyState == 4) && this._complete))
      this.respondToReadyState(this.transport.readyState);
  },

  setRequestHeaders: function() {
    var headers = {
      'X-Requested-With': 'XMLHttpRequest',
      'X-Prototype-Version': Prototype.Version,
      'Accept': 'text/javascript, text/html, application/xml, text/xml, */*'
    };

    if (this.method == 'post') {
      headers['Content-type'] = this.options.contentType +
        (this.options.encoding ? '; charset=' + this.options.encoding : '');

      /* Force "Connection: close" for older Mozilla browsers to work
       * around a bug where XMLHttpRequest sends an incorrect
       * Content-length header. See Mozilla Bugzilla #246651.
       */
      if (this.transport.overrideMimeType &&
          (navigator.userAgent.match(/Gecko\/(\d{4})/) || [0,2005])[1] < 2005)
            headers['Connection'] = 'close';
    }

    // user-defined headers
    if (typeof this.options.requestHeaders == 'object') {
      var extras = this.options.requestHeaders;

      if (Object.isFunction(extras.push))
        for (var i = 0, length = extras.length; i < length; i += 2)
          headers[extras[i]] = extras[i+1];
      else
        $H(extras).each(function(pair) { headers[pair.key] = pair.value });
    }

    for (var name in headers)
      this.transport.setRequestHeader(name, headers[name]);
  },

  success: function() {
    var status = this.getStatus();
    return !status || (status >= 200 && status < 300);
  },

  getStatus: function() {
    try {
      return this.transport.status || 0;
    } catch (e) { return 0 }
  },

  respondToReadyState: function(readyState) {
    var state = Ajax.Request.Events[readyState], response = new Ajax.Response(this);

    if (state == 'Complete') {
      try {
        this._complete = true;
        (this.options['on' + response.status]
         || this.options['on' + (this.success() ? 'Success' : 'Failure')]
         || Prototype.emptyFunction)(response, response.headerJSON);
      } catch (e) {
        this.dispatchException(e);
      }

      var contentType = response.getHeader('Content-type');
      if (this.options.evalJS == 'force'
          || (this.options.evalJS && this.isSameOrigin() && contentType
          && contentType.match(/^\s*(text|application)\/(x-)?(java|ecma)script(;.*)?\s*$/i)))
        this.evalResponse();
    }

    try {
      (this.options['on' + state] || Prototype.emptyFunction)(response, response.headerJSON);
      Ajax.Responders.dispatch('on' + state, this, response, response.headerJSON);
    } catch (e) {
      this.dispatchException(e);
    }

    if (state == 'Complete') {
      // avoid memory leak in MSIE: clean up
      this.transport.onreadystatechange = Prototype.emptyFunction;
    }
  },

  isSameOrigin: function() {
    var m = this.url.match(/^\s*https?:\/\/[^\/]*/);
    return !m || (m[0] == '#{protocol}//#{domain}#{port}'.interpolate({
      protocol: location.protocol,
      domain: document.domain,
      port: location.port ? ':' + location.port : ''
    }));
  },

  getHeader: function(name) {
    try {
      return this.transport.getResponseHeader(name) || null;
    } catch (e) { return null }
  },

  evalResponse: function() {
    try {
      return eval((this.transport.responseText || '').unfilterJSON());
    } catch (e) {
      this.dispatchException(e);
    }
  },

  dispatchException: function(exception) {
    (this.options.onException || Prototype.emptyFunction)(this, exception);
    Ajax.Responders.dispatch('onException', this, exception);
  }
});

Ajax.Request.Events =
  ['Uninitialized', 'Loading', 'Loaded', 'Interactive', 'Complete'];

Ajax.Response = Class.create({
  initialize: function(request){
    this.request = request;
    var transport  = this.transport  = request.transport,
        readyState = this.readyState = transport.readyState;

    if((readyState > 2 && !Prototype.Browser.IE) || readyState == 4) {
      this.status       = this.getStatus();
      this.statusText   = this.getStatusText();
      this.responseText = String.interpret(transport.responseText);
      this.headerJSON   = this._getHeaderJSON();
    }

    if(readyState == 4) {
      var xml = transport.responseXML;
      this.responseXML  = Object.isUndefined(xml) ? null : xml;
      this.responseJSON = this._getResponseJSON();
    }
  },

  status:      0,
  statusText: '',

  getStatus: Ajax.Request.prototype.getStatus,

  getStatusText: function() {
    try {
      return this.transport.statusText || '';
    } catch (e) { return '' }
  },

  getHeader: Ajax.Request.prototype.getHeader,

  getAllHeaders: function() {
    try {
      return this.getAllResponseHeaders();
    } catch (e) { return null }
  },

  getResponseHeader: function(name) {
    return this.transport.getResponseHeader(name);
  },

  getAllResponseHeaders: function() {
    return this.transport.getAllResponseHeaders();
  },

  _getHeaderJSON: function() {
    var json = this.getHeader('X-JSON');
    if (!json) return null;
    json = decodeURIComponent(escape(json));
    try {
      return json.evalJSON(this.request.options.sanitizeJSON ||
        !this.request.isSameOrigin());
    } catch (e) {
      this.request.dispatchException(e);
    }
  },

  _getResponseJSON: function() {
    var options = this.request.options;
    if (!options.evalJSON || (options.evalJSON != 'force' &&
      !(this.getHeader('Content-type') || '').include('application/json')) ||
        this.responseText.blank())
          return null;
    try {
      return this.responseText.evalJSON(options.sanitizeJSON ||
        !this.request.isSameOrigin());
    } catch (e) {
      this.request.dispatchException(e);
    }
  }
});

Ajax.Updater = Class.create(Ajax.Request, {
  initialize: function($super, container, url, options) {
    this.container = {
      success: (container.success || container),
      failure: (container.failure || (container.success ? null : container))
    };

    options = Object.clone(options);
    var onComplete = options.onComplete;
    options.onComplete = (function(response, json) {
      this.updateContent(response.responseText);
      if (Object.isFunction(onComplete)) onComplete(response, json);
    }).bind(this);

    $super(url, options);
  },

  updateContent: function(responseText) {
    var receiver = this.container[this.success() ? 'success' : 'failure'],
        options = this.options;

    if (!options.evalScripts) responseText = responseText.stripScripts();

    if (receiver = $(receiver)) {
      if (options.insertion) {
        if (Object.isString(options.insertion)) {
          var insertion = { }; insertion[options.insertion] = responseText;
          receiver.insert(insertion);
        }
        else options.insertion(receiver, responseText);
      }
      else receiver.update(responseText);
    }
  }
});

Ajax.PeriodicalUpdater = Class.create(Ajax.Base, {
  initialize: function($super, container, url, options) {
    $super(options);
    this.onComplete = this.options.onComplete;

    this.frequency = (this.options.frequency || 2);
    this.decay = (this.options.decay || 1);

    this.updater = { };
    this.container = container;
    this.url = url;

    this.start();
  },

  start: function() {
    this.options.onComplete = this.updateComplete.bind(this);
    this.onTimerEvent();
  },

  stop: function() {
    this.updater.options.onComplete = undefined;
    clearTimeout(this.timer);
    (this.onComplete || Prototype.emptyFunction).apply(this, arguments);
  },

  updateComplete: function(response) {
    if (this.options.decay) {
      this.decay = (response.responseText == this.lastText ?
        this.decay * this.options.decay : 1);

      this.lastText = response.responseText;
    }
    this.timer = this.onTimerEvent.bind(this).delay(this.decay * this.frequency);
  },

  onTimerEvent: function() {
    this.updater = new Ajax.Updater(this.container, this.url, this.options);
  }
});
function $(element) {
  if (arguments.length > 1) {
    for (var i = 0, elements = [], length = arguments.length; i < length; i++)
      elements.push($(arguments[i]));
    return elements;
  }
  if (Object.isString(element))
    element = document.getElementById(element);
  return Element.extend(element);
}

if (Prototype.BrowserFeatures.XPath) {
  document._getElementsByXPath = function(expression, parentElement) {
    var results = [];
    var query = document.evaluate(expression, $(parentElement) || document,
      null, XPathResult.ORDERED_NODE_SNAPSHOT_TYPE, null);
    for (var i = 0, length = query.snapshotLength; i < length; i++)
      results.push(Element.extend(query.snapshotItem(i)));
    return results;
  };
}

/*--------------------------------------------------------------------------*/

if (!window.Node) var Node = { };

if (!Node.ELEMENT_NODE) {
  // DOM level 2 ECMAScript Language Binding
  Object.extend(Node, {
    ELEMENT_NODE: 1,
    ATTRIBUTE_NODE: 2,
    TEXT_NODE: 3,
    CDATA_SECTION_NODE: 4,
    ENTITY_REFERENCE_NODE: 5,
    ENTITY_NODE: 6,
    PROCESSING_INSTRUCTION_NODE: 7,
    COMMENT_NODE: 8,
    DOCUMENT_NODE: 9,
    DOCUMENT_TYPE_NODE: 10,
    DOCUMENT_FRAGMENT_NODE: 11,
    NOTATION_NODE: 12
  });
}

(function() {
  var element = this.Element;
  this.Element = function(tagName, attributes) {
    attributes = attributes || { };
    tagName = tagName.toLowerCase();
    var cache = Element.cache;
    if (Prototype.Browser.IE && attributes.name) {
      tagName = '<' + tagName + ' name="' + attributes.name + '">';
      delete attributes.name;
      return Element.writeAttribute(document.createElement(tagName), attributes);
    }
    if (!cache[tagName]) cache[tagName] = Element.extend(document.createElement(tagName));
    return Element.writeAttribute(cache[tagName].cloneNode(false), attributes);
  };
  Object.extend(this.Element, element || { });
  if (element) this.Element.prototype = element.prototype;
}).call(window);

Element.cache = { };

Element.Methods = {
  visible: function(element) {
    return $(element).style.display != 'none';
  },

  toggle: function(element) {
    element = $(element);
    Element[Element.visible(element) ? 'hide' : 'show'](element);
    return element;
  },

  hide: function(element) {
    element = $(element);
    element.style.display = 'none';
    return element;
  },

  show: function(element) {
    element = $(element);
    element.style.display = '';
    return element;
  },

  remove: function(element) {
    element = $(element);
    element.parentNode.removeChild(element);
    return element;
  },

  update: function(element, content) {
    element = $(element);
    if (content && content.toElement) content = content.toElement();
    if (Object.isElement(content)) return element.update().insert(content);
    content = Object.toHTML(content);
    element.innerHTML = content.stripScripts();
    content.evalScripts.bind(content).defer();
    return element;
  },

  replace: function(element, content) {
    element = $(element);
    if (content && content.toElement) content = content.toElement();
    else if (!Object.isElement(content)) {
      content = Object.toHTML(content);
      var range = element.ownerDocument.createRange();
      range.selectNode(element);
      content.evalScripts.bind(content).defer();
      content = range.createContextualFragment(content.stripScripts());
    }
    element.parentNode.replaceChild(content, element);
    return element;
  },

  insert: function(element, insertions) {
    element = $(element);

    if (Object.isString(insertions) || Object.isNumber(insertions) ||
        Object.isElement(insertions) || (insertions && (insertions.toElement || insertions.toHTML)))
          insertions = {bottom:insertions};

    var content, insert, tagName, childNodes;

    for (var position in insertions) {
      content  = insertions[position];
      position = position.toLowerCase();
      insert = Element._insertionTranslations[position];

      if (content && content.toElement) content = content.toElement();
      if (Object.isElement(content)) {
        insert(element, content);
        continue;
      }

      content = Object.toHTML(content);

      tagName = ((position == 'before' || position == 'after')
        ? element.parentNode : element).tagName.toUpperCase();

      childNodes = Element._getContentFromAnonymousElement(tagName, content.stripScripts());

      if (position == 'top' || position == 'after') childNodes.reverse();
      childNodes.each(insert.curry(element));

      content.evalScripts.bind(content).defer();
    }

    return element;
  },

  wrap: function(element, wrapper, attributes) {
    element = $(element);
    if (Object.isElement(wrapper))
      $(wrapper).writeAttribute(attributes || { });
    else if (Object.isString(wrapper)) wrapper = new Element(wrapper, attributes);
    else wrapper = new Element('div', wrapper);
    if (element.parentNode)
      element.parentNode.replaceChild(wrapper, element);
    wrapper.appendChild(element);
    return wrapper;
  },

  inspect: function(element) {
    element = $(element);
    var result = '<' + element.tagName.toLowerCase();
    $H({'id': 'id', 'className': 'class'}).each(function(pair) {
      var property = pair.first(), attribute = pair.last();
      var value = (element[property] || '').toString();
      if (value) result += ' ' + attribute + '=' + value.inspect(true);
    });
    return result + '>';
  },

  recursivelyCollect: function(element, property) {
    element = $(element);
    var elements = [];
    while (element = element[property])
      if (element.nodeType == 1)
        elements.push(Element.extend(element));
    return elements;
  },

  ancestors: function(element) {
    return $(element).recursivelyCollect('parentNode');
  },

  descendants: function(element) {
    return $(element).select("*");
  },

  firstDescendant: function(element) {
    element = $(element).firstChild;
    while (element && element.nodeType != 1) element = element.nextSibling;
    return $(element);
  },

  immediateDescendants: function(element) {
    if (!(element = $(element).firstChild)) return [];
    while (element && element.nodeType != 1) element = element.nextSibling;
    if (element) return [element].concat($(element).nextSiblings());
    return [];
  },

  previousSiblings: function(element) {
    return $(element).recursivelyCollect('previousSibling');
  },

  nextSiblings: function(element) {
    return $(element).recursivelyCollect('nextSibling');
  },

  siblings: function(element) {
    element = $(element);
    return element.previousSiblings().reverse().concat(element.nextSiblings());
  },

  match: function(element, selector) {
    if (Object.isString(selector))
      selector = new Selector(selector);
    return selector.match($(element));
  },

  up: function(element, expression, index) {
    element = $(element);
    if (arguments.length == 1) return $(element.parentNode);
    var ancestors = element.ancestors();
    return Object.isNumber(expression) ? ancestors[expression] :
      Selector.findElement(ancestors, expression, index);
  },

  down: function(element, expression, index) {
    element = $(element);
    if (arguments.length == 1) return element.firstDescendant();
    return Object.isNumber(expression) ? element.descendants()[expression] :
      Element.select(element, expression)[index || 0];
  },

  previous: function(element, expression, index) {
    element = $(element);
    if (arguments.length == 1) return $(Selector.handlers.previousElementSibling(element));
    var previousSiblings = element.previousSiblings();
    return Object.isNumber(expression) ? previousSiblings[expression] :
      Selector.findElement(previousSiblings, expression, index);
  },

  next: function(element, expression, index) {
    element = $(element);
    if (arguments.length == 1) return $(Selector.handlers.nextElementSibling(element));
    var nextSiblings = element.nextSiblings();
    return Object.isNumber(expression) ? nextSiblings[expression] :
      Selector.findElement(nextSiblings, expression, index);
  },

  select: function() {
    var args = $A(arguments), element = $(args.shift());
    return Selector.findChildElements(element, args);
  },

  adjacent: function() {
    var args = $A(arguments), element = $(args.shift());
    return Selector.findChildElements(element.parentNode, args).without(element);
  },

  identify: function(element) {
    element = $(element);
    var id = element.readAttribute('id'), self = arguments.callee;
    if (id) return id;
    do { id = 'anonymous_element_' + self.counter++ } while ($(id));
    element.writeAttribute('id', id);
    return id;
  },

  readAttribute: function(element, name) {
    element = $(element);
    if (Prototype.Browser.IE) {
      var t = Element._attributeTranslations.read;
      if (t.values[name]) return t.values[name](element, name);
      if (t.names[name]) name = t.names[name];
      if (name.include(':')) {
        return (!element.attributes || !element.attributes[name]) ? null :
         element.attributes[name].value;
      }
    }
    return element.getAttribute(name);
  },

  writeAttribute: function(element, name, value) {
    element = $(element);
    var attributes = { }, t = Element._attributeTranslations.write;

    if (typeof name == 'object') attributes = name;
    else attributes[name] = Object.isUndefined(value) ? true : value;

    for (var attr in attributes) {
      name = t.names[attr] || attr;
      value = attributes[attr];
      if (t.values[attr]) name = t.values[attr](element, value);
      if (value === false || value === null)
        element.removeAttribute(name);
      else if (value === true)
        element.setAttribute(name, name);
      else element.setAttribute(name, value);
    }
    return element;
  },

  getHeight: function(element) {
    return $(element).getDimensions().height;
  },

  getWidth: function(element) {
    return $(element).getDimensions().width;
  },

  classNames: function(element) {
    return new Element.ClassNames(element);
  },

  hasClassName: function(element, className) {
    if (!(element = $(element))) return;
    var elementClassName = element.className;
    return (elementClassName.length > 0 && (elementClassName == className ||
      new RegExp("(^|\\s)" + className + "(\\s|$)").test(elementClassName)));
  },

  addClassName: function(element, className) {
    if (!(element = $(element))) return;
    if (!element.hasClassName(className))
      element.className += (element.className ? ' ' : '') + className;
    return element;
  },

  removeClassName: function(element, className) {
    if (!(element = $(element))) return;
    element.className = element.className.replace(
      new RegExp("(^|\\s+)" + className + "(\\s+|$)"), ' ').strip();
    return element;
  },

  toggleClassName: function(element, className) {
    if (!(element = $(element))) return;
    return element[element.hasClassName(className) ?
      'removeClassName' : 'addClassName'](className);
  },

  // removes whitespace-only text node children
  cleanWhitespace: function(element) {
    element = $(element);
    var node = element.firstChild;
    while (node) {
      var nextNode = node.nextSibling;
      if (node.nodeType == 3 && !/\S/.test(node.nodeValue))
        element.removeChild(node);
      node = nextNode;
    }
    return element;
  },

  empty: function(element) {
    return $(element).innerHTML.blank();
  },

  descendantOf: function(element, ancestor) {
    element = $(element), ancestor = $(ancestor);

    if (element.compareDocumentPosition)
      return (element.compareDocumentPosition(ancestor) & 8) === 8;

    if (ancestor.contains)
      return ancestor.contains(element) && ancestor !== element;

    while (element = element.parentNode)
      if (element == ancestor) return true;

    return false;
  },

  scrollTo: function(element) {
    element = $(element);
    var pos = element.cumulativeOffset();
    window.scrollTo(pos[0], pos[1]);
    return element;
  },

  getStyle: function(element, style) {
    element = $(element);
    style = style == 'float' ? 'cssFloat' : style.camelize();
    var value = element.style[style];
    if (!value || value == 'auto') {
      var css = document.defaultView.getComputedStyle(element, null);
      value = css ? css[style] : null;
    }
    if (style == 'opacity') return value ? parseFloat(value) : 1.0;
    return value == 'auto' ? null : value;
  },

  getOpacity: function(element) {
    return $(element).getStyle('opacity');
  },

  setStyle: function(element, styles) {
    element = $(element);
    var elementStyle = element.style, match;
    if (Object.isString(styles)) {
      element.style.cssText += ';' + styles;
      return styles.include('opacity') ?
        element.setOpacity(styles.match(/opacity:\s*(\d?\.?\d*)/)[1]) : element;
    }
    for (var property in styles)
      if (property == 'opacity') element.setOpacity(styles[property]);
      else
        elementStyle[(property == 'float' || property == 'cssFloat') ?
          (Object.isUndefined(elementStyle.styleFloat) ? 'cssFloat' : 'styleFloat') :
            property] = styles[property];

    return element;
  },

  setOpacity: function(element, value) {
    element = $(element);
    element.style.opacity = (value == 1 || value === '') ? '' :
      (value < 0.00001) ? 0 : value;
    return element;
  },

  getDimensions: function(element) {
    element = $(element);
    var display = element.getStyle('display');
    if (display != 'none' && display != null) // Safari bug
      return {width: element.offsetWidth, height: element.offsetHeight};

    // All *Width and *Height properties give 0 on elements with display none,
    // so enable the element temporarily
    var els = element.style;
    var originalVisibility = els.visibility;
    var originalPosition = els.position;
    var originalDisplay = els.display;
    els.visibility = 'hidden';
    els.position = 'absolute';
    els.display = 'block';
    var originalWidth = element.clientWidth;
    var originalHeight = element.clientHeight;
    els.display = originalDisplay;
    els.position = originalPosition;
    els.visibility = originalVisibility;
    return {width: originalWidth, height: originalHeight};
  },

  makePositioned: function(element) {
    element = $(element);
    var pos = Element.getStyle(element, 'position');
    if (pos == 'static' || !pos) {
      element._madePositioned = true;
      element.style.position = 'relative';
      // Opera returns the offset relative to the positioning context, when an
      // element is position relative but top and left have not been defined
      if (Prototype.Browser.Opera) {
        element.style.top = 0;
        element.style.left = 0;
      }
    }
    return element;
  },

  undoPositioned: function(element) {
    element = $(element);
    if (element._madePositioned) {
      element._madePositioned = undefined;
      element.style.position =
        element.style.top =
        element.style.left =
        element.style.bottom =
        element.style.right = '';
    }
    return element;
  },

  makeClipping: function(element) {
    element = $(element);
    if (element._overflow) return element;
    element._overflow = Element.getStyle(element, 'overflow') || 'auto';
    if (element._overflow !== 'hidden')
      element.style.overflow = 'hidden';
    return element;
  },

  undoClipping: function(element) {
    element = $(element);
    if (!element._overflow) return element;
    element.style.overflow = element._overflow == 'auto' ? '' : element._overflow;
    element._overflow = null;
    return element;
  },

  cumulativeOffset: function(element) {
    var valueT = 0, valueL = 0;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;
      element = element.offsetParent;
    } while (element);
    return Element._returnOffset(valueL, valueT);
  },

  positionedOffset: function(element) {
    var valueT = 0, valueL = 0;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;
      element = element.offsetParent;
      if (element) {
        if (element.tagName.toUpperCase() == 'BODY') break;
        var p = Element.getStyle(element, 'position');
        if (p !== 'static') break;
      }
    } while (element);
    return Element._returnOffset(valueL, valueT);
  },

  absolutize: function(element) {
    element = $(element);
    if (element.getStyle('position') == 'absolute') return element;
    // Position.prepare(); // To be done manually by Scripty when it needs it.

    var offsets = element.positionedOffset();
    var top     = offsets[1];
    var left    = offsets[0];
    var width   = element.clientWidth;
    var height  = element.clientHeight;

    element._originalLeft   = left - parseFloat(element.style.left  || 0);
    element._originalTop    = top  - parseFloat(element.style.top || 0);
    element._originalWidth  = element.style.width;
    element._originalHeight = element.style.height;

    element.style.position = 'absolute';
    element.style.top    = top + 'px';
    element.style.left   = left + 'px';
    element.style.width  = width + 'px';
    element.style.height = height + 'px';
    return element;
  },

  relativize: function(element) {
    element = $(element);
    if (element.getStyle('position') == 'relative') return element;
    // Position.prepare(); // To be done manually by Scripty when it needs it.

    element.style.position = 'relative';
    var top  = parseFloat(element.style.top  || 0) - (element._originalTop || 0);
    var left = parseFloat(element.style.left || 0) - (element._originalLeft || 0);

    element.style.top    = top + 'px';
    element.style.left   = left + 'px';
    element.style.height = element._originalHeight;
    element.style.width  = element._originalWidth;
    return element;
  },

  cumulativeScrollOffset: function(element) {
    var valueT = 0, valueL = 0;
    do {
      valueT += element.scrollTop  || 0;
      valueL += element.scrollLeft || 0;
      element = element.parentNode;
    } while (element);
    return Element._returnOffset(valueL, valueT);
  },

  getOffsetParent: function(element) {
    if (element.offsetParent) return $(element.offsetParent);
    if (element == document.body) return $(element);

    while ((element = element.parentNode) && element != document.body)
      if (Element.getStyle(element, 'position') != 'static')
        return $(element);

    return $(document.body);
  },

  viewportOffset: function(forElement) {
    var valueT = 0, valueL = 0;

    var element = forElement;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;

      // Safari fix
      if (element.offsetParent == document.body &&
        Element.getStyle(element, 'position') == 'absolute') break;

    } while (element = element.offsetParent);

    element = forElement;
    do {
      if (!Prototype.Browser.Opera || (element.tagName && (element.tagName.toUpperCase() == 'BODY'))) {
        valueT -= element.scrollTop  || 0;
        valueL -= element.scrollLeft || 0;
      }
    } while (element = element.parentNode);

    return Element._returnOffset(valueL, valueT);
  },

  clonePosition: function(element, source) {
    var options = Object.extend({
      setLeft:    true,
      setTop:     true,
      setWidth:   true,
      setHeight:  true,
      offsetTop:  0,
      offsetLeft: 0
    }, arguments[2] || { });

    // find page position of source
    source = $(source);
    var p = source.viewportOffset();

    // find coordinate system to use
    element = $(element);
    var delta = [0, 0];
    var parent = null;
    // delta [0,0] will do fine with position: fixed elements,
    // position:absolute needs offsetParent deltas
    if (Element.getStyle(element, 'position') == 'absolute') {
      parent = element.getOffsetParent();
      delta = parent.viewportOffset();
    }

    // correct by body offsets (fixes Safari)
    if (parent == document.body) {
      delta[0] -= document.body.offsetLeft;
      delta[1] -= document.body.offsetTop;
    }

    // set position
    if (options.setLeft)   element.style.left  = (p[0] - delta[0] + options.offsetLeft) + 'px';
    if (options.setTop)    element.style.top   = (p[1] - delta[1] + options.offsetTop) + 'px';
    if (options.setWidth)  element.style.width = source.offsetWidth + 'px';
    if (options.setHeight) element.style.height = source.offsetHeight + 'px';
    return element;
  }
};

Element.Methods.identify.counter = 1;

Object.extend(Element.Methods, {
  getElementsBySelector: Element.Methods.select,
  childElements: Element.Methods.immediateDescendants
});

Element._attributeTranslations = {
  write: {
    names: {
      className: 'class',
      htmlFor:   'for'
    },
    values: { }
  }
};

if (Prototype.Browser.Opera) {
  Element.Methods.getStyle = Element.Methods.getStyle.wrap(
    function(proceed, element, style) {
      switch (style) {
        case 'left': case 'top': case 'right': case 'bottom':
          if (proceed(element, 'position') === 'static') return null;
        case 'height': case 'width':
          // returns '0px' for hidden elements; we want it to return null
          if (!Element.visible(element)) return null;

          // returns the border-box dimensions rather than the content-box
          // dimensions, so we subtract padding and borders from the value
          var dim = parseInt(proceed(element, style), 10);

          if (dim !== element['offset' + style.capitalize()])
            return dim + 'px';

          var properties;
          if (style === 'height') {
            properties = ['border-top-width', 'padding-top',
             'padding-bottom', 'border-bottom-width'];
          }
          else {
            properties = ['border-left-width', 'padding-left',
             'padding-right', 'border-right-width'];
          }
          return properties.inject(dim, function(memo, property) {
            var val = proceed(element, property);
            return val === null ? memo : memo - parseInt(val, 10);
          }) + 'px';
        default: return proceed(element, style);
      }
    }
  );

  Element.Methods.readAttribute = Element.Methods.readAttribute.wrap(
    function(proceed, element, attribute) {
      if (attribute === 'title') return element.title;
      return proceed(element, attribute);
    }
  );
}

else if (Prototype.Browser.IE) {
  // IE doesn't report offsets correctly for static elements, so we change them
  // to "relative" to get the values, then change them back.
  Element.Methods.getOffsetParent = Element.Methods.getOffsetParent.wrap(
    function(proceed, element) {
      element = $(element);
      // IE throws an error if element is not in document
      try { element.offsetParent }
      catch(e) { return $(document.body) }
      var position = element.getStyle('position');
      if (position !== 'static') return proceed(element);
      element.setStyle({ position: 'relative' });
      var value = proceed(element);
      element.setStyle({ position: position });
      return value;
    }
  );

  $w('positionedOffset viewportOffset').each(function(method) {
    Element.Methods[method] = Element.Methods[method].wrap(
      function(proceed, element) {
        element = $(element);
        try { element.offsetParent }
        catch(e) { return Element._returnOffset(0,0) }
        var position = element.getStyle('position');
        if (position !== 'static') return proceed(element);
        // Trigger hasLayout on the offset parent so that IE6 reports
        // accurate offsetTop and offsetLeft values for position: fixed.
        var offsetParent = element.getOffsetParent();
        if (offsetParent && offsetParent.getStyle('position') === 'fixed')
          offsetParent.setStyle({ zoom: 1 });
        element.setStyle({ position: 'relative' });
        var value = proceed(element);
        element.setStyle({ position: position });
        return value;
      }
    );
  });

  Element.Methods.cumulativeOffset = Element.Methods.cumulativeOffset.wrap(
    function(proceed, element) {
      try { element.offsetParent }
      catch(e) { return Element._returnOffset(0,0) }
      return proceed(element);
    }
  );

  Element.Methods.getStyle = function(element, style) {
    element = $(element);
    style = (style == 'float' || style == 'cssFloat') ? 'styleFloat' : style.camelize();
    var value = element.style[style];
    if (!value && element.currentStyle) value = element.currentStyle[style];

    if (style == 'opacity') {
      if (value = (element.getStyle('filter') || '').match(/alpha\(opacity=(.*)\)/))
        if (value[1]) return parseFloat(value[1]) / 100;
      return 1.0;
    }

    if (value == 'auto') {
      if ((style == 'width' || style == 'height') && (element.getStyle('display') != 'none'))
        return element['offset' + style.capitalize()] + 'px';
      return null;
    }
    return value;
  };

  Element.Methods.setOpacity = function(element, value) {
    function stripAlpha(filter){
      return filter.replace(/alpha\([^\)]*\)/gi,'');
    }
    element = $(element);
    var currentStyle = element.currentStyle;
    if ((currentStyle && !currentStyle.hasLayout) ||
      (!currentStyle && element.style.zoom == 'normal'))
        element.style.zoom = 1;

    var filter = element.getStyle('filter'), style = element.style;
    if (value == 1 || value === '') {
      (filter = stripAlpha(filter)) ?
        style.filter = filter : style.removeAttribute('filter');
      return element;
    } else if (value < 0.00001) value = 0;
    style.filter = stripAlpha(filter) +
      'alpha(opacity=' + (value * 100) + ')';
    return element;
  };

  Element._attributeTranslations = {
    read: {
      names: {
        'class': 'className',
        'for':   'htmlFor'
      },
      values: {
        _getAttr: function(element, attribute) {
          return element.getAttribute(attribute, 2);
        },
        _getAttrNode: function(element, attribute) {
          var node = element.getAttributeNode(attribute);
          return node ? node.value : "";
        },
        _getEv: function(element, attribute) {
          attribute = element.getAttribute(attribute);
          return attribute ? attribute.toString().slice(23, -2) : null;
        },
        _flag: function(element, attribute) {
          return $(element).hasAttribute(attribute) ? attribute : null;
        },
        style: function(element) {
          return element.style.cssText.toLowerCase();
        },
        title: function(element) {
          return element.title;
        }
      }
    }
  };

  Element._attributeTranslations.write = {
    names: Object.extend({
      cellpadding: 'cellPadding',
      cellspacing: 'cellSpacing'
    }, Element._attributeTranslations.read.names),
    values: {
      checked: function(element, value) {
        element.checked = !!value;
      },

      style: function(element, value) {
        element.style.cssText = value ? value : '';
      }
    }
  };

  Element._attributeTranslations.has = {};

  $w('colSpan rowSpan vAlign dateTime accessKey tabIndex ' +
      'encType maxLength readOnly longDesc frameBorder').each(function(attr) {
    Element._attributeTranslations.write.names[attr.toLowerCase()] = attr;
    Element._attributeTranslations.has[attr.toLowerCase()] = attr;
  });

  (function(v) {
    Object.extend(v, {
      href:        v._getAttr,
      src:         v._getAttr,
      type:        v._getAttr,
      action:      v._getAttrNode,
      disabled:    v._flag,
      checked:     v._flag,
      readonly:    v._flag,
      multiple:    v._flag,
      onload:      v._getEv,
      onunload:    v._getEv,
      onclick:     v._getEv,
      ondblclick:  v._getEv,
      onmousedown: v._getEv,
      onmouseup:   v._getEv,
      onmouseover: v._getEv,
      onmousemove: v._getEv,
      onmouseout:  v._getEv,
      onfocus:     v._getEv,
      onblur:      v._getEv,
      onkeypress:  v._getEv,
      onkeydown:   v._getEv,
      onkeyup:     v._getEv,
      onsubmit:    v._getEv,
      onreset:     v._getEv,
      onselect:    v._getEv,
      onchange:    v._getEv
    });
  })(Element._attributeTranslations.read.values);
}

else if (Prototype.Browser.Gecko && /rv:1\.8\.0/.test(navigator.userAgent)) {
  Element.Methods.setOpacity = function(element, value) {
    element = $(element);
    element.style.opacity = (value == 1) ? 0.999999 :
      (value === '') ? '' : (value < 0.00001) ? 0 : value;
    return element;
  };
}

else if (Prototype.Browser.WebKit) {
  Element.Methods.setOpacity = function(element, value) {
    element = $(element);
    element.style.opacity = (value == 1 || value === '') ? '' :
      (value < 0.00001) ? 0 : value;

    if (value == 1)
      if(element.tagName.toUpperCase() == 'IMG' && element.width) {
        element.width++; element.width--;
      } else try {
        var n = document.createTextNode(' ');
        element.appendChild(n);
        element.removeChild(n);
      } catch (e) { }

    return element;
  };

  // Safari returns margins on body which is incorrect if the child is absolutely
  // positioned.  For performance reasons, redefine Element#cumulativeOffset for
  // KHTML/WebKit only.
  Element.Methods.cumulativeOffset = function(element) {
    var valueT = 0, valueL = 0;
    do {
      valueT += element.offsetTop  || 0;
      valueL += element.offsetLeft || 0;
      if (element.offsetParent == document.body)
        if (Element.getStyle(element, 'position') == 'absolute') break;

      element = element.offsetParent;
    } while (element);

    return Element._returnOffset(valueL, valueT);
  };
}

if (Prototype.Browser.IE || Prototype.Browser.Opera) {
  // IE and Opera are missing .innerHTML support for TABLE-related and SELECT elements
  Element.Methods.update = function(element, content) {
    element = $(element);

    if (content && content.toElement) content = content.toElement();
    if (Object.isElement(content)) return element.update().insert(content);

    content = Object.toHTML(content);
    var tagName = element.tagName.toUpperCase();

    if (tagName in Element._insertionTranslations.tags) {
      $A(element.childNodes).each(function(node) { element.removeChild(node) });
      Element._getContentFromAnonymousElement(tagName, content.stripScripts())
        .each(function(node) { element.appendChild(node) });
    }
    else element.innerHTML = content.stripScripts();

    content.evalScripts.bind(content).defer();
    return element;
  };
}

if ('outerHTML' in document.createElement('div')) {
  Element.Methods.replace = function(element, content) {
    element = $(element);

    if (content && content.toElement) content = content.toElement();
    if (Object.isElement(content)) {
      element.parentNode.replaceChild(content, element);
      return element;
    }

    content = Object.toHTML(content);
    var parent = element.parentNode, tagName = parent.tagName.toUpperCase();

    if (Element._insertionTranslations.tags[tagName]) {
      var nextSibling = element.next();
      var fragments = Element._getContentFromAnonymousElement(tagName, content.stripScripts());
      parent.removeChild(element);
      if (nextSibling)
        fragments.each(function(node) { parent.insertBefore(node, nextSibling) });
      else
        fragments.each(function(node) { parent.appendChild(node) });
    }
    else element.outerHTML = content.stripScripts();

    content.evalScripts.bind(content).defer();
    return element;
  };
}

Element._returnOffset = function(l, t) {
  var result = [l, t];
  result.left = l;
  result.top = t;
  return result;
};

Element._getContentFromAnonymousElement = function(tagName, html) {
  var div = new Element('div'), t = Element._insertionTranslations.tags[tagName];
  if (t) {
    div.innerHTML = t[0] + html + t[1];
    t[2].times(function() { div = div.firstChild });
  } else div.innerHTML = html;
  return $A(div.childNodes);
};

Element._insertionTranslations = {
  before: function(element, node) {
    element.parentNode.insertBefore(node, element);
  },
  top: function(element, node) {
    element.insertBefore(node, element.firstChild);
  },
  bottom: function(element, node) {
    element.appendChild(node);
  },
  after: function(element, node) {
    element.parentNode.insertBefore(node, element.nextSibling);
  },
  tags: {
    TABLE:  ['<table>',                '</table>',                   1],
    TBODY:  ['<table><tbody>',         '</tbody></table>',           2],
    TR:     ['<table><tbody><tr>',     '</tr></tbody></table>',      3],
    TD:     ['<table><tbody><tr><td>', '</td></tr></tbody></table>', 4],
    SELECT: ['<select>',               '</select>',                  1]
  }
};

(function() {
  Object.extend(this.tags, {
    THEAD: this.tags.TBODY,
    TFOOT: this.tags.TBODY,
    TH:    this.tags.TD
  });
}).call(Element._insertionTranslations);

Element.Methods.Simulated = {
  hasAttribute: function(element, attribute) {
    attribute = Element._attributeTranslations.has[attribute] || attribute;
    var node = $(element).getAttributeNode(attribute);
    return !!(node && node.specified);
  }
};

Element.Methods.ByTag = { };

Object.extend(Element, Element.Methods);

if (!Prototype.BrowserFeatures.ElementExtensions &&
    document.createElement('div')['__proto__']) {
  window.HTMLElement = { };
  window.HTMLElement.prototype = document.createElement('div')['__proto__'];
  Prototype.BrowserFeatures.ElementExtensions = true;
}

Element.extend = (function() {
  if (Prototype.BrowserFeatures.SpecificElementExtensions)
    return Prototype.K;

  var Methods = { }, ByTag = Element.Methods.ByTag;

  var extend = Object.extend(function(element) {
    if (!element || element._extendedByPrototype ||
        element.nodeType != 1 || element == window) return element;

    var methods = Object.clone(Methods),
      tagName = element.tagName.toUpperCase(), property, value;

    // extend methods for specific tags
    if (ByTag[tagName]) Object.extend(methods, ByTag[tagName]);

    for (property in methods) {
      value = methods[property];
      if (Object.isFunction(value) && !(property in element))
        element[property] = value.methodize();
    }

    element._extendedByPrototype = Prototype.emptyFunction;
    return element;

  }, {
    refresh: function() {
      // extend methods for all tags (Safari doesn't need this)
      if (!Prototype.BrowserFeatures.ElementExtensions) {
        Object.extend(Methods, Element.Methods);
        Object.extend(Methods, Element.Methods.Simulated);
      }
    }
  });

  extend.refresh();
  return extend;
})();

Element.hasAttribute = function(element, attribute) {
  if (element.hasAttribute) return element.hasAttribute(attribute);
  return Element.Methods.Simulated.hasAttribute(element, attribute);
};

Element.addMethods = function(methods) {
  var F = Prototype.BrowserFeatures, T = Element.Methods.ByTag;

  if (!methods) {
    Object.extend(Form, Form.Methods);
    Object.extend(Form.Element, Form.Element.Methods);
    Object.extend(Element.Methods.ByTag, {
      "FORM":     Object.clone(Form.Methods),
      "INPUT":    Object.clone(Form.Element.Methods),
      "SELECT":   Object.clone(Form.Element.Methods),
      "TEXTAREA": Object.clone(Form.Element.Methods)
    });
  }

  if (arguments.length == 2) {
    var tagName = methods;
    methods = arguments[1];
  }

  if (!tagName) Object.extend(Element.Methods, methods || { });
  else {
    if (Object.isArray(tagName)) tagName.each(extend);
    else extend(tagName);
  }

  function extend(tagName) {
    tagName = tagName.toUpperCase();
    if (!Element.Methods.ByTag[tagName])
      Element.Methods.ByTag[tagName] = { };
    Object.extend(Element.Methods.ByTag[tagName], methods);
  }

  function copy(methods, destination, onlyIfAbsent) {
    onlyIfAbsent = onlyIfAbsent || false;
    for (var property in methods) {
      var value = methods[property];
      if (!Object.isFunction(value)) continue;
      if (!onlyIfAbsent || !(property in destination))
        destination[property] = value.methodize();
    }
  }

  function findDOMClass(tagName) {
    var klass;
    var trans = {
      "OPTGROUP": "OptGroup", "TEXTAREA": "TextArea", "P": "Paragraph",
      "FIELDSET": "FieldSet", "UL": "UList", "OL": "OList", "DL": "DList",
      "DIR": "Directory", "H1": "Heading", "H2": "Heading", "H3": "Heading",
      "H4": "Heading", "H5": "Heading", "H6": "Heading", "Q": "Quote",
      "INS": "Mod", "DEL": "Mod", "A": "Anchor", "IMG": "Image", "CAPTION":
      "TableCaption", "COL": "TableCol", "COLGROUP": "TableCol", "THEAD":
      "TableSection", "TFOOT": "TableSection", "TBODY": "TableSection", "TR":
      "TableRow", "TH": "TableCell", "TD": "TableCell", "FRAMESET":
      "FrameSet", "IFRAME": "IFrame"
    };
    if (trans[tagName]) klass = 'HTML' + trans[tagName] + 'Element';
    if (window[klass]) return window[klass];
    klass = 'HTML' + tagName + 'Element';
    if (window[klass]) return window[klass];
    klass = 'HTML' + tagName.capitalize() + 'Element';
    if (window[klass]) return window[klass];

    window[klass] = { };
    window[klass].prototype = document.createElement(tagName)['__proto__'];
    return window[klass];
  }

  if (F.ElementExtensions) {
    copy(Element.Methods, HTMLElement.prototype);
    copy(Element.Methods.Simulated, HTMLElement.prototype, true);
  }

  if (F.SpecificElementExtensions) {
    for (var tag in Element.Methods.ByTag) {
      var klass = findDOMClass(tag);
      if (Object.isUndefined(klass)) continue;
      copy(T[tag], klass.prototype);
    }
  }

  Object.extend(Element, Element.Methods);
  delete Element.ByTag;

  if (Element.extend.refresh) Element.extend.refresh();
  Element.cache = { };
};

document.viewport = {
  getDimensions: function() {
    var dimensions = { }, B = Prototype.Browser;
    $w('width height').each(function(d) {
      var D = d.capitalize();
      if (B.WebKit && !document.evaluate) {
        // Safari <3.0 needs self.innerWidth/Height
        dimensions[d] = self['inner' + D];
      } else if (B.Opera && parseFloat(window.opera.version()) < 9.5) {
        // Opera <9.5 needs document.body.clientWidth/Height
        dimensions[d] = document.body['client' + D]
      } else {
        dimensions[d] = document.documentElement['client' + D];
      }
    });
    return dimensions;
  },

  getWidth: function() {
    return this.getDimensions().width;
  },

  getHeight: function() {
    return this.getDimensions().height;
  },

  getScrollOffsets: function() {
    return Element._returnOffset(
      window.pageXOffset || document.documentElement.scrollLeft || document.body.scrollLeft,
      window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop);
  }
};
/* Portions of the Selector class are derived from Jack Slocum's DomQuery,
 * part of YUI-Ext version 0.40, distributed under the terms of an MIT-style
 * license.  Please see http://www.yui-ext.com/ for more information. */

var Selector = Class.create({
  initialize: function(expression) {
    this.expression = expression.strip();

    if (this.shouldUseSelectorsAPI()) {
      this.mode = 'selectorsAPI';
    } else if (this.shouldUseXPath()) {
      this.mode = 'xpath';
      this.compileXPathMatcher();
    } else {
      this.mode = "normal";
      this.compileMatcher();
    }

  },

  shouldUseXPath: function() {
    if (!Prototype.BrowserFeatures.XPath) return false;

    var e = this.expression;

    // Safari 3 chokes on :*-of-type and :empty
    if (Prototype.Browser.WebKit &&
     (e.include("-of-type") || e.include(":empty")))
      return false;

    // XPath can't do namespaced attributes, nor can it read
    // the "checked" property from DOM nodes
    if ((/(\[[\w-]*?:|:checked)/).test(e))
      return false;

    return true;
  },

  shouldUseSelectorsAPI: function() {
    if (!Prototype.BrowserFeatures.SelectorsAPI) return false;

    if (!Selector._div) Selector._div = new Element('div');

    // Make sure the browser treats the selector as valid. Test on an
    // isolated element to minimize cost of this check.
    try {
      Selector._div.querySelector(this.expression);
    } catch(e) {
      return false;
    }

    return true;
  },

  compileMatcher: function() {
    var e = this.expression, ps = Selector.patterns, h = Selector.handlers,
        c = Selector.criteria, le, p, m;

    if (Selector._cache[e]) {
      this.matcher = Selector._cache[e];
      return;
    }

    this.matcher = ["this.matcher = function(root) {",
                    "var r = root, h = Selector.handlers, c = false, n;"];

    while (e && le != e && (/\S/).test(e)) {
      le = e;
      for (var i in ps) {
        p = ps[i];
        if (m = e.match(p)) {
          this.matcher.push(Object.isFunction(c[i]) ? c[i](m) :
            new Template(c[i]).evaluate(m));
          e = e.replace(m[0], '');
          break;
        }
      }
    }

    this.matcher.push("return h.unique(n);\n}");
    eval(this.matcher.join('\n'));
    Selector._cache[this.expression] = this.matcher;
  },

  compileXPathMatcher: function() {
    var e = this.expression, ps = Selector.patterns,
        x = Selector.xpath, le, m;

    if (Selector._cache[e]) {
      this.xpath = Selector._cache[e]; return;
    }

    this.matcher = ['.//*'];
    while (e && le != e && (/\S/).test(e)) {
      le = e;
      for (var i in ps) {
        if (m = e.match(ps[i])) {
          this.matcher.push(Object.isFunction(x[i]) ? x[i](m) :
            new Template(x[i]).evaluate(m));
          e = e.replace(m[0], '');
          break;
        }
      }
    }

    this.xpath = this.matcher.join('');
    Selector._cache[this.expression] = this.xpath;
  },

  findElements: function(root) {
    root = root || document;
    var e = this.expression, results;

    switch (this.mode) {
      case 'selectorsAPI':
        // querySelectorAll queries document-wide, then filters to descendants
        // of the context element. That's not what we want.
        // Add an explicit context to the selector if necessary.
        if (root !== document) {
          var oldId = root.id, id = $(root).identify();
          e = "#" + id + " " + e;
        }

        results = $A(root.querySelectorAll(e)).map(Element.extend);
        root.id = oldId;

        return results;
      case 'xpath':
        return document._getElementsByXPath(this.xpath, root);
      default:
       return this.matcher(root);
    }
  },

  match: function(element) {
    this.tokens = [];

    var e = this.expression, ps = Selector.patterns, as = Selector.assertions;
    var le, p, m;

    while (e && le !== e && (/\S/).test(e)) {
      le = e;
      for (var i in ps) {
        p = ps[i];
        if (m = e.match(p)) {
          // use the Selector.assertions methods unless the selector
          // is too complex.
          if (as[i]) {
            this.tokens.push([i, Object.clone(m)]);
            e = e.replace(m[0], '');
          } else {
            // reluctantly do a document-wide search
            // and look for a match in the array
            return this.findElements(document).include(element);
          }
        }
      }
    }

    var match = true, name, matches;
    for (var i = 0, token; token = this.tokens[i]; i++) {
      name = token[0], matches = token[1];
      if (!Selector.assertions[name](element, matches)) {
        match = false; break;
      }
    }

    return match;
  },

  toString: function() {
    return this.expression;
  },

  inspect: function() {
    return "#<Selector:" + this.expression.inspect() + ">";
  }
});

Object.extend(Selector, {
  _cache: { },

  xpath: {
    descendant:   "//*",
    child:        "/*",
    adjacent:     "/following-sibling::*[1]",
    laterSibling: '/following-sibling::*',
    tagName:      function(m) {
      if (m[1] == '*') return '';
      return "[local-name()='" + m[1].toLowerCase() +
             "' or local-name()='" + m[1].toUpperCase() + "']";
    },
    className:    "[contains(concat(' ', @class, ' '), ' #{1} ')]",
    id:           "[@id='#{1}']",
    attrPresence: function(m) {
      m[1] = m[1].toLowerCase();
      return new Template("[@#{1}]").evaluate(m);
    },
    attr: function(m) {
      m[1] = m[1].toLowerCase();
      m[3] = m[5] || m[6];
      return new Template(Selector.xpath.operators[m[2]]).evaluate(m);
    },
    pseudo: function(m) {
      var h = Selector.xpath.pseudos[m[1]];
      if (!h) return '';
      if (Object.isFunction(h)) return h(m);
      return new Template(Selector.xpath.pseudos[m[1]]).evaluate(m);
    },
    operators: {
      '=':  "[@#{1}='#{3}']",
      '!=': "[@#{1}!='#{3}']",
      '^=': "[starts-with(@#{1}, '#{3}')]",
      '$=': "[substring(@#{1}, (string-length(@#{1}) - string-length('#{3}') + 1))='#{3}']",
      '*=': "[contains(@#{1}, '#{3}')]",
      '~=': "[contains(concat(' ', @#{1}, ' '), ' #{3} ')]",
      '|=': "[contains(concat('-', @#{1}, '-'), '-#{3}-')]"
    },
    pseudos: {
      'first-child': '[not(preceding-sibling::*)]',
      'last-child':  '[not(following-sibling::*)]',
      'only-child':  '[not(preceding-sibling::* or following-sibling::*)]',
      'empty':       "[count(*) = 0 and (count(text()) = 0)]",
      'checked':     "[@checked]",
      'disabled':    "[(@disabled) and (@type!='hidden')]",
      'enabled':     "[not(@disabled) and (@type!='hidden')]",
      'not': function(m) {
        var e = m[6], p = Selector.patterns,
            x = Selector.xpath, le, v;

        var exclusion = [];
        while (e && le != e && (/\S/).test(e)) {
          le = e;
          for (var i in p) {
            if (m = e.match(p[i])) {
              v = Object.isFunction(x[i]) ? x[i](m) : new Template(x[i]).evaluate(m);
              exclusion.push("(" + v.substring(1, v.length - 1) + ")");
              e = e.replace(m[0], '');
              break;
            }
          }
        }
        return "[not(" + exclusion.join(" and ") + ")]";
      },
      'nth-child':      function(m) {
        return Selector.xpath.pseudos.nth("(count(./preceding-sibling::*) + 1) ", m);
      },
      'nth-last-child': function(m) {
        return Selector.xpath.pseudos.nth("(count(./following-sibling::*) + 1) ", m);
      },
      'nth-of-type':    function(m) {
        return Selector.xpath.pseudos.nth("position() ", m);
      },
      'nth-last-of-type': function(m) {
        return Selector.xpath.pseudos.nth("(last() + 1 - position()) ", m);
      },
      'first-of-type':  function(m) {
        m[6] = "1"; return Selector.xpath.pseudos['nth-of-type'](m);
      },
      'last-of-type':   function(m) {
        m[6] = "1"; return Selector.xpath.pseudos['nth-last-of-type'](m);
      },
      'only-of-type':   function(m) {
        var p = Selector.xpath.pseudos; return p['first-of-type'](m) + p['last-of-type'](m);
      },
      nth: function(fragment, m) {
        var mm, formula = m[6], predicate;
        if (formula == 'even') formula = '2n+0';
        if (formula == 'odd')  formula = '2n+1';
        if (mm = formula.match(/^(\d+)$/)) // digit only
          return '[' + fragment + "= " + mm[1] + ']';
        if (mm = formula.match(/^(-?\d*)?n(([+-])(\d+))?/)) { // an+b
          if (mm[1] == "-") mm[1] = -1;
          var a = mm[1] ? Number(mm[1]) : 1;
          var b = mm[2] ? Number(mm[2]) : 0;
          predicate = "[((#{fragment} - #{b}) mod #{a} = 0) and " +
          "((#{fragment} - #{b}) div #{a} >= 0)]";
          return new Template(predicate).evaluate({
            fragment: fragment, a: a, b: b });
        }
      }
    }
  },

  criteria: {
    tagName:      'n = h.tagName(n, r, "#{1}", c);      c = false;',
    className:    'n = h.className(n, r, "#{1}", c);    c = false;',
    id:           'n = h.id(n, r, "#{1}", c);           c = false;',
    attrPresence: 'n = h.attrPresence(n, r, "#{1}", c); c = false;',
    attr: function(m) {
      m[3] = (m[5] || m[6]);
      return new Template('n = h.attr(n, r, "#{1}", "#{3}", "#{2}", c); c = false;').evaluate(m);
    },
    pseudo: function(m) {
      if (m[6]) m[6] = m[6].replace(/"/g, '\\"');
      return new Template('n = h.pseudo(n, "#{1}", "#{6}", r, c); c = false;').evaluate(m);
    },
    descendant:   'c = "descendant";',
    child:        'c = "child";',
    adjacent:     'c = "adjacent";',
    laterSibling: 'c = "laterSibling";'
  },

  patterns: {
    // combinators must be listed first
    // (and descendant needs to be last combinator)
    laterSibling: /^\s*~\s*/,
    child:        /^\s*>\s*/,
    adjacent:     /^\s*\+\s*/,
    descendant:   /^\s/,

    // selectors follow
    tagName:      /^\s*(\*|[\w\-]+)(\b|$)?/,
    id:           /^#([\w\-\*]+)(\b|$)/,
    className:    /^\.([\w\-\*]+)(\b|$)/,
    pseudo:
/^:((first|last|nth|nth-last|only)(-child|-of-type)|empty|checked|(en|dis)abled|not)(\((.*?)\))?(\b|$|(?=\s|[:+~>]))/,
    attrPresence: /^\[((?:[\w]+:)?[\w]+)\]/,
    attr:         /\[((?:[\w-]*:)?[\w-]+)\s*(?:([!^$*~|]?=)\s*((['"])([^\4]*?)\4|([^'"][^\]]*?)))?\]/
  },

  // for Selector.match and Element#match
  assertions: {
    tagName: function(element, matches) {
      return matches[1].toUpperCase() == element.tagName.toUpperCase();
    },

    className: function(element, matches) {
      return Element.hasClassName(element, matches[1]);
    },

    id: function(element, matches) {
      return element.id === matches[1];
    },

    attrPresence: function(element, matches) {
      return Element.hasAttribute(element, matches[1]);
    },

    attr: function(element, matches) {
      var nodeValue = Element.readAttribute(element, matches[1]);
      return nodeValue && Selector.operators[matches[2]](nodeValue, matches[5] || matches[6]);
    }
  },

  handlers: {
    // UTILITY FUNCTIONS
    // joins two collections
    concat: function(a, b) {
      for (var i = 0, node; node = b[i]; i++)
        a.push(node);
      return a;
    },

    // marks an array of nodes for counting
    mark: function(nodes) {
      var _true = Prototype.emptyFunction;
      for (var i = 0, node; node = nodes[i]; i++)
        node._countedByPrototype = _true;
      return nodes;
    },

    unmark: function(nodes) {
      for (var i = 0, node; node = nodes[i]; i++)
        node._countedByPrototype = undefined;
      return nodes;
    },

    // mark each child node with its position (for nth calls)
    // "ofType" flag indicates whether we're indexing for nth-of-type
    // rather than nth-child
    index: function(parentNode, reverse, ofType) {
      parentNode._countedByPrototype = Prototype.emptyFunction;
      if (reverse) {
        for (var nodes = parentNode.childNodes, i = nodes.length - 1, j = 1; i >= 0; i--) {
          var node = nodes[i];
          if (node.nodeType == 1 && (!ofType || node._countedByPrototype)) node.nodeIndex = j++;
        }
      } else {
        for (var i = 0, j = 1, nodes = parentNode.childNodes; node = nodes[i]; i++)
          if (node.nodeType == 1 && (!ofType || node._countedByPrototype)) node.nodeIndex = j++;
      }
    },

    // filters out duplicates and extends all nodes
    unique: function(nodes) {
      if (nodes.length == 0) return nodes;
      var results = [], n;
      for (var i = 0, l = nodes.length; i < l; i++)
        if (!(n = nodes[i])._countedByPrototype) {
          n._countedByPrototype = Prototype.emptyFunction;
          results.push(Element.extend(n));
        }
      return Selector.handlers.unmark(results);
    },

    // COMBINATOR FUNCTIONS
    descendant: function(nodes) {
      var h = Selector.handlers;
      for (var i = 0, results = [], node; node = nodes[i]; i++)
        h.concat(results, node.getElementsByTagName('*'));
      return results;
    },

    child: function(nodes) {
      var h = Selector.handlers;
      for (var i = 0, results = [], node; node = nodes[i]; i++) {
        for (var j = 0, child; child = node.childNodes[j]; j++)
          if (child.nodeType == 1 && child.tagName != '!') results.push(child);
      }
      return results;
    },

    adjacent: function(nodes) {
      for (var i = 0, results = [], node; node = nodes[i]; i++) {
        var next = this.nextElementSibling(node);
        if (next) results.push(next);
      }
      return results;
    },

    laterSibling: function(nodes) {
      var h = Selector.handlers;
      for (var i = 0, results = [], node; node = nodes[i]; i++)
        h.concat(results, Element.nextSiblings(node));
      return results;
    },

    nextElementSibling: function(node) {
      while (node = node.nextSibling)
        if (node.nodeType == 1) return node;
      return null;
    },

    previousElementSibling: function(node) {
      while (node = node.previousSibling)
        if (node.nodeType == 1) return node;
      return null;
    },

    // TOKEN FUNCTIONS
    tagName: function(nodes, root, tagName, combinator) {
      var uTagName = tagName.toUpperCase();
      var results = [], h = Selector.handlers;
      if (nodes) {
        if (combinator) {
          // fastlane for ordinary descendant combinators
          if (combinator == "descendant") {
            for (var i = 0, node; node = nodes[i]; i++)
              h.concat(results, node.getElementsByTagName(tagName));
            return results;
          } else nodes = this[combinator](nodes);
          if (tagName == "*") return nodes;
        }
        for (var i = 0, node; node = nodes[i]; i++)
          if (node.tagName.toUpperCase() === uTagName) results.push(node);
        return results;
      } else return root.getElementsByTagName(tagName);
    },

    id: function(nodes, root, id, combinator) {
      var targetNode = $(id), h = Selector.handlers;
      if (!targetNode) return [];
      if (!nodes && root == document) return [targetNode];
      if (nodes) {
        if (combinator) {
          if (combinator == 'child') {
            for (var i = 0, node; node = nodes[i]; i++)
              if (targetNode.parentNode == node) return [targetNode];
          } else if (combinator == 'descendant') {
            for (var i = 0, node; node = nodes[i]; i++)
              if (Element.descendantOf(targetNode, node)) return [targetNode];
          } else if (combinator == 'adjacent') {
            for (var i = 0, node; node = nodes[i]; i++)
              if (Selector.handlers.previousElementSibling(targetNode) == node)
                return [targetNode];
          } else nodes = h[combinator](nodes);
        }
        for (var i = 0, node; node = nodes[i]; i++)
          if (node == targetNode) return [targetNode];
        return [];
      }
      return (targetNode && Element.descendantOf(targetNode, root)) ? [targetNode] : [];
    },

    className: function(nodes, root, className, combinator) {
      if (nodes && combinator) nodes = this[combinator](nodes);
      return Selector.handlers.byClassName(nodes, root, className);
    },

    byClassName: function(nodes, root, className) {
      if (!nodes) nodes = Selector.handlers.descendant([root]);
      var needle = ' ' + className + ' ';
      for (var i = 0, results = [], node, nodeClassName; node = nodes[i]; i++) {
        nodeClassName = node.className;
        if (nodeClassName.length == 0) continue;
        if (nodeClassName == className || (' ' + nodeClassName + ' ').include(needle))
          results.push(node);
      }
      return results;
    },

    attrPresence: function(nodes, root, attr, combinator) {
      if (!nodes) nodes = root.getElementsByTagName("*");
      if (nodes && combinator) nodes = this[combinator](nodes);
      var results = [];
      for (var i = 0, node; node = nodes[i]; i++)
        if (Element.hasAttribute(node, attr)) results.push(node);
      return results;
    },

    attr: function(nodes, root, attr, value, operator, combinator) {
      if (!nodes) nodes = root.getElementsByTagName("*");
      if (nodes && combinator) nodes = this[combinator](nodes);
      var handler = Selector.operators[operator], results = [];
      for (var i = 0, node; node = nodes[i]; i++) {
        var nodeValue = Element.readAttribute(node, attr);
        if (nodeValue === null) continue;
        if (handler(nodeValue, value)) results.push(node);
      }
      return results;
    },

    pseudo: function(nodes, name, value, root, combinator) {
      if (nodes && combinator) nodes = this[combinator](nodes);
      if (!nodes) nodes = root.getElementsByTagName("*");
      return Selector.pseudos[name](nodes, value, root);
    }
  },

  pseudos: {
    'first-child': function(nodes, value, root) {
      for (var i = 0, results = [], node; node = nodes[i]; i++) {
        if (Selector.handlers.previousElementSibling(node)) continue;
          results.push(node);
      }
      return results;
    },
    'last-child': function(nodes, value, root) {
      for (var i = 0, results = [], node; node = nodes[i]; i++) {
        if (Selector.handlers.nextElementSibling(node)) continue;
          results.push(node);
      }
      return results;
    },
    'only-child': function(nodes, value, root) {
      var h = Selector.handlers;
      for (var i = 0, results = [], node; node = nodes[i]; i++)
        if (!h.previousElementSibling(node) && !h.nextElementSibling(node))
          results.push(node);
      return results;
    },
    'nth-child':        function(nodes, formula, root) {
      return Selector.pseudos.nth(nodes, formula, root);
    },
    'nth-last-child':   function(nodes, formula, root) {
      return Selector.pseudos.nth(nodes, formula, root, true);
    },
    'nth-of-type':      function(nodes, formula, root) {
      return Selector.pseudos.nth(nodes, formula, root, false, true);
    },
    'nth-last-of-type': function(nodes, formula, root) {
      return Selector.pseudos.nth(nodes, formula, root, true, true);
    },
    'first-of-type':    function(nodes, formula, root) {
      return Selector.pseudos.nth(nodes, "1", root, false, true);
    },
    'last-of-type':     function(nodes, formula, root) {
      return Selector.pseudos.nth(nodes, "1", root, true, true);
    },
    'only-of-type':     function(nodes, formula, root) {
      var p = Selector.pseudos;
      return p['last-of-type'](p['first-of-type'](nodes, formula, root), formula, root);
    },

    // handles the an+b logic
    getIndices: function(a, b, total) {
      if (a == 0) return b > 0 ? [b] : [];
      return $R(1, total).inject([], function(memo, i) {
        if (0 == (i - b) % a && (i - b) / a >= 0) memo.push(i);
        return memo;
      });
    },

    // handles nth(-last)-child, nth(-last)-of-type, and (first|last)-of-type
    nth: function(nodes, formula, root, reverse, ofType) {
      if (nodes.length == 0) return [];
      if (formula == 'even') formula = '2n+0';
      if (formula == 'odd')  formula = '2n+1';
      var h = Selector.handlers, results = [], indexed = [], m;
      h.mark(nodes);
      for (var i = 0, node; node = nodes[i]; i++) {
        if (!node.parentNode._countedByPrototype) {
          h.index(node.parentNode, reverse, ofType);
          indexed.push(node.parentNode);
        }
      }
      if (formula.match(/^\d+$/)) { // just a number
        formula = Number(formula);
        for (var i = 0, node; node = nodes[i]; i++)
          if (node.nodeIndex == formula) results.push(node);
      } else if (m = formula.match(/^(-?\d*)?n(([+-])(\d+))?/)) { // an+b
        if (m[1] == "-") m[1] = -1;
        var a = m[1] ? Number(m[1]) : 1;
        var b = m[2] ? Number(m[2]) : 0;
        var indices = Selector.pseudos.getIndices(a, b, nodes.length);
        for (var i = 0, node, l = indices.length; node = nodes[i]; i++) {
          for (var j = 0; j < l; j++)
            if (node.nodeIndex == indices[j]) results.push(node);
        }
      }
      h.unmark(nodes);
      h.unmark(indexed);
      return results;
    },

    'empty': function(nodes, value, root) {
      for (var i = 0, results = [], node; node = nodes[i]; i++) {
        // IE treats comments as element nodes
        if (node.tagName == '!' || node.firstChild) continue;
        results.push(node);
      }
      return results;
    },

    'not': function(nodes, selector, root) {
      var h = Selector.handlers, selectorType, m;
      var exclusions = new Selector(selector).findElements(root);
      h.mark(exclusions);
      for (var i = 0, results = [], node; node = nodes[i]; i++)
        if (!node._countedByPrototype) results.push(node);
      h.unmark(exclusions);
      return results;
    },

    'enabled': function(nodes, value, root) {
      for (var i = 0, results = [], node; node = nodes[i]; i++)
        if (!node.disabled && (!node.type || node.type !== 'hidden'))
          results.push(node);
      return results;
    },

    'disabled': function(nodes, value, root) {
      for (var i = 0, results = [], node; node = nodes[i]; i++)
        if (node.disabled) results.push(node);
      return results;
    },

    'checked': function(nodes, value, root) {
      for (var i = 0, results = [], node; node = nodes[i]; i++)
        if (node.checked) results.push(node);
      return results;
    }
  },

  operators: {
    '=':  function(nv, v) { return nv == v; },
    '!=': function(nv, v) { return nv != v; },
    '^=': function(nv, v) { return nv == v || nv && nv.startsWith(v); },
    '$=': function(nv, v) { return nv == v || nv && nv.endsWith(v); },
    '*=': function(nv, v) { return nv == v || nv && nv.include(v); },
    '$=': function(nv, v) { return nv.endsWith(v); },
    '*=': function(nv, v) { return nv.include(v); },
    '~=': function(nv, v) { return (' ' + nv + ' ').include(' ' + v + ' '); },
    '|=': function(nv, v) { return ('-' + (nv || "").toUpperCase() +
     '-').include('-' + (v || "").toUpperCase() + '-'); }
  },

  split: function(expression) {
    var expressions = [];
    expression.scan(/(([\w#:.~>+()\s-]+|\*|\[.*?\])+)\s*(,|$)/, function(m) {
      expressions.push(m[1].strip());
    });
    return expressions;
  },

  matchElements: function(elements, expression) {
    var matches = $$(expression), h = Selector.handlers;
    h.mark(matches);
    for (var i = 0, results = [], element; element = elements[i]; i++)
      if (element._countedByPrototype) results.push(element);
    h.unmark(matches);
    return results;
  },

  findElement: function(elements, expression, index) {
    if (Object.isNumber(expression)) {
      index = expression; expression = false;
    }
    return Selector.matchElements(elements, expression || '*')[index || 0];
  },

  findChildElements: function(element, expressions) {
    expressions = Selector.split(expressions.join(','));
    var results = [], h = Selector.handlers;
    for (var i = 0, l = expressions.length, selector; i < l; i++) {
      selector = new Selector(expressions[i].strip());
      h.concat(results, selector.findElements(element));
    }
    return (l > 1) ? h.unique(results) : results;
  }
});

if (Prototype.Browser.IE) {
  Object.extend(Selector.handlers, {
    // IE returns comment nodes on getElementsByTagName("*").
    // Filter them out.
    concat: function(a, b) {
      for (var i = 0, node; node = b[i]; i++)
        if (node.tagName !== "!") a.push(node);
      return a;
    },

    // IE improperly serializes _countedByPrototype in (inner|outer)HTML.
    unmark: function(nodes) {
      for (var i = 0, node; node = nodes[i]; i++)
        node.removeAttribute('_countedByPrototype');
      return nodes;
    }
  });
}

function $$() {
  return Selector.findChildElements(document, $A(arguments));
}
var Form = {
  reset: function(form) {
    $(form).reset();
    return form;
  },

  serializeElements: function(elements, options) {
    if (typeof options != 'object') options = { hash: !!options };
    else if (Object.isUndefined(options.hash)) options.hash = true;
    var key, value, submitted = false, submit = options.submit;

    var data = elements.inject({ }, function(result, element) {
      if (!element.disabled && element.name) {
        key = element.name; value = $(element).getValue();
        if (value != null && element.type != 'file' && (element.type != 'submit' || (!submitted &&
            submit !== false && (!submit || key == submit) && (submitted = true)))) {
          if (key in result) {
            // a key is already present; construct an array of values
            if (!Object.isArray(result[key])) result[key] = [result[key]];
            result[key].push(value);
          }
          else result[key] = value;
        }
      }
      return result;
    });

    return options.hash ? data : Object.toQueryString(data);
  }
};

Form.Methods = {
  serialize: function(form, options) {
    return Form.serializeElements(Form.getElements(form), options);
  },

  getElements: function(form) {
    return $A($(form).getElementsByTagName('*')).inject([],
      function(elements, child) {
        if (Form.Element.Serializers[child.tagName.toLowerCase()])
          elements.push(Element.extend(child));
        return elements;
      }
    );
  },

  getInputs: function(form, typeName, name) {
    form = $(form);
    var inputs = form.getElementsByTagName('input');

    if (!typeName && !name) return $A(inputs).map(Element.extend);

    for (var i = 0, matchingInputs = [], length = inputs.length; i < length; i++) {
      var input = inputs[i];
      if ((typeName && input.type != typeName) || (name && input.name != name))
        continue;
      matchingInputs.push(Element.extend(input));
    }

    return matchingInputs;
  },

  disable: function(form) {
    form = $(form);
    Form.getElements(form).invoke('disable');
    return form;
  },

  enable: function(form) {
    form = $(form);
    Form.getElements(form).invoke('enable');
    return form;
  },

  findFirstElement: function(form) {
    var elements = $(form).getElements().findAll(function(element) {
      return 'hidden' != element.type && !element.disabled;
    });
    var firstByIndex = elements.findAll(function(element) {
      return element.hasAttribute('tabIndex') && element.tabIndex >= 0;
    }).sortBy(function(element) { return element.tabIndex }).first();

    return firstByIndex ? firstByIndex : elements.find(function(element) {
      return ['input', 'select', 'textarea'].include(element.tagName.toLowerCase());
    });
  },

  focusFirstElement: function(form) {
    form = $(form);
    form.findFirstElement().activate();
    return form;
  },

  request: function(form, options) {
    form = $(form), options = Object.clone(options || { });

    var params = options.parameters, action = form.readAttribute('action') || '';
    if (action.blank()) action = window.location.href;
    options.parameters = form.serialize(true);

    if (params) {
      if (Object.isString(params)) params = params.toQueryParams();
      Object.extend(options.parameters, params);
    }

    if (form.hasAttribute('method') && !options.method)
      options.method = form.method;

    return new Ajax.Request(action, options);
  }
};

/*--------------------------------------------------------------------------*/

Form.Element = {
  focus: function(element) {
    $(element).focus();
    return element;
  },

  select: function(element) {
    $(element).select();
    return element;
  }
};

Form.Element.Methods = {
  serialize: function(element) {
    element = $(element);
    if (!element.disabled && element.name) {
      var value = element.getValue();
      if (value != undefined) {
        var pair = { };
        pair[element.name] = value;
        return Object.toQueryString(pair);
      }
    }
    return '';
  },

  getValue: function(element) {
    element = $(element);
    var method = element.tagName.toLowerCase();
    return Form.Element.Serializers[method](element);
  },

  setValue: function(element, value) {
    element = $(element);
    var method = element.tagName.toLowerCase();
    Form.Element.Serializers[method](element, value);
    return element;
  },

  clear: function(element) {
    $(element).value = '';
    return element;
  },

  present: function(element) {
    return $(element).value != '';
  },

  activate: function(element) {
    element = $(element);
    try {
      element.focus();
      if (element.select && (element.tagName.toLowerCase() != 'input' ||
          !['button', 'reset', 'submit'].include(element.type)))
        element.select();
    } catch (e) { }
    return element;
  },

  disable: function(element) {
    element = $(element);
    element.disabled = true;
    return element;
  },

  enable: function(element) {
    element = $(element);
    element.disabled = false;
    return element;
  }
};

/*--------------------------------------------------------------------------*/

var Field = Form.Element;
var $F = Form.Element.Methods.getValue;

/*--------------------------------------------------------------------------*/

Form.Element.Serializers = {
  input: function(element, value) {
    switch (element.type.toLowerCase()) {
      case 'checkbox':
      case 'radio':
        return Form.Element.Serializers.inputSelector(element, value);
      default:
        return Form.Element.Serializers.textarea(element, value);
    }
  },

  inputSelector: function(element, value) {
    if (Object.isUndefined(value)) return element.checked ? element.value : null;
    else element.checked = !!value;
  },

  textarea: function(element, value) {
    if (Object.isUndefined(value)) return element.value;
    else element.value = value;
  },

  select: function(element, value) {
    if (Object.isUndefined(value))
      return this[element.type == 'select-one' ?
        'selectOne' : 'selectMany'](element);
    else {
      var opt, currentValue, single = !Object.isArray(value);
      for (var i = 0, length = element.length; i < length; i++) {
        opt = element.options[i];
        currentValue = this.optionValue(opt);
        if (single) {
          if (currentValue == value) {
            opt.selected = true;
            return;
          }
        }
        else opt.selected = value.include(currentValue);
      }
    }
  },

  selectOne: function(element) {
    var index = element.selectedIndex;
    return index >= 0 ? this.optionValue(element.options[index]) : null;
  },

  selectMany: function(element) {
    var values, length = element.length;
    if (!length) return null;

    for (var i = 0, values = []; i < length; i++) {
      var opt = element.options[i];
      if (opt.selected) values.push(this.optionValue(opt));
    }
    return values;
  },

  optionValue: function(opt) {
    // extend element because hasAttribute may not be native
    return Element.extend(opt).hasAttribute('value') ? opt.value : opt.text;
  }
};

/*--------------------------------------------------------------------------*/

Abstract.TimedObserver = Class.create(PeriodicalExecuter, {
  initialize: function($super, element, frequency, callback) {
    $super(callback, frequency);
    this.element   = $(element);
    this.lastValue = this.getValue();
  },

  execute: function() {
    var value = this.getValue();
    if (Object.isString(this.lastValue) && Object.isString(value) ?
        this.lastValue != value : String(this.lastValue) != String(value)) {
      this.callback(this.element, value);
      this.lastValue = value;
    }
  }
});

Form.Element.Observer = Class.create(Abstract.TimedObserver, {
  getValue: function() {
    return Form.Element.getValue(this.element);
  }
});

Form.Observer = Class.create(Abstract.TimedObserver, {
  getValue: function() {
    return Form.serialize(this.element);
  }
});

/*--------------------------------------------------------------------------*/

Abstract.EventObserver = Class.create({
  initialize: function(element, callback) {
    this.element  = $(element);
    this.callback = callback;

    this.lastValue = this.getValue();
    if (this.element.tagName.toLowerCase() == 'form')
      this.registerFormCallbacks();
    else
      this.registerCallback(this.element);
  },

  onElementEvent: function() {
    var value = this.getValue();
    if (this.lastValue != value) {
      this.callback(this.element, value);
      this.lastValue = value;
    }
  },

  registerFormCallbacks: function() {
    Form.getElements(this.element).each(this.registerCallback, this);
  },

  registerCallback: function(element) {
    if (element.type) {
      switch (element.type.toLowerCase()) {
        case 'checkbox':
        case 'radio':
          Event.observe(element, 'click', this.onElementEvent.bind(this));
          break;
        default:
          Event.observe(element, 'change', this.onElementEvent.bind(this));
          break;
      }
    }
  }
});

Form.Element.EventObserver = Class.create(Abstract.EventObserver, {
  getValue: function() {
    return Form.Element.getValue(this.element);
  }
});

Form.EventObserver = Class.create(Abstract.EventObserver, {
  getValue: function() {
    return Form.serialize(this.element);
  }
});
if (!window.Event) var Event = { };

Object.extend(Event, {
  KEY_BACKSPACE: 8,
  KEY_TAB:       9,
  KEY_RETURN:   13,
  KEY_ESC:      27,
  KEY_LEFT:     37,
  KEY_UP:       38,
  KEY_RIGHT:    39,
  KEY_DOWN:     40,
  KEY_DELETE:   46,
  KEY_HOME:     36,
  KEY_END:      35,
  KEY_PAGEUP:   33,
  KEY_PAGEDOWN: 34,
  KEY_INSERT:   45,

  cache: { },

  relatedTarget: function(event) {
    var element;
    switch(event.type) {
      case 'mouseover': element = event.fromElement; break;
      case 'mouseout':  element = event.toElement;   break;
      default: return null;
    }
    return Element.extend(element);
  }
});

Event.Methods = (function() {
  var isButton;

  if (Prototype.Browser.IE) {
    var buttonMap = { 0: 1, 1: 4, 2: 2 };
    isButton = function(event, code) {
      return event.button == buttonMap[code];
    };

  } else if (Prototype.Browser.WebKit) {
    isButton = function(event, code) {
      switch (code) {
        case 0: return event.which == 1 && !event.metaKey;
        case 1: return event.which == 1 && event.metaKey;
        default: return false;
      }
    };

  } else {
    isButton = function(event, code) {
      return event.which ? (event.which === code + 1) : (event.button === code);
    };
  }

  return {
    isLeftClick:   function(event) { return isButton(event, 0) },
    isMiddleClick: function(event) { return isButton(event, 1) },
    isRightClick:  function(event) { return isButton(event, 2) },

    element: function(event) {
      event = Event.extend(event);

      var node          = event.target,
          type          = event.type,
          currentTarget = event.currentTarget;

      if (currentTarget && currentTarget.tagName) {
        // Firefox screws up the "click" event when moving between radio buttons
        // via arrow keys. It also screws up the "load" and "error" events on images,
        // reporting the document as the target instead of the original image.
        if (type === 'load' || type === 'error' ||
          (type === 'click' && currentTarget.tagName.toLowerCase() === 'input'
            && currentTarget.type === 'radio'))
              node = currentTarget;
      }
      if (node.nodeType == Node.TEXT_NODE) node = node.parentNode;
      return Element.extend(node);
    },

    findElement: function(event, expression) {
      var element = Event.element(event);
      if (!expression) return element;
      var elements = [element].concat(element.ancestors());
      return Selector.findElement(elements, expression, 0);
    },

    pointer: function(event) {
      var docElement = document.documentElement,
      body = document.body || { scrollLeft: 0, scrollTop: 0 };
      return {
        x: event.pageX || (event.clientX +
          (docElement.scrollLeft || body.scrollLeft) -
          (docElement.clientLeft || 0)),
        y: event.pageY || (event.clientY +
          (docElement.scrollTop || body.scrollTop) -
          (docElement.clientTop || 0))
      };
    },

    pointerX: function(event) { return Event.pointer(event).x },
    pointerY: function(event) { return Event.pointer(event).y },

    stop: function(event) {
      Event.extend(event);
      event.preventDefault();
      event.stopPropagation();
      event.stopped = true;
    }
  };
})();

Event.extend = (function() {
  var methods = Object.keys(Event.Methods).inject({ }, function(m, name) {
    m[name] = Event.Methods[name].methodize();
    return m;
  });

  if (Prototype.Browser.IE) {
    Object.extend(methods, {
      stopPropagation: function() { this.cancelBubble = true },
      preventDefault:  function() { this.returnValue = false },
      inspect: function() { return "[object Event]" }
    });

    return function(event) {
      if (!event) return false;
      if (event._extendedByPrototype) return event;

      event._extendedByPrototype = Prototype.emptyFunction;
      var pointer = Event.pointer(event);
      Object.extend(event, {
        target: event.srcElement,
        relatedTarget: Event.relatedTarget(event),
        pageX:  pointer.x,
        pageY:  pointer.y
      });
      return Object.extend(event, methods);
    };

  } else {
    Event.prototype = Event.prototype || document.createEvent("HTMLEvents")['__proto__'];
    Object.extend(Event.prototype, methods);
    return Prototype.K;
  }
})();

Object.extend(Event, (function() {
  var cache = Event.cache;

  function getEventID(element) {
    if (element._prototypeEventID) return element._prototypeEventID[0];
    arguments.callee.id = arguments.callee.id || 1;
    return element._prototypeEventID = [++arguments.callee.id];
  }

  function getDOMEventName(eventName) {
    if (eventName && eventName.include(':')) return "dataavailable";
    return eventName;
  }

  function getCacheForID(id) {
    return cache[id] = cache[id] || { };
  }

  function getWrappersForEventName(id, eventName) {
    var c = getCacheForID(id);
    return c[eventName] = c[eventName] || [];
  }

  function createWrapper(element, eventName, handler) {
    var id = getEventID(element);
    var c = getWrappersForEventName(id, eventName);
    if (c.pluck("handler").include(handler)) return false;

    var wrapper = function(event) {
      if (!Event || !Event.extend ||
        (event.eventName && event.eventName != eventName))
          return false;

      Event.extend(event);
      handler.call(element, event);
    };

    wrapper.handler = handler;
    c.push(wrapper);
    return wrapper;
  }

  function findWrapper(id, eventName, handler) {
    var c = getWrappersForEventName(id, eventName);
    return c.find(function(wrapper) { return wrapper.handler == handler });
  }

  function destroyWrapper(id, eventName, handler) {
    var c = getCacheForID(id);
    if (!c[eventName]) return false;
    c[eventName] = c[eventName].without(findWrapper(id, eventName, handler));
  }

  function destroyCache() {
    for (var id in cache)
      for (var eventName in cache[id])
        cache[id][eventName] = null;
  }


  // Internet Explorer needs to remove event handlers on page unload
  // in order to avoid memory leaks.
  if (window.attachEvent) {
    window.attachEvent("onunload", destroyCache);
  }

  // Safari has a dummy event handler on page unload so that it won't
  // use its bfcache. Safari <= 3.1 has an issue with restoring the "document"
  // object when page is returned to via the back button using its bfcache.
  if (Prototype.Browser.WebKit) {
    window.addEventListener('unload', Prototype.emptyFunction, false);
  }

  return {
    observe: function(element, eventName, handler) {
      element = $(element);
      var name = getDOMEventName(eventName);

      var wrapper = createWrapper(element, eventName, handler);
      if (!wrapper) return element;

      if (element.addEventListener) {
        element.addEventListener(name, wrapper, false);
      } else {
        element.attachEvent("on" + name, wrapper);
      }

      return element;
    },

    stopObserving: function(element, eventName, handler) {
      element = $(element);
      var id = getEventID(element), name = getDOMEventName(eventName);

      if (!handler && eventName) {
        getWrappersForEventName(id, eventName).each(function(wrapper) {
          element.stopObserving(eventName, wrapper.handler);
        });
        return element;

      } else if (!eventName) {
        Object.keys(getCacheForID(id)).each(function(eventName) {
          element.stopObserving(eventName);
        });
        return element;
      }

      var wrapper = findWrapper(id, eventName, handler);
      if (!wrapper) return element;

      if (element.removeEventListener) {
        element.removeEventListener(name, wrapper, false);
      } else {
        element.detachEvent("on" + name, wrapper);
      }

      destroyWrapper(id, eventName, handler);

      return element;
    },

    fire: function(element, eventName, memo) {
      element = $(element);
      if (element == document && document.createEvent && !element.dispatchEvent)
        element = document.documentElement;

      var event;
      if (document.createEvent) {
        event = document.createEvent("HTMLEvents");
        event.initEvent("dataavailable", true, true);
      } else {
        event = document.createEventObject();
        event.eventType = "ondataavailable";
      }

      event.eventName = eventName;
      event.memo = memo || { };

      if (document.createEvent) {
        element.dispatchEvent(event);
      } else {
        element.fireEvent(event.eventType, event);
      }

      return Event.extend(event);
    }
  };
})());

Object.extend(Event, Event.Methods);

Element.addMethods({
  fire:          Event.fire,
  observe:       Event.observe,
  stopObserving: Event.stopObserving
});

Object.extend(document, {
  fire:          Element.Methods.fire.methodize(),
  observe:       Element.Methods.observe.methodize(),
  stopObserving: Element.Methods.stopObserving.methodize(),
  loaded:        false
});

(function() {
  /* Support for the DOMContentLoaded event is based on work by Dan Webb,
     Matthias Miller, Dean Edwards and John Resig. */

  var timer;

  function fireContentLoadedEvent() {
    if (document.loaded) return;
    if (timer) window.clearInterval(timer);
    document.fire("dom:loaded");
    document.loaded = true;
  }

  if (document.addEventListener) {
    if (Prototype.Browser.WebKit) {
      timer = window.setInterval(function() {
        if (/loaded|complete/.test(document.readyState))
          fireContentLoadedEvent();
      }, 0);

      Event.observe(window, "load", fireContentLoadedEvent);

    } else {
      document.addEventListener("DOMContentLoaded",
        fireContentLoadedEvent, false);
    }

  } else {
    document.write("<script id=__onDOMContentLoaded defer src=//:><\/script>");
    $("__onDOMContentLoaded").onreadystatechange = function() {
      if (this.readyState == "complete") {
        this.onreadystatechange = null;
        fireContentLoadedEvent();
      }
    };
  }
})();
/*------------------------------- DEPRECATED -------------------------------*/

Hash.toQueryString = Object.toQueryString;

var Toggle = { display: Element.toggle };

Element.Methods.childOf = Element.Methods.descendantOf;

var Insertion = {
  Before: function(element, content) {
    return Element.insert(element, {before:content});
  },

  Top: function(element, content) {
    return Element.insert(element, {top:content});
  },

  Bottom: function(element, content) {
    return Element.insert(element, {bottom:content});
  },

  After: function(element, content) {
    return Element.insert(element, {after:content});
  }
};

var $continue = new Error('"throw $continue" is deprecated, use "return" instead');

// This should be moved to script.aculo.us; notice the deprecated methods
// further below, that map to the newer Element methods.
var Position = {
  // set to true if needed, warning: firefox performance problems
  // NOT neeeded for page scrolling, only if draggable contained in
  // scrollable elements
  includeScrollOffsets: false,

  // must be called before calling withinIncludingScrolloffset, every time the
  // page is scrolled
  prepare: function() {
    this.deltaX =  window.pageXOffset
                || document.documentElement.scrollLeft
                || document.body.scrollLeft
                || 0;
    this.deltaY =  window.pageYOffset
                || document.documentElement.scrollTop
                || document.body.scrollTop
                || 0;
  },

  // caches x/y coordinate pair to use with overlap
  within: function(element, x, y) {
    if (this.includeScrollOffsets)
      return this.withinIncludingScrolloffsets(element, x, y);
    this.xcomp = x;
    this.ycomp = y;
    this.offset = Element.cumulativeOffset(element);

    return (y >= this.offset[1] &&
            y <  this.offset[1] + element.offsetHeight &&
            x >= this.offset[0] &&
            x <  this.offset[0] + element.offsetWidth);
  },

  withinIncludingScrolloffsets: function(element, x, y) {
    var offsetcache = Element.cumulativeScrollOffset(element);

    this.xcomp = x + offsetcache[0] - this.deltaX;
    this.ycomp = y + offsetcache[1] - this.deltaY;
    this.offset = Element.cumulativeOffset(element);

    return (this.ycomp >= this.offset[1] &&
            this.ycomp <  this.offset[1] + element.offsetHeight &&
            this.xcomp >= this.offset[0] &&
            this.xcomp <  this.offset[0] + element.offsetWidth);
  },

  // within must be called directly before
  overlap: function(mode, element) {
    if (!mode) return 0;
    if (mode == 'vertical')
      return ((this.offset[1] + element.offsetHeight) - this.ycomp) /
        element.offsetHeight;
    if (mode == 'horizontal')
      return ((this.offset[0] + element.offsetWidth) - this.xcomp) /
        element.offsetWidth;
  },

  // Deprecation layer -- use newer Element methods now (1.5.2).

  cumulativeOffset: Element.Methods.cumulativeOffset,

  positionedOffset: Element.Methods.positionedOffset,

  absolutize: function(element) {
    Position.prepare();
    return Element.absolutize(element);
  },

  relativize: function(element) {
    Position.prepare();
    return Element.relativize(element);
  },

  realOffset: Element.Methods.cumulativeScrollOffset,

  offsetParent: Element.Methods.getOffsetParent,

  page: Element.Methods.viewportOffset,

  clone: function(source, target, options) {
    options = options || { };
    return Element.clonePosition(target, source, options);
  }
};

/*--------------------------------------------------------------------------*/

if (!document.getElementsByClassName) document.getElementsByClassName = function(instanceMethods){
  function iter(name) {
    return name.blank() ? null : "[contains(concat(' ', @class, ' '), ' " + name + " ')]";
  }

  instanceMethods.getElementsByClassName = Prototype.BrowserFeatures.XPath ?
  function(element, className) {
    className = className.toString().strip();
    var cond = /\s/.test(className) ? $w(className).map(iter).join('') : iter(className);
    return cond ? document._getElementsByXPath('.//*' + cond, element) : [];
  } : function(element, className) {
    className = className.toString().strip();
    var elements = [], classNames = (/\s/.test(className) ? $w(className) : null);
    if (!classNames && !className) return elements;

    var nodes = $(element).getElementsByTagName('*');
    className = ' ' + className + ' ';

    for (var i = 0, child, cn; child = nodes[i]; i++) {
      if (child.className && (cn = ' ' + child.className + ' ') && (cn.include(className) ||
          (classNames && classNames.all(function(name) {
            return !name.toString().blank() && cn.include(' ' + name + ' ');
          }))))
        elements.push(Element.extend(child));
    }
    return elements;
  };

  return function(className, parentElement) {
    return $(parentElement || document.body).getElementsByClassName(className);
  };
}(Element.Methods);

/*--------------------------------------------------------------------------*/

Element.ClassNames = Class.create();
Element.ClassNames.prototype = {
  initialize: function(element) {
    this.element = $(element);
  },

  _each: function(iterator) {
    this.element.className.split(/\s+/).select(function(name) {
      return name.length > 0;
    })._each(iterator);
  },

  set: function(className) {
    this.element.className = className;
  },

  add: function(classNameToAdd) {
    if (this.include(classNameToAdd)) return;
    this.set($A(this).concat(classNameToAdd).join(' '));
  },

  remove: function(classNameToRemove) {
    if (!this.include(classNameToRemove)) return;
    this.set($A(this).without(classNameToRemove).join(' '));
  },

  toString: function() {
    return $A(this).join(' ');
  }
};

Object.extend(Element.ClassNames.prototype, Enumerable);

/*--------------------------------------------------------------------------*/

Element.addMethods();






// script.aculo.us scriptaculous.js v1.8.2, Tue Nov 18 18:30:58 +0100 2008

// Copyright (c) 2005-2008 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// For details, see the script.aculo.us web site: http://script.aculo.us/

var Scriptaculous = {
  Version: '1.8.2',
  require: function(libraryName) {
    // inserting via DOM fails in Safari 2.0, so brute force approach
    document.write('<script type="text/javascript" src="'+libraryName+'"><\/script>');
  },
  REQUIRED_PROTOTYPE: '1.6.0.3',
  load: function() {
    function convertVersionString(versionString) {
      var v = versionString.replace(/_.*|\./g, '');
      v = parseInt(v + '0'.times(4-v.length));
      return versionString.indexOf('_') > -1 ? v-1 : v;
    }

    if((typeof Prototype=='undefined') ||
       (typeof Element == 'undefined') ||
       (typeof Element.Methods=='undefined') ||
       (convertVersionString(Prototype.Version) <
        convertVersionString(Scriptaculous.REQUIRED_PROTOTYPE)))
       throw("script.aculo.us requires the Prototype JavaScript framework >= " +
        Scriptaculous.REQUIRED_PROTOTYPE);

    var js = /scriptaculous\.js(\?.*)?$/;
    $$('head script[src]').findAll(function(s) {
      return s.src.match(js);
    }).each(function(s) {
      var path = s.src.replace(js, ''),
      includes = s.src.match(/\?.*load=([a-z,]*)/);
      (includes ? includes[1] : 'builder,effects,dragdrop,controls,slider,sound').split(',').each(
       function(include) { Scriptaculous.require(path+include+'.js') });
    });
  }
};

Scriptaculous.load();







// script.aculo.us builder.js v1.8.2, Tue Nov 18 18:30:58 +0100 2008

// Copyright (c) 2005-2008 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
//
// script.aculo.us is freely distributable under the terms of an MIT-style license.
// For details, see the script.aculo.us web site: http://script.aculo.us/

var Builder = {
  NODEMAP: {
    AREA: 'map',
    CAPTION: 'table',
    COL: 'table',
    COLGROUP: 'table',
    LEGEND: 'fieldset',
    OPTGROUP: 'select',
    OPTION: 'select',
    PARAM: 'object',
    TBODY: 'table',
    TD: 'table',
    TFOOT: 'table',
    TH: 'table',
    THEAD: 'table',
    TR: 'table'
  },
  // note: For Firefox < 1.5, OPTION and OPTGROUP tags are currently broken,
  //       due to a Firefox bug
  node: function(elementName) {
    elementName = elementName.toUpperCase();

    // try innerHTML approach
    var parentTag = this.NODEMAP[elementName] || 'div';
    var parentElement = document.createElement(parentTag);
    try { // prevent IE "feature": http://dev.rubyonrails.org/ticket/2707
      parentElement.innerHTML = "<" + elementName + "></" + elementName + ">";
    } catch(e) {}
    var element = parentElement.firstChild || null;

    // see if browser added wrapping tags
    if(element && (element.tagName.toUpperCase() != elementName))
      element = element.getElementsByTagName(elementName)[0];

    // fallback to createElement approach
    if(!element) element = document.createElement(elementName);

    // abort if nothing could be created
    if(!element) return;

    // attributes (or text)
    if(arguments[1])
      if(this._isStringOrNumber(arguments[1]) ||
        (arguments[1] instanceof Array) ||
        arguments[1].tagName) {
          this._children(element, arguments[1]);
        } else {
          var attrs = this._attributes(arguments[1]);
          if(attrs.length) {
            try { // prevent IE "feature": http://dev.rubyonrails.org/ticket/2707
              parentElement.innerHTML = "<" +elementName + " " +
                attrs + "></" + elementName + ">";
            } catch(e) {}
            element = parentElement.firstChild || null;
            // workaround firefox 1.0.X bug
            if(!element) {
              element = document.createElement(elementName);
              for(attr in arguments[1])
                element[attr == 'class' ? 'className' : attr] = arguments[1][attr];
            }
            if(element.tagName.toUpperCase() != elementName)
              element = parentElement.getElementsByTagName(elementName)[0];
          }
        }

    // text, or array of children
    if(arguments[2])
      this._children(element, arguments[2]);

     return $(element);
  },
  _text: function(text) {
     return document.createTextNode(text);
  },

  ATTR_MAP: {
    'className': 'class',
    'htmlFor': 'for'
  },

  _attributes: function(attributes) {
    var attrs = [];
    for(attribute in attributes)
      attrs.push((attribute in this.ATTR_MAP ? this.ATTR_MAP[attribute] : attribute) +
          '="' + attributes[attribute].toString().escapeHTML().gsub(/"/,'&quot;') + '"');
    return attrs.join(" ");
  },
  _children: function(element, children) {
    if(children.tagName) {
      element.appendChild(children);
      return;
    }
    if(typeof children=='object') { // array can hold nodes and text
      children.flatten().each( function(e) {
        if(typeof e=='object')
          element.appendChild(e);
        else
          if(Builder._isStringOrNumber(e))
            element.appendChild(Builder._text(e));
      });
    } else
      if(Builder._isStringOrNumber(children))
        element.appendChild(Builder._text(children));
  },
  _isStringOrNumber: function(param) {
    return(typeof param=='string' || typeof param=='number');
  },
  build: function(html) {
    var element = this.node('div');
    $(element).update(html.strip());
    return element.down();
  },
  dump: function(scope) {
    if(typeof scope != 'object' && typeof scope != 'function') scope = window; //global scope

    var tags = ("A ABBR ACRONYM ADDRESS APPLET AREA B BASE BASEFONT BDO BIG BLOCKQUOTE BODY " +
      "BR BUTTON CAPTION CENTER CITE CODE COL COLGROUP DD DEL DFN DIR DIV DL DT EM FIELDSET " +
      "FONT FORM FRAME FRAMESET H1 H2 H3 H4 H5 H6 HEAD HR HTML I IFRAME IMG INPUT INS ISINDEX "+
      "KBD LABEL LEGEND LI LINK MAP MENU META NOFRAMES NOSCRIPT OBJECT OL OPTGROUP OPTION P "+
      "PARAM PRE Q S SAMP SCRIPT SELECT SMALL SPAN STRIKE STRONG STYLE SUB SUP TABLE TBODY TD "+
      "TEXTAREA TFOOT TH THEAD TITLE TR TT U UL VAR").split(/\s+/);

    tags.each( function(tag){
      scope[tag] = function() {
        return Builder.node.apply(Builder, [tag].concat($A(arguments)));
      };
    });
  }
};







// script.aculo.us effects.js v1.8.2, Tue Nov 18 18:30:58 +0100 2008

// Copyright (c) 2005-2008 Thomas Fuchs (http://script.aculo.us, http://mir.aculo.us)
// Contributors:
//  Justin Palmer (http://encytemedia.com/)
//  Mark Pilgrim (http://diveintomark.org/)
//  Martin Bialasinki
//
// script.aculo.us is freely distributable under the terms of an MIT-style license.
// For details, see the script.aculo.us web site: http://script.aculo.us/

// converts rgb() and #xxx to #xxxxxx format,
// returns self (or first argument) if not convertable
String.prototype.parseColor = function() {
  var color = '#';
  if (this.slice(0,4) == 'rgb(') {
    var cols = this.slice(4,this.length-1).split(',');
    var i=0; do { color += parseInt(cols[i]).toColorPart() } while (++i<3);
  } else {
    if (this.slice(0,1) == '#') {
      if (this.length==4) for(var i=1;i<4;i++) color += (this.charAt(i) + this.charAt(i)).toLowerCase();
      if (this.length==7) color = this.toLowerCase();
    }
  }
  return (color.length==7 ? color : (arguments[0] || this));
};

/*--------------------------------------------------------------------------*/

Element.collectTextNodes = function(element) {
  return $A($(element).childNodes).collect( function(node) {
    return (node.nodeType==3 ? node.nodeValue :
      (node.hasChildNodes() ? Element.collectTextNodes(node) : ''));
  }).flatten().join('');
};

Element.collectTextNodesIgnoreClass = function(element, className) {
  return $A($(element).childNodes).collect( function(node) {
    return (node.nodeType==3 ? node.nodeValue :
      ((node.hasChildNodes() && !Element.hasClassName(node,className)) ?
        Element.collectTextNodesIgnoreClass(node, className) : ''));
  }).flatten().join('');
};

Element.setContentZoom = function(element, percent) {
  element = $(element);
  element.setStyle({fontSize: (percent/100) + 'em'});
  if (Prototype.Browser.WebKit) window.scrollBy(0,0);
  return element;
};

Element.getInlineOpacity = function(element){
  return $(element).style.opacity || '';
};

Element.forceRerendering = function(element) {
  try {
    element = $(element);
    var n = document.createTextNode(' ');
    element.appendChild(n);
    element.removeChild(n);
  } catch(e) { }
};

/*--------------------------------------------------------------------------*/

var Effect = {
  _elementDoesNotExistError: {
    name: 'ElementDoesNotExistError',
    message: 'The specified DOM element does not exist, but is required for this effect to operate'
  },
  Transitions: {
    linear: Prototype.K,
    sinoidal: function(pos) {
      return (-Math.cos(pos*Math.PI)/2) + .5;
    },
    reverse: function(pos) {
      return 1-pos;
    },
    flicker: function(pos) {
      var pos = ((-Math.cos(pos*Math.PI)/4) + .75) + Math.random()/4;
      return pos > 1 ? 1 : pos;
    },
    wobble: function(pos) {
      return (-Math.cos(pos*Math.PI*(9*pos))/2) + .5;
    },
    pulse: function(pos, pulses) {
      return (-Math.cos((pos*((pulses||5)-.5)*2)*Math.PI)/2) + .5;
    },
    spring: function(pos) {
      return 1 - (Math.cos(pos * 4.5 * Math.PI) * Math.exp(-pos * 6));
    },
    none: function(pos) {
      return 0;
    },
    full: function(pos) {
      return 1;
    }
  },
  DefaultOptions: {
    duration:   1.0,   // seconds
    fps:        100,   // 100= assume 66fps max.
    sync:       false, // true for combining
    from:       0.0,
    to:         1.0,
    delay:      0.0,
    queue:      'parallel'
  },
  tagifyText: function(element) {
    var tagifyStyle = 'position:relative';
    if (Prototype.Browser.IE) tagifyStyle += ';zoom:1';

    element = $(element);
    $A(element.childNodes).each( function(child) {
      if (child.nodeType==3) {
        child.nodeValue.toArray().each( function(character) {
          element.insertBefore(
            new Element('span', {style: tagifyStyle}).update(
              character == ' ' ? String.fromCharCode(160) : character),
              child);
        });
        Element.remove(child);
      }
    });
  },
  multiple: function(element, effect) {
    var elements;
    if (((typeof element == 'object') ||
        Object.isFunction(element)) &&
       (element.length))
      elements = element;
    else
      elements = $(element).childNodes;

    var options = Object.extend({
      speed: 0.1,
      delay: 0.0
    }, arguments[2] || { });
    var masterDelay = options.delay;

    $A(elements).each( function(element, index) {
      new effect(element, Object.extend(options, { delay: index * options.speed + masterDelay }));
    });
  },
  PAIRS: {
    'slide':  ['SlideDown','SlideUp'],
    'blind':  ['BlindDown','BlindUp'],
    'appear': ['Appear','Fade']
  },
  toggle: function(element, effect) {
    element = $(element);
    effect = (effect || 'appear').toLowerCase();
    var options = Object.extend({
      queue: { position:'end', scope:(element.id || 'global'), limit: 1 }
    }, arguments[2] || { });
    Effect[element.visible() ?
      Effect.PAIRS[effect][1] : Effect.PAIRS[effect][0]](element, options);
  }
};

Effect.DefaultOptions.transition = Effect.Transitions.sinoidal;

/* ------------- core effects ------------- */

Effect.ScopedQueue = Class.create(Enumerable, {
  initialize: function() {
    this.effects  = [];
    this.interval = null;
  },
  _each: function(iterator) {
    this.effects._each(iterator);
  },
  add: function(effect) {
    var timestamp = new Date().getTime();

    var position = Object.isString(effect.options.queue) ?
      effect.options.queue : effect.options.queue.position;

    switch(position) {
      case 'front':
        // move unstarted effects after this effect
        this.effects.findAll(function(e){ return e.state=='idle' }).each( function(e) {
            e.startOn  += effect.finishOn;
            e.finishOn += effect.finishOn;
          });
        break;
      case 'with-last':
        timestamp = this.effects.pluck('startOn').max() || timestamp;
        break;
      case 'end':
        // start effect after last queued effect has finished
        timestamp = this.effects.pluck('finishOn').max() || timestamp;
        break;
    }

    effect.startOn  += timestamp;
    effect.finishOn += timestamp;

    if (!effect.options.queue.limit || (this.effects.length < effect.options.queue.limit))
      this.effects.push(effect);

    if (!this.interval)
      this.interval = setInterval(this.loop.bind(this), 15);
  },
  remove: function(effect) {
    this.effects = this.effects.reject(function(e) { return e==effect });
    if (this.effects.length == 0) {
      clearInterval(this.interval);
      this.interval = null;
    }
  },
  loop: function() {
    var timePos = new Date().getTime();
    for(var i=0, len=this.effects.length;i<len;i++)
      this.effects[i] && this.effects[i].loop(timePos);
  }
});

Effect.Queues = {
  instances: $H(),
  get: function(queueName) {
    if (!Object.isString(queueName)) return queueName;

    return this.instances.get(queueName) ||
      this.instances.set(queueName, new Effect.ScopedQueue());
  }
};
Effect.Queue = Effect.Queues.get('global');

Effect.Base = Class.create({
  position: null,
  start: function(options) {
    function codeForEvent(options,eventName){
      return (
        (options[eventName+'Internal'] ? 'this.options.'+eventName+'Internal(this);' : '') +
        (options[eventName] ? 'this.options.'+eventName+'(this);' : '')
      );
    }
    if (options && options.transition === false) options.transition = Effect.Transitions.linear;
    this.options      = Object.extend(Object.extend({ },Effect.DefaultOptions), options || { });
    this.currentFrame = 0;
    this.state        = 'idle';
    this.startOn      = this.options.delay*1000;
    this.finishOn     = this.startOn+(this.options.duration*1000);
    this.fromToDelta  = this.options.to-this.options.from;
    this.totalTime    = this.finishOn-this.startOn;
    this.totalFrames  = this.options.fps*this.options.duration;

    this.render = (function() {
      function dispatch(effect, eventName) {
        if (effect.options[eventName + 'Internal'])
          effect.options[eventName + 'Internal'](effect);
        if (effect.options[eventName])
          effect.options[eventName](effect);
      }

      return function(pos) {
        if (this.state === "idle") {
          this.state = "running";
          dispatch(this, 'beforeSetup');
          if (this.setup) this.setup();
          dispatch(this, 'afterSetup');
        }
        if (this.state === "running") {
          pos = (this.options.transition(pos) * this.fromToDelta) + this.options.from;
          this.position = pos;
          dispatch(this, 'beforeUpdate');
          if (this.update) this.update(pos);
          dispatch(this, 'afterUpdate');
        }
      };
    })();

    this.event('beforeStart');
    if (!this.options.sync)
      Effect.Queues.get(Object.isString(this.options.queue) ?
        'global' : this.options.queue.scope).add(this);
  },
  loop: function(timePos) {
    if (timePos >= this.startOn) {
      if (timePos >= this.finishOn) {
        this.render(1.0);
        this.cancel();
        this.event('beforeFinish');
        if (this.finish) this.finish();
        this.event('afterFinish');
        return;
      }
      var pos   = (timePos - this.startOn) / this.totalTime,
          frame = (pos * this.totalFrames).round();
      if (frame > this.currentFrame) {
        this.render(pos);
        this.currentFrame = frame;
      }
    }
  },
  cancel: function() {
    if (!this.options.sync)
      Effect.Queues.get(Object.isString(this.options.queue) ?
        'global' : this.options.queue.scope).remove(this);
    this.state = 'finished';
  },
  event: function(eventName) {
    if (this.options[eventName + 'Internal']) this.options[eventName + 'Internal'](this);
    if (this.options[eventName]) this.options[eventName](this);
  },
  inspect: function() {
    var data = $H();
    for(property in this)
      if (!Object.isFunction(this[property])) data.set(property, this[property]);
    return '#<Effect:' + data.inspect() + ',options:' + $H(this.options).inspect() + '>';
  }
});

Effect.Parallel = Class.create(Effect.Base, {
  initialize: function(effects) {
    this.effects = effects || [];
    this.start(arguments[1]);
  },
  update: function(position) {
    this.effects.invoke('render', position);
  },
  finish: function(position) {
    this.effects.each( function(effect) {
      effect.render(1.0);
      effect.cancel();
      effect.event('beforeFinish');
      if (effect.finish) effect.finish(position);
      effect.event('afterFinish');
    });
  }
});

Effect.Tween = Class.create(Effect.Base, {
  initialize: function(object, from, to) {
    object = Object.isString(object) ? $(object) : object;
    var args = $A(arguments), method = args.last(),
      options = args.length == 5 ? args[3] : null;
    this.method = Object.isFunction(method) ? method.bind(object) :
      Object.isFunction(object[method]) ? object[method].bind(object) :
      function(value) { object[method] = value };
    this.start(Object.extend({ from: from, to: to }, options || { }));
  },
  update: function(position) {
    this.method(position);
  }
});

Effect.Event = Class.create(Effect.Base, {
  initialize: function() {
    this.start(Object.extend({ duration: 0 }, arguments[0] || { }));
  },
  update: Prototype.emptyFunction
});

Effect.Opacity = Class.create(Effect.Base, {
  initialize: function(element) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    // make this work on IE on elements without 'layout'
    if (Prototype.Browser.IE && (!this.element.currentStyle.hasLayout))
      this.element.setStyle({zoom: 1});
    var options = Object.extend({
      from: this.element.getOpacity() || 0.0,
      to:   1.0
    }, arguments[1] || { });
    this.start(options);
  },
  update: function(position) {
    this.element.setOpacity(position);
  }
});

Effect.Move = Class.create(Effect.Base, {
  initialize: function(element) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({
      x:    0,
      y:    0,
      mode: 'relative'
    }, arguments[1] || { });
    this.start(options);
  },
  setup: function() {
    this.element.makePositioned();
    this.originalLeft = parseFloat(this.element.getStyle('left') || '0');
    this.originalTop  = parseFloat(this.element.getStyle('top')  || '0');
    if (this.options.mode == 'absolute') {
      this.options.x = this.options.x - this.originalLeft;
      this.options.y = this.options.y - this.originalTop;
    }
  },
  update: function(position) {
    this.element.setStyle({
      left: (this.options.x  * position + this.originalLeft).round() + 'px',
      top:  (this.options.y  * position + this.originalTop).round()  + 'px'
    });
  }
});

// for backwards compatibility
Effect.MoveBy = function(element, toTop, toLeft) {
  return new Effect.Move(element,
    Object.extend({ x: toLeft, y: toTop }, arguments[3] || { }));
};

Effect.Scale = Class.create(Effect.Base, {
  initialize: function(element, percent) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({
      scaleX: true,
      scaleY: true,
      scaleContent: true,
      scaleFromCenter: false,
      scaleMode: 'box',        // 'box' or 'contents' or { } with provided values
      scaleFrom: 100.0,
      scaleTo:   percent
    }, arguments[2] || { });
    this.start(options);
  },
  setup: function() {
    this.restoreAfterFinish = this.options.restoreAfterFinish || false;
    this.elementPositioning = this.element.getStyle('position');

    this.originalStyle = { };
    ['top','left','width','height','fontSize'].each( function(k) {
      this.originalStyle[k] = this.element.style[k];
    }.bind(this));

    this.originalTop  = this.element.offsetTop;
    this.originalLeft = this.element.offsetLeft;

    var fontSize = this.element.getStyle('font-size') || '100%';
    ['em','px','%','pt'].each( function(fontSizeType) {
      if (fontSize.indexOf(fontSizeType)>0) {
        this.fontSize     = parseFloat(fontSize);
        this.fontSizeType = fontSizeType;
      }
    }.bind(this));

    this.factor = (this.options.scaleTo - this.options.scaleFrom)/100;

    this.dims = null;
    if (this.options.scaleMode=='box')
      this.dims = [this.element.offsetHeight, this.element.offsetWidth];
    if (/^content/.test(this.options.scaleMode))
      this.dims = [this.element.scrollHeight, this.element.scrollWidth];
    if (!this.dims)
      this.dims = [this.options.scaleMode.originalHeight,
                   this.options.scaleMode.originalWidth];
  },
  update: function(position) {
    var currentScale = (this.options.scaleFrom/100.0) + (this.factor * position);
    if (this.options.scaleContent && this.fontSize)
      this.element.setStyle({fontSize: this.fontSize * currentScale + this.fontSizeType });
    this.setDimensions(this.dims[0] * currentScale, this.dims[1] * currentScale);
  },
  finish: function(position) {
    if (this.restoreAfterFinish) this.element.setStyle(this.originalStyle);
  },
  setDimensions: function(height, width) {
    var d = { };
    if (this.options.scaleX) d.width = width.round() + 'px';
    if (this.options.scaleY) d.height = height.round() + 'px';
    if (this.options.scaleFromCenter) {
      var topd  = (height - this.dims[0])/2;
      var leftd = (width  - this.dims[1])/2;
      if (this.elementPositioning == 'absolute') {
        if (this.options.scaleY) d.top = this.originalTop-topd + 'px';
        if (this.options.scaleX) d.left = this.originalLeft-leftd + 'px';
      } else {
        if (this.options.scaleY) d.top = -topd + 'px';
        if (this.options.scaleX) d.left = -leftd + 'px';
      }
    }
    this.element.setStyle(d);
  }
});

Effect.Highlight = Class.create(Effect.Base, {
  initialize: function(element) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({ startcolor: '#ffff99' }, arguments[1] || { });
    this.start(options);
  },
  setup: function() {
    // Prevent executing on elements not in the layout flow
    if (this.element.getStyle('display')=='none') { this.cancel(); return; }
    // Disable background image during the effect
    this.oldStyle = { };
    if (!this.options.keepBackgroundImage) {
      this.oldStyle.backgroundImage = this.element.getStyle('background-image');
      this.element.setStyle({backgroundImage: 'none'});
    }
    if (!this.options.endcolor)
      this.options.endcolor = this.element.getStyle('background-color').parseColor('#ffffff');
    if (!this.options.restorecolor)
      this.options.restorecolor = this.element.getStyle('background-color');
    // init color calculations
    this._base  = $R(0,2).map(function(i){ return parseInt(this.options.startcolor.slice(i*2+1,i*2+3),16) }.bind(this));
    this._delta = $R(0,2).map(function(i){ return parseInt(this.options.endcolor.slice(i*2+1,i*2+3),16)-this._base[i] }.bind(this));
  },
  update: function(position) {
    this.element.setStyle({backgroundColor: $R(0,2).inject('#',function(m,v,i){
      return m+((this._base[i]+(this._delta[i]*position)).round().toColorPart()); }.bind(this)) });
  },
  finish: function() {
    this.element.setStyle(Object.extend(this.oldStyle, {
      backgroundColor: this.options.restorecolor
    }));
  }
});

Effect.ScrollTo = function(element) {
  var options = arguments[1] || { },
  scrollOffsets = document.viewport.getScrollOffsets(),
  elementOffsets = $(element).cumulativeOffset();

  if (options.offset) elementOffsets[1] += options.offset;

  return new Effect.Tween(null,
    scrollOffsets.top,
    elementOffsets[1],
    options,
    function(p){ scrollTo(scrollOffsets.left, p.round()); }
  );
};

/* ------------- combination effects ------------- */

Effect.Fade = function(element) {
  element = $(element);
  var oldOpacity = element.getInlineOpacity();
  var options = Object.extend({
    from: element.getOpacity() || 1.0,
    to:   0.0,
    afterFinishInternal: function(effect) {
      if (effect.options.to!=0) return;
      effect.element.hide().setStyle({opacity: oldOpacity});
    }
  }, arguments[1] || { });
  return new Effect.Opacity(element,options);
};

Effect.Appear = function(element) {
  element = $(element);
  var options = Object.extend({
  from: (element.getStyle('display') == 'none' ? 0.0 : element.getOpacity() || 0.0),
  to:   1.0,
  // force Safari to render floated elements properly
  afterFinishInternal: function(effect) {
    effect.element.forceRerendering();
  },
  beforeSetup: function(effect) {
    effect.element.setOpacity(effect.options.from).show();
  }}, arguments[1] || { });
  return new Effect.Opacity(element,options);
};

Effect.Puff = function(element) {
  element = $(element);
  var oldStyle = {
    opacity: element.getInlineOpacity(),
    position: element.getStyle('position'),
    top:  element.style.top,
    left: element.style.left,
    width: element.style.width,
    height: element.style.height
  };
  return new Effect.Parallel(
   [ new Effect.Scale(element, 200,
      { sync: true, scaleFromCenter: true, scaleContent: true, restoreAfterFinish: true }),
     new Effect.Opacity(element, { sync: true, to: 0.0 } ) ],
     Object.extend({ duration: 1.0,
      beforeSetupInternal: function(effect) {
        Position.absolutize(effect.effects[0].element);
      },
      afterFinishInternal: function(effect) {
         effect.effects[0].element.hide().setStyle(oldStyle); }
     }, arguments[1] || { })
   );
};

Effect.BlindUp = function(element) {
  element = $(element);
  element.makeClipping();
  return new Effect.Scale(element, 0,
    Object.extend({ scaleContent: false,
      scaleX: false,
      restoreAfterFinish: true,
      afterFinishInternal: function(effect) {
        effect.element.hide().undoClipping();
      }
    }, arguments[1] || { })
  );
};

Effect.BlindDown = function(element) {
  element = $(element);
  var elementDimensions = element.getDimensions();
  return new Effect.Scale(element, 100, Object.extend({
    scaleContent: false,
    scaleX: false,
    scaleFrom: 0,
    scaleMode: {originalHeight: elementDimensions.height, originalWidth: elementDimensions.width},
    restoreAfterFinish: true,
    afterSetup: function(effect) {
      effect.element.makeClipping().setStyle({height: '0px'}).show();
    },
    afterFinishInternal: function(effect) {
      effect.element.undoClipping();
    }
  }, arguments[1] || { }));
};

Effect.SwitchOff = function(element) {
  element = $(element);
  var oldOpacity = element.getInlineOpacity();
  return new Effect.Appear(element, Object.extend({
    duration: 0.4,
    from: 0,
    transition: Effect.Transitions.flicker,
    afterFinishInternal: function(effect) {
      new Effect.Scale(effect.element, 1, {
        duration: 0.3, scaleFromCenter: true,
        scaleX: false, scaleContent: false, restoreAfterFinish: true,
        beforeSetup: function(effect) {
          effect.element.makePositioned().makeClipping();
        },
        afterFinishInternal: function(effect) {
          effect.element.hide().undoClipping().undoPositioned().setStyle({opacity: oldOpacity});
        }
      });
    }
  }, arguments[1] || { }));
};

Effect.DropOut = function(element) {
  element = $(element);
  var oldStyle = {
    top: element.getStyle('top'),
    left: element.getStyle('left'),
    opacity: element.getInlineOpacity() };
  return new Effect.Parallel(
    [ new Effect.Move(element, {x: 0, y: 100, sync: true }),
      new Effect.Opacity(element, { sync: true, to: 0.0 }) ],
    Object.extend(
      { duration: 0.5,
        beforeSetup: function(effect) {
          effect.effects[0].element.makePositioned();
        },
        afterFinishInternal: function(effect) {
          effect.effects[0].element.hide().undoPositioned().setStyle(oldStyle);
        }
      }, arguments[1] || { }));
};

Effect.Shake = function(element) {
  element = $(element);
  var options = Object.extend({
    distance: 20,
    duration: 0.5
  }, arguments[1] || {});
  var distance = parseFloat(options.distance);
  var split = parseFloat(options.duration) / 10.0;
  var oldStyle = {
    top: element.getStyle('top'),
    left: element.getStyle('left') };
    return new Effect.Move(element,
      { x:  distance, y: 0, duration: split, afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x: -distance*2, y: 0, duration: split*2,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x:  distance*2, y: 0, duration: split*2,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x: -distance*2, y: 0, duration: split*2,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x:  distance*2, y: 0, duration: split*2,  afterFinishInternal: function(effect) {
    new Effect.Move(effect.element,
      { x: -distance, y: 0, duration: split, afterFinishInternal: function(effect) {
        effect.element.undoPositioned().setStyle(oldStyle);
  }}); }}); }}); }}); }}); }});
};

Effect.SlideDown = function(element) {
  element = $(element).cleanWhitespace();
  // SlideDown need to have the content of the element wrapped in a container element with fixed height!
  var oldInnerBottom = element.down().getStyle('bottom');
  var elementDimensions = element.getDimensions();
  return new Effect.Scale(element, 100, Object.extend({
    scaleContent: false,
    scaleX: false,
    scaleFrom: window.opera ? 0 : 1,
    scaleMode: {originalHeight: elementDimensions.height, originalWidth: elementDimensions.width},
    restoreAfterFinish: true,
    afterSetup: function(effect) {
      effect.element.makePositioned();
      effect.element.down().makePositioned();
      if (window.opera) effect.element.setStyle({top: ''});
      effect.element.makeClipping().setStyle({height: '0px'}).show();
    },
    afterUpdateInternal: function(effect) {
      effect.element.down().setStyle({bottom:
        (effect.dims[0] - effect.element.clientHeight) + 'px' });
    },
    afterFinishInternal: function(effect) {
      effect.element.undoClipping().undoPositioned();
      effect.element.down().undoPositioned().setStyle({bottom: oldInnerBottom}); }
    }, arguments[1] || { })
  );
};

Effect.SlideUp = function(element) {
  element = $(element).cleanWhitespace();
  var oldInnerBottom = element.down().getStyle('bottom');
  var elementDimensions = element.getDimensions();
  return new Effect.Scale(element, window.opera ? 0 : 1,
   Object.extend({ scaleContent: false,
    scaleX: false,
    scaleMode: 'box',
    scaleFrom: 100,
    scaleMode: {originalHeight: elementDimensions.height, originalWidth: elementDimensions.width},
    restoreAfterFinish: true,
    afterSetup: function(effect) {
      effect.element.makePositioned();
      effect.element.down().makePositioned();
      if (window.opera) effect.element.setStyle({top: ''});
      effect.element.makeClipping().show();
    },
    afterUpdateInternal: function(effect) {
      effect.element.down().setStyle({bottom:
        (effect.dims[0] - effect.element.clientHeight) + 'px' });
    },
    afterFinishInternal: function(effect) {
      effect.element.hide().undoClipping().undoPositioned();
      effect.element.down().undoPositioned().setStyle({bottom: oldInnerBottom});
    }
   }, arguments[1] || { })
  );
};

// Bug in opera makes the TD containing this element expand for a instance after finish
Effect.Squish = function(element) {
  return new Effect.Scale(element, window.opera ? 1 : 0, {
    restoreAfterFinish: true,
    beforeSetup: function(effect) {
      effect.element.makeClipping();
    },
    afterFinishInternal: function(effect) {
      effect.element.hide().undoClipping();
    }
  });
};

Effect.Grow = function(element) {
  element = $(element);
  var options = Object.extend({
    direction: 'center',
    moveTransition: Effect.Transitions.sinoidal,
    scaleTransition: Effect.Transitions.sinoidal,
    opacityTransition: Effect.Transitions.full
  }, arguments[1] || { });
  var oldStyle = {
    top: element.style.top,
    left: element.style.left,
    height: element.style.height,
    width: element.style.width,
    opacity: element.getInlineOpacity() };

  var dims = element.getDimensions();
  var initialMoveX, initialMoveY;
  var moveX, moveY;

  switch (options.direction) {
    case 'top-left':
      initialMoveX = initialMoveY = moveX = moveY = 0;
      break;
    case 'top-right':
      initialMoveX = dims.width;
      initialMoveY = moveY = 0;
      moveX = -dims.width;
      break;
    case 'bottom-left':
      initialMoveX = moveX = 0;
      initialMoveY = dims.height;
      moveY = -dims.height;
      break;
    case 'bottom-right':
      initialMoveX = dims.width;
      initialMoveY = dims.height;
      moveX = -dims.width;
      moveY = -dims.height;
      break;
    case 'center':
      initialMoveX = dims.width / 2;
      initialMoveY = dims.height / 2;
      moveX = -dims.width / 2;
      moveY = -dims.height / 2;
      break;
  }

  return new Effect.Move(element, {
    x: initialMoveX,
    y: initialMoveY,
    duration: 0.01,
    beforeSetup: function(effect) {
      effect.element.hide().makeClipping().makePositioned();
    },
    afterFinishInternal: function(effect) {
      new Effect.Parallel(
        [ new Effect.Opacity(effect.element, { sync: true, to: 1.0, from: 0.0, transition: options.opacityTransition }),
          new Effect.Move(effect.element, { x: moveX, y: moveY, sync: true, transition: options.moveTransition }),
          new Effect.Scale(effect.element, 100, {
            scaleMode: { originalHeight: dims.height, originalWidth: dims.width },
            sync: true, scaleFrom: window.opera ? 1 : 0, transition: options.scaleTransition, restoreAfterFinish: true})
        ], Object.extend({
             beforeSetup: function(effect) {
               effect.effects[0].element.setStyle({height: '0px'}).show();
             },
             afterFinishInternal: function(effect) {
               effect.effects[0].element.undoClipping().undoPositioned().setStyle(oldStyle);
             }
           }, options)
      );
    }
  });
};

Effect.Shrink = function(element) {
  element = $(element);
  var options = Object.extend({
    direction: 'center',
    moveTransition: Effect.Transitions.sinoidal,
    scaleTransition: Effect.Transitions.sinoidal,
    opacityTransition: Effect.Transitions.none
  }, arguments[1] || { });
  var oldStyle = {
    top: element.style.top,
    left: element.style.left,
    height: element.style.height,
    width: element.style.width,
    opacity: element.getInlineOpacity() };

  var dims = element.getDimensions();
  var moveX, moveY;

  switch (options.direction) {
    case 'top-left':
      moveX = moveY = 0;
      break;
    case 'top-right':
      moveX = dims.width;
      moveY = 0;
      break;
    case 'bottom-left':
      moveX = 0;
      moveY = dims.height;
      break;
    case 'bottom-right':
      moveX = dims.width;
      moveY = dims.height;
      break;
    case 'center':
      moveX = dims.width / 2;
      moveY = dims.height / 2;
      break;
  }

  return new Effect.Parallel(
    [ new Effect.Opacity(element, { sync: true, to: 0.0, from: 1.0, transition: options.opacityTransition }),
      new Effect.Scale(element, window.opera ? 1 : 0, { sync: true, transition: options.scaleTransition, restoreAfterFinish: true}),
      new Effect.Move(element, { x: moveX, y: moveY, sync: true, transition: options.moveTransition })
    ], Object.extend({
         beforeStartInternal: function(effect) {
           effect.effects[0].element.makePositioned().makeClipping();
         },
         afterFinishInternal: function(effect) {
           effect.effects[0].element.hide().undoClipping().undoPositioned().setStyle(oldStyle); }
       }, options)
  );
};

Effect.Pulsate = function(element) {
  element = $(element);
  var options    = arguments[1] || { },
    oldOpacity = element.getInlineOpacity(),
    transition = options.transition || Effect.Transitions.linear,
    reverser   = function(pos){
      return 1 - transition((-Math.cos((pos*(options.pulses||5)*2)*Math.PI)/2) + .5);
    };

  return new Effect.Opacity(element,
    Object.extend(Object.extend({  duration: 2.0, from: 0,
      afterFinishInternal: function(effect) { effect.element.setStyle({opacity: oldOpacity}); }
    }, options), {transition: reverser}));
};

Effect.Fold = function(element) {
  element = $(element);
  var oldStyle = {
    top: element.style.top,
    left: element.style.left,
    width: element.style.width,
    height: element.style.height };
  element.makeClipping();
  return new Effect.Scale(element, 5, Object.extend({
    scaleContent: false,
    scaleX: false,
    afterFinishInternal: function(effect) {
    new Effect.Scale(element, 1, {
      scaleContent: false,
      scaleY: false,
      afterFinishInternal: function(effect) {
        effect.element.hide().undoClipping().setStyle(oldStyle);
      } });
  }}, arguments[1] || { }));
};

Effect.Morph = Class.create(Effect.Base, {
  initialize: function(element) {
    this.element = $(element);
    if (!this.element) throw(Effect._elementDoesNotExistError);
    var options = Object.extend({
      style: { }
    }, arguments[1] || { });

    if (!Object.isString(options.style)) this.style = $H(options.style);
    else {
      if (options.style.include(':'))
        this.style = options.style.parseStyle();
      else {
        this.element.addClassName(options.style);
        this.style = $H(this.element.getStyles());
        this.element.removeClassName(options.style);
        var css = this.element.getStyles();
        this.style = this.style.reject(function(style) {
          return style.value == css[style.key];
        });
        options.afterFinishInternal = function(effect) {
          effect.element.addClassName(effect.options.style);
          effect.transforms.each(function(transform) {
            effect.element.style[transform.style] = '';
          });
        };
      }
    }
    this.start(options);
  },

  setup: function(){
    function parseColor(color){
      if (!color || ['rgba(0, 0, 0, 0)','transparent'].include(color)) color = '#ffffff';
      color = color.parseColor();
      return $R(0,2).map(function(i){
        return parseInt( color.slice(i*2+1,i*2+3), 16 );
      });
    }
    this.transforms = this.style.map(function(pair){
      var property = pair[0], value = pair[1], unit = null;

      if (value.parseColor('#zzzzzz') != '#zzzzzz') {
        value = value.parseColor();
        unit  = 'color';
      } else if (property == 'opacity') {
        value = parseFloat(value);
        if (Prototype.Browser.IE && (!this.element.currentStyle.hasLayout))
          this.element.setStyle({zoom: 1});
      } else if (Element.CSS_LENGTH.test(value)) {
          var components = value.match(/^([\+\-]?[0-9\.]+)(.*)$/);
          value = parseFloat(components[1]);
          unit = (components.length == 3) ? components[2] : null;
      }

      var originalValue = this.element.getStyle(property);
      return {
        style: property.camelize(),
        originalValue: unit=='color' ? parseColor(originalValue) : parseFloat(originalValue || 0),
        targetValue: unit=='color' ? parseColor(value) : value,
        unit: unit
      };
    }.bind(this)).reject(function(transform){
      return (
        (transform.originalValue == transform.targetValue) ||
        (
          transform.unit != 'color' &&
          (isNaN(transform.originalValue) || isNaN(transform.targetValue))
        )
      );
    });
  },
  update: function(position) {
    var style = { }, transform, i = this.transforms.length;
    while(i--)
      style[(transform = this.transforms[i]).style] =
        transform.unit=='color' ? '#'+
          (Math.round(transform.originalValue[0]+
            (transform.targetValue[0]-transform.originalValue[0])*position)).toColorPart() +
          (Math.round(transform.originalValue[1]+
            (transform.targetValue[1]-transform.originalValue[1])*position)).toColorPart() +
          (Math.round(transform.originalValue[2]+
            (transform.targetValue[2]-transform.originalValue[2])*position)).toColorPart() :
        (transform.originalValue +
          (transform.targetValue - transform.originalValue) * position).toFixed(3) +
            (transform.unit === null ? '' : transform.unit);
    this.element.setStyle(style, true);
  }
});

Effect.Transform = Class.create({
  initialize: function(tracks){
    this.tracks  = [];
    this.options = arguments[1] || { };
    this.addTracks(tracks);
  },
  addTracks: function(tracks){
    tracks.each(function(track){
      track = $H(track);
      var data = track.values().first();
      this.tracks.push($H({
        ids:     track.keys().first(),
        effect:  Effect.Morph,
        options: { style: data }
      }));
    }.bind(this));
    return this;
  },
  play: function(){
    return new Effect.Parallel(
      this.tracks.map(function(track){
        var ids = track.get('ids'), effect = track.get('effect'), options = track.get('options');
        var elements = [$(ids) || $$(ids)].flatten();
        return elements.map(function(e){ return new effect(e, Object.extend({ sync:true }, options)) });
      }).flatten(),
      this.options
    );
  }
});

Element.CSS_PROPERTIES = $w(
  'backgroundColor backgroundPosition borderBottomColor borderBottomStyle ' +
  'borderBottomWidth borderLeftColor borderLeftStyle borderLeftWidth ' +
  'borderRightColor borderRightStyle borderRightWidth borderSpacing ' +
  'borderTopColor borderTopStyle borderTopWidth bottom clip color ' +
  'fontSize fontWeight height left letterSpacing lineHeight ' +
  'marginBottom marginLeft marginRight marginTop markerOffset maxHeight '+
  'maxWidth minHeight minWidth opacity outlineColor outlineOffset ' +
  'outlineWidth paddingBottom paddingLeft paddingRight paddingTop ' +
  'right textIndent top width wordSpacing zIndex');

Element.CSS_LENGTH = /^(([\+\-]?[0-9\.]+)(em|ex|px|in|cm|mm|pt|pc|\%))|0$/;

String.__parseStyleElement = document.createElement('div');
String.prototype.parseStyle = function(){
  var style, styleRules = $H();
  if (Prototype.Browser.WebKit)
    style = new Element('div',{style:this}).style;
  else {
    String.__parseStyleElement.innerHTML = '<div style="' + this + '"></div>';
    style = String.__parseStyleElement.childNodes[0].style;
  }

  Element.CSS_PROPERTIES.each(function(property){
    if (style[property]) styleRules.set(property, style[property]);
  });

  if (Prototype.Browser.IE && this.include('opacity'))
    styleRules.set('opacity', this.match(/opacity:\s*((?:0|1)?(?:\.\d*)?)/)[1]);

  return styleRules;
};

if (document.defaultView && document.defaultView.getComputedStyle) {
  Element.getStyles = function(element) {
    var css = document.defaultView.getComputedStyle($(element), null);
    return Element.CSS_PROPERTIES.inject({ }, function(styles, property) {
      styles[property] = css[property];
      return styles;
    });
  };
} else {
  Element.getStyles = function(element) {
    element = $(element);
    var css = element.currentStyle, styles;
    styles = Element.CSS_PROPERTIES.inject({ }, function(results, property) {
      results[property] = css[property];
      return results;
    });
    if (!styles.opacity) styles.opacity = element.getOpacity();
    return styles;
  };
}

Effect.Methods = {
  morph: function(element, style) {
    element = $(element);
    new Effect.Morph(element, Object.extend({ style: style }, arguments[2] || { }));
    return element;
  },
  visualEffect: function(element, effect, options) {
    element = $(element);
    var s = effect.dasherize().camelize(), klass = s.charAt(0).toUpperCase() + s.substring(1);
    new Effect[klass](element, options);
    return element;
  },
  highlight: function(element, options) {
    element = $(element);
    new Effect.Highlight(element, options);
    return element;
  }
};

$w('fade appear grow shrink fold blindUp blindDown slideUp slideDown '+
  'pulsate shake puff squish switchOff dropOut').each(
  function(effect) {
    Effect.Methods[effect] = function(element, options){
      element = $(element);
      Effect[effect.charAt(0).toUpperCase() + effect.substring(1)](element, options);
      return element;
    };
  }
);

$w('getInlineOpacity forceRerendering setContentZoom collectTextNodes collectTextNodesIgnoreClass getStyles').each(
  function(f) { Effect.Methods[f] = Element[f]; }
);

Element.addMethods(Effect.Methods);








if (Object.isUndefined(Effect)) {
  throw ("dragdrop.js requires including script.aculo.us' effects.js library");
}
var Droppables = {
  drops: [],
  remove: function (a) {
    this.drops = this.drops.reject(function (b) {
      return b.element == $(a);
    });
  },
  add: function (c) {
    c = $(c);
    var a = Object.extend({
      greedy: true,
      hoverclass: null,
      tree: false
    }, arguments[1] || {});
    if (a.containment) {
      a._containers = [];
      var b = a.containment;
      if (Object.isArray(b)) {
        b.each(function (d) {
          a._containers.push($(d));
        });
      } else {
        a._containers.push($(b));
      }
    }
    if (a.accept) {
      a.accept = [a.accept].flatten();
    }
    Element.makePositioned(c);
    a.element = c;
    this.drops.push(a);
  },
  findDeepestChild: function (a) {
    deepest = a[0];
    for (i = 1; i < a.length; ++i) {
      if (Element.isParent(a[i].element, deepest.element)) {
        deepest = a[i];
      }
    }
    return deepest;
  },
  isContained: function (c, a) {
    var b;
    if (a.tree) {
      b = c.treeNode;
    } else {
      b = c.parentNode;
    }
    return a._containers.detect(function (d) {
      return b == d;
    });
  },
  isAffected: function (a, b, c) {
    return ((c.element != b) && ((!c._containers) || this.isContained(b, c)) && ((!c.accept) || (Element.classNames(b).detect(function (d) {
      return c.accept.include(d);
    }))) && Position.within(c.element, a[0], a[1]));
  },
  deactivate: function (a) {
    if (a.hoverclass) {
      Element.removeClassName(a.element, a.hoverclass);
    }
    this.last_active = null;
  },
  activate: function (a) {
    if (a.hoverclass) {
      Element.addClassName(a.element, a.hoverclass);
    }
    this.last_active = a;
  },
  show: function (a, c) {
    if (!this.drops.length) {
      return;
    }
    var d, b = [];
    this.drops.each(function (e) {
      if (Droppables.isAffected(a, c, e)) {
        b.push(e);
      }
    });
    if (b.length > 0) {
      d = Droppables.findDeepestChild(b);
    }
    if (this.last_active && this.last_active != d) {
      this.deactivate(this.last_active);
    }
    if (d) {
      Position.within(d.element, a[0], a[1]);
      if (d.onHover) {
        d.onHover(c, d.element, Position.overlap(d.overlap, d.element));
      }
      if (d != this.last_active) {
        Droppables.activate(d);
      }
    }
  },
  fire: function (b, a) {
    if (!this.last_active) {
      return;
    }
    Position.prepare();
    if (this.isAffected([Event.pointerX(b), Event.pointerY(b)], a, this.last_active)) {
      if (this.last_active.onDrop) {
        this.last_active.onDrop(a, this.last_active.element, b);
        return true;
      }
    }
  },
  reset: function () {
    if (this.last_active) {
      this.deactivate(this.last_active);
    }
  }
};
var Draggables = {
  drags: [],
  observers: [],
  register: function (a) {
    if (this.drags.length == 0) {
      this.eventMouseUp = this.endDrag.bindAsEventListener(this);
      this.eventMouseMove = this.updateDrag.bindAsEventListener(this);
      this.eventKeypress = this.keyPress.bindAsEventListener(this);
      Event.observe(document, "mouseup", this.eventMouseUp);
      Event.observe(document, "mousemove", this.eventMouseMove);
      Event.observe(document, "keypress", this.eventKeypress);
    }
    this.drags.push(a);
  },
  unregister: function (a) {
    this.drags = this.drags.reject(function (b) {
      return b == a;
    });
    if (this.drags.length == 0) {
      Event.stopObserving(document, "mouseup", this.eventMouseUp);
      Event.stopObserving(document, "mousemove", this.eventMouseMove);
      Event.stopObserving(document, "keypress", this.eventKeypress);
    }
  },
  activate: function (a) {
    if (a.options.delay) {
      this._timeout = setTimeout(function () {
        Draggables._timeout = null;
        window.focus();
        Draggables.activeDraggable = a;
      }.bind(this), a.options.delay);
    } else {
      window.focus();
      this.activeDraggable = a;
    }
  },
  deactivate: function () {
    this.activeDraggable = null;
  },
  updateDrag: function (a) {
    if (!this.activeDraggable) {
      return;
    }
    var b = [Event.pointerX(a), Event.pointerY(a)];
    if (this._lastPointer && (this._lastPointer.inspect() == b.inspect())) {
      return;
    }
    this._lastPointer = b;
    this.activeDraggable.updateDrag(a, b);
  },
  endDrag: function (a) {
    if (this._timeout) {
      clearTimeout(this._timeout);
      this._timeout = null;
    }
    if (!this.activeDraggable) {
      return;
    }
    this._lastPointer = null;
    this.activeDraggable.endDrag(a);
    this.activeDraggable = null;
  },
  keyPress: function (a) {
    if (this.activeDraggable) {
      this.activeDraggable.keyPress(a);
    }
  },
  addObserver: function (a) {
    this.observers.push(a);
    this._cacheObserverCallbacks();
  },
  removeObserver: function (a) {
    this.observers = this.observers.reject(function (b) {
      return b.element == a;
    });
    this._cacheObserverCallbacks();
  },
  notify: function (c, a, b) {
    if (this[c + "Count"] > 0) {
      this.observers.each(function (d) {
        if (d[c]) {
          d[c](c, a, b);
        }
      });
    }
    if (a.options[c]) {
      a.options[c](a, b);
    }
  },
  _cacheObserverCallbacks: function () {
    ["onStart", "onEnd", "onDrag"].each(function (a) {
      Draggables[a + "Count"] = Draggables.observers.select(function (b) {
        return b[a];
      }).length;
    });
  }
};
var Draggable = Class.create({
  initialize: function (c) {
    var b = {
      handle: false,
      reverteffect: function (e, f, g) {
        var d = Math.sqrt(Math.abs(f ^ 2) + Math.abs(g ^ 2)) * 0.02;
        new Effect.Move(e, {
          x: -g,
          y: -f,
          duration: d,
          queue: {
            scope: "_draggable",
            position: "end"
          }
        });
      },
      endeffect: function (d) {
        var e = Object.isNumber(d._opacity) ? d._opacity : 1;
        new Effect.Opacity(d, {
          duration: 0.2,
          from: 0.7,
          to: e,
          queue: {
            scope: "_draggable",
            position: "end"
          },
          afterFinish: function () {
            Draggable._dragging[d] = false;
          }
        });
      },
      zindex: 1000,
      revert: false,
      quiet: false,
      scroll: false,
      scrollSensitivity: 20,
      scrollSpeed: 15,
      snap: false,
      delay: 0
    };
    if (!arguments[1] || Object.isUndefined(arguments[1].endeffect)) {
      Object.extend(b, {
        starteffect: function (d) {
          d._opacity = Element.getOpacity(d);
          Draggable._dragging[d] = true;
          new Effect.Opacity(d, {
            duration: 0.2,
            from: d._opacity,
            to: 0.7
          });
        }
      });
    }
    var a = Object.extend(b, arguments[1] || {});
    this.element = $(c);
    if (a.handle && Object.isString(a.handle)) {
      this.handle = this.element.down("." + a.handle, 0);
    }
    if (!this.handle) {
      this.handle = $(a.handle);
    }
    if (!this.handle) {
      this.handle = this.element;
    }
    if (a.scroll && !a.scroll.scrollTo && !a.scroll.outerHTML) {
      a.scroll = $(a.scroll);
      this._isScrollChild = Element.childOf(this.element, a.scroll);
    }
    Element.makePositioned(this.element);
    this.options = a;
    this.dragging = false;
    this.eventMouseDown = this.initDrag.bindAsEventListener(this);
    Event.observe(this.handle, "mousedown", this.eventMouseDown);
    Draggables.register(this);
  },
  destroy: function () {
    Event.stopObserving(this.handle, "mousedown", this.eventMouseDown);
    Draggables.unregister(this);
  },
  currentDelta: function () {
    return ([parseInt(Element.getStyle(this.element, "left") || "0"), parseInt(Element.getStyle(this.element, "top") || "0")]);
  },
  initDrag: function (a) {
    if (!Object.isUndefined(Draggable._dragging[this.element]) && Draggable._dragging[this.element]) {
      return;
    }
    if (Event.isLeftClick(a)) {
      var c = Event.element(a);
      if ((tag_name = c.tagName.toUpperCase()) && (tag_name == "INPUT" || tag_name == "SELECT" || tag_name == "OPTION" || tag_name == "BUTTON" || tag_name == "TEXTAREA")) {
        return;
      }
      var d = [Event.pointerX(a), Event.pointerY(a)];
      var b = Position.cumulativeOffset(this.element);
      this.offset = [0, 1].map(function (e) {
        return (d[e] - b[e]);
      });
      Draggables.activate(this);
      Event.stop(a);
    }
  },
  startDrag: function (b) {
    this.dragging = true;
    if (!this.delta) {
      this.delta = this.currentDelta();
    }
    if (this.options.zindex) {
      this.originalZ = parseInt(Element.getStyle(this.element, "z-index") || 0);
      this.element.style.zIndex = this.options.zindex;
    }
    if (this.options.ghosting) {
      this._clone = this.element.cloneNode(true);
      this._originallyAbsolute = (this.element.getStyle("position") == "absolute");
      if (!this._originallyAbsolute) {
        Position.absolutize(this.element);
      }
      this.element.parentNode.insertBefore(this._clone, this.element);
    }
    if (this.options.scroll) {
      if (this.options.scroll == window) {
        var a = this._getWindowScroll(this.options.scroll);
        this.originalScrollLeft = a.left;
        this.originalScrollTop = a.top;
      } else {
        this.originalScrollLeft = this.options.scroll.scrollLeft;
        this.originalScrollTop = this.options.scroll.scrollTop;
      }
    }
    Draggables.notify("onStart", this, b);
    if (this.options.starteffect) {
      this.options.starteffect(this.element);
    }
  },
  updateDrag: function (event, pointer) {
    if (!this.dragging) {
      this.startDrag(event);
    }
    if (!this.options.quiet) {
      Position.prepare();
      Droppables.show(pointer, this.element);
    }
    Draggables.notify("onDrag", this, event);
    this.draw(pointer);
    if (this.options.change) {
      this.options.change(this);
    }
    if (this.options.scroll) {
      this.stopScrolling();
      var p;
      if (this.options.scroll == window) {
        with(this._getWindowScroll(this.options.scroll)) {
          p = [left, top, left + width, top + height];
        }
      } else {
        p = Position.page(this.options.scroll);
        p[0] += this.options.scroll.scrollLeft + Position.deltaX;
        p[1] += this.options.scroll.scrollTop + Position.deltaY;
        p.push(p[0] + this.options.scroll.offsetWidth);
        p.push(p[1] + this.options.scroll.offsetHeight);
      }
      var speed = [0, 0];
      if (pointer[0] < (p[0] + this.options.scrollSensitivity)) {
        speed[0] = pointer[0] - (p[0] + this.options.scrollSensitivity);
      }
      if (pointer[1] < (p[1] + this.options.scrollSensitivity)) {
        speed[1] = pointer[1] - (p[1] + this.options.scrollSensitivity);
      }
      if (pointer[0] > (p[2] - this.options.scrollSensitivity)) {
        speed[0] = pointer[0] - (p[2] - this.options.scrollSensitivity);
      }
      if (pointer[1] > (p[3] - this.options.scrollSensitivity)) {
        speed[1] = pointer[1] - (p[3] - this.options.scrollSensitivity);
      }
      this.startScrolling(speed);
    }
    if (Prototype.Browser.WebKit) {
      window.scrollBy(0, 0);
    }
    Event.stop(event);
  },
  finishDrag: function (f, c) {
    this.dragging = false;
    if (this.options.quiet) {
      Position.prepare();
      var d = [Event.pointerX(f), Event.pointerY(f)];
      Droppables.show(d, this.element);
    }
    if (this.options.ghosting) {
      if (!this._originallyAbsolute) {
        Position.relativize(this.element);
      }
      delete this._originallyAbsolute;
      Element.remove(this._clone);
      this._clone = null;
    }
    var b = false;
    if (c) {
      b = Droppables.fire(f, this.element);
      if (!b) {
        b = false;
      }
    }
    if (b && this.options.onDropped) {
      this.options.onDropped(this.element);
    }
    Draggables.notify("onEnd", this, f);
    var a = this.options.revert;
    if (a && Object.isFunction(a)) {
      a = a(this.element);
    }
    var e = this.currentDelta();
    if (a && this.options.reverteffect) {
      if (b == 0 || a != "failure") {
        this.options.reverteffect(this.element, e[1] - this.delta[1], e[0] - this.delta[0]);
      }
    } else {
      this.delta = e;
    }
    if (this.options.zindex) {
      this.element.style.zIndex = this.originalZ;
    }
    if (this.options.endeffect) {
      this.options.endeffect(this.element);
    }
    Draggables.deactivate(this);
    Droppables.reset();
  },
  keyPress: function (a) {
    if (a.keyCode != Event.KEY_ESC) {
      return;
    }
    this.finishDrag(a, false);
    Event.stop(a);
  },
  endDrag: function (a) {
    if (!this.dragging) {
      return;
    }
    this.stopScrolling();
    this.finishDrag(a, true);
    Event.stop(a);
  },
  draw: function (a) {
    var b = Position.cumulativeOffset(this.element);
    if (this.options.ghosting) {
      var e = Position.realOffset(this.element);
      b[0] += e[0] - Position.deltaX;
      b[1] += e[1] - Position.deltaY;
    }
    var c = this.currentDelta();
    b[0] -= c[0];
    b[1] -= c[1];
    if (this.options.scroll && (this.options.scroll != window && this._isScrollChild)) {
      b[0] -= this.options.scroll.scrollLeft - this.originalScrollLeft;
      b[1] -= this.options.scroll.scrollTop - this.originalScrollTop;
    }
    var d = [0, 1].map(function (g) {
      return (a[g] - b[g] - this.offset[g]);
    }.bind(this));
    if (this.options.snap) {
      if (Object.isFunction(this.options.snap)) {
        d = this.options.snap(d[0], d[1], this);
      } else {
        if (Object.isArray(this.options.snap)) {
          d = d.map(function (h, g) {
            return (h / this.options.snap[g]).round() * this.options.snap[g];
          }.bind(this));
        } else {
          d = d.map(function (g) {
            return (g / this.options.snap).round() * this.options.snap;
          }.bind(this));
        }
      }
    }
    var f = this.element.style;
    if ((!this.options.constraint) || (this.options.constraint == "horizontal")) {
      f.left = d[0] + "px";
    }
    if ((!this.options.constraint) || (this.options.constraint == "vertical")) {
      f.top = d[1] + "px";
    }
    if (f.visibility == "hidden") {
      f.visibility = "";
    }
  },
  stopScrolling: function () {
    if (this.scrollInterval) {
      clearInterval(this.scrollInterval);
      this.scrollInterval = null;
      Draggables._lastScrollPointer = null;
    }
  },
  startScrolling: function (a) {
    if (!(a[0] || a[1])) {
      return;
    }
    this.scrollSpeed = [a[0] * this.options.scrollSpeed, a[1] * this.options.scrollSpeed];
    this.lastScrolled = new Date();
    this.scrollInterval = setInterval(this.scroll.bind(this), 10);
  },
  scroll: function () {
    var current = new Date();
    var delta = current - this.lastScrolled;
    this.lastScrolled = current;
    if (this.options.scroll == window) {
      with(this._getWindowScroll(this.options.scroll)) {
        if (this.scrollSpeed[0] || this.scrollSpeed[1]) {
          var d = delta / 1000;
          this.options.scroll.scrollTo(left + d * this.scrollSpeed[0], top + d * this.scrollSpeed[1]);
        }
      }
    } else {
      this.options.scroll.scrollLeft += this.scrollSpeed[0] * delta / 1000;
      this.options.scroll.scrollTop += this.scrollSpeed[1] * delta / 1000;
    }
    Position.prepare();
    Droppables.show(Draggables._lastPointer, this.element);
    Draggables.notify("onDrag", this);
    if (this._isScrollChild) {
      Draggables._lastScrollPointer = Draggables._lastScrollPointer || $A(Draggables._lastPointer);
      Draggables._lastScrollPointer[0] += this.scrollSpeed[0] * delta / 1000;
      Draggables._lastScrollPointer[1] += this.scrollSpeed[1] * delta / 1000;
      if (Draggables._lastScrollPointer[0] < 0) {
        Draggables._lastScrollPointer[0] = 0;
      }
      if (Draggables._lastScrollPointer[1] < 0) {
        Draggables._lastScrollPointer[1] = 0;
      }
      this.draw(Draggables._lastScrollPointer);
    }
    if (this.options.change) {
      this.options.change(this);
    }
  },
  _getWindowScroll: function (w) {
    var T, L, W, H;
    with(w.document) {
      if (w.document.documentElement && documentElement.scrollTop) {
        T = documentElement.scrollTop;
        L = documentElement.scrollLeft;
      } else {
        if (w.document.body) {
          T = body.scrollTop;
          L = body.scrollLeft;
        }
      }
      if (w.innerWidth) {
        W = w.innerWidth;
        H = w.innerHeight;
      } else {
        if (w.document.documentElement && documentElement.clientWidth) {
          W = documentElement.clientWidth;
          H = documentElement.clientHeight;
        } else {
          W = body.offsetWidth;
          H = body.offsetHeight;
        }
      }
    }
    return {
      top: T,
      left: L,
      width: W,
      height: H
    };
  }
});
Draggable._dragging = {};
var SortableObserver = Class.create({
  initialize: function (b, a) {
    this.element = $(b);
    this.observer = a;
    this.lastValue = Sortable.serialize(this.element);
  },
  onStart: function () {
    this.lastValue = Sortable.serialize(this.element);
  },
  onEnd: function () {
    Sortable.unmark();
    if (this.lastValue != Sortable.serialize(this.element)) {
      this.observer(this.element);
    }
  }
});
var Sortable = {
  SERIALIZE_RULE: /^[^_\-](?:[A-Za-z0-9\-\_]*)[_](.*)$/,
  sortables: {},
  _findRootElement: function (a) {
    while (a.tagName.toUpperCase() != "BODY") {
      if (a.id && Sortable.sortables[a.id]) {
        return a;
      }
      a = a.parentNode;
    }
  },
  options: function (a) {
    a = Sortable._findRootElement($(a));
    if (!a) {
      return;
    }
    return Sortable.sortables[a.id];
  },
  destroy: function (a) {
    a = $(a);
    var b = Sortable.sortables[a.id];
    if (b) {
      Draggables.removeObserver(b.element);
      b.droppables.each(function (c) {
        Droppables.remove(c);
      });
      b.draggables.invoke("destroy");
      delete Sortable.sortables[b.element.id];
    }
  },
  create: function (d) {
    d = $(d);
    var e = Object.extend({
      element: d,
      tag: "li",
      dropOnEmpty: false,
      tree: false,
      treeTag: "ul",
      overlap: "vertical",
      constraint: "vertical",
      containment: d,
      handle: false,
      only: false,
      delay: 0,
      hoverclass: null,
      ghosting: false,
      quiet: false,
      scroll: false,
      scrollSensitivity: 20,
      scrollSpeed: 15,
      format: this.SERIALIZE_RULE,
      elements: false,
      handles: false,
      onChange: Prototype.emptyFunction,
      onUpdate: Prototype.emptyFunction
    }, arguments[1] || {});
    this.destroy(d);
    var a = {
      revert: true,
      quiet: e.quiet,
      scroll: e.scroll,
      scrollSpeed: e.scrollSpeed,
      scrollSensitivity: e.scrollSensitivity,
      delay: e.delay,
      ghosting: e.ghosting,
      constraint: e.constraint,
      handle: e.handle
    };
    if (e.starteffect) {
      a.starteffect = e.starteffect;
    }
    if (e.reverteffect) {
      a.reverteffect = e.reverteffect;
    } else {
      if (e.ghosting) {
        a.reverteffect = function (f) {
          f.style.top = 0;
          f.style.left = 0;
        };
      }
    }
    if (e.endeffect) {
      a.endeffect = e.endeffect;
    }
    if (e.zindex) {
      a.zindex = e.zindex;
    }
    var c = {
      overlap: e.overlap,
      containment: e.containment,
      tree: e.tree,
      hoverclass: e.hoverclass,
      onHover: Sortable.onHover
    };
    var b = {
      onHover: Sortable.onEmptyHover,
      overlap: e.overlap,
      containment: e.containment,
      hoverclass: e.hoverclass
    };
    Element.cleanWhitespace(d);
    e.draggables = [];
    e.droppables = [];
    if (e.dropOnEmpty || e.tree) {
      Droppables.add(d, b);
      e.droppables.push(d);
    }(e.elements || this.findElements(d, e) || []).each(function (f, h) {
      var g = e.handles ? $(e.handles[h]) : (e.handle ? $(f).select("." + e.handle)[0] : f);
      e.draggables.push(new Draggable(f, Object.extend(a, {
        handle: g
      })));
      Droppables.add(f, c);
      if (e.tree) {
        f.treeNode = d;
      }
      e.droppables.push(f);
    });
    if (e.tree) {
      (Sortable.findTreeElements(d, e) || []).each(function (f) {
        Droppables.add(f, b);
        f.treeNode = d;
        e.droppables.push(f);
      });
    }
    this.sortables[d.id] = e;
    Draggables.addObserver(new SortableObserver(d, e.onUpdate));
  },
  findElements: function (b, a) {
    return Element.findChildren(b, a.only, a.tree ? true : false, a.tag);
  },
  findTreeElements: function (b, a) {
    return Element.findChildren(b, a.only, a.tree ? true : false, a.treeTag);
  },
  onHover: function (b, c, a) {
    if (Element.isParent(c, b)) {
      return;
    }
    if (a > 0.33 && a < 0.66 && Sortable.options(c).tree) {
      return;
    } else {
      if (a > 0.5) {
        Sortable.mark(c, "before");
        if (c.previousSibling != b) {
          var e = b.parentNode;
          b.style.visibility = "hidden";
          c.parentNode.insertBefore(b, c);
          if (c.parentNode != e) {
            Sortable.options(e).onChange(b);
          }
          Sortable.options(c.parentNode).onChange(b);
        }
      } else {
        Sortable.mark(c, "after");
        var d = c.nextSibling || null;
        if (d != b) {
          var e = b.parentNode;
          b.style.visibility = "hidden";
          c.parentNode.insertBefore(b, d);
          if (c.parentNode != e) {
            Sortable.options(e).onChange(b);
          }
          Sortable.options(c.parentNode).onChange(b);
        }
      }
    }
  },
  onEmptyHover: function (k, g, f) {
    var e = k.parentNode;
    var d = Sortable.options(g);
    if (!Element.isParent(g, k)) {
      var h;
      var b = Sortable.findElements(g, {
        tag: d.tag,
        only: d.only
      });
      var c = null;
      if (b) {
        var a = Element.offsetSize(g, d.overlap) * (1 - f);
        for (h = 0; h < b.length; h += 1) {
          if (a - Element.offsetSize(b[h], d.overlap) >= 0) {
            a -= Element.offsetSize(b[h], d.overlap);
          } else {
            if (a - (Element.offsetSize(b[h], d.overlap) / 2) >= 0) {
              c = h + 1 < b.length ? b[h + 1] : null;
              break;
            } else {
              c = b[h];
              break;
            }
          }
        }
      }
      g.insertBefore(k, c);
      Sortable.options(e).onChange(k);
      d.onChange(k);
    }
  },
  unmark: function () {
    if (Sortable._marker) {
      Sortable._marker.hide();
    }
  },
  mark: function (d, a) {
    var b = Sortable.options(d.parentNode);
    if (b && !b.ghosting) {
      return;
    }
    if (!Sortable._marker) {
      Sortable._marker = ($("dropmarker") || Element.extend(document.createElement("DIV"))).hide().addClassName("dropmarker").setStyle({
        position: "absolute"
      });
      document.getElementsByTagName("body").item(0).appendChild(Sortable._marker);
    }
    var c = Position.cumulativeOffset(d);
    Sortable._marker.setStyle({
      left: c[0] + "px",
      top: c[1] + "px"
    });
    if (a == "after") {
      if (b.overlap == "horizontal") {
        Sortable._marker.setStyle({
          left: (c[0] + d.clientWidth) + "px"
        });
      } else {
        Sortable._marker.setStyle({
          top: (c[1] + d.clientHeight) + "px"
        });
      }
    }
    Sortable._marker.show();
  },
  _tree: function (d, g, c) {
    var e = Sortable.findElements(d, g) || [];
    for (var f = 0; f < e.length; ++f) {
      var a = e[f].id.match(g.format);
      if (!a) {
        continue;
      }
      var b = {
        id: encodeURIComponent(a ? a[1] : null),
        element: d,
        parent: c,
        children: [],
        position: c.children.length,
        container: $(e[f]).down(g.treeTag)
      };
      if (b.container) {
        this._tree(b.container, g, b);
      }
      c.children.push(b);
    }
    return c;
  },
  tree: function (b) {
    b = $(b);
    var c = this.options(b);
    var d = Object.extend({
      tag: c.tag,
      treeTag: c.treeTag,
      only: c.only,
      name: b.id,
      format: c.format
    }, arguments[1] || {});
    var a = {
      id: null,
      parent: null,
      children: [],
      container: b,
      position: 0
    };
    return Sortable._tree(b, d, a);
  },
  _constructIndex: function (b) {
    var a = "";
    do {
      if (b.id) {
        a = "[" + b.position + "]" + a;
      }
    } while ((b = b.parent) != null);
    return a;
  },
  sequence: function (b) {
    b = $(b);
    var a = Object.extend(this.options(b), arguments[1] || {});
    return $(this.findElements(b, a) || []).map(function (c) {
      return c.id.match(a.format) ? c.id.match(a.format)[1] : "";
    });
  },
  setSequence: function (d, c) {
    d = $(d);
    var a = Object.extend(this.options(d), arguments[2] || {});
    var b = {};
    this.findElements(d, a).each(function (e) {
      if (e.id.match(a.format)) {
        b[e.id.match(a.format)[1]] = [e, e.parentNode];
      }
      e.parentNode.removeChild(e);
    });
    c.each(function (f) {
      var e = b[f];
      if (e) {
        e[1].appendChild(e[0]);
        delete b[f];
      }
    });
  },
  serialize: function (b) {
    b = $(b);
    var c = Object.extend(Sortable.options(b), arguments[1] || {});
    var a = encodeURIComponent((arguments[1] && arguments[1].name) ? arguments[1].name : b.id);
    if (c.tree) {
      return Sortable.tree(b, arguments[1]).children.map(function (d) {
        return [a + Sortable._constructIndex(d) + "[id]=" + encodeURIComponent(d.id)].concat(d.children.map(arguments.callee));
      }).flatten().join("&");
    } else {
      return Sortable.sequence(b, arguments[1]).map(function (d) {
        return a + "[]=" + encodeURIComponent(d);
      }).join("&");
    }
  }
};
Element.isParent = function (b, a) {
  if (!b.parentNode || b == a) {
    return false;
  }
  if (b.parentNode == a) {
    return true;
  }
  return Element.isParent(b.parentNode, a);
};
Element.findChildren = function (c, e, a, d) {
  if (!c.hasChildNodes()) {
    return null;
  }
  d = d.toUpperCase();
  if (e) {
    e = [e].flatten();
  }
  var b = [];
  $A(c.childNodes).each(function (f) {
    if (f.tagName && f.tagName.toUpperCase() == d && (!e || (Element.classNames(f).detect(function (h) {
      return e.include(h);
    })))) {
      b.push(f);
    }
    if (a) {
      var g = Element.findChildren(f, e, a, d);
      if (g) {
        b.push(g);
      }
    }
  });
  return (b.length > 0 ? b.flatten() : []);
};
Element.offsetSize = function (a, b) {
  return a["offset" + ((b == "vertical" || b == "height") ? "Height" : "Width")];
};
if (typeof Effect == "undefined") {
  throw ("controls.js requires including script.aculo.us' effects.js library");
}
var Autocompleter = {};
Autocompleter.Base = Class.create({
  baseInitialize: function (c, b, a) {
    c = $(c);
    this.element = c;
    this.update = $(b);
    this.hasFocus = false;
    this.changed = false;
    this.active = false;
    this.index = 0;
    this.entryCount = 0;
    this.oldElementValue = this.element.value;
    if (this.setOptions) {
      this.setOptions(a);
    } else {
      this.options = a || {};
    }
    this.options.paramName = this.options.paramName || this.element.name;
    this.options.tokens = this.options.tokens || [];
    this.options.frequency = this.options.frequency || 0.4;
    this.options.minChars = this.options.minChars || 1;
    this.options.onShow = this.options.onShow || function (e, d) {
      if (!d.style.position || d.style.position == "absolute") {
        d.style.position = "absolute";
        Position.clone(e, d, {
          setHeight: false,
          offsetTop: e.offsetHeight
        });
      }
      Effect.Appear(d, {
        duration: 0.15
      });
    };
    this.options.onHide = this.options.onHide || function (e, d) {
      new Effect.Fade(d, {
        duration: 0.15
      });
    };
    if (typeof (this.options.tokens) == "string") {
      this.options.tokens = new Array(this.options.tokens);
    }
    if (!this.options.tokens.include("\n")) {
      this.options.tokens.push("\n");
    }
    this.observer = null;
    this.element.setAttribute("autocomplete", "off");
    Element.hide(this.update);
    Event.observe(this.element, "blur", this.onBlur.bindAsEventListener(this));
    Event.observe(this.element, "keydown", this.onKeyPress.bindAsEventListener(this));
  },
  show: function () {
    if (Element.getStyle(this.update, "display") == "none") {
      this.options.onShow(this.element, this.update);
    }
    if (!this.iefix && (Prototype.Browser.IE) && (Element.getStyle(this.update, "position") == "absolute")) {
      new Insertion.After(this.update, '<iframe id="' + this.update.id + '_iefix" style="display:none;position:absolute;filter:progid:DXImageTransform.Microsoft.Alpha(opacity=0);" src="javascript:false;" frameborder="0" scrolling="no"></iframe>');
      this.iefix = $(this.update.id + "_iefix");
    }
    if (this.iefix) {
      setTimeout(this.fixIEOverlapping.bind(this), 50);
    }
  },
  fixIEOverlapping: function () {
    Position.clone(this.update, this.iefix, {
      setTop: (!this.update.style.height)
    });
    this.iefix.style.zIndex = 1;
    this.update.style.zIndex = 2;
    Element.show(this.iefix);
  },
  hide: function () {
    this.stopIndicator();
    if (Element.getStyle(this.update, "display") != "none") {
      this.options.onHide(this.element, this.update);
    }
    if (this.iefix) {
      Element.hide(this.iefix);
    }
  },
  startIndicator: function () {
    if (this.options.indicator) {
      Element.show(this.options.indicator);
    }
  },
  stopIndicator: function () {
    if (this.options.indicator) {
      Element.hide(this.options.indicator);
    }
  },
  onKeyPress: function (a) {
    if (this.active) {
      switch (a.keyCode) {
        case Event.KEY_TAB:
        case Event.KEY_RETURN:
          this.selectEntry();
          Event.stop(a);
        case Event.KEY_ESC:
          this.hide();
          this.active = false;
          Event.stop(a);
          return;
        case Event.KEY_LEFT:
        case Event.KEY_RIGHT:
          return;
        case Event.KEY_UP:
          this.markPrevious();
          this.render();
          Event.stop(a);
          return;
        case Event.KEY_DOWN:
          this.markNext();
          this.render();
          Event.stop(a);
          return;
      }
    } else {
      if (a.keyCode == Event.KEY_TAB || a.keyCode == Event.KEY_RETURN || (Prototype.Browser.WebKit > 0 && a.keyCode == 0)) {
        return;
      }
    }
    this.changed = true;
    this.hasFocus = true;
    if (this.observer) {
      clearTimeout(this.observer);
    }
    this.observer = setTimeout(this.onObserverEvent.bind(this), this.options.frequency * 1000);
  },
  activate: function () {
    this.changed = false;
    this.hasFocus = true;
    this.getUpdatedChoices();
  },
  onHover: function (b) {
    var a = Event.findElement(b, "LI");
    if (this.index != a.autocompleteIndex) {
      this.index = a.autocompleteIndex;
      this.render();
    }
    Event.stop(b);
  },
  onClick: function (b) {
    var a = Event.findElement(b, "LI");
    this.index = a.autocompleteIndex;
    this.selectEntry();
    this.hide();
  },
  onBlur: function (a) {
    setTimeout(this.hide.bind(this), 250);
    this.hasFocus = false;
    this.active = false;
  },
  render: function () {
    if (this.entryCount > 0) {
      for (var a = 0; a < this.entryCount; a++) {
        this.index == a ? Element.addClassName(this.getEntry(a), "selected") : Element.removeClassName(this.getEntry(a), "selected");
      }
      if (this.hasFocus) {
        this.show();
        this.active = true;
      }
    } else {
      this.active = false;
      this.hide();
    }
  },
  markPrevious: function () {
    if (this.index > 0) {
      this.index--;
    } else {
      this.index = this.entryCount - 1;
    }
    this.getEntry(this.index).scrollIntoView(true);
  },
  markNext: function () {
    if (this.index < this.entryCount - 1) {
      this.index++;
    } else {
      this.index = 0;
    }
    this.getEntry(this.index).scrollIntoView(false);
  },
  getEntry: function (a) {
    return this.update.firstChild.childNodes[a];
  },
  getCurrentEntry: function () {
    return this.getEntry(this.index);
  },
  selectEntry: function () {
    this.active = false;
    this.updateElement(this.getCurrentEntry());
  },
  updateElement: function (b) {
    if (this.options.updateElement) {
      this.options.updateElement(b);
      return;
    }
    var d = "";
    if (this.options.select) {
      var a = $(b).select("." + this.options.select) || [];
      if (a.length > 0) {
        d = Element.collectTextNodes(a[0], this.options.select);
      }
    } else {
      d = Element.collectTextNodesIgnoreClass(b, "informal");
    }
    var e = this.getTokenBounds();
    if (e[0] != -1) {
      var c = this.element.value.substr(0, e[0]);
      var f = this.element.value.substr(e[0]).match(/^\s+/);
      if (f) {
        c += f[0];
      }
      this.element.value = c + d + this.element.value.substr(e[1]);
    } else {
      this.element.value = d;
    }
    this.oldElementValue = this.element.value;
    this.element.focus();
    if (this.options.afterUpdateElement) {
      this.options.afterUpdateElement(this.element, b);
    }
  },
  updateChoices: function (b) {
    if (!this.changed && this.hasFocus) {
      this.update.innerHTML = b;
      Element.cleanWhitespace(this.update);
      Element.cleanWhitespace(this.update.down());
      if (this.update.firstChild && this.update.down().childNodes) {
        this.entryCount = this.update.down().childNodes.length;
        for (var a = 0; a < this.entryCount; a++) {
          var c = this.getEntry(a);
          c.autocompleteIndex = a;
          this.addObservers(c);
        }
      } else {
        this.entryCount = 0;
      }
      this.stopIndicator();
      this.index = 0;
      if (this.entryCount == 1 && this.options.autoSelect) {
        this.selectEntry();
        this.hide();
      } else {
        this.render();
      }
    }
  },
  addObservers: function (a) {
    Event.observe(a, "mouseover", this.onHover.bindAsEventListener(this));
    Event.observe(a, "click", this.onClick.bindAsEventListener(this));
  },
  onObserverEvent: function () {
    this.changed = false;
    this.tokenBounds = null;
    if (this.getToken().length >= this.options.minChars) {
      this.getUpdatedChoices();
    } else {
      this.active = false;
      this.hide();
    }
    this.oldElementValue = this.element.value;
  },
  getToken: function () {
    var a = this.getTokenBounds();
    return this.element.value.substring(a[0], a[1]).strip();
  },
  getTokenBounds: function () {
    if (null != this.tokenBounds) {
      return this.tokenBounds;
    }
    var e = this.element.value;
    if (e.strip().empty()) {
      return [-1, 0];
    }
    var d = arguments.callee.getFirstDifferencePos(e, this.oldElementValue);
    var b = (d == this.oldElementValue.length ? 1 : 0);
    var f = -1,
      g = e.length;
    var c;
    for (var h = 0, a = this.options.tokens.length; h < a; ++h) {
      c = e.lastIndexOf(this.options.tokens[h], d + b - 1);
      if (c > f) {
        f = c;
      }
      c = e.indexOf(this.options.tokens[h], d + b);
      if (-1 != c && c < g) {
        g = c;
      }
    }
    return (this.tokenBounds = [f + 1, g]);
  }
});
Autocompleter.Base.prototype.getTokenBounds.getFirstDifferencePos = function (c, a) {
  var b = Math.min(c.length, a.length);
  for (var d = 0; d < b; ++d) {
    if (c[d] != a[d]) {
      return d;
    }
  }
  return b;
};
Ajax.Autocompleter = Class.create(Autocompleter.Base, {
  initialize: function (c, b, d, a) {
    this.baseInitialize(c, b, a);
    this.options.asynchronous = true;
    this.options.onComplete = this.onComplete.bind(this);
    this.options.defaultParams = this.options.parameters || null;
    this.url = d;
  },
  getUpdatedChoices: function () {
    this.startIndicator();
    var a = encodeURIComponent(this.options.paramName) + "=" + encodeURIComponent(this.getToken());
    this.options.parameters = this.options.callback ? this.options.callback(this.element, a) : a;
    if (this.options.defaultParams) {
      this.options.parameters += "&" + this.options.defaultParams;
    }
    new Ajax.Request(this.url, this.options);
  },
  onComplete: function (a) {
    this.updateChoices(a.responseText);
  }
});
Autocompleter.Local = Class.create(Autocompleter.Base, {
  initialize: function (d, b, c, a) {
    this.baseInitialize(d, b, a);
    this.options.array = c;
  },
  getUpdatedChoices: function () {
    this.updateChoices(this.options.selector(this));
  },
  setOptions: function (a) {
    this.options = Object.extend({
      choices: 10,
      partialSearch: true,
      partialChars: 2,
      ignoreCase: true,
      fullSearch: false,
      selector: function (k) {
        var g = [];
        var h = [];
        var c = k.getToken();
        var d = 0;
        for (var f = 0; f < k.options.array.length && g.length < k.options.choices; f++) {
          var e = k.options.array[f];
          var b = k.options.ignoreCase ? e.toLowerCase().indexOf(c.toLowerCase()) : e.indexOf(c);
          while (b != -1) {
            if (b == 0 && e.length != c.length) {
              g.push("<li><strong>" + e.substr(0, c.length) + "</strong>" + e.substr(c.length) + "</li>");
              break;
            } else {
              if (c.length >= k.options.partialChars && k.options.partialSearch && b != -1) {
                if (k.options.fullSearch || /\s/.test(e.substr(b - 1, 1))) {
                  h.push("<li>" + e.substr(0, b) + "<strong>" + e.substr(b, c.length) + "</strong>" + e.substr(b + c.length) + "</li>");
                  break;
                }
              }
            }
            b = k.options.ignoreCase ? e.toLowerCase().indexOf(c.toLowerCase(), b + 1) : e.indexOf(c, b + 1);
          }
        }
        if (h.length) {
          g = g.concat(h.slice(0, k.options.choices - g.length));
        }
        return "<ul>" + g.join("") + "</ul>";
      }
    }, a || {});
  }
});
Field.scrollFreeActivate = function (a) {
  setTimeout(function () {
    Field.activate(a);
  }, 1);
};
Ajax.InPlaceEditor = Class.create({
  initialize: function (b, c, a) {
    this.url = c;
    this.element = b = $(b);
    this.prepareOptions();
    this._controls = {};
    arguments.callee.dealWithDeprecatedOptions(a);
    Object.extend(this.options, a || {});
    if (!this.options.formId && this.element.id) {
      this.options.formId = this.element.id + "-inplaceeditor";
      if ($(this.options.formId)) {
        this.options.formId = "";
      }
    }
    if (this.options.externalControl) {
      this.options.externalControl = $(this.options.externalControl);
    }
    if (!this.options.externalControl) {
      this.options.externalControlOnly = false;
    }
    this._originalBackground = this.element.getStyle("background-color") || "transparent";
    this.element.title = this.options.clickToEditText;
    this._boundCancelHandler = this.handleFormCancellation.bind(this);
    this._boundComplete = (this.options.onComplete || Prototype.emptyFunction).bind(this);
    this._boundFailureHandler = this.handleAJAXFailure.bind(this);
    this._boundSubmitHandler = this.handleFormSubmission.bind(this);
    this._boundWrapperHandler = this.wrapUp.bind(this);
    this.registerListeners();
  },
  checkForEscapeOrReturn: function (a) {
    if (!this._editing || a.ctrlKey || a.altKey || a.shiftKey) {
      return;
    }
    if (Event.KEY_ESC == a.keyCode) {
      this.handleFormCancellation(a);
    } else {
      if (Event.KEY_RETURN == a.keyCode) {
        this.handleFormSubmission(a);
      }
    }
  },
  createControl: function (b, f, g) {
    var d = this.options[b + "Control"];
    var c = this.options[b + "Text"];
    if ("button" == d) {
      var a = document.createElement("input");
      a.type = "submit";
      a.value = c;
      a.className = "editor_" + b + "_button";
      if ("cancel" == b) {
        a.onclick = this._boundCancelHandler;
      }
      this._form.appendChild(a);
      this._controls[b] = a;
    } else {
      if ("link" == d) {
        var e = document.createElement("a");
        e.href = "#";
        e.appendChild(document.createTextNode(c));
        e.onclick = "cancel" == b ? this._boundCancelHandler : this._boundSubmitHandler;
        e.className = "editor_" + b + "_link";
        if (g) {
          e.className += " " + g;
        }
        this._form.appendChild(e);
        this._controls[b] = e;
      }
    }
  },
  createEditField: function () {
    var b = (this.options.loadTextURL ? this.options.loadingText : this.getText());
    var c;
    if (1 >= this.options.rows && !/\r|\n/.test(this.getText())) {
      c = document.createElement("input");
      c.type = "text";
      var a = this.options.size || this.options.cols || 0;
      if (0 < a) {
        c.size = a;
      }
    } else {
      c = document.createElement("textarea");
      c.rows = (1 >= this.options.rows ? this.options.autoRows : this.options.rows);
      c.cols = this.options.cols || 40;
    }
    c.name = this.options.paramName;
    c.value = b;
    c.className = "editor_field";
    if (this.options.submitOnBlur) {
      c.onblur = this._boundSubmitHandler;
    }
    this._controls.editor = c;
    if (this.options.loadTextURL) {
      this.loadExternalText();
    }
    this._form.appendChild(this._controls.editor);
  },
  createForm: function () {
    var b = this;

    function a(d, c) {
      var e = b.options["text" + d + "Controls"];
      if (!e || c === false) {
        return;
      }
      b._form.appendChild(document.createTextNode(e));
    }
    this._form = $(document.createElement("form"));
    this._form.id = this.options.formId;
    this._form.addClassName(this.options.formClassName);
    this._form.onsubmit = this._boundSubmitHandler;
    this.createEditField();
    if ("textarea" == this._controls.editor.tagName.toLowerCase()) {
      this._form.appendChild(document.createElement("br"));
    }
    if (this.options.onFormCustomization) {
      this.options.onFormCustomization(this, this._form);
    }
    a("Before", this.options.okControl || this.options.cancelControl);
    this.createControl("ok", this._boundSubmitHandler);
    a("Between", this.options.okControl && this.options.cancelControl);
    this.createControl("cancel", this._boundCancelHandler, "editor_cancel");
    a("After", this.options.okControl || this.options.cancelControl);
  },
  destroy: function () {
    if (this._oldInnerHTML) {
      this.element.innerHTML = this._oldInnerHTML;
    }
    this.leaveEditMode();
    this.unregisterListeners();
  },
  enterEditMode: function (a) {
    if (this._saving || this._editing) {
      return;
    }
    this._editing = true;
    this.triggerCallback("onEnterEditMode");
    if (this.options.externalControl) {
      this.options.externalControl.hide();
    }
    this.element.hide();
    this.createForm();
    this.element.parentNode.insertBefore(this._form, this.element);
    if (!this.options.loadTextURL) {
      this.postProcessEditField();
    }
    if (a) {
      Event.stop(a);
    }
  },
  enterHover: function (a) {
    if (this.options.hoverClassName) {
      this.element.addClassName(this.options.hoverClassName);
    }
    if (this._saving) {
      return;
    }
    this.triggerCallback("onEnterHover");
  },
  getText: function () {
    return this.element.innerHTML.unescapeHTML();
  },
  handleAJAXFailure: function (a) {
    this.triggerCallback("onFailure", a);
    if (this._oldInnerHTML) {
      this.element.innerHTML = this._oldInnerHTML;
      this._oldInnerHTML = null;
    }
  },
  handleFormCancellation: function (a) {
    this.wrapUp();
    if (a) {
      Event.stop(a);
    }
  },
  handleFormSubmission: function (c) {
    var e = this._form;
    var d = $F(this._controls.editor);
    this.prepareSubmission();
    var b = this.options.callback(e, d) || "";
    if (Object.isString(b)) {
      b = b.toQueryParams();
    }
    b.editorId = this.element.id;
    if (this.options.htmlResponse) {
      var a = Object.extend({
        evalScripts: true
      }, this.options.ajaxOptions);
      Object.extend(a, {
        parameters: b,
        onComplete: this._boundWrapperHandler,
        onFailure: this._boundFailureHandler
      });
      new Ajax.Updater({
        success: this.element
      }, this.url, a);
    } else {
      var a = Object.extend({
        method: "get"
      }, this.options.ajaxOptions);
      Object.extend(a, {
        parameters: b,
        onComplete: this._boundWrapperHandler,
        onFailure: this._boundFailureHandler
      });
      new Ajax.Request(this.url, a);
    }
    if (c) {
      Event.stop(c);
    }
  },
  leaveEditMode: function () {
    this.element.removeClassName(this.options.savingClassName);
    this.removeForm();
    this.leaveHover();
    this.element.style.backgroundColor = this._originalBackground;
    this.element.show();
    if (this.options.externalControl) {
      this.options.externalControl.show();
    }
    this._saving = false;
    this._editing = false;
    this._oldInnerHTML = null;
    this.triggerCallback("onLeaveEditMode");
  },
  leaveHover: function (a) {
    if (this.options.hoverClassName) {
      this.element.removeClassName(this.options.hoverClassName);
    }
    if (this._saving) {
      return;
    }
    this.triggerCallback("onLeaveHover");
  },
  loadExternalText: function () {
    this._form.addClassName(this.options.loadingClassName);
    this._controls.editor.disabled = true;
    var a = Object.extend({
      method: "get"
    }, this.options.ajaxOptions);
    Object.extend(a, {
      parameters: "editorId=" + encodeURIComponent(this.element.id),
      onComplete: Prototype.emptyFunction,
      onSuccess: function (b) {
        this._form.removeClassName(this.options.loadingClassName);
        var c = b.responseText;
        if (this.options.stripLoadedTextTags) {
          c = c.stripTags();
        }
        this._controls.editor.value = c;
        this._controls.editor.disabled = false;
        this.postProcessEditField();
      }.bind(this),
      onFailure: this._boundFailureHandler
    });
    new Ajax.Request(this.options.loadTextURL, a);
  },
  postProcessEditField: function () {
    var a = this.options.fieldPostCreation;
    if (a) {
      $(this._controls.editor)["focus" == a ? "focus" : "activate"]();
    }
  },
  prepareOptions: function () {
    this.options = Object.clone(Ajax.InPlaceEditor.DefaultOptions);
    Object.extend(this.options, Ajax.InPlaceEditor.DefaultCallbacks);
    [this._extraDefaultOptions].flatten().compact().each(function (a) {
      Object.extend(this.options, a);
    }.bind(this));
  },
  prepareSubmission: function () {
    this._saving = true;
    this.removeForm();
    this.leaveHover();
    this.showSaving();
  },
  registerListeners: function () {
    this._listeners = {};
    var a;
    $H(Ajax.InPlaceEditor.Listeners).each(function (b) {
      a = this[b.value].bind(this);
      this._listeners[b.key] = a;
      if (!this.options.externalControlOnly) {
        this.element.observe(b.key, a);
      }
      if (this.options.externalControl) {
        this.options.externalControl.observe(b.key, a);
      }
    }.bind(this));
  },
  removeForm: function () {
    if (!this._form) {
      return;
    }
    this._form.remove();
    this._form = null;
    this._controls = {};
  },
  showSaving: function () {
    this._oldInnerHTML = this.element.innerHTML;
    this.element.innerHTML = this.options.savingText;
    this.element.addClassName(this.options.savingClassName);
    this.element.style.backgroundColor = this._originalBackground;
    this.element.show();
  },
  triggerCallback: function (b, a) {
    if ("function" == typeof this.options[b]) {
      this.options[b](this, a);
    }
  },
  unregisterListeners: function () {
    $H(this._listeners).each(function (a) {
      if (!this.options.externalControlOnly) {
        this.element.stopObserving(a.key, a.value);
      }
      if (this.options.externalControl) {
        this.options.externalControl.stopObserving(a.key, a.value);
      }
    }.bind(this));
  },
  wrapUp: function (a) {
    this.leaveEditMode();
    this._boundComplete(a, this.element);
  }
});
Object.extend(Ajax.InPlaceEditor.prototype, {
  dispose: Ajax.InPlaceEditor.prototype.destroy
});
Ajax.InPlaceCollectionEditor = Class.create(Ajax.InPlaceEditor, {
  initialize: function ($super, b, c, a) {
    this._extraDefaultOptions = Ajax.InPlaceCollectionEditor.DefaultOptions;
    $super(b, c, a);
  },
  createEditField: function () {
    var a = document.createElement("select");
    a.name = this.options.paramName;
    a.size = 1;
    this._controls.editor = a;
    this._collection = this.options.collection || [];
    if (this.options.loadCollectionURL) {
      this.loadCollection();
    } else {
      this.checkForExternalText();
    }
    this._form.appendChild(this._controls.editor);
  },
  loadCollection: function () {
    this._form.addClassName(this.options.loadingClassName);
    this.showLoadingText(this.options.loadingCollectionText);
    var options = Object.extend({
      method: "get"
    }, this.options.ajaxOptions);
    Object.extend(options, {
      parameters: "editorId=" + encodeURIComponent(this.element.id),
      onComplete: Prototype.emptyFunction,
      onSuccess: function (transport) {
        var js = transport.responseText.strip();
        if (!/^\[.*\]$/.test(js)) {
          throw ("Server returned an invalid collection representation.");
        }
        this._collection = eval(js);
        this.checkForExternalText();
      }.bind(this),
      onFailure: this.onFailure
    });
    new Ajax.Request(this.options.loadCollectionURL, options);
  },
  showLoadingText: function (b) {
    this._controls.editor.disabled = true;
    var a = this._controls.editor.firstChild;
    if (!a) {
      a = document.createElement("option");
      a.value = "";
      this._controls.editor.appendChild(a);
      a.selected = true;
    }
    a.update((b || "").stripScripts().stripTags());
  },
  checkForExternalText: function () {
    this._text = this.getText();
    if (this.options.loadTextURL) {
      this.loadExternalText();
    } else {
      this.buildOptionList();
    }
  },
  loadExternalText: function () {
    this.showLoadingText(this.options.loadingText);
    var a = Object.extend({
      method: "get"
    }, this.options.ajaxOptions);
    Object.extend(a, {
      parameters: "editorId=" + encodeURIComponent(this.element.id),
      onComplete: Prototype.emptyFunction,
      onSuccess: function (b) {
        this._text = b.responseText.strip();
        this.buildOptionList();
      }.bind(this),
      onFailure: this.onFailure
    });
    new Ajax.Request(this.options.loadTextURL, a);
  },
  buildOptionList: function () {
    this._form.removeClassName(this.options.loadingClassName);
    this._collection = this._collection.map(function (d) {
      return 2 === d.length ? d : [d, d].flatten();
    });
    var c = ("value" in this.options) ? this.options.value : this._text;
    var a = this._collection.any(function (d) {
      return d[0] == c;
    }.bind(this));
    this._controls.editor.update("");
    var b;
    this._collection.each(function (d, e) {
      b = document.createElement("option");
      b.value = d[0];
      b.selected = a ? d[0] == c : 0 == e;
      b.appendChild(document.createTextNode(d[1]));
      this._controls.editor.appendChild(b);
    }.bind(this));
    this._controls.editor.disabled = false;
    Field.scrollFreeActivate(this._controls.editor);
  }
});
Ajax.InPlaceEditor.prototype.initialize.dealWithDeprecatedOptions = function (a) {
  if (!a) {
    return;
  }

  function b(d, c) {
    if (d in a || c === undefined) {
      return;
    }
    a[d] = c;
  }
  b("cancelControl", (a.cancelLink ? "link" : (a.cancelButton ? "button" : a.cancelLink == a.cancelButton == false ? false : undefined)));
  b("okControl", (a.okLink ? "link" : (a.okButton ? "button" : a.okLink == a.okButton == false ? false : undefined)));
  b("highlightColor", a.highlightcolor);
  b("highlightEndColor", a.highlightendcolor);
};
Object.extend(Ajax.InPlaceEditor, {
  DefaultOptions: {
    ajaxOptions: {},
    autoRows: 3,
    cancelControl: "link",
    cancelText: "cancel",
    clickToEditText: "Click to edit",
    externalControl: null,
    externalControlOnly: false,
    fieldPostCreation: "activate",
    formClassName: "inplaceeditor-form",
    formId: null,
    highlightColor: "#ffff99",
    highlightEndColor: "#ffffff",
    hoverClassName: "",
    htmlResponse: true,
    loadingClassName: "inplaceeditor-loading",
    loadingText: "Loading...",
    okControl: "button",
    okText: "ok",
    paramName: "value",
    rows: 1,
    savingClassName: "inplaceeditor-saving",
    savingText: "Saving...",
    size: 0,
    stripLoadedTextTags: false,
    submitOnBlur: false,
    textAfterControls: "",
    textBeforeControls: "",
    textBetweenControls: ""
  },
  DefaultCallbacks: {
    callback: function (a) {
      return Form.serialize(a);
    },
    onComplete: function (b, a) {
      new Effect.Highlight(a, {
        startcolor: this.options.highlightColor,
        keepBackgroundImage: true
      });
    },
    onEnterEditMode: null,
    onEnterHover: function (a) {
      a.element.style.backgroundColor = a.options.highlightColor;
      if (a._effect) {
        a._effect.cancel();
      }
    },
    onFailure: function (b, a) {
      alert("Error communication with the server: " + b.responseText.stripTags());
    },
    onFormCustomization: null,
    onLeaveEditMode: null,
    onLeaveHover: function (a) {
      a._effect = new Effect.Highlight(a.element, {
        startcolor: a.options.highlightColor,
        endcolor: a.options.highlightEndColor,
        restorecolor: a._originalBackground,
        keepBackgroundImage: true
      });
    }
  },
  Listeners: {
    click: "enterEditMode",
    keydown: "checkForEscapeOrReturn",
    mouseover: "enterHover",
    mouseout: "leaveHover"
  }
});
Ajax.InPlaceCollectionEditor.DefaultOptions = {
  loadingCollectionText: "Loading options..."
};
Form.Element.DelayedObserver = Class.create({
  initialize: function (c, a, b) {
    this.delay = a || 0.5;
    this.element = $(c);
    this.callback = b;
    this.timer = null;
    this.lastValue = $F(this.element);
    Event.observe(this.element, "keyup", this.delayedListener.bindAsEventListener(this));
  },
  delayedListener: function (a) {
    if (this.lastValue == $F(this.element)) {
      return;
    }
    if (this.timer) {
      clearTimeout(this.timer);
    }
    this.timer = setTimeout(this.onTimerEvent.bind(this), this.delay * 1000);
    this.lastValue = $F(this.element);
  },
  onTimerEvent: function () {
    this.timer = null;
    this.callback(this.element, $F(this.element));
  }
});
if (!Control) {
  var Control = {};
}
Control.Slider = Class.create({
  initialize: function (b, a, d) {
    var c = this;
    if (Object.isArray(b)) {
      this.handles = b.collect(function (e) {
        return $(e);
      });
    } else {
      this.handles = [$(b)];
    }
    this.track = $(a);
    this.options = d || {};
    this.axis = this.options.axis || "horizontal";
    this.increment = this.options.increment || 1;
    this.step = parseInt(this.options.step || "1");
    this.range = this.options.range || $R(0, 1);
    this.value = 0;
    this.values = this.handles.map(function () {
      return 0;
    });
    this.spans = this.options.spans ? this.options.spans.map(function (e) {
      return $(e);
    }) : false;
    this.options.startSpan = $(this.options.startSpan || null);
    this.options.endSpan = $(this.options.endSpan || null);
    this.restricted = this.options.restricted || false;
    this.maximum = this.options.maximum || this.range.end;
    this.minimum = this.options.minimum || this.range.start;
    this.alignX = parseInt(this.options.alignX || "0");
    this.alignY = parseInt(this.options.alignY || "0");
    this.trackLength = this.maximumOffset() - this.minimumOffset();
    this.handleLength = this.isVertical() ? (this.handles[0].offsetHeight != 0 ? this.handles[0].offsetHeight : this.handles[0].style.height.replace(/px$/, "")) : (this.handles[0].offsetWidth != 0 ? this.handles[0].offsetWidth : this.handles[0].style.width.replace(/px$/, ""));
    this.active = false;
    this.dragging = false;
    this.disabled = false;
    if (this.options.disabled) {
      this.setDisabled();
    }
    this.allowedValues = this.options.values ? this.options.values.sortBy(Prototype.K) : false;
    if (this.allowedValues) {
      this.minimum = this.allowedValues.min();
      this.maximum = this.allowedValues.max();
    }
    this.eventMouseDown = this.startDrag.bindAsEventListener(this);
    this.eventMouseUp = this.endDrag.bindAsEventListener(this);
    this.eventMouseMove = this.update.bindAsEventListener(this);
    this.handles.each(function (e, f) {
      f = c.handles.length - 1 - f;
      c.setValue(parseFloat((Object.isArray(c.options.sliderValue) ? c.options.sliderValue[f] : c.options.sliderValue) || c.range.start), f);
      e.makePositioned().observe("mousedown", c.eventMouseDown);
    });
    this.track.observe("mousedown", this.eventMouseDown);
    document.observe("mouseup", this.eventMouseUp);
    document.observe("mousemove", this.eventMouseMove);
    this.initialized = true;
  },
  dispose: function () {
    var a = this;
    Event.stopObserving(this.track, "mousedown", this.eventMouseDown);
    Event.stopObserving(document, "mouseup", this.eventMouseUp);
    Event.stopObserving(document, "mousemove", this.eventMouseMove);
    this.handles.each(function (b) {
      Event.stopObserving(b, "mousedown", a.eventMouseDown);
    });
  },
  setDisabled: function () {
    this.disabled = true;
  },
  setEnabled: function () {
    this.disabled = false;
  },
  getNearestValue: function (a) {
    if (this.allowedValues) {
      if (a >= this.allowedValues.max()) {
        return (this.allowedValues.max());
      }
      if (a <= this.allowedValues.min()) {
        return (this.allowedValues.min());
      }
      var b = Math.abs(this.allowedValues[0] - a);
      var c = this.allowedValues[0];
      this.allowedValues.each(function (e) {
        var d = Math.abs(e - a);
        if (d <= b) {
          c = e;
          b = d;
        }
      });
      return c;
    }
    if (a > this.range.end) {
      return this.range.end;
    }
    if (a < this.range.start) {
      return this.range.start;
    }
    return a;
  },
  setValue: function (b, a) {
    if (!this.active) {
      this.activeHandleIdx = a || 0;
      this.activeHandle = this.handles[this.activeHandleIdx];
      this.updateStyles();
    }
    a = a || this.activeHandleIdx || 0;
    if (this.initialized && this.restricted) {
      if ((a > 0) && (b < this.values[a - 1])) {
        b = this.values[a - 1];
      }
      if ((a < (this.handles.length - 1)) && (b > this.values[a + 1])) {
        b = this.values[a + 1];
      }
    }
    b = this.getNearestValue(b);
    this.values[a] = b;
    this.value = this.values[0];
    this.handles[a].style[this.isVertical() ? "top" : "left"] = this.translateToPx(b);
    this.drawSpans();
    if (!this.dragging || !this.event) {
      this.updateFinished();
    }
  },
  setValueBy: function (b, a) {
    this.setValue(this.values[a || this.activeHandleIdx || 0] + b, a || this.activeHandleIdx || 0);
  },
  translateToPx: function (a) {
    return Math.round(((this.trackLength - this.handleLength) / (this.range.end - this.range.start)) * (a - this.range.start)) + "px";
  },
  translateToValue: function (a) {
    return ((a / (this.trackLength - this.handleLength) * (this.range.end - this.range.start)) + this.range.start);
  },
  getRange: function (b) {
    var a = this.values.sortBy(Prototype.K);
    b = b || 0;
    return $R(a[b], a[b + 1]);
  },
  minimumOffset: function () {
    return (this.isVertical() ? this.alignY : this.alignX);
  },
  maximumOffset: function () {
    return (this.isVertical() ? (this.track.offsetHeight != 0 ? this.track.offsetHeight : this.track.style.height.replace(/px$/, "")) - this.alignY : (this.track.offsetWidth != 0 ? this.track.offsetWidth : this.track.style.width.replace(/px$/, "")) - this.alignX);
  },
  isVertical: function () {
    return (this.axis == "vertical");
  },
  drawSpans: function () {
    var a = this;
    if (this.spans) {
      $R(0, this.spans.length - 1).each(function (b) {
        a.setSpan(a.spans[b], a.getRange(b));
      });
    }
    if (this.options.startSpan) {
      this.setSpan(this.options.startSpan, $R(0, this.values.length > 1 ? this.getRange(0).min() : this.value));
    }
    if (this.options.endSpan) {
      this.setSpan(this.options.endSpan, $R(this.values.length > 1 ? this.getRange(this.spans.length - 1).max() : this.value, this.maximum));
    }
  },
  setSpan: function (b, a) {
    if (this.isVertical()) {
      b.style.top = this.translateToPx(a.start);
      b.style.height = this.translateToPx(a.end - a.start + this.range.start);
    } else {
      b.style.left = this.translateToPx(a.start);
      b.style.width = this.translateToPx(a.end - a.start + this.range.start);
    }
  },
  updateStyles: function () {
    this.handles.each(function (a) {
      Element.removeClassName(a, "selected");
    });
    Element.addClassName(this.activeHandle, "selected");
  },
  startDrag: function (d) {
    if (Event.isLeftClick(d)) {
      if (!this.disabled) {
        this.active = true;
        var c = Event.element(d);
        var b = [Event.pointerX(d), Event.pointerY(d)];
        var a = c;
        if (a == this.track) {
          var e = Position.cumulativeOffset(this.track);
          this.event = d;
          this.setValue(this.translateToValue((this.isVertical() ? b[1] - e[1] : b[0] - e[0]) - (this.handleLength / 2)));
          var e = Position.cumulativeOffset(this.activeHandle);
          this.offsetX = (b[0] - e[0]);
          this.offsetY = (b[1] - e[1]);
        } else {
          while ((this.handles.indexOf(c) == -1) && c.parentNode) {
            c = c.parentNode;
          }
          if (this.handles.indexOf(c) != -1) {
            this.activeHandle = c;
            this.activeHandleIdx = this.handles.indexOf(this.activeHandle);
            this.updateStyles();
            var e = Position.cumulativeOffset(this.activeHandle);
            this.offsetX = (b[0] - e[0]);
            this.offsetY = (b[1] - e[1]);
          }
        }
      }
      Event.stop(d);
    }
  },
  update: function (a) {
    if (this.active) {
      if (!this.dragging) {
        this.dragging = true;
      }
      this.draw(a);
      if (Prototype.Browser.WebKit) {
        window.scrollBy(0, 0);
      }
      Event.stop(a);
    }
  },
  draw: function (c) {
    var b = [Event.pointerX(c), Event.pointerY(c)];
    var a = Position.cumulativeOffset(this.track);
    b[0] -= this.offsetX + a[0];
    b[1] -= this.offsetY + a[1];
    this.event = c;
    this.setValue(this.translateToValue(this.isVertical() ? b[1] : b[0]));
    if (this.initialized && this.options.onSlide) {
      this.options.onSlide(this.values.length > 1 ? this.values : this.value, this);
    }
  },
  endDrag: function (a) {
    if (this.active && this.dragging) {
      this.finishDrag(a, true);
      Event.stop(a);
    }
    this.active = false;
    this.dragging = false;
  },
  finishDrag: function (a, b) {
    this.active = false;
    this.dragging = false;
    this.updateFinished();
  },
  updateFinished: function () {
    if (this.initialized && this.options.onChange) {
      this.options.onChange(this.values.length > 1 ? this.values : this.value, this);
    }
    this.event = null;
  }
});
Sound = {
  tracks: {},
  _enabled: true,
  template: new Template('<embed style="height:0" id="sound_#{track}_#{id}" src="#{url}" loop="false" autostart="true" hidden="true"/>'),
  enable: function () {
    Sound._enabled = true;
  },
  disable: function () {
    Sound._enabled = false;
  },
  play: function (b) {
    if (!Sound._enabled) {
      return;
    }
    var a = Object.extend({
      track: "global",
      url: b,
      replace: false
    }, arguments[1] || {});
    if (a.replace && this.tracks[a.track]) {
      $R(0, this.tracks[a.track].id).each(function (c) {
        var d = $("sound_" + a.track + "_" + c);
        d.Stop && d.Stop();
        d.remove();
      });
      this.tracks[a.track] = null;
    }
    if (!this.tracks[a.track]) {
      this.tracks[a.track] = {
        id: 0
      };
    } else {
      this.tracks[a.track].id++;
    }
    a.id = this.tracks[a.track].id;
    $$("body")[0].insert(Prototype.Browser.IE ? new Element("bgsound", {
      id: "sound_" + a.track + "_" + a.id,
      src: a.url,
      loop: 1,
      autostart: true
    }) : Sound.template.evaluate(a));
  }
};
if (Prototype.Browser.Gecko && navigator.userAgent.indexOf("Win") > 0) {
  if (navigator.plugins && $A(navigator.plugins).detect(function (a) {
    return a.name.indexOf("QuickTime") != -1;
  })) {
    Sound.template = new Template('<object id="sound_#{track}_#{id}" width="0" height="0" type="audio/mpeg" data="#{url}"/>');
  } else {
    Sound.play = function () {};
  }
}
var swfobject = function () {
  var aq = "undefined",
    aD = "object",
    ab = "Shockwave Flash",
    X = "ShockwaveFlash.ShockwaveFlash",
    aE = "application/x-shockwave-flash",
    ac = "SWFObjectExprInst",
    ax = "onreadystatechange",
    af = window,
    aL = document,
    aB = navigator,
    aa = false,
    Z = [aN],
    aG = [],
    ag = [],
    al = [],
    aJ, ad, ap, at, ak = false,
    aU = false,
    aH, an, aI = true,
    ah = function () {
      var a = typeof aL.getElementById != aq && typeof aL.getElementsByTagName != aq && typeof aL.createElement != aq,
        e = aB.userAgent.toLowerCase(),
        c = aB.platform.toLowerCase(),
        h = c ? /win/.test(c) : /win/.test(e),
        l = c ? /mac/.test(c) : /mac/.test(e),
        g = /webkit/.test(e) ? parseFloat(e.replace(/^.*webkit\/(\d+(\.\d+)?).*$/, "$1")) : false,
        d = !+"\v1",
        f = [0, 0, 0],
        m = null;
      if (typeof aB.plugins != aq && typeof aB.plugins[ab] == aD) {
        m = aB.plugins[ab].description;
        if (m && !(typeof aB.mimeTypes != aq && aB.mimeTypes[aE] && !aB.mimeTypes[aE].enabledPlugin)) {
          aa = true;
          d = false;
          m = m.replace(/^.*\s+(\S+\s+\S+$)/, "$1");
          f[0] = parseInt(m.replace(/^(.*)\..*$/, "$1"), 10);
          f[1] = parseInt(m.replace(/^.*\.(.*)\s.*$/, "$1"), 10);
          f[2] = /[a-zA-Z]/.test(m) ? parseInt(m.replace(/^.*[a-zA-Z]+(.*)$/, "$1"), 10) : 0;
        }
      } else {
        if (typeof af.ActiveXObject != aq) {
          try {
            var k = new ActiveXObject(X);
            if (k) {
              m = k.GetVariable("$version");
              if (m) {
                d = true;
                m = m.split(" ")[1].split(",");
                f = [parseInt(m[0], 10), parseInt(m[1], 10), parseInt(m[2], 10)];
              }
            }
          } catch (b) {}
        }
      }
      return {
        w3: a,
        pv: f,
        wk: g,
        ie: d,
        win: h,
        mac: l
      };
    }(),
    aK = function () {
      if (!ah.w3) {
        return;
      }
      if ((typeof aL.readyState != aq && aL.readyState == "complete") || (typeof aL.readyState == aq && (aL.getElementsByTagName("body")[0] || aL.body))) {
        aP();
      }
      if (!ak) {
        if (typeof aL.addEventListener != aq) {
          aL.addEventListener("DOMContentLoaded", aP, false);
        }
        if (ah.ie && ah.win) {
          aL.attachEvent(ax, function () {
            if (aL.readyState == "complete") {
              aL.detachEvent(ax, arguments.callee);
              aP();
            }
          });
          if (af == top) {
            (function () {
              if (ak) {
                return;
              }
              try {
                aL.documentElement.doScroll("left");
              } catch (a) {
                setTimeout(arguments.callee, 0);
                return;
              }
              aP();
            })();
          }
        }
        if (ah.wk) {
          (function () {
            if (ak) {
              return;
            }
            if (!/loaded|complete/.test(aL.readyState)) {
              setTimeout(arguments.callee, 0);
              return;
            }
            aP();
          })();
        }
        aC(aP);
      }
    }();

  function aP() {
    if (ak) {
      return;
    }
    try {
      var b = aL.getElementsByTagName("body")[0].appendChild(ar("span"));
      b.parentNode.removeChild(b);
    } catch (a) {
      return;
    }
    ak = true;
    var d = Z.length;
    for (var c = 0; c < d; c++) {
      Z[c]();
    }
  }

  function aj(a) {
    if (ak) {
      a();
    } else {
      Z[Z.length] = a;
    }
  }

  function aC(a) {
    if (typeof af.addEventListener != aq) {
      af.addEventListener("load", a, false);
    } else {
      if (typeof aL.addEventListener != aq) {
        aL.addEventListener("load", a, false);
      } else {
        if (typeof af.attachEvent != aq) {
          aM(af, "onload", a);
        } else {
          if (typeof af.onload == "function") {
            var b = af.onload;
            af.onload = function () {
              b();
              a();
            };
          } else {
            af.onload = a;
          }
        }
      }
    }
  }

  function aN() {
    if (aa) {
      Y();
    } else {
      am();
    }
  }

  function Y() {
    var d = aL.getElementsByTagName("body")[0];
    var b = ar(aD);
    b.setAttribute("type", aE);
    var a = d.appendChild(b);
    if (a) {
      var c = 0;
      (function () {
        if (typeof a.GetVariable != aq) {
          var e = a.GetVariable("$version");
          if (e) {
            e = e.split(" ")[1].split(",");
            ah.pv = [parseInt(e[0], 10), parseInt(e[1], 10), parseInt(e[2], 10)];
          }
        } else {
          if (c < 10) {
            c++;
            setTimeout(arguments.callee, 10);
            return;
          }
        }
        d.removeChild(b);
        a = null;
        am();
      })();
    } else {
      am();
    }
  }

  function am() {
    var g = aG.length;
    if (g > 0) {
      for (var h = 0; h < g; h++) {
        var c = aG[h].id;
        var n = aG[h].callbackFn;
        var a = {
          success: false,
          id: c
        };
        if (ah.pv[0] > 0) {
          var k = aS(c);
          if (k) {
            if (ao(aG[h].swfVersion) && !(ah.wk && ah.wk < 312)) {
              ay(c, true);
              if (n) {
                a.success = true;
                a.ref = av(c);
                n(a);
              }
            } else {
              if (aG[h].expressInstall && au()) {
                var e = {};
                e.data = aG[h].expressInstall;
                e.width = k.getAttribute("width") || "0";
                e.height = k.getAttribute("height") || "0";
                if (k.getAttribute("class")) {
                  e.styleclass = k.getAttribute("class");
                }
                if (k.getAttribute("align")) {
                  e.align = k.getAttribute("align");
                }
                var f = {};
                var d = k.getElementsByTagName("param");
                var m = d.length;
                for (var l = 0; l < m; l++) {
                  if (d[l].getAttribute("name").toLowerCase() != "movie") {
                    f[d[l].getAttribute("name")] = d[l].getAttribute("value");
                  }
                }
                ae(e, f, c, n);
              } else {
                aF(k);
                if (n) {
                  n(a);
                }
              }
            }
          }
        } else {
          ay(c, true);
          if (n) {
            var b = av(c);
            if (b && typeof b.SetVariable != aq) {
              a.success = true;
              a.ref = b;
            }
            n(a);
          }
        }
      }
    }
  }

  function av(b) {
    var d = null;
    var c = aS(b);
    if (c && c.nodeName == "OBJECT") {
      if (typeof c.SetVariable != aq) {
        d = c;
      } else {
        var a = c.getElementsByTagName(aD)[0];
        if (a) {
          d = a;
        }
      }
    }
    return d;
  }

  function au() {
    return !aU && ao("6.0.65") && (ah.win || ah.mac) && !(ah.wk && ah.wk < 312);
  }

  function ae(f, d, h, e) {
    aU = true;
    ap = e || null;
    at = {
      success: false,
      id: h
    };
    var a = aS(h);
    if (a) {
      if (a.nodeName == "OBJECT") {
        aJ = aO(a);
        ad = null;
      } else {
        aJ = a;
        ad = h;
      }
      f.id = ac;
      if (typeof f.width == aq || (!/%$/.test(f.width) && parseInt(f.width, 10) < 310)) {
        f.width = "310";
      }
      if (typeof f.height == aq || (!/%$/.test(f.height) && parseInt(f.height, 10) < 137)) {
        f.height = "137";
      }
      aL.title = aL.title.slice(0, 47) + " - Flash Player Installation";
      var b = ah.ie && ah.win ? "ActiveX" : "PlugIn",
        c = "MMredirectURL=" + af.location.toString().replace(/&/g, "%26") + "&MMplayerType=" + b + "&MMdoctitle=" + aL.title;
      if (typeof d.flashvars != aq) {
        d.flashvars += "&" + c;
      } else {
        d.flashvars = c;
      }
      if (ah.ie && ah.win && a.readyState != 4) {
        var g = ar("div");
        h += "SWFObjectNew";
        g.setAttribute("id", h);
        a.parentNode.insertBefore(g, a);
        a.style.display = "none";
        (function () {
          if (a.readyState == 4) {
            a.parentNode.removeChild(a);
          } else {
            setTimeout(arguments.callee, 10);
          }
        })();
      }
      aA(f, d, h);
    }
  }

  function aF(a) {
    if (ah.ie && ah.win && a.readyState != 4) {
      var b = ar("div");
      a.parentNode.insertBefore(b, a);
      b.parentNode.replaceChild(aO(a), b);
      a.style.display = "none";
      (function () {
        if (a.readyState == 4) {
          a.parentNode.removeChild(a);
        } else {
          setTimeout(arguments.callee, 10);
        }
      })();
    } else {
      a.parentNode.replaceChild(aO(a), a);
    }
  }

  function aO(b) {
    var d = ar("div");
    if (ah.win && ah.ie) {
      d.innerHTML = b.innerHTML;
    } else {
      var e = b.getElementsByTagName(aD)[0];
      if (e) {
        var a = e.childNodes;
        if (a) {
          var f = a.length;
          for (var c = 0; c < f; c++) {
            if (!(a[c].nodeType == 1 && a[c].nodeName == "PARAM") && !(a[c].nodeType == 8)) {
              d.appendChild(a[c].cloneNode(true));
            }
          }
        }
      }
    }
    return d;
  }

  function aA(e, g, c) {
    var d, a = aS(c);
    if (ah.wk && ah.wk < 312) {
      return d;
    }
    if (a) {
      if (typeof e.id == aq) {
        e.id = c;
      }
      if (ah.ie && ah.win) {
        var f = "";
        for (var k in e) {
          if (e[k] != Object.prototype[k]) {
            if (k.toLowerCase() == "data") {
              g.movie = e[k];
            } else {
              if (k.toLowerCase() == "styleclass") {
                f += ' class="' + e[k] + '"';
              } else {
                if (k.toLowerCase() != "classid") {
                  f += " " + k + '="' + e[k] + '"';
                }
              }
            }
          }
        }
        var h = "";
        for (var l in g) {
          if (g[l] != Object.prototype[l]) {
            h += '<param name="' + l + '" value="' + g[l] + '" />';
          }
        }
        a.outerHTML = '<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"' + f + ">" + h + "</object>";
        ag[ag.length] = e.id;
        d = aS(e.id);
      } else {
        var b = ar(aD);
        b.setAttribute("type", aE);
        for (var m in e) {
          if (e[m] != Object.prototype[m]) {
            if (m.toLowerCase() == "styleclass") {
              b.setAttribute("class", e[m]);
            } else {
              if (m.toLowerCase() != "classid") {
                b.setAttribute(m, e[m]);
              }
            }
          }
        }
        for (var n in g) {
          if (g[n] != Object.prototype[n] && n.toLowerCase() != "movie") {
            aQ(b, n, g[n]);
          }
        }
        a.parentNode.replaceChild(b, a);
        d = b;
      }
    }
    return d;
  }

  function aQ(b, d, c) {
    var a = ar("param");
    a.setAttribute("name", d);
    a.setAttribute("value", c);
    b.appendChild(a);
  }

  function aw(a) {
    var b = aS(a);
    if (b && b.nodeName == "OBJECT") {
      if (ah.ie && ah.win) {
        b.style.display = "none";
        (function () {
          if (b.readyState == 4) {
            aT(a);
          } else {
            setTimeout(arguments.callee, 10);
          }
        })();
      } else {
        b.parentNode.removeChild(b);
      }
    }
  }

  function aT(a) {
    var b = aS(a);
    if (b) {
      for (var c in b) {
        if (typeof b[c] == "function") {
          b[c] = null;
        }
      }
      b.parentNode.removeChild(b);
    }
  }

  function aS(a) {
    var c = null;
    try {
      c = aL.getElementById(a);
    } catch (b) {}
    return c;
  }

  function ar(a) {
    return aL.createElement(a);
  }

  function aM(a, c, b) {
    a.attachEvent(c, b);
    al[al.length] = [a, c, b];
  }

  function ao(a) {
    var b = ah.pv,
      c = a.split(".");
    c[0] = parseInt(c[0], 10);
    c[1] = parseInt(c[1], 10) || 0;
    c[2] = parseInt(c[2], 10) || 0;
    return (b[0] > c[0] || (b[0] == c[0] && b[1] > c[1]) || (b[0] == c[0] && b[1] == c[1] && b[2] >= c[2])) ? true : false;
  }

  function az(b, f, a, c) {
    if (ah.ie && ah.mac) {
      return;
    }
    var e = aL.getElementsByTagName("head")[0];
    if (!e) {
      return;
    }
    var g = (a && typeof a == "string") ? a : "screen";
    if (c) {
      aH = null;
      an = null;
    }
    if (!aH || an != g) {
      var d = ar("style");
      d.setAttribute("type", "text/css");
      d.setAttribute("media", g);
      aH = e.appendChild(d);
      if (ah.ie && ah.win && typeof aL.styleSheets != aq && aL.styleSheets.length > 0) {
        aH = aL.styleSheets[aL.styleSheets.length - 1];
      }
      an = g;
    }
    if (ah.ie && ah.win) {
      if (aH && typeof aH.addRule == aD) {
        aH.addRule(b, f);
      }
    } else {
      if (aH && typeof aL.createTextNode != aq) {
        aH.appendChild(aL.createTextNode(b + " {" + f + "}"));
      }
    }
  }

  function ay(a, c) {
    if (!aI) {
      return;
    }
    var b = c ? "visible" : "hidden";
    if (ak && aS(a)) {
      aS(a).style.visibility = b;
    } else {
      az("#" + a, "visibility:" + b);
    }
  }

  function ai(b) {
    var a = /[\\\"<>\.;]/;
    var c = a.exec(b) != null;
    return c && typeof encodeURIComponent != aq ? encodeURIComponent(b) : b;
  }
  var aR = function () {
    if (ah.ie && ah.win) {
      window.attachEvent("onunload", function () {
        var a = al.length;
        for (var b = 0; b < a; b++) {
          al[b][0].detachEvent(al[b][1], al[b][2]);
        }
        var d = ag.length;
        for (var c = 0; c < d; c++) {
          aw(ag[c]);
        }
        for (var e in ah) {
          ah[e] = null;
        }
        ah = null;
        for (var f in swfobject) {
          swfobject[f] = null;
        }
        swfobject = null;
      });
    }
  }();
  return {
    registerObject: function (a, e, c, b) {
      if (ah.w3 && a && e) {
        var d = {};
        d.id = a;
        d.swfVersion = e;
        d.expressInstall = c;
        d.callbackFn = b;
        aG[aG.length] = d;
        ay(a, false);
      } else {
        if (b) {
          b({
            success: false,
            id: a
          });
        }
      }
    },
    getObjectById: function (a) {
      if (ah.w3) {
        return av(a);
      }
    },
    embedSWF: function (m, e, h, f, c, a, b, k, g, l) {
      if (typeof (cnn_adbpswf) === "function") {
        cnn_adbpswf(m);
      }
      var d = {
        success: false,
        id: e
      };
      if (ah.w3 && !(ah.wk && ah.wk < 312) && m && e && h && f && c) {
        ay(e, false);
        aj(function () {
          h += "";
          f += "";
          var s = {};
          if (g && typeof g === aD) {
            for (var q in g) {
              s[q] = g[q];
            }
          }
          s.data = m;
          s.width = h;
          s.height = f;
          var p = {};
          if (k && typeof k === aD) {
            for (var r in k) {
              p[r] = k[r];
            }
          }
          if (b && typeof b === aD) {
            for (var n in b) {
              if (typeof p.flashvars != aq) {
                p.flashvars += "&" + n + "=" + b[n];
              } else {
                p.flashvars = n + "=" + b[n];
              }
            }
          }
          if (ao(c)) {
            var o = aA(s, p, e);
            if (s.id == e) {
              ay(e, true);
            }
            d.success = true;
            d.ref = o;
          } else {
            if (a && au()) {
              s.data = a;
              ae(s, p, e, l);
              return;
            } else {
              ay(e, true);
            }
          }
          if (l) {
            l(d);
          }
        });
      } else {
        if (l) {
          l(d);
        }
      }
    },
    switchOffAutoHideShow: function () {
      aI = false;
    },
    ua: ah,
    getFlashPlayerVersion: function () {
      return {
        major: ah.pv[0],
        minor: ah.pv[1],
        release: ah.pv[2]
      };
    },
    hasFlashPlayerVersion: ao,
    createSWF: function (a, b, c) {
      if (ah.w3) {
        return aA(a, b, c);
      } else {
        return undefined;
      }
    },
    showExpressInstall: function (b, a, d, c) {
      if (ah.w3 && au()) {
        ae(b, a, d, c);
      }
    },
    removeSWF: function (a) {
      if (ah.w3) {
        aw(a);
      }
    },
    createCSS: function (b, a, c, d) {
      if (ah.w3) {
        az(b, a, c, d);
      }
    },
    addDomLoadEvent: aj,
    addLoadEvent: aC,
    getQueryParamValue: function (b) {
      var a = aL.location.search || aL.location.hash;
      if (a) {
        if (/\?/.test(a)) {
          a = a.split("?")[1];
        }
        if (b == null) {
          return ai(a);
        }
        var c = a.split("&");
        for (var d = 0; d < c.length; d++) {
          if (c[d].substring(0, c[d].indexOf("=")) == b) {
            return ai(c[d].substring((c[d].indexOf("=") + 1)));
          }
        }
      }
      return "";
    },
    expressInstallCallback: function () {
      if (aU) {
        var a = aS(ac);
        if (a && aJ) {
          a.parentNode.replaceChild(aJ, a);
          if (ad) {
            ay(ad, true);
            if (ah.ie && ah.win) {
              aJ.style.display = "block";
            }
          }
          if (ap) {
            ap(at);
          }
        }
        aU = false;
      }
    }
  };
}();
var cnnLockToggle = false;

function CNN_getCookies() {
  var d = [];
  if (document.cookie) {
    var c = document.cookie.split("; ");
    for (var b = 0; b < c.length; b++) {
      var a = c[b].split("=");
      d[a[0]] = unescape(a[1]) || null;
    }
  }
  return d;
}

function CNN_parseCookieData(a) {
  var d = {};
  var e = a.split("&");
  for (var b = 0; b < e.length; b++) {
    var c = e[b].split(":");
    d[c[0]] = c[1] || null;
  }
  return d;
}

function CNN_setCookie(c, e, a, g, d, f) {
  var b = 0;
  if (a) {
    if ((typeof (a) == "string") && Date.parse(a)) {
      b = a;
    } else {
      if (typeof (a) == "number") {
        b = (new Date((new Date()).getTime() + a * 3600000)).toGMTString();
      }
    }
  }
  document.cookie = c + "=" + escape(e) + ((b) ? (";expires=" + b) : "") + ((g) ? ";path=" + g : "") + ((d) ? ";domain=" + d : "") + ((f && (f === true)) ? "; secure" : "");
}

function CNN_removeCookie(b, d, c) {
  var a = CNN_getCookies();
  var e = a[b] || null;
  if (e) {
    document.cookie = b + "=" + escape(e) + "; expires=Fri, 13-Apr-1970 00:00:00 GMT" + ((d) ? ";path=" + d : "") + ((c) ? ";domain=" + c : "");
  }
}
var allCookies = CNN_getCookies();
var cnnDomainArray = location.hostname.split(".");
var cnnCurrDomain = (cnnDomainArray.length > 1) ? "." + cnnDomainArray[cnnDomainArray.length - 2] + "." + cnnDomainArray[cnnDomainArray.length - 1] : "";

function cnnLiveVideo(a) {
  if (!a) {
    a = "1";
  }
  var b = "/video/live/live.html?stream=stream" + a;
  if (html5Check) {
    b = "/video/flashLive/live.ipad_nf.html";
  }
  CNN_openPopup(b, "liveplayer", "scrollbars=yes,resizable=yes,width=672,height=540");
}

function CNN_openPopup(c, b, e, a) {
  var f = location.hostname;
  if (window == top) {
    window.top.name = "opener";
  }
  var d = window.open(c, b, e);
  if (d) {
    cnnHasOpenPopup = 1;
  }
  if (d && d.opener) {
    if (a) {
      d.opener.location = a;
    }
  }
  if (d) {
    d.focus();
  }
}

function cnnToggleUGC(a, c) {
  if (cnnLockToggle) {
    return;
  }
  cnnLockToggle = true;
  var b = (c.parentNode.className.indexOf("Closed") > -1) ? true : false;
  Effect.toggle(a, "blind", {
    beforeStart: function (f) {
      try {
        c.blur();
      } catch (d) {}
      if (b) {
        switch (c.parentNode.className) {
          case "cnnOpinionClosed":
            c.parentNode.className = "cnnOpinion";
            break;
          case "cnnIReportClosed":
            c.parentNode.className = "cnnIReport";
            break;
          case "cnnBlogsClosed":
            c.parentNode.className = "cnnBlogs";
            Sphere.Widget.search();
            break;
          default:
        }
      }
    },
    afterFinish: function (d) {
      if (!b) {
        switch (c.parentNode.className) {
          case "cnnOpinion":
            c.parentNode.className = "cnnOpinionClosed";
            break;
          case "cnnIReport":
            c.parentNode.className = "cnnIReportClosed";
            break;
          case "cnnBlogs":
            c.parentNode.className = "cnnBlogsClosed";
            break;
          default:
        }
      }
      cnnLockToggle = false;
    }
  });
}
var cnnHorizontalSlider = (typeof Class == "object") ? Class.create() : {};
cnnHorizontalSlider.prototype = {
  initialize: function (d, g, b, c, a) {
    try {
      this.locked = false;
      this.objName = d;
      this.elIdentifier = b;
      this.container = g;
      this.navDiv = c;
      this.viewPort = a;
      this.sliderWidth = this.findPanels();
      this.numScreens = Math.round(this.sliderWidth / 2);
      this.negativeOffSetMax = this.setOffSet();
      this.positiveOffSetMax = 0;
      this.currentPanel = 0;
      this.inactiveDot;
      this.activeDot;
      this.setSliderWidth();
      this.buildNav();
      this.getCurrentOffSet();
    } catch (f) {}
  },
  findPanels: function () {
    var a = $(this.container).getElementsByTagName("div");
    var c = 0;
    for (var b = 0; b < a.length; b++) {
      if (a[b].className == this.elIdentifier + " cnnMar9L" || a[b].className == this.elIdentifier) {
        c++;
      }
    }
    return c;
  },
  setCurrentPanel: function (a) {
    this.getCurrentOffSet();
    this.currentPanel = (this.currOffSet / this.viewPort) * -1;
    this.updateNav();
  },
  setOffSet: function () {
    return ((this.numScreens * this.viewPort) - this.viewPort) * -1;
  },
  calculateSliderWidth: function () {
    return this.viewPort * this.numScreens;
  },
  setSliderWidth: function () {
    $(this.container).style.width = this.calculateSliderWidth() + "px";
  },
  buildNav: function () {},
  updateNav: function () {},
  getCurrentOffSet: function (a) {
    this.currOffSet = (!isNaN(parseInt($(this.container).style.left, 10))) ? parseInt($(this.container).style.left, 10) : 0;
  },
  btnSlide: function (a) {
    if (!this.locked) {
      this.locked = true;
      var b = this;
      this.timer = setTimeout(function () {
        b.getCurrentOffSet();
        var c = (a * b.viewPort) * -1;
        var d = (c > b.currOffSet) ? (c - b.currOffSet) : (b.currOffSet - c) * -1;
        var e = (d > 0) ? 2 * (d / b.viewPort) : (2 * (d / b.viewPort)) * -1;
        if (e < 0) {
          e = e * -1;
        }
        if (b.currOffSet > b.negativeOffSetMax || b.currOffSet < b.positiveOffSetMax) {
          new Effect.MoveBy($(b.container).id, 0, d, {
            duration: e,
            beforeStart: function () {
              b.showImages();
            },
            afterFinish: function () {
              b.setCurrentPanel();
            }
          });
        }
        b.locked = false;
      }, 300);
    }
  }
};
var globalSlideCheck = 0;
var globalTabCheck = 0;
var cnn_GallerySlider = (typeof Class === "object") ? Class.create() : {};
cnn_GallerySlider.prototype = Object.extend(new cnnHorizontalSlider(), {
  initialize: function (a) {
    this.config = a;
    this.defaults = {
      galleryContainerId: "cnn_GallerySliderContainer",
      galleryStripClass: "cnn_fabcaslab",
      galleryTabContainerId: "cnnGalleryTabs",
      nextButtonContainerId: "cnn_fabcnext",
      prevButtonContainerId: "cnn_fabcprev",
      galleryAdPrefix: "gallery_",
      displayWidth: 906
    };
    this.settings = Object.extend(this.defaults, this.config);
    try {
      this.elIdentifier = this.settings.galleryStripClass;
      this.container = this.settings.galleryContainerId;
      this.navDiv = this.settings.navContainer;
      this.viewPort = this.settings.displayWidth;
      this.currentTab = this.settings.currentTab || 0;
    } catch (b) {}
    try {
      this.locked = false;
      this.sliderWidth = this.findPanels();
      this.numScreens = this.sliderWidth;
      this.negativeOffSetMax = this.setOffSet();
      this.positiveOffSetMax = 0;
      this.currentPanel = 0;
      this.inactiveDot = "";
      this.activeDot = "";
      this.setSliderWidth();
      this.buildNav();
      this.getCurrentOffSet();
      this.tabLnks;
      this.numTabs;
      this.requestPanelAd(this.currentTab, this.currentPanel);
      this.numImgsPerPanel = 7;
      this.showImages("init");
    } catch (b) {}
  },
  callOmniture: function (a) {},
  showImages: function (a) {
    var b = a ? $(this.settings.galleryContainerId).down() : $(this.settings.galleryContainerId);
    b.select(".cnn_fabcatz img").each(function (d, c) {
      if (d.className == "cnnContentImg" && d.style.display != "block") {
        d.style.display = "block";
      }
    });
  },
  buildTabs: function (c) {
    tabBtnContainer = $(this.settings.galleryTabContainerId);
    this.tabLnks = tabBtnContainer.getElementsByTagName("a");
    this.numTabs = this.tabLnks.length;
    var a = false;
    var d = this;
    var b = 0;
    if (typeof (c) != "undefined") {
      this.callOmniture("HP mid button " + (c + 1));
    }
    if (typeof c === "undefined") {
      for (b = 0, len = this.numTabs; b < len; b++) {
        if (this.tabLnks[b].className == "cnn_fabtabbtn cnn_fabtabbtnon") {
          c = b;
          a = true;
        }
      }
      if (!a) {
        c = 0;
        this.currentTab = 0;
      }
      this.currentTab = c;
    } else {
      this.currentTab = c;
    }
    for (b = 0, len = this.numTabs; b < len; b++) {
      if (b != c) {
        this.tabLnks[b].className = "cnn_fabtabbtn";
        this.tabLnks[b].onclick = function () {
          d.changeTab(this.href);
          return false;
        };
      } else {
        this.tabLnks[b].className = "cnn_fabtabbtn cnn_fabtabbtnon";
        this.tabLnks[b].onclick = function () {
          return false;
        };
      }
    }
  },
  buildNav: function () {
    this.buildTabs();
    prevBtnContainer = $(this.settings.prevButtonContainerId);
    nextBtnContainer = $(this.settings.nextButtonContainerId);
    prevBtnContainer.className = "cnn_fabcprv_off";
    nextBtnContainer.className = this.sliderWidth > 1 ? "cnn_fabcnxt" : "cnn_fabcnxt_off";
    if (this.sliderWidth > 1) {
      prevBtnContainer.observe("click", this.slidePrev.bind(this));
      nextBtnContainer.observe("click", this.slideNext.bind(this));
    }
  },
  slideNext: function () {
    if ((this.currentPanel + 1) < this.numScreens) {
      this.btnSlide(this.currentPanel + 1);
    }
    if (globalSlideCheck != this.currentPanel + 1 || globalTabCheck != 0) {
      globalSlideCheck = this.currentPanel + 1;
      globalTabCheck = 0;
      this.callOmniture("HP mid right arrow");
    }
  },
  slidePrev: function () {
    if (this.currentPanel > 0) {
      this.btnSlide(this.currentPanel - 1);
    }
    if (globalSlideCheck != this.currentPanel - 1 || globalTabCheck != 0) {
      globalSlideCheck = this.currentPanel - 1;
      globalTabCheck = 0;
      this.callOmniture("HP mid left arrow");
    }
  },
  updateNav: function () {
    this.requestPanelAd(this.currentTab, this.currentPanel);
    if ((this.currentPanel + 1) < this.numScreens) {
      $(this.settings.nextButtonContainerId).className = "cnn_fabcnxt";
    } else {
      $(this.settings.nextButtonContainerId).className = "cnn_fabcnxt_off";
    }
    if (this.currentPanel > 0) {
      $(this.settings.prevButtonContainerId).className = "cnn_fabcprv";
    } else {
      $(this.settings.prevButtonContainerId).className = "cnn_fabcprv_off";
    }
  },
  changeTab: function (a, b) {
    var c = this;
    new Ajax.Request(a, {
      method: "get",
      onSuccess: function (f) {
        c.resetSlider(f.responseText);
        for (var e = 0, d = c.numTabs; e < d; e++) {
          if (a == c.tabLnks[e].href) {
            c.buildTabs(e);
          }
        }
      }
    });
    globalTabCheck = 1;
  },
  resetSlider: function (b) {
    var c = this,
      a = $(c.settings.galleryContainerId).up();
    Effect.Fade(this.container, {
      duration: 0.5,
      afterFinish: function () {
        $(c.container).remove();
        var d = document.createElement("div");
        d.setAttribute("style", "display:none");
        d.setAttribute("id", c.settings.galleryContainerId);
        a.appendChild(d);
        $(c.container).update(b);
        c.initialize(Object.extend(c.settings, {
          currentTab: c.currentTab
        }));
        Effect.Appear(c.container, {
          duration: 0.5
        });
      }
    });
  },
  requestPanelAd: function (c, b) {
    var d = this;
    if ($(this.settings.galleryAdPrefix + c + "_ad_" + b) && !$(this.settings.galleryAdPrefix + c + "_ad_" + b + "Container")) {
      if (this.varDefined("CNN_" + this.settings.galleryAdPrefix + c + "_ad_" + b)) {
        var a = document.createElement("div");
        a.setAttribute("id", this.settings.galleryAdPrefix + c + "_ad_" + b + "Container");
        $(this.settings.galleryAdPrefix + c + "_ad_" + b).appendChild(a);
        new Ajax.Updater({
          success: $(this.settings.galleryAdPrefix + c + "_ad_" + b + "Container")
        }, this.returnVarValue("CNN_" + this.settings.galleryAdPrefix + c + "_ad_" + b), {
          method: "get",
          evalScripts: true,
          asynchronous: true,
          onSuccess: function () {
            if ($(d.settings.galleryAdPrefix + c + "_ad_" + b + "_adgif")) {
              $(d.settings.galleryAdPrefix + c + "_ad_" + b + "_adgif").innerHTML = '<img src="http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/advertisement.gif" width="58" height="5" alt="" border="0">';
            }
          }
        });
      }
    }
  },
  varDefined: function (val) {
    var t;
    var expression = "t = (typeof(" + val + ') !== "undefined");';
    eval(expression);
    return t;
  },
  returnVarValue: function (val) {
    return eval(val);
  }
});
var cnn_SectionGallery, cnn_SectionGallery2;
Event.observe(window, "load", function () {
  if ($("cnn_GallerySliderContainer") && typeof cnn_SectionGallery !== "object") {
    cnn_SectionGallery = new cnn_GallerySlider();
  }
  if ($("cnn_Gallery2SliderContainer") && typeof cnn_SectionGallery2 !== "object") {
    cnn_SectionGallery2 = new cnn_GallerySlider({
      galleryContainerId: "cnn_Gallery2SliderContainer",
      galleryTabContainerId: "cnnGallery2Tabs",
      nextButtonContainerId: "cnn_fabcnext2",
      prevButtonContainerId: "cnn_fabcprev2",
      galleryAdPrefix: "gallery2_"
    });
  }
  cnnInitOverlay();
});
var CNN_T1Flipper = {
  prev: function () {},
  next: function () {},
  play: function () {},
  stop: function () {},
  imgClick: function () {}
};
var cnnT1Flipper = CNN_T1Flipper;
if (typeof Class === "object") {
  CNN_T1Flipper = Class.create();
  CNN_T1Flipper.prototype = {
    initialize: function () {
      this.locked = false;
      this.panels = $$("#cnn_maint1lftf .cnn_flpprt1pnl");
      this.navboxes = $$("#cnn_maint1lftf .cnn_flpprt1nvbx");
      this.iterator = 0;
      this.timer;
      this.autoPlay = false;
      for (var b = 1, a = this.panels.length; b < a; ++b) {
        this.panels[b].hide();
      }
    },
    navigatePanel: function (b) {
      var a = this.iterator;
      if (b === "prev") {
        if (a <= 0) {
          a = this.panels.size() - 1;
        } else {
          a -= 1;
        }
      } else {
        if (a >= this.panels.size() - 1) {
          a = 0;
        } else {
          a += 1;
        }
      }
      this.showPanel(a);
    },
    showPanel: function (b) {
      var a = this;
      if (a.panels.size() > 0 && a.navboxes.size() > 0 && typeof b === "number" && b !== a.iterator && 0 <= b && b <= a.panels.size()) {
        a.locked = true;
        Effect.Fade(a.panels[a.iterator], {
          duration: 0.25,
          afterFinish: function () {
            a.panels[a.iterator].removeClassName("cnn_flpprt1pnl_active");
            a.navboxes[a.iterator].removeClassName("cnn_flpprt1nvbx_active");
            a.iterator = b;
            a.panels[a.iterator].addClassName("cnn_flpprt1pnl_active");
            a.navboxes[a.iterator].addClassName("cnn_flpprt1nvbx_active");
            Effect.Appear(a.panels[a.iterator], {
              duration: 0.25,
              afterFinish: function () {
                a.locked = false;
                if (a.autoPlay) {
                  a.play();
                }
              }
            });
          }
        });
      }
    },
    prev: function () {
      this.stop();
      this.navigatePanel("prev");
    },
    next: function () {
      this.stop();
      this.navigatePanel("next");
    },
    play: function () {
      var a = this;
      if (a.panels.size() > 0 && a.navboxes.size() > 0) {
        a.autoPlay = true;
        a.timer = window.setTimeout(function () {
          a.navigatePanel("next");
        }, 8000);
      }
    },
    stop: function () {
      this.autoPlay = false;
      window.clearTimeout(this.timer);
    },
    imgClick: function (a) {
      if (a) {
        window.location.href = a;
      }
    }
  };
}
var cnn_stryichgcrr = 1;
var cnn_stryichgmax = 0;

function cnn_stryichgS(a) {
  if (a != cnn_stryichgcrr) {
    $("cnn_stryichgnm" + cnn_stryichgcrr).className = "cnn_stryichgn" + cnn_stryichgcrr;
    $("cnn_stryichgnm" + a).className = "cnn_stryichgn" + a + " cnn_stryichgn" + a + "on";
    $("cnnImageChangerImg").src = CNN_storyImageGallery[a - 1].image;
    if ($("cnnImageChangerCap")) {
      $("cnnImageChangerCap").update(CNN_storyImageGallery[a - 1].caption);
      $("cnnImageChangerImg").setAttribute("alt", CNN_storyImageGallery[a - 1].caption);
    } else {
      $("cnnImageChangerImg").setAttribute("alt", CNN_storyImageGallery[a - 1].image);
    }
    cnn_stryichgcrr = a;
  }
}

function cnn_stryichgP() {
  var a = cnn_stryichgcrr;
  if (a == 1) {
    a = cnn_stryichgmax;
  } else {
    a--;
  }
  cnn_stryichgS(a);
}

function cnn_stryichgN() {
  var a = cnn_stryichgcrr;
  if (a == cnn_stryichgmax) {
    a = 1;
  } else {
    a++;
  }
  cnn_stryichgS(a);
}

function cnn_stryichgInit() {
  temp_s = "";
  cnn_stryichgmax = CNN_storyImageGallery.length;
  for (i = 1; i <= cnn_stryichgmax; i++) {
    temp_s += '<a id="cnn_stryichgnm' + i + '" href="javascript:cnn_stryichgS(' + i + ');" class="cnn_stryichgn' + i;
    if (i == 1) {
      temp_s += " cnn_stryichgn" + i + "on";
    }
    temp_s += '"><img src="http://i.cdn.turner.com/cnn/.element/img/3.0/1px.gif" border="0"></a>';
  }
  Element.update("cnn_stryichgnm", temp_s);
}

function cnn_stryichgS_New(a) {
  if (a != cnn_stryichgcrr) {
    $("cnn_stryichgnmL" + cnn_stryichgcrr).className = "cnn_stryichgn" + cnn_stryichgcrr;
    $("cnn_stryichgnmL" + a).className = "cnn_stryichgn" + a + " cnn_stryichgn" + a + "on";
    $("cnnImageChangerImg").src = CNN_storyImageGallery[a - 1].image;
    if ($("cnnImageChangerCap")) {
      $("cnnImageChangerCap").update(CNN_storyImageGallery[a - 1].caption);
      $("cnnMediaTitleCap").update(CNN_storyImageGallery[a - 1].head);
      $("cnnImageChangerImg").setAttribute("alt", CNN_storyImageGallery[a - 1].caption);
    } else {
      $("cnnImageChangerImg").setAttribute("alt", CNN_storyImageGallery[a - 1].image);
    }
    cnn_stryichgcrr = a;
    if (typeof (cnn_adbptrackpgalimg) == "function" && typeof (CNN_storyImageGallery) != "undefined") {
      cnn_adbptrackpgalimg(CNN_storyImageGallery[a - 1].image, photo_gallery);
    }
  }
}

function cnn_storyChanger() {
  var a = "";
  var b = CNN_storyImageGallery.length;
  for (i = 1; i <= b; i++) {
    a += '<a title="cnn_galleryhvr' + i + '" id="cnn_stryichgnmL' + i + '" href="javascript:cnn_stryichgS_New(' + i + ');" class="cnn_stryichgn' + i;
    if (i == 1) {
      a += " cnn_stryichgn" + i + "on";
    }
    a += '"><img src="http://i.cdn.turner.com/cnn/.element/img/3.0/1px.gif" border="0"></a>';
  }
  Element.update("cnn_stryichgnmL", a);
}

function cnn_stryichgP_New() {
  var a = cnn_stryichgcrr;
  if (a == 1) {
    a = cnn_stryichgmax;
  } else {
    a--;
  }
  cnn_stryichgS_New(a);
}

function cnn_stryichgN_New() {
  var a = cnn_stryichgcrr;
  if (a == cnn_stryichgmax) {
    a = 1;
  } else {
    a++;
  }
  cnn_stryichgS_New(a);
}

function CNN_renderRecommend(e) {
  var a = e.assets.length;
  var d = 0;
  var c = '<h4>We recommend</h4><ul class="cnn_bulletbin">';
  for (var b = 0; b < a; b++) {
    var f = "";
    if (e.assets[b].site.toLowerCase() !== "cnn" && e.assets[b]["site-url"] !== "" && e.assets[b].siteId.indexOf("http://") === -1) {
      f += e.assets[b]["site-url"];
    }
    f += e.assets[b].siteId;
    c += '<li><a href="' + f + '">' + e.assets[b].headline + "</a>";
    if (e.assets[b].wool != "") {
      c += " <span>" + e.assets[b].wool.replace(": ", "") + "</span>";
    }
    c += "</li>";
    d++;
    if (d > 2) {
      break;
    }
  }
  c += "</ul>";
  return c;
}

function cnnMouseDown(a) {
  if (cnnDropdownOpen) {
    cnnDD.mouseDownBody(a);
  }
  if (cnnOverlayMenuOpen) {
    cnnOverlayMouseDownBody(a);
  }
  return true;
}
var cnnOverlayOpenId = "";
var cnnOverlayClickedId = "";
var cnnOverlayMenuOpen = false;
var cnnOverlayClass = [];

function cnnInitOverlay() {
  document.body.onmousedown = cnnMouseDown;
  cnnAddOverlayEvents("cnnOverlayLnk");
}

function cnnShowOverlay(a) {
  if ($(a)) {
    if ($(a).style.display == "block") {
      $(a).style.display = "none";
    } else {
      $(a).style.display = "block";
      cnnOverlayOpenId = a;
      cnnOverlayMenuOpen = true;
      cnnOverlayClickedId = "";
    }
  }
}

function cnnHideOverlay(a) {
  if ($(a)) {
    $(a).style.display = "none";
    cnnOverlayOpenId = "";
    cnnOverlayMenuOpen = false;
  }
}

function cnnGetOverlayMenuId(a) {
  return a.href.substring(a.href.indexOf("'") + 1, a.href.lastIndexOf("'"));
}

function cnnAddOverlayEvents(e) {
  var a = document.getElementsByClassName(e);
  for (var d = 0; d < a.length; d++) {
    var c = a[d];
    c.onmousedown = cnnOverlayMouseDownBtn;
    var f = cnnGetOverlayMenuId(c);
    if ($(f)) {
      $(f).onmousedown = cnnOverlayMouseDownMenu;
    }
    cnnOverlayClass[f] = e;
    if ((navigator.userAgent.indexOf("Safari") != -1) && (navigator.userAgent.indexOf("Mac") != -1)) {
      if (c.onmouseout && c.onmouseout.toString().indexOf("cnnImgSwap") != -1) {
        c.onclick = function b() {
          this.onmouseout();
          return true;
        };
      }
    }
  }
}

function cnnOverlayMouseDownBtn(a) {
  var b = cnnGetOverlayMenuId(this);
  cnnOverlayClickedId = b;
  return true;
}

function cnnOverlayMouseDownMenu(a) {
  cnnOverlayClickedId = this.id;
  return true;
}

function cnnOverlayMouseDownBody(a) {
  if (cnnOverlayOpenId != cnnOverlayClickedId) {
    cnnHideOverlay(cnnOverlayOpenId);
  }
  cnnOverlayClickedId = "";
  return true;
}
var cdn_prefix = "http://i.cdn.turner.com/cnn/";

function cnn_EleObjs(a) {
  if (typeof (a) == "string") {
    if (document.getElementById) {
      a = document.getElementById(a);
    } else {
      if (document.all) {
        a = document.all[a];
      } else {
        a = null;
      }
    }
  }
  return a;
}

function cnnRenderTimeStamp(s, g) {
  var a = (location.hostname.indexOf("edition.") > -1) ? true : false;
  var c = (s) ? new Date(s) : c;
  var e = new Array("Sun", "Mon", "Tue", "Wed", "Thur", "Fri", "Sat");
  var l = new Array("January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December");
  var f = new Date();
  var r = "";
  var k = f.getTime() - c.getTime();
  var o = Math.floor(k / 1000 / 60 / 60 / 24);
  k -= o * 1000 * 60 * 60 * 24;
  var m = Math.floor(k / 1000 / 60 / 60);
  k -= m * 1000 * 60 * 60;
  var d = Math.floor(k / 1000 / 60);
  k -= d * 1000 * 60;
  var t = (o > 1) ? "days" : "day";
  var h = (m > 1) ? "hours" : "hour";
  var b = (d > 1) ? "minutes" : "minute";
  var p = "min";
  var q = "";
  var n = "";
  if (g) {
    q = (a) ? g[0] : g[1];
  } else {
    q = "updated " + (!a ? e[c.getUTCDay()] : "") + " " + l[c.getUTCMonth()] + " " + c.getUTCDate() + ", " + c.getUTCFullYear();
  }
  if (m > 4 && o >= 0 || o >= 1) {
    return n;
  } else {
    if (m <= 4 && m >= 1) {
      switch (r) {
        case "homepage":
          return n;
          break;
        case "search_07":
          if (d > 0) {
            return '<span class="cnnContentTimeStampGrey">updated ' + m + " " + h + ", " + d + " " + b + " ago</span>";
          } else {
            return '<span class="cnnContentTimeStampGrey">updated ' + m + " " + h + " ago</span>";
          }
          break;
        case "sectionSpr10":
          if (d > 0) {
            return '<span class="cnnContentTimeStampGrey">updated ' + m + " " + h + ", " + d + "mins ago</span>";
          } else {
            return '<span class="cnnContentTimeStampGrey">updated ' + m + " " + h + " ago</span>";
          }
          break;
        case "mosaic":
        default:
          if (d > 0) {
            return '<div class="cnnGryTmeStmp">updated ' + m + " " + h + ", " + d + " " + b + " ago</div>";
          } else {
            return '<div class="cnnGryTmeStmp">updated ' + m + " " + h + " ago</div>";
          }
      }
    } else {
      switch (r) {
        case "homepage":
          if (m < 1 && d > 0) {
            return "<span>" + d + " min</span>";
          } else {
            return "<span>1 min</span>";
          }
          break;
        case "sectionSpr10":
          if (m < 1 && d > 0) {
            return "<span>" + d + " mins ago</span>";
          } else {
            return "<span>1 min</span>";
          }
          break;
        case "search_07":
          if (m < 1 && d > 0) {
            return '<span class="cnnContentTimeStamp">updated ' + d + " " + b + " ago</span>";
          } else {
            return '<span class="cnnContentTimeStamp">updated 1 minute ago</span>';
          }
        case "mosaic":
        default:
          if (m < 1 && d > 0) {
            return "<span>updated " + d + " " + b + " ago</span>";
          } else {
            return "<span>updated 1 minute ago</span>";
          }
      }
    }
  }
}

function cnn_clsbnbnnr(a) {
  $("cnnBannerContainer").style.display = "none";
  document.cookie = "bannerLastClosed=" + a + "; path=/; domain=cnn.com";
}

function cnnRenderGenericBanner(c, g, e, f, b, a) {
  if (document.cookie.length > 0) {
    cookieName = "bannerLastClosed";
    cookieStart = document.cookie.indexOf(cookieName + "=");
    if (cookieStart != -1) {
      cookieStart = cookieStart + cookieName.length + 1;
      cookieEnd = document.cookie.indexOf(";", cookieStart);
      if (cookieEnd == -1) {
        cookieEnd = document.cookie.length;
      }
      bannerLastClosed = unescape(document.cookie.substring(cookieStart, cookieEnd));
      currentBannerTimestamp = c.id;
      if (parseInt(bannerLastClosed, 10) >= parseInt(currentBannerTimestamp, 10)) {
        return "<!-- Breaking news banner not updated since " + c.id + " -->";
      }
    }
  }
  var d = '<div class="cnn_maincntnr" style="margin-top:6px;"><div class="cnn_contentarea"><div class="cnn_sdbx"><div class="cnn_sdbx1"><div class="cnn_sdbx2"><div class="cnn_sdbx3"><div class="cnn_sdbx4"><div class="cnn_sdbx5"><div class="cnn_sdbxcntnt"><div id="cnn_bnbcntr"><div id="cnn_bnblft">';
  if (b.length > 0) {
    if (a.length > 0) {
      d += '<a href="' + a + '">';
    }
    d += '<img border="0" height="52" width="156" src="' + cdn_prefix + "/.element/img/3.0/main/" + b + '">';
    if (a.length > 0) {
      d += "</a>";
    }
  } else {
    if (swfobject.hasFlashPlayerVersion("8.0.0")) {
      d += '<object id="cnnAnimatedBannerTitle" height="52" width="156" data="' + g + '" pluginspage="http://www.macromedia.com/go/getflashplayer" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" type="application/x-shockwave-flash">';
      d += '<param value="' + g + '" name="movie"/>';
      d += '<param value="false" name="menu"/>';
      d += '<param value="high" name="quality"/>';
      d += '<param value="always" name="allowScriptAccess"/>';
      d += '<param value="transparent" name="wmode"/>';
      d += '<embed height="52" width="156" wmode="transparent" allowscriptaccess="always" quality="high" menu="false" src="' + g + '" name="cnnAnimatedBannerTitle" pluginspage="http://www.macromedia.com/go/getflashplayer" type="application/x-shockwave-flash"/></object>';
    } else {
      d += '<img height="52" width="156" src="' + cdn_prefix + '/.element/img/3.0/main/breakingnews.gif">';
    }
  }
  d += '</div><div id="cnn_bnbrgt1"><div>';
  if (a.length > 0) {
    d += '<a style="color: rgb(255, 255, 255)" href="' + a + '">';
  }
  d += c.content + "&nbsp;";
  if (a.length > 0) {
    d += "</a>";
  }
  if (typeof (c.linkTitle) != "undefined") {
    d += '<a id="cnn_bnbrgt3" style="opacity: 1; filter: alpha(opacity = 100);" href="' + c.linkURL + '">' + c.linkTitle + "</a>";
  }
  d += "</div></div>";
  d += '<div id="cnn_bnbrgt2" style="opacity: 1; filter: alpha(opacity = 100);"></div><div id="cnn_bnbrgt4">';
  d += '<a href="javascript:cnn_clsbnbnnr(' + c.id + ');"><img src="' + cdn_prefix + '/.element/img/3.0/1px.gif" border="0"></a></div></div></div></div></div></div></div></div></div></div></div>';
  return d;
}

function cnnRenderDomesticBanner(c) {
  var f = cdn_prefix + "/.element/swf/3.0/breaking.news/yellowBanner2.swf";
  var d = "";
  var e = "";
  var b = "";
  var a = "";
  switch (c.type) {
    case "Live Breaking News":
      d = "cnnYellow";
      e = "cnnBlack";
      break;
    case "Breaking News":
      d = "cnnBlack";
      e = "cnnYellow";
      break;
    case "Live Developing Story":
      d = "cnnRed";
      e = "cnnBlack";
      f = "http://i2.cdn.turner.com/cnn/.element/swf/2.0/breaking_news/bn_dev_domestic.swf";
      break;
    case "Developing Story":
      d = "cnnBlack";
      e = "cnnRed";
      break;
    case "Watch Now":
      d = "cnnBlue";
      e = "cnnBlue";
      break;
    case "Live Election Coverage":
      d = "cnnBlackElex";
      e = "cnnDrkBlue";
      break;
    case "Live Inauguration Coverage":
      d = "cnnBlackElex";
      e = "cnnDrkGry";
      break;
    case "Connect with CNN":
      d = "cnnBlue";
      e = "cnnBlack";
      f = "http://i2.cdn.turner.com/cnn/.element/swf/2.0/breaking_news/bn_connectWithCNN.swf";
      break;
    case "Live Now (sponsored)":
      d = "cnnBlue";
      e = "cnnBlack";
      f = "http://i2.cdn.turner.com/cnn/.element/swf/2.0/breaking_news/bn_liveNow.swf";
      break;
    case "Live Now":
      d = "cnnBlue";
      e = "cnnBlack";
      f = "http://i2.cdn.turner.com/cnn/.element/swf/2.0/breaking_news/bn_liveNow.swf";
      break;
    case "Royal Wedding":
      b = "RW_live_banner.jpg";
      a = "http://www.cnn.com/SPECIALS/2011/royal.wedding/live/";
      if (document.location.pathname == "/" || document.location.pathname == "/index.html" || document.location.pathname == "/SPECIALS/2011/royal.wedding/live/") {
        return "";
      }
      break;
    default:
      return "";
  }
  return cnnRenderGenericBanner(c, f, d, e, b, a);
}

function cnnRenderInternationalBanner(c) {
  var f = cdn_prefix + "/.element/swf/3.0/breaking.news/yellowBanner2.swf";
  var d = "";
  var e = "";
  var b = "";
  var a = "";
  switch (c.type) {
    case "Live Breaking News":
      d = "cnnYellow";
      e = "cnnBlack";
      break;
    case "Breaking News":
      d = "cnnBlack";
      e = "cnnYellow";
      break;
    case "Live Developing Story":
      d = "cnnYellow";
      e = "cnnBlack";
      f = cdn_prefix + "/.element/swf/2.0/breaking_news/bn_dev.swf";
      break;
    case "Developing Story":
      d = "cnnBlack";
      e = "cnnYellow";
      break;
    case "Watch Now":
      d = "cnnBlue";
      e = "cnnBlue";
      break;
    case "Connect with CNN":
      d = "cnnBlue";
      e = "cnnBlack";
      f = cdn_prefix + "/.element/swf/2.0/breaking_news/bn_connectWithCNN.swf";
      break;
    case "Live Now (sponsored)":
      d = "cnnBlue";
      e = "cnnBlack";
      f = cdn_prefix + "/.element/swf/2.0/breaking_news/bn_liveNow.swf";
      break;
    case "Live Now":
      d = "cnnBlue";
      e = "cnnBlack";
      f = cdn_prefix + "/.element/swf/2.0/breaking_news/bn_liveNow.swf";
      break;
    case "Royal Wedding":
      b = "RW_live_banner.jpg";
      a = "http://www.cnn.com/SPECIALS/2011/royal.wedding/live/";
      if (document.location.pathname == "/" || document.location.pathname == "/index.html" || document.location.pathname == "/SPECIALS/2011/royal.wedding/live/") {
        return "";
      }
      break;
    default:
      return "";
  }
  return cnnRenderGenericBanner(c, f, d, e, b, a);
}
var VBS_Result = false;

function CNN_FlashDetect() {}
CNN_FlashDetect.prototype.maxVersionToDetect = 10;
CNN_FlashDetect.prototype.minVersionToDetect = 3;
CNN_FlashDetect.prototype.hasPlugin = (navigator.mimeTypes && navigator.mimeTypes.length && navigator.mimeTypes["application/x-shockwave-flash"] && navigator.mimeTypes["application/x-shockwave-flash"].enabledPlugin);
CNN_FlashDetect.prototype.hasActiveX = window.ActiveXObject;
CNN_FlashDetect.prototype.hasWinIE = (navigator.userAgent && (navigator.userAgent.indexOf("MSIE") != -1) && navigator.appVersion && (navigator.appVersion.indexOf("Win") != -1));
CNN_FlashDetect.prototype.getVersion = function () {
  var b = 0;
  var d = 0;
  if (this.hasActiveX) {
    var c = false;
    for (d = this.maxVersionToDetect; d >= this.minVersionToDetect && !c; b = (c ? d : b), d--) {
      try {
        c = new ActiveXObject("ShockwaveFlash.ShockwaveFlash." + d);
      } catch (f) {}
    }
  } else {
    if (this.hasWinIE) {
      VBS_Result = false;
      for (d = this.maxVersionToDetect; d >= this.minVersionToDetect && !VBS_Result; b = (VBS_Result ? d : b), d--) {
        execScript('on error resume next: VBS_Result = IsObject( CreateObject( "ShockwaveFlash.ShockwaveFlash.' + d + '" ) )', "VBScript");
      }
    } else {
      if (this.hasPlugin) {
        if (navigator.plugins && navigator.plugins.length && navigator.plugins["Shockwave Flash"]) {
          var g = navigator.plugins["Shockwave Flash"].description.split(" ");
          for (d = 0; d < g.length; ++d) {
            var a = parseInt(g[d], 10);
            if (isNaN(a)) {
              continue;
            } else {
              b = a;
              break;
            }
          }
        }
      }
    }
  }
  return (b);
};
CNN_FlashDetect.prototype.detectVersion = function (b) {
  var a = false;
  if (!isNaN(b)) {
    a = (parseInt(this.getVersion(), 10) >= parseInt(b, 10));
  }
  return (a);
};

function CNN_FlashObject(b, a, e, d, c, f) {
  this.m_name = b;
  this.m_src = a;
  this.m_width = e;
  this.m_height = d;
  this.m_flashVars = f;
  if (c) {
    this.setParams(c);
  }
}
CNN_FlashObject.prototype.m_name = "";
CNN_FlashObject.prototype.m_src = "";
CNN_FlashObject.prototype.m_width = "";
CNN_FlashObject.prototype.m_height = "";
CNN_FlashObject.prototype.m_flashVars = "";
CNN_FlashObject.prototype.m_params = {
  menu: "false",
  quality: "high",
  allowScriptAccess: "always",
  wmode: "transparent"
};
CNN_FlashObject.prototype.setParam = function (a, b) {
  this.m_params[a] = b;
};
CNN_FlashObject.prototype.setParams = function (a) {
  if (typeof a == "object") {
    for (var b in a) {
      if (a[b]) {
        this.setParam(b, a[b]);
      }
    }
  }
};
CNN_FlashObject.prototype.getParam = function (a) {
  return (this.m_params[a]);
};
CNN_FlashObject.prototype.getParams = function () {
  return (this.m_params);
};
CNN_FlashObject.prototype.getFlashVarsString = function () {
  var a = "";
  if (typeof this.m_flashVars == "string") {
    a = this.m_flashVars;
  } else {
    if (typeof this.m_flashVars == "object") {
      for (var b in this.m_flashVars) {
        if (a != "") {
          a += "&";
        }
        a += b + "=" + escape(this.m_flashVars[b]);
      }
    }
  }
  return (a);
};
CNN_FlashObject.prototype.getAttributeString = function (a, b) {
  return (b ? " " + a + '="' + b + '"' : "");
};
CNN_FlashObject.prototype.getParamTag = function (a, b) {
  return (b ? '<param name="' + a + '" value="' + b + '">' : "");
};
CNN_FlashObject.prototype.getHtml = function () {
  var b = "";
  var a = "";
  var c = "http://www.macromedia.com/go/getflashplayer";
  b += '<object type="application/x-shockwave-flash" 					classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"';
  b += this.getAttributeString("pluginspage", c);
  b += this.getAttributeString("id", this.m_name);
  b += this.getAttributeString("data", this.m_src);
  b += this.getAttributeString("width", this.m_width);
  b += this.getAttributeString("height", this.m_height);
  b += ">";
  b += this.getParamTag("movie", this.m_src);
  for (a in this.getParams()) {
    b += this.getParamTag(a, this.getParam(a));
  }
  b += this.getParamTag("flashVars", this.getFlashVarsString());
  b += '<embed type="application/x-shockwave-flash"';
  b += this.getAttributeString("pluginspage", c);
  b += this.getAttributeString("name", this.m_name);
  b += this.getAttributeString("src", this.m_src);
  b += this.getAttributeString("width", this.m_width);
  b += this.getAttributeString("height", this.m_height);
  for (a in this.getParams()) {
    b += this.getAttributeString(a, this.getParam(a));
  }
  b += this.getAttributeString("flashVars", this.getFlashVarsString());
  b += ">";
  b += "</embed>";
  b += "</object>";
  return (b);
};
CNN_FlashObject.prototype.writeHtml = function () {
  document.write(this.getHtml());
};
CNN_FlashObject.prototype.writeMosaicHtml = function (a) {
  document.getElementById(a).innerHTML = this.getHtml();
};
var cnnDropdownOpen = false;
var cnnDocDomain = "";
if (location.hostname.indexOf("cnn.com") > 0) {
  cnnDocDomain = "cnn.com";
}
if (location.hostname.indexOf("turner.com") > 0) {
  cnnDocDomain = "turner.com";
}
if (cnnDocDomain) {
  document.domain = cnnDocDomain;
}

function validateSearch(b) {
  var d = b.elements["query"];
  var c = d.value;
  if (c != "" || c != null) {
    c = cnnLeftTrim(c);
    var a = new RegExp("[w*|W*]*<[[w*|W*]*|/[w*|W*]]>[w*|W*]*");
    if (a.exec(c) || (c == null) || (c.length == 0) || (c.indexOf(">") >= 0) || (c.indexOf(";") >= 0)) {
      alert("Please enter a valid search term and try again." + "\n" + "HTML, URLs, and Scripts are not allowed.");
    } else {
      d.value = c;
      b.submit();
    }
  }
  return false;
}

function cnnLeftTrim(a) {
  while (a.substring(0, 1) == " ") {
    a = a.substring(1, a.length);
  }
  return a;
}
var cnnPSproducts = "";
var cnnProducts = [];

function cnn_geturlqargs() {
  var b = {};
  var f = location.search.substring(1);
  var e = f.split("&");
  for (var c = 0; c < e.length; c++) {
    var g = e[c].indexOf("=");
    if (g == -1) {
      continue;
    }
    var a = e[c].substring(0, g);
    var d = e[c].substring(g + 1);
    b[a] = unescape(d);
  }
  return b;
}
var html5Check = /\b(iPad|iPod|iPhone)\b/.test(window.navigator.userAgent);
var CNN_GalleryManager = function () {
  this.id = settings.id;
  var a;
  a = new Element("div", {
    "class": "cnn_gallery_test"
  }).update("" + "</div>");
  return a;
};
var CNN_SlideShowManager = (function () {
  var a = function (l) {
    this.index = -1;
    this.id = l.id;
    this.xmlurl = l.xmlurl;
    this.width = l.width || 640;
    this.height = l.height || 360;
    this.xmldoc = l.xmldoc;
    this.imageUrlRoot = l.imageUrlRoot || this.xmldoc.querySelector("gallery:root > dir").firstChild.nodeValue || "";
    this.images = [];
    this.inited = false;
    this.wrapper = null;
    this.media = null;
    this.title = null;
    this.caption = null;
    this.pager = null;
    this.pages = null;
    var o = function (r, s) {
      var q = "";
      try {
        q = r.querySelector(s).firstChild.nodeValue;
      } catch (t) {}
      return q;
    };
    for (var k = 0, m = this.xmldoc.querySelectorAll("gallery:root > imgs > img"), h = m.length, p = null, n = {}; k < h; k++) {
      p = m.item(k);
      n = {};
      n["caption"] = o(p, "caption");
      n["title"] = o(p, "title");
      n["lgUrl"] = "" + this.imageUrlRoot + o(p, "lgUrl");
      n["source"] = o(p, "source");
      if (n["lgUrl"]) {
        this.images.push(n);
      }
    }
  };
  a.prototype = {
    slideshowTemplate: (function () {
      var h;
      h = new Element("div", {
        "class": "cnn_html_slideshow"
      }).update("" + '<div class="cnn_html_slideshow_media">' + '<div class="cnn_html_media">' + "</div>" + '<div class="cnn_html_slideshow_media_overlay">' + '<div class="cnn_html_slideshow_media_caption"></div>' + "</div>" + "</div>" + '<div class="cnn_html_slideshow_metadata">' + '<div class="cnn_html_media_title"></div>' + "</div>");
      return h;
    })(),
    pagerTemplate: (function () {
      var h;
      h = new Element("div", {
        "class": "cnn_html_slideshow_controls"
      }).update("" + '<span class="prev_slide">&lt;</span>' + '<span class="next_slide">&gt;</span>' + '<div class="cnn_html_slideshow_pager_container">' + '<ul class="cnn_html_slideshow_pager">' + "</ul>" + "</div>");
      return h;
    })(),
    init: function () {
      if (this.inited) {
        console.log('already inited slideshow "' + this.id + '"');
      } else {
        this.inited = true;
        if (this.images.length === 0) {
          $(this.id).update('<img src="http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/640x360_ns_ipad.gif" width="' + this.width + '" height="' + this.height + '" alt="" border="0">');
        } else {
          this.wrapper = this.slideshowTemplate.cloneNode(true);
          this.media = this.wrapper.select(".cnn_html_media")[0];
          this.media.setStyle({
            width: this.width,
            height: this.height
          });
          this.title = this.wrapper.select(".cnn_html_media_title")[0];
          this.caption = this.wrapper.select(".cnn_html_slideshow_media_caption")[0];
          if (this.images.length > 1) {
            this.pager = this.pagerTemplate.cloneNode(true);
            this.pages = this.pager.select(".cnn_html_slideshow_pager")[0];
            this.pager.select(".prev_slide")[0].observe("click", this.showPrev.bind(this));
            this.pager.select(".next_slide")[0].observe("click", this.showNext.bind(this));
            for (var k = 0, h = this.images.length; k < h; k++) {
              this.pages.insert(new Element("li").update("" + (k + 1)).observe("click", this.show.bind(this, k)));
            }
            this.wrapper.insert(this.pager);
          }
          $(this.id).update(this.wrapper);
          this.show(0);
        }
      }
    },
    showPrev: function () {
      var h = this.index;
      if (h <= 0) {
        h = this.images.length - 1;
      } else {
        h -= 1;
      }
      this.show(h);
    },
    showNext: function () {
      var h = this.index;
      if (h >= this.images.length - 1) {
        h = 0;
      } else {
        h += 1;
      }
      this.show(h);
    },
    show: function (k) {
      var p;
      if (this.media !== null && k !== this.index) {
        p = this.images[k];
        this.media.setStyle({
          backgroundImage: "url('" + p["lgUrl"] + "')",
          backgroundRepeat: "no-repeat",
          backgroundPosition: "center center",
          backgroundSize: "auto auto"
        });
        this.title.update(p["title"]);
        this.caption.update(p["caption"]);
        if (this.index !== -1) {
          this.pages.childElements()[this.index].removeClassName("selected");
        }
        if (k !== -1) {
          this.pages.childElements()[k].addClassName("selected");
        }
        if (k !== -1 && this.index !== -1) {
          var h = this.pages.parentElement,
            o = h.offsetWidth,
            l = this.pages.offsetWidth,
            n = l / this.images.length,
            m = -1 * k * n + ((o - n) / 2);
          if (l > o) {
            if (m > 0) {
              m = 0;
            }
            if (m < o - l) {
              m = o - l;
            }
            this.pages.style.left = "" + m + "px";
          }
        }
        this.index = k;
      }
    }
  };
  var c = [],
    g = {}, e = function (m, k, l) {
      var h = l ? l : {};
      if (typeof h.width !== "undefined" && h.width === 416) {
        h.height = 234;
      }
      if (c.indexOf(m) !== -1) {
        console.log('slideshow id "' + m + '" was already registered');
      } else {
        h.id = m;
        h.xmlurl = k;
        new Ajax.Request(k, {
          onSuccess: function (n) {
            h.xmldoc = n.responseXML;
            c.push(m);
            g[m] = new a(h);
            g[m].init();
          },
          onFailure: function (n) {
            $(m).update('<img src="http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/640x360_ns_ipad.gif" width="' + this.width + '" height="' + this.height + '" alt="" border="0">');
          }
        });
      }
    }, d = function () {
      return c;
    }, b = function () {
      var h = [];
      c.each(function (k) {
        h.push(g[k]);
      });
      return h;
    }, f = function (h) {
      if (c.indexOf(h) === -1) {
        console.log('There is no slideshow with id "' + h + '"');
      } else {
        return g[h];
      }
    };
  return ({
    register: e,
    getIds: d,
    getSlideShows: b,
    getSlideShow: f
  });
})();

function cnn_onMemFBinit() {}
var CNN_SlideShowManagerAlt = (function () {
  var a = function (l) {
    this.index = -1;
    this.id = l.id;
    this.xmlurl = l.xmlurl;
    this.width = l.width || 640;
    this.height = l.height || 360;
    this.xmldoc = l.xmldoc;
    this.explainer = (this.xmlurl.indexOf("explainer.") > -1) ? 1 : 0;
    if (this.explainer === 1) {
      this.imageUrlRoot = this.xmlurl.split("data.xml")[0] + "media/";
    } else {
      this.imageUrlRoot = l.imageUrlRoot || this.xmldoc.querySelector("gallery:root > dir").firstChild.nodeValue || "";
    }
    this.images = [];
    this.inited = false;
    this.wrapper = null;
    this.media = null;
    this.title = null;
    this.caption = null;
    this.pager = null;
    this.pages = null;
    var n = function (t, u) {
      var s = "";
      try {
        s = t.querySelector(u).firstChild.nodeValue;
      } catch (v) {}
      return s;
    };
    var h = this.explainer ? "data:root > tabs > tab" : "gallery:root > imgs > img";
    for (var o = 0, p = this.xmldoc.querySelectorAll(h), m = p.length, r = null, k = {}; o < m; o++) {
      r = p.item(o);
      k = {};
      k["caption"] = n(r, "caption");
      if (this.explainer) {
        k["headline"] = n(r, "headline");
        var q = this.xmldoc.getElementsByTagName("headline")[0].firstChild.nodeValue;
        console.log("title = " + q);
        k["label"] = n(r, "label");
        k["file"] = "" + this.imageUrlRoot + r.querySelector("content").getAttribute("file");
        k["caption"] = "<h4>" + n(r, "headline") + "</h4>" + k["caption"];
        k["lgUrl"] = k["file"];
      } else {
        k["title"] = n(r, "title");
        k["lgUrl"] = "" + this.imageUrlRoot + n(r, "lgUrl");
        k["source"] = n(r, "source");
      }
      if (k["lgUrl"]) {
        this.images.push(k);
      }
    }
  };
  a.prototype = {
    slideshowTemplate: (function () {
      var h;
      h = new Element("div", {
        "class": "cnnExplainer cnn_html_slideshow"
      }).update("" + '<div class="cnn_html_slideshow_media">' + '<div class="cnn_html_media">' + "</div>" + '<div class="cnn_html_slideshow_media_overlay">' + '<div class="cnn_html_slideshow_media_caption"></div>' + "</div>" + "</div>" + '<div class="cnn_html_slideshow_metadata">' + '<div class="cnn_html_media_title"></div>' + "</div>");
      return h;
    }()),
    pagerTemplate: (function () {
      var h;
      h = new Element("div", {
        "class": "cnn_html_slideshow_controls"
      }).update("" + '<span class="prev_slide">&lt;</span>' + '<span class="next_slide">&gt;</span>' + '<div class="cnn_html_slideshow_pager_container">' + '<ul class="cnn_html_slideshow_pager">' + "</ul>" + "</div>");
      return h;
    }()),
    init: function () {
      if (this.inited) {
        console.log('already inited slideshow "' + this.id + '"');
      } else {
        this.inited = true;
        if (this.images.length === 0) {
          $(this.id).update('<img src="http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/640x360_ns_ipad.gif" width="' + this.width + '" height="' + this.height + '" alt="" border="0">');
        } else {
          this.wrapper = this.slideshowTemplate.cloneNode(true);
          this.media = this.wrapper.select(".cnn_html_media")[0];
          this.media.setStyle({
            width: this.width,
            height: this.height
          });
          this.title = this.wrapper.select(".cnn_html_media_title")[0];
          console.log("this.title = " + this.title);
          this.caption = this.wrapper.select(".cnn_html_slideshow_media_caption")[0];
          if (this.images.length > 1) {
            this.pager = this.pagerTemplate.cloneNode(true);
            this.pages = this.pager.select(".cnn_html_slideshow_pager")[0];
            this.pager.select(".prev_slide")[0].observe("click", this.showPrev.bind(this));
            this.pager.select(".next_slide")[0].observe("click", this.showNext.bind(this));
            for (var l = 0, k = this.images.length; l < k; l++) {
              var h = (this.explainer === 1) ? this.images[l]["label"] : ("" + (l + 1));
              this.pages.insert(new Element("li").update(h).observe("click", this.show.bind(this, l)));
            }
            this.wrapper.insert(this.pager);
          }
          $(this.id).update(this.wrapper);
          this.show(0);
        }
      }
    },
    showPrev: function () {
      var h = this.index;
      if (h <= 0) {
        h = this.images.length - 1;
      } else {
        h -= 1;
      }
      this.show(h);
    },
    showNext: function () {
      var h = this.index;
      if (h >= this.images.length - 1) {
        h = 0;
      } else {
        h += 1;
      }
      this.show(h);
    },
    show: function (k) {
      var p;
      if (this.media !== null && k !== this.index) {
        p = this.images[k];
        this.media.setStyle({
          backgroundImage: "url('" + p["lgUrl"] + "')",
          backgroundRepeat: "no-repeat",
          backgroundPosition: "center center",
          backgroundSize: "auto auto"
        });
        this.title.update(p["title"]);
        this.caption.update(p["caption"]);
        if (this.index !== -1) {
          this.pages.childElements()[this.index].removeClassName("selected");
        }
        if (k !== -1) {
          this.pages.childElements()[k].addClassName("selected");
        }
        if (k !== -1 && this.index !== -1) {
          var h = this.pages.parentNode,
            o = h.offsetWidth,
            l = this.pages.offsetWidth,
            n = l / this.images.length,
            m = -1 * k * n + ((o - n) / 2);
          if (l > o) {
            if (m > 0) {
              m = 0;
            }
            if (m < o - l) {
              m = o - l;
            }
            this.pages.style.left = "" + m + "px";
          }
        }
        this.index = k;
      }
    }
  };
  var c = [],
    g = {}, e = function (m, k, l) {
      var h = l ? l : {};
      if (typeof h.width !== "undefined" && h.width === 416) {
        h.height = 234;
      }
      if (c.indexOf(m) !== -1) {
        console.log('slideshow id "' + m + '" was already registered');
      } else {
        h.id = m;
        h.xmlurl = k;
        new Ajax.Request(k, {
          onSuccess: function (n) {
            h.xmldoc = n.responseXML;
            c.push(m);
            g[m] = new a(h);
            g[m].init();
          },
          onFailure: function (n) {
            $(m).update('<img src="http://i.cdn.turner.com/cnn/.element/img/3.0/global/misc/640x360_ns_ipad.gif" width="' + this.width + '" height="' + this.height + '" alt="" border="0">');
          }
        });
      }
    }, d = function () {
      return c;
    }, b = function () {
      var h = [];
      c.each(function (k) {
        h.push(g[k]);
      });
      return h;
    }, f = function (h) {
      if (c.indexOf(h) === -1) {
        console.log('There is no slideshow with id "' + h + '"');
      } else {
        return g[h];
      }
    };
  return ({
    register: e,
    getIds: d,
    getSlideShows: b,
    getSlideShow: f
  });
}());
if (Object.isUndefined(cnn_metadata)) {
  var cnn_metadata = {
    "section": [],
    "friendly_name": "",
    "template_type": "",
    "template_type_content": "",
    "business": {
      "cnn": {
        "page": {
          "broadcast_franchise": ""
        },
        "video": {}
      }
    },
    "user": {
      "authenticated": "",
      "segment": {
        "age": "",
        "zip": "",
        "gender": ""
      }
    }
  };
}
if (allCookies["CNN_memberID"]) {
  cnn_metadata.user.authenticated = 1;
}

function CSIManager() {
  if ((CSIManager.caller && CSIManager.getInstance) && (CSIManager.caller != CSIManager.getInstance)) {
    if ((navigator.userAgent.indexOf("Safari") == -1) && (navigator.userAgent.indexOf("Opera") == -1)) {
      throw new Error("There is no public constructor for CSIManager.");
    }
  }
  this.CSIObjects = new Array();
  this.delayedCSIList = new Array();
  this.domIDConfig = new Array();
  this.domOnLoad = new Array();
  this.domOnBeforeLoad = new Array();
  this.useDelayedCSI = false;
  this.numberofRequests = 0;
  var a = new Date();
  this.iframeOffset = 0;
  this.queueAllCalls = false;
  this.queuedCallArray = new Array();
  this.eventTypes = new Array();
  this.currentEventType = "";
  this.eventTypeFunctions = new Array();
  this.watchEventTypeNodes = new Array();
  this.isPolling = false;
  this.pollingInterval = 10000;
  this.minimumInterval = 9999;
  this.domRefreshHook = false;
  this.pollingUrl = false;
  var d = navigator.userAgent.toLowerCase();
  if ((d.indexOf("msie") > -1) && (d.indexOf("mac") > -1)) {
    this.useDelayedCSI = true;
  }
  this.dojoSupport = (typeof dojo == "undefined") ? false : true;
  this.prototypeSupport = (typeof Prototype == "undefined") ? false : true;
  this.noFramework = (!this.dojoSupport && !this.prototypeSupport) ? true : false;
  var e = this;
  var c = function () {
    e.initialize();
  };
  var b = function (g) {
    if (g.persisted) {
      window.setTimeout("CSIManager.getInstance().delayedProcessing();", 2000);
    }
  };
  if (this.prototypeSupport) {
    Event.observe(window, "load", c);
    Event.observe(window, "pageshow", b);
  } else {
    if (this.dojoSupport) {
      dojo.addOnLoad(c);
    } else {
      if (this.noFramework) {
        if (window.addEventListener) {
          window.addEventListener("load", c, false);
          window.addEventListener("pageshow", b, false);
        } else {
          if (window.attachEvent) {
            window.attachEvent("onload", c);
          } else {
            var f = null;
            if (window.onload) {
              f = window.onload;
            }
            window.onload = function () {
              c();
              if (f != null) {
                f();
              }
            };
          }
        }
      }
    }
  }
}
CSIManager.prototype.initialize = function () {
  if (!this.useDelayedCSI) {
    this.queueAllCalls = true;
    var a = document.createElement("div");
    a.setAttribute("id", "csimanagerdiv");
    document.body.appendChild(a);
    var a = document.createElement("div");
    a.setAttribute("id", "csimanagerdivdelayed");
    document.body.appendChild(a);
    this.useDelayedCSI = true;
    this.queueAllCalls = false;
    this.processAnyQueuedCalls();
    this.queuedCallArray = null;
  }
};
CSIManager.prototype.processAnyQueuedCalls = function () {
  if (this.queuedCallArray && this.queuedCallArray != null) {
    for (var b = 0; b < this.queuedCallArray.length; b++) {
      var a = this.queuedCallArray[b];
      this.queuedCallArray[b] = "";
      if (a) {
        this.call(a.url, a.args, a.domId, a.funcObj, a.breakCache, a.overrideID);
      }
    }
  }
};
CSIManager.__instance__ = null;
CSIManager.getInstance = function () {
  if (this.__instance__ == null) {
    this.__instance__ = new CSIManager();
  }
  return this.__instance__;
};
CSIManager.prototype.addOnLoadById = function (c, b) {
  var a = this.domOnLoad[c];
  if (!a) {
    a = new Array();
  }
  a.push(b);
  this.domOnLoad[c] = a;
};
CSIManager.prototype.addOnBeforeLoadById = function (c, b) {
  var a = this.domOnBeforeLoad[c];
  if (!a) {
    a = new Array();
  }
  a.push(b);
  this.domOnBeforeLoad[c] = a;
};
CSIManager.prototype.setConfigForId = function (b, a) {
  this.domIDConfig[b] = a;
};
CSIManager.prototype.getConfigForId = function (b) {
  var a = this.domIDConfig[b];
  if (!a) {
    a = new Object();
  }
  return a;
};
CSIManager.prototype.registerEventType = function (b, a) {
  if (b && a) {
    this.eventTypes[b] = a;
  }
};
CSIManager.prototype.callObject = function (callObj, eventType) {
  var resultObj;
  var url;
  var args;
  var domId;
  var decoratingFunction;
  var breakCache;
  var overrideID;
  var callEventType = eventType;
  var forcediframe;
  this.currentEventType = eventType;
  if (callObj) {
    resultObj = callObj;
    url = resultObj.url;
    args = resultObj.args;
    domId = resultObj.domId;
    funcObj = resultObj.funcObj;
    breakCache = resultObj.breakCache;
    overrideID = resultObj.overrideID;
    forcediframe = resultObj.isIframeForced;
    if (this.queueAllCalls) {
      var queuedObj = new Object();
      queuedObj.url = url;
      queuedObj.args = args;
      queuedObj.domId = domId;
      queuedObj.funcObj = funcObj;
      queuedObj.breakCache = breakCache;
      queuedObj.overrideId = overrideId;
      this.queuedCallArray.push(queuedObj);
    } else {
      if ((!this.useDelayedCSI) && (document && document.readyState && (document.readyState == "complete"))) {
        this.initialize();
      }
      if (forcediframe === undefined || forcediframe === false) {
        forcediframe = false;
        if (url.indexOf("http") == 0) {
          forcediframe = true;
          if (url.indexOf(window.location.hostname) > -1) {
            forcediframe = false;
          }
        }
      }
      this.numberofRequests++;
      var internalDomId = "csi" + (this.iframeOffset + this.numberofRequests);
      if (overrideID) {
        internalDomId = overrideID;
      }
      var domList = new Array();
      var functionList = new Array();
      if (url.indexOf(document.domain) == -1 && url.indexOf("http") > -1) {
        return false;
      }
      if (domId.join) {
        domList = domId;
      } else {
        domList.push(domId);
      }
      if (funcObj) {
        if (funcObj.join) {
          functionList = funcObj;
        } else {
          functionList.push(funcObj);
        }
      }
      this.CSIObjects[internalDomId] = {
        functionList: functionList,
        dom: domList,
        url: url,
        args: args,
        csiRequestNum: this.numberofRequests,
        disableCache: breakCache
      };
      var newCSI = new Object();
      newCSI.src = url;
      newCSI.id = internalDomId;
      newCSI.domId = domList;
      newCSI.args = args;
      newCSI.breakCache = breakCache;
      newCSI.csiRequestNum = this.numberofRequests;
      this.delayedCSIList[this.delayedCSIList.length] = newCSI;
      var today = new Date();
      var currTime = today.getTime() % 60;
      var iframeArgs = (breakCache) ? "time=" + currTime : "";
      if (args) {
        iframeArgs = (iframeArgs) ? iframeArgs + "&" : "";
        iframeArgs += args;
      }
      if (forcediframe === false) {
        try {
          if (funcObj) {
            var xhrObject = null;
            if (this.dojoSupport) {
              try {
                if (navigator.userAgent.toLowerCase().indexOf("msie 7.0") != -1) {
                  throw new Error("NoDojoSupport");
                }
                var bindArgs = {
                  url: url + "?" + iframeArgs + "&csiID=" + internalDomId,
                  mimetype: "text/html",
                  transport: "IframeTransport"
                };
                xhrObject = dojo.io.bind(bindArgs);
              } catch (err) {
                throw new Error("DojoFailure");
              }
            } else {
              if (this.prototypeSupport) {
                try {
                  if (navigator.userAgent.toLowerCase().indexOf("safari") != -1) {
                    throw new Error("SafariCrossDomainFailure");
                  }
                  var csiMgr = this;
                  xhrObject = new Ajax.Request(url, {
                    method: "get",
                    parameters: iframeArgs + "&csiID=" + internalDomId,
                    onComplete: function (response) {
                      if (response && response.responseText && response.responseText.indexOf('id="jsCode"') != -1) {
                        var startStr = 'id="jsCode"';
                        var startPos = response.responseText.indexOf(startStr) + startStr.length;
                        var firstSlice = response.responseText.slice(startPos, response.responseText.indexOf("</textarea>"));
                        var beginningNode = firstSlice.indexOf(">") + 1;
                        var myCode = firstSlice.substring(beginningNode);
                        var obj = eval("(" + myCode + ")");
                        csiMgr.callBackJS(obj, internalDomId);
                      }
                      if (response && (!response.responseText)) {
                        callObj.isIframeForced = true;
                        CSIManager.getInstance().callObject(callObj, eventType);
                      }
                    },
                    onException: function (x, o) {
                      throw new Error("PrototypeException for url [" + url + "]: " + o.messageText);
                    },
                    onFailure: function (x, o) {
                      throw new Error("PrototypeFailure");
                    }
                  });
                } catch (err) {
                  throw new Error("PrototypeFailure");
                }
              } else {
                throw new Error("NoXHRFramework");
              }
            }
          } else {
            throw new Error("NoCallBackFunction");
          }
        } catch (err) {
          forcediframe = true;
        }
      }
      if (forcediframe) {
        if (this.useDelayedCSI) {
          var realIframeUrl = url + "?" + iframeArgs + "&csiID=" + internalDomId;
          var iframeObj = document.createElement("iframe");
          iframeObj.setAttribute("src", realIframeUrl);
          iframeObj.setAttribute("id", "csiDataIframe" + internalDomId);
          iframeObj.setAttribute("name", "csiDataIframe" + internalDomId);
          iframeObj.setAttribute("width", "10");
          iframeObj.setAttribute("height", "10");
          iframeObj.setAttribute("style", "visibility:hidden;position:absolute;top:0px;left:-100px;");
          iframeObj.style.top = "0px";
          iframeObj.style.left = "-100px";
          iframeObj.style.position = "absolute";
          var containerDiv = document.createElement("div");
          containerDiv.setAttribute("id", "csiIframeObjs" + internalDomId);
          containerDiv.appendChild(iframeObj);
          if (document.getElementById("csimanagerdiv")) {
            document.getElementById("csimanagerdiv").appendChild(containerDiv);
            if (navigator.userAgent.indexOf("MSIE") != -1) {
              window.setTimeout("var tmpIframObj=document.getElementById('csiDataIframe" + internalDomId + "');if(tmpIframObj.readyState=='uninitialized'){tmpIframObj.src=tmpIframObj.getAttribute('src');tmpIframObj.position='absolute';tmpIframObj.style.left='-100px';}", 500);
            }
          }
        } else {
          var iframeHtmlSrc = '<div id="csiIframeObjs' + internalDomId + '"><iframe src="' + url + "?" + iframeArgs + "&csiID=" + internalDomId + '" name="csiDataIframe' + internalDomId + '" id="csiDataIframe' + internalDomId + '" width="10" height="10" style="visibility:hidden;position:absolute;top:0px;left:-100px;"></iframe></div>';
          document.write(iframeHtmlSrc);
        }
      }
    }
  }
};
CSIManager.prototype.call = function (a, g, c, b, h, d, k, e) {
  var f = new Object();
  f.url = a;
  f.args = g;
  f.domId = c;
  f.funcObj = b;
  f.breakCache = h;
  f.overrideID = d;
  f.isIframeForced = e;
  revertToCallObject(f, k);
};
CSIManager.prototype.callBackHtml = function (b, e) {
  var a = false;
  if (document.getElementById) {
    a = document.getElementById(e);
    if (!a) {
      if (this.CSIObjects[e] && this.CSIObjects[e].dom) {
        e = this.CSIObjects[e].dom;
        a = document.getElementById(e);
      }
    }
  } else {
    if (document.all) {
      a = document.all[e];
      if (!a) {
        if (this.CSIObjects[e] && this.CSIObjects[e].dom) {
          e = this.CSIObjects[e].dom;
          a = document.all[e];
        }
      }
    }
  }
  if (a) {
    a.innerHTML = b;
  }
  var c = 0;
  if (c) {
    var d = c.style.top || "0px";
    c.style.top = "1px";
    c.style.top = d;
  }
};
CSIManager.prototype.callBackJS = function (p, n) {
  if (this.CSIObjects[n]) {
    var b = this.CSIObjects[n].functionList;
    var m = this.CSIObjects[n].dom;
    if (b) {
      var q = b.length;
      var c = m.length;
      if (q != c) {
        if (c < q) {
          var l = m[c - 1];
          for (var g = c; g < q; g++) {
            m.push(l);
          }
          c = m.length;
        } else {
          var a = b[q - 1];
          for (var g = q; g < c; g++) {
            b.push(a);
          }
          q = b.length;
        }
      }
      for (var h = 0; h < b.length; h++) {
        var k = b[h];
        if (k) {
          var e = this.getConfigForId(m[h]);
          var o = this.domOnBeforeLoad[m[h]];
          if (o) {
            for (var g = 0; g < o.length; g++) {
              var d = o[g];
              d(p, m[h], e);
            }
          }
          this.callBackHtml(k(p, m[h], e, this.currentEventType), m[h]);
          var f = this.domOnLoad[m[h]];
          if (f) {
            for (var g = 0; g < f.length; g++) {
              var d = f[g];
              d(p, m[h], e);
            }
          }
        }
      }
      this.CSIObjects[n] = "";
    }
  }
};
CSIManager.prototype.delayedProcessing = function () {
  if (document.body && document.body.innerHTML && this.useDelayedCSI) {
    var d = document.getElementById("csimanagerdivdelayed") || document.all["csimanagerdivdelayed"];
    var k = "";
    for (var f = 0; f < this.delayedCSIList.length; f++) {
      var a = this.delayedCSIList[f].src;
      var b = this.delayedCSIList[f].id;
      var h = new Date();
      var g = this.delayedCSIList[f].breakCache;
      var c = h.getTime() % 60;
      var e = (g) ? "&time=" + c : "";
      if (this.delayedCSIList[f].args) {
        e = e + "&" + this.delayedCSIList[f].args;
      }
      k += '<iframe src="' + a + "?csiID=" + b + e + '" name="csiDataIframe' + b + '" id="csiDataIframe' + b + '" width="10" height="10" style="visibility:hidden;position:absolute;top:0px;left:-100px;"></iframe>';
    }
    if (d) {
      d.innerHTML = k;
    }
  }
};
CSIManager.prototype.handleClientData = function (cliWinbj, cliDoc) {
  var targetWindow = top;
  try {
    if (parent.CSIManager) {
      targetWindow = parent;
    }
  } catch (err) {}
  var docId = "";
  var paramStr = cliWinbj.location.hash;
  if (!paramStr) {
    paramStr = cliWinbj.location.search.substring(1);
  }
  var queryId = "";
  var keyValPairs = paramStr.split("&");
  if (!keyValPairs) {
    keyValPairs = new Array();
    keyValPairs[keyValPairs.length] = query;
  }
  for (var counter = 0; counter < keyValPairs.length; counter++) {
    var keyVal = keyValPairs[counter].split("=");
    if (keyVal[0] == "csiID") {
      queryId = keyVal[1];
      counter = keyValPairs.length + 1;
    }
  }
  var wId = "";
  if (cliWinbj.name && (cliWinbj.name.indexOf("csiDataIframe") == 0)) {
    wId = cliWinbj.name.substring(13);
  }
  if (wId == "" && cliWinbj.frameElement && cliWinbj.frameElement.id && (cliWinbj.frameElement.id.indexOf("csiDataIframe") == 0)) {
    wId = cliWinbj.frameElement.id.substring(13);
  }
  docId = wId;
  if (cliDoc.mainForm.htmlArea && cliDoc.mainForm.htmlArea.value) {
    var rawHtml = cliDoc.mainForm.htmlArea.value;
    if (rawHtml) {
      targetWindow.CSIManager.getInstance().callBackHtml(rawHtml, docId);
    }
  } else {
    if (cliDoc.mainForm.jsCode.value) {
      var rawJS = cliDoc.mainForm.jsCode.value;
      if (rawJS) {
        targetWindow.CSIManager.getInstance().callBackJS(eval("(" + rawJS + ")"), docId);
      }
    }
  }
};
CSIManager.prototype.registerEventTypeNode = function (b, a) {
  if (this.eventTypes[a]) {
    this.watchEventTypeNodes[b] = a;
  }
  if (!this.isPolling) {
    this.startPoll();
  }
};
CSIManager.prototype.setPollingUrl = function (b, a) {
  this.pollingUrl = b;
  if (a && a > this.minimumInterval) {
    this.pollingInterval = a;
  }
};
CSIManager.prototype.startPoll = function () {
  if (!this.isPolling && (this.pollingUrl)) {
    this.pollingId = window.setTimeout("CSIManager.getInstance().poll()", this.pollingInterval);
    this.isPolling = true;
  }
};
CSIManager.prototype.poll = function () {
  if (!this.domRefreshHook) {
    var a = document.createElement("iframe");
    this.domRefreshHook = document.body.appendChild(a);
  }
  this.domRefreshHook.setAttribute("src", this.pollingUrl);
};
CSIManager.prototype.handleData = function (d) {
  this.isPolling = false;
  if (d.intervalTime) {
    if (d.intervalTime > this.minimumInterval) {
      this.pollingInterval = d.intervalTime;
    }
  }
  if (d.entries) {
    for (var a = 0; a < d.entries.length; a++) {
      var e = d.entries[a];
      var c = this.watchEventTypeNodes[e];
      if (c) {
        var b = this.eventTypes[c];
        b(c, e);
      }
    }
  }
  this.startPoll();
};
CSIManager.prototype.reset = function () {
  this.eventTypes = new Array();
  this.currentEventType = "";
  this.eventTypeFunctions = new Array();
  this.watchEventTypeNodes = new Array();
};
CSIManager.getInstance();

function revertToCallObject(b, a) {
  CSIManager.getInstance().callObject(b, a);
}

function StorageManager() {
  if (StorageManager.caller != StorageManager.getInstance) {
    if ((navigator.userAgent.indexOf("Safari") == -1) && (navigator.userAgent.indexOf("Opera") == -1)) {
      throw new Error("There is no public constructor for StorageManager.");
    }
  }
  this.ondownloadFunctionArray = new Array();
  this.onloadFunctionArray = new Array();
  this.failedStorageOptions = new Array();
  this.loadComplete = function () {
    var f = true;
    try {
      this.getStorage().put("validationTest", "test");
      var e = this.getStorage().get("validationTest");
      if (e != "test") {
        f = false;
      }
      this.getStorage().remove("validationTest");
    } catch (c) {
      f = false;
    }
    if (f) {
      var d = this.onloadFunctionArray;
      for (var b = 0; b < d.length; b++) {
        var a = d[b];
        a(StorageManager.getInstance().getStorage());
      }
    } else {
      this.reselectStorage();
    }
  };
  this.downloadComplete = function () {
    this.loadComplete();
    var c = this.ondownloadFunctionArray;
    for (var b = 0; b < c.length; b++) {
      var a = c[b];
      a(StorageManager.getInstance().getStorage());
    }
  };
  this.addOnLoad = function (a) {
    this.onloadFunctionArray.push(a);
  };
  this.addOnDownLoad = function (a) {
    this.ondownloadFunctionArray.push(a);
  };
  this.availableStores = new Array();
  this.addStorageType = function (a) {
    this.availableStores.push(a);
  };
  this.currentStorageMechanism = false;
  this.getStorage = function () {
    if (this.currentStorageMechanism) {
      return this.currentStorageMechanism;
    }
    for (var b = 0; b < this.availableStores.length; b++) {
      var a = this.availableStores[b];
      if ((a.isSupported()) && (!this.failedStorageOptions[a.name])) {
        this.currentStorageMechanism = a;
        this.currentStorageMechanism.initialize();
        return this.currentStorageMechanism;
      }
    }
    return false;
  };
  this.reselectStorage = function () {
    this.failedStorageOptions[this.getStorage().name] = 1;
    this.currentStorageMechanism = false;
    this.getStorage();
  };
  this.currentSync = false;
  this.setSyncMechanism = function (a) {
    this.currentSync = a;
  };
  this.download = function () {
    this.getStorage().load();
    if (this.currentSync) {
      if (this.currentSync.hasUpdatedContent(this.currentStorageMechanism)) {
        this.currentSync.getUpdatedContent(this.currentStorageMechanism);
      } else {
        this.downloadComplete();
      }
    }
  };
  this.mergeNewData = function (c) {
    var e = this.getStorage();
    var d = this.currentSync.getBaseManagedKey();
    for (var b = 0; b < c.length; b++) {
      var a = c[b];
      e.put(a.key, a.value);
    }
    e.save();
    this.downloadComplete();
  };
  this.upload = function () {
    if (this.currentSync) {
      var g = this.getStorage();
      if (g) {
        var f = g.getAllKeys();
        var b = new Array();
        var d = this.currentSync.getBaseManagedKey();
        for (var a = 0; a < f.length; a++) {
          var e = f[a].indexOf(d);
          if (e == 0) {
            var c = new Object();
            c.key = f[a].substring(e);
            c.value = g.get(f[a]);
            b.push(c);
          }
        }
        this.currentSync.send(b);
      }
    }
  };
}
StorageManager.__instance__ = null;
StorageManager.getInstance = function () {
  if (this.__instance__ == null) {
    this.__instance__ = new StorageManager();
  }
  return this.__instance__;
};

function AbstractStorageMechanism() {
  this.name = "AbstractStorage";
  this.dataObjects;
  this.keysExpireDates;
  this.maxCapacity = Number.MAX_VALUE;
  this.singleEntrymaxCapacity = Number.MAX_VALUE;
  this.allKeys;
  this.isSupported = function () {
    return false;
  };
  this.initialize = function () {
    this.dataObjects = new Array();
    this.allKeys = new Array();
    this.keysExpireDates = new Array();
  };
  this.setOnload = function (a) {
    StorageManager.getInstance().addOnLoad(a);
  };
  this.put = function (b, d, a) {
    try {
      if (this.dataObjects[b] === undefined || this.dataObjects[b] === false) {
        if (!a) {
          a = new Date(new Date().getTime() + 7 * 24 * 3600000);
        }
        this.keysExpireDates[b] = a;
        this.allKeys.push(b);
      }
      this.dataObjects[b] = d;
      return true;
    } catch (c) {
      return false;
    }
  };
  this.get = function (a) {
    return this.dataObjects[a];
  };
  this.remove = function (c) {
    if (this.contains(c)) {
      var a = new Array();
      for (var b = 0; b < this.allKeys.length; b++) {
        if (this.allKeys[b] != c) {
          a.push(this.allKeys[b]);
        }
      }
      this.allKeys = a;
      this.dataObjects[c] = false;
    }
  };
  this.contains = function (a) {
    if (this.dataObjects[a]) {
      return true;
    } else {
      return false;
    }
  };
  this.getAllKeys = function (a) {
    return this.allKeys;
  };
  this.save = function () {};
  this.load = function () {
    StorageManager.getInstance().loadComplete();
  };
  this.clear = function () {};
}

function CookieStorageMechanism() {
  this.name = "CookieStorage";
  this.maxCapacity = 20480;
  this.path = "/";
  this.domain = "";
  this.secure = false;
  this.createCookie = function (key, value, expiration) {
    document.cookie = key + "=" + value + ((expiration) ? (";expires=" + expiration) : "") + ((this.path) ? ";path=" + this.path : "") + ((this.domain) ? ";domain=" + this.domain : "") + ((this.secure && (this.secure == true)) ? "; secure" : "");
  };
  this.isSupported = function () {
    return (document.cookie || document.cookie == "");
  };
  this.save = function () {
    this.clear();
    var allKeys = this.getAllKeys();
    var lengthCount = 0;
    for (var i = 0; i < allKeys.length; i++) {
      var currentKey = allKeys[i];
      var value = this.get(currentKey);
      var newObject = new Object();
      newObject.value = value;
      newObject.expireDate = (this.keysExpireDates[currentKey]).getTime();
      dataString = escape(JSON.stringify(newObject));
      if ((lengthCount + dataString.length) > this.maxCapacity) {
        return false;
      } else {
        lengthCount += dataString.length;
        this.createCookie("js_" + currentKey, dataString, (this.keysExpireDates[currentKey]).toGMTString());
      }
    }
    return true;
  };
  this.load = function () {
    if (document.cookie != "") {
      var cookieArr = document.cookie.split("; ");
      for (var i = 0; i < cookieArr.length; i++) {
        var key = cookieArr[i].substring(0, cookieArr[i].indexOf("="));
        if (key.indexOf("js_") == 0) {
          storedObject = eval("(" + (unescape(cookieArr[i].substring(cookieArr[i].indexOf("=") + 1))) + ")");
          key = key.substring(3);
          this.put(key, storedObject.value, new Date(storedObject.expireDate));
        }
      }
    }
    StorageManager.getInstance().loadComplete();
  };
  this.clear = function () {
    if (document.cookie != "") {
      var cookieArr = document.cookie.split("; ");
      for (var i = 0; i < cookieArr.length; i++) {
        var key = cookieArr[i].substring(0, cookieArr[i].indexOf("="));
        if (key.indexOf("js_") == 0) {
          toExpireDateString = (new Date((new Date()).getTime() - (24 * 60 * 60 * 60 * 1000))).toGMTString();
          this.createCookie(key, "clear this", toExpireDateString);
        }
      }
    }
  };
}

function DOMStorageMechanism() {
  this.name = "DOMStorage";
  this.maxCapacity = 3145728;
  this.isSupported = function () {
    return (window.globalStorage && (window.globalStorage != null));
  };
  this.save = function () {
    var allKeys = this.getAllKeys();
    var storedObject = new Array();
    for (var i = 0; i < allKeys.length; i++) {
      var currentKey = allKeys[i];
      var value = this.get(currentKey);
      var newObject = new Object();
      newObject.key = currentKey;
      newObject.value = value;
      newObject.expireDate = (this.keysExpireDates[currentKey]).toGMTString();
      storedObject.push(newObject);
    }
    dataString = JSON.stringify(storedObject);
    if (dataString.length > this.maxCapacity) {
      return false;
    } else {
      window.globalStorage[document.domain].storage = dataString;
    }
    return true;
  };
  this.load = function () {
    var storedDataObjectsStr = window.globalStorage[document.domain].storage + "";
    if (storedDataObjectsStr) {
      storedDataObjects = eval("(" + storedDataObjectsStr + ")");
      if (storedDataObjects && storedDataObjects != "") {
        for (var i = 0; i < storedDataObjects.length; i++) {
          var storedObject = storedDataObjects[i];
          if ((new Date(storedObject.expireDate)).getTime() > (new Date().getTime())) {
            this.put(storedObject.key, storedObject.value, new Date(storedObject.expireDate));
          }
        }
      }
    }
    StorageManager.getInstance().loadComplete();
  };
  this.clear = function () {
    window.globalStorage[document.domain].storage = JSON.stringify(new Object());
  };
}

function LocalStorageMechanism() {
  this.name = "localStorage";
  this.maxCapacity = 5000000;
  this.key = "undefined";
  this.isSupported = function () {
    return (window.localStorage && (window.localStorage != null));
  };
  this.save = function () {
    var allKeys = this.getAllKeys();
    var currentSize = 0;
    for (var i = 0; i < allKeys.length; i++) {
      var currentKey = allKeys[i];
      var value = this.get(currentKey);
      var newObject = new Object();
      newObject.key = currentKey;
      newObject.value = value;
      newObject.expireDate = (this.keysExpireDates[currentKey]).toGMTString();
      dataString = JSON.stringify(newObject);
      currentSize += dataString.length;
      if (currentSize > this.maxCapacity) {
        return false;
      } else {
        window.localStorage.setItem(currentKey, dataString);
      }
    }
    return true;
  };
  this.load = function () {
    if (window.localStorage) {
      var localStorage = window.localStorage;
      for (j = 0; j <= localStorage.length - 1; j++) {
        var key = localStorage.key(j);
        var storedDataString = localStorage.getItem(key);
        var storedDataObject;
        try {
          storedDataObject = eval("(" + storedDataString + ")");
        } catch (e) {}
        if (storedDataObject && storedDataObject != "") {
          if ((new Date(storedDataObject.expireDate)).getTime() > (new Date().getTime())) {
            this.put(storedDataObject.key, storedDataObject.value, new Date(storedDataObject.expireDate));
          }
        }
      }
    }
    StorageManager.getInstance().loadComplete();
  };
  this.clear = function () {
    window.localStorage.clear();
  };
}

function IEStorageMechanism() {
  this.name = "IEStorage";
  this.maxCapacity = 65536;
  this.isSupported = function () {
    return (navigator.userAgent.indexOf("MSIE") != -1);
  };
  this.initialize = function () {
    this.dataObjects = new Array();
    this.allKeys = new Array();
    this.keysExpireDates = new Array();
    this.dataHook = false;
    var a = document.createElement("iframe");
    a.setAttribute("src", "/.element/js/3.0/scripts/IEPersistence.html");
    a.setAttribute("name", "IEPersistence");
    a.setAttribute("width", "10");
    a.setAttribute("height", "10");
    a.setAttribute("style", "visibility:hidden;position:absolute;top:0px;left:-100px;");
    a.style.top = "0px";
    a.style.left = "-100px";
    a.style.position = "absolute";
    document.documentElement.appendChild(a);
  };
  this.load = function () {};
  this.save = function () {
    var c = this.getAllKeys();
    var e = new Array();
    for (var b = 0; b < c.length; b++) {
      var f = c[b];
      var d = this.get(f);
      var a = new Object();
      a.key = f;
      a.value = d;
      a.expireDate = (this.keysExpireDates[f]).toGMTString();
      e.push(a);
    }
    dataString = JSON.stringify(e);
    if (dataString.length > this.maxCapacity) {
      return false;
    } else {
      if (this.dataHook && this.dataHook.saveData) {
        this.dataHook.saveData(JSON.stringify(e));
      }
    }
    return true;
  };
  this.clear = function () {
    this.dataHook.saveData("");
  };
}
CookieStorageMechanism.prototype = new AbstractStorageMechanism;
DOMStorageMechanism.prototype = new AbstractStorageMechanism;
LocalStorageMechanism.prototype = new AbstractStorageMechanism;
IEStorageMechanism.prototype = new AbstractStorageMechanism;
StorageManager.getInstance().addStorageType(new LocalStorageMechanism());
StorageManager.getInstance().addStorageType(new DOMStorageMechanism());
StorageManager.getInstance().addStorageType(new IEStorageMechanism());
StorageManager.getInstance().addStorageType(new CookieStorageMechanism());
Array.prototype.______array = "______array";
var JSON = {
  org: "http://www.JSON.org",
  copyright: "(c)2005 JSON.org",
  license: "http://www.crockford.com/JSON/license.html",
  stringify: function (a, g) {
    var h, e, b, f = "",
      d;
    switch (typeof a) {
      case "object":
        if (a) {
          if (a.______array == "______array") {
            for (e = 0; e < a.length; ++e) {
              d = this.stringify(a[e]);
              if (f) {
                f += ",";
              }
              f += d;
            }
            return "[" + f + "]";
          } else {
            if (typeof a.toString != "undefined") {
              for (e in a) {
                d = a[e];
                if (typeof d != "undefined" && typeof d != "function") {
                  d = this.stringify(d);
                  if (f) {
                    f += ",";
                  }
                  f += this.stringify(e, true) + ":" + d;
                }
              }
              return "{" + f + "}";
            }
          }
        }
        return "null";
      case "number":
        return isFinite(a) ? String(a) : "null";
      case "string":
        b = a.length;
        if (!g) {
          f = '"';
        }
        for (e = 0; e < b; e += 1) {
          h = a.charAt(e);
          if (h >= " ") {
            if (h == "\\" || h == '"') {
              f += "\\";
            }
            f += h;
          } else {
            switch (h) {
              case "\b":
                f += "\\b";
                break;
              case "\f":
                f += "\\f";
                break;
              case "\n":
                f += "\\n";
                break;
              case "\r":
                f += "\\r";
                break;
              case "\t":
                f += "\\t";
                break;
              default:
                h = h.charCodeAt();
                f += "\\u00" + Math.floor(h / 16).toString(16) + (h % 16).toString(16);
            }
          }
        }
        if (!g) {
          return f + '"';
        } else {
          return f;
        }
      case "boolean":
        return String(a);
      default:
        return "null";
    }
  },
  parse: function (n) {
    var d = 0;
    var a = " ";

    function m(o) {
      throw {
        name: "JSONError",
        message: o,
        at: d - 1,
        text: n
      };
    }

    function g() {
      a = n.charAt(d);
      d += 1;
      return a;
    }

    function k() {
      while (a != "" && a <= " ") {
        g();
      }
    }

    function l() {
      var q, r = "",
        p, o;
      if (a == '"') {
        outer: while (g()) {
          if (a == '"') {
            g();
            return r;
          } else {
            if (a == "\\") {
              switch (g()) {
                case "b":
                  r += "\b";
                  break;
                case "f":
                  r += "\f";
                  break;
                case "n":
                  r += "\n";
                  break;
                case "r":
                  r += "\r";
                  break;
                case "t":
                  r += "\t";
                  break;
                case "u":
                  o = 0;
                  for (q = 0; q < 4; q += 1) {
                    p = parseInt(g(), 16);
                    if (!isFinite(p)) {
                      break outer;
                    }
                    o = o * 16 + p;
                  }
                  r += String.fromCharCode(o);
                  break;
                default:
                  r += a;
              }
            } else {
              r += a;
            }
          }
        }
      }
      m("Bad string");
    }

    function h() {
      var o = [];
      if (a == "[") {
        g();
        k();
        if (a == "]") {
          g();
          return o;
        }
        while (a) {
          o.push(c());
          k();
          if (a == "]") {
            g();
            return o;
          } else {
            if (a != ",") {
              break;
            }
          }
          g();
          k();
        }
      }
      m("Bad array");
    }

    function e() {
      var p, q = {};
      if (a == "{") {
        g();
        k();
        if (a == "}") {
          g();
          return q;
        }
        while (a) {
          p = l();
          k();
          if (a != ":") {
            break;
          }
          g();
          q[p] = c();
          k();
          if (a == "}") {
            g();
            return q;
          } else {
            if (a != ",") {
              break;
            }
          }
          g();
          k();
        }
      }
      m("Bad object");
    }

    function f() {
      var p = "",
        o;
      if (a == "-") {
        p = "-";
        g();
      }
      while (a >= "0" && a <= "9") {
        p += a;
        g();
      }
      if (a == ".") {
        p += ".";
        while (g() && a >= "0" && a <= "9") {
          p += a;
        }
      }
      if (a == "e" || a == "E") {
        p += "e";
        g();
        if (a == "-" || a == "+") {
          p += a;
          g();
        }
        while (a >= "0" && a <= "9") {
          p += a;
          g();
        }
      }
      o = +p;
      if (!isFinite(o)) {
        m("Bad number");
      } else {
        return o;
      }
    }

    function b() {
      switch (a) {
        case "t":
          if (g() == "r" && g() == "u" && g() == "e") {
            g();
            return true;
          }
          break;
        case "f":
          if (g() == "a" && g() == "l" && g() == "s" && g() == "e") {
            g();
            return false;
          }
          break;
        case "n":
          if (g() == "u" && g() == "l" && g() == "l") {
            g();
            return null;
          }
          break;
      }
      m("Syntax error");
    }

    function c() {
      k();
      switch (a) {
        case "{":
          return e();
        case "[":
          return h();
        case '"':
          return l();
        case "-":
          return f();
        default:
          return a >= "0" && a <= "9" ? f() : b();
      }
    }
    return c();
  }
};
var is_loadedOvly = 0;

function ms_QueueManager() {
  var queue = [];
  var queueCurrentItem = null;
  var iframeDivId = "";
  var iframeId = "";
  var iframeBlankUrl = "";
  var isIframeReady = false;
  var isQueueRunning = false;
  var requestMade = false;
  var waitingForResponse = false;
  var blankIframeTimer = null;
  var requestTimer = null;
  var queuePosition = -1;
  var iframeTimeoutCounter = 0;
  var requestTimeoutCounter = 0;
  var TIMEOUT = 50;
  var REQUEST_TIMEOUT = 10;
  this.init = function (divId, blankUrl) {
    document.write('<div id="' + divId + '" style="position:absolute; bottom:0; left: -700px;"></div>');
    iframeDivId = divId;
    iframeId = divId + "_iframe";
    iframeBlankUrl = blankUrl;
    REQUEST_TIMEOUT = REQUEST_TIMEOUT * 1000;
  };
  this.addRequest = function (queueItem) {
    queue[queue.length] = queueItem;
    if (isQueueRunning == false) {
      isQueueRunning = true;
      processQueue();
    }
  };
  this.requestReceived = function () {
    waitingForResponse = false;
    clearWaitForRequest();
    destroyIframe();
    processQueue();
  };
  var processQueue = function () {
    queuePosition++;
    if (queuePosition >= queue.length) {
      resetQueue();
    } else {
      queueCurrentItem = queue[queuePosition];
      createIframe();
    }
  };
  var createIframe = function () {
    isIframeReady = false;
    var thebody = document.getElementsByTagName("body")[0];
    var tempIFrame = document.createElement("iframe");
    tempIFrame.setAttribute("id", iframeId);
    tempIFrame.setAttribute("name", iframeId);
    tempIFrame.style.position = "absolute";
    tempIFrame.style.bottom = "0";
    tempIFrame.style.left = "-600px";
    thebody.appendChild(tempIFrame);
    if (location.pathname.indexOf("profile") > -1) {
      frames[iframeId].location.replace(iframeBlankUrl);
    }
    waitForRequest("iframe");
  };
  var destroyIframe = function () {
    if (location.pathname.indexOf("profile") > -1) {
      $(iframeDivId).innerHTML = "";
    }
    x = window.frames[iframeId];
  };
  var resetQueue = function () {
    isQueueRunning = false;
    destroyIframe();
    queue = [];
    queuePosition = -1;
    queueItem = null;
  };
  var doGet = function () {
    waitingForResponse = true;
    var url = makeQueryString(queueCurrentItem);
    frames[iframeId].location.replace(url);
    waitForRequest("get");
  };
  var doPost = function () {
    var html = drawForm(queueCurrentItem, "msHiddenIframeForm");
    var iframeWin = getIframeWindow();
    waitingForResponse = true;
    iframeWin.document.body.innerHTML = html;
    iframeWin.document.getElementById("msHiddenIframeForm").submit();
    waitForRequest("post");
  };
  var waitForRequest = function (type) {
    switch (type) {
      case "post":
        if (waitingForResponse == false) {
          clearWaitForRequest();
          processQueue();
          return;
        }
        break;
      case "get":
        if (waitingForResponse == false) {
          clearWaitForRequest();
          processQueue();
          return;
        }
        break;
      case "blankForPost":
        if (isIframeReady == true) {
          clearWaitForRequest();
          doPost();
          return;
        }
        break;
      case "iframe":
        if (isIframeReady == true) {
          clearWaitForRequest();
          if (queueCurrentItem.method == "post") {
            doPost();
          } else {
            doGet();
          }
          return;
        }
        break;
    }
    if ((requestTimeoutCounter * TIMEOUT) >= REQUEST_TIMEOUT) {
      clearWaitForRequest();
      requestFailed(type);
      return;
    } else {
      requestTimeoutCounter++;
      requestTimer = setTimeout(function timeoutWaitForRequest() {
        waitForRequest(type);
      }, TIMEOUT);
    }
  };
  var clearWaitForRequest = function () {
    clearTimeout(requestTimer);
    requestTimeoutCounter = 0;
  };
  var requestFailed = function (type) {
    destroyIframe();
    var response = {};
    response["errors"] = ["request timed out"];
    eval(queueCurrentItem.params.callback + "(response);");
    processQueue();
  };
  var makeQueryString = function (queueItem) {
    var queryString = "";
    queryString += queueItem.url;
    if (queueItem.params.len > 0) {
      queryString += "?";
      var i = 0;
      for (key in queueItem.params) {
        if (key != "len") {
          queryString += key + "=" + escapeParam(queueItem.params[key]);
          if (i < (queueItem.params.len - 1)) {
            queryString += "&";
          }
        }
        i++;
      }
    }
    return queryString;
  };
  var escapeParam = function (param) {
    return escape(param).replace(/\+/g, "%2b");
  };
  var drawForm = function (queueItem, formId) {
    var html = "";
    for (key in queueItem.params) {
      html += '<input type="hidden" name="' + key + '" value="' + queueItem.params[key] + '"/>';
    }
    html = '<form id="' + formId + '" method="' + queueItem.method + '" action="' + queueItem.url + '">' + html + "</form>";
    return html;
  };
  var getIframeWindow = function () {
    var r = $(iframeId).contentWindow || $(iframeId).contentDocument;
    return r;
  };
  this.setIframeReady = function () {
    isIframeReady = true;
  };
}

function ms_QueueItem(a, c) {
  var b = a;
  var e = c;
  var d = {};
  this.addParam = function (f, g) {
    d[f] = g;
  };
  this.getQueueItem = function () {
    var f = 0;
    for (key in d) {
      f++;
    }
    d["len"] = f;
    return {
      "url": b,
      "method": e,
      "params": d
    };
  };
}
var ms_documentDomain = "cnn.com";
var ms_baseStandard = "http://audience.cnn.com/services/cnn/";
var ms_baseSecure = "http://audience.cnn.com/services/cnn/";
var ms_echoURL = "http://audience.cnn.com/services/cnn/echo.api";
var ms_blankURL = "http://audience.cnn.com/services/cnn/blank.api?callback=msQueueManager.setIframeReady";
var msIframeDiv = "cnnConnectMsIframe";
var msQueueManager = null;
var msStorage = {};
document.domain = ms_documentDomain;
msQueueManager = new ms_QueueManager();

function ms_isLoggedIn() {
  var a = allCookies["authid"] || null;
  if (a == null) {
    return false;
  } else {
    return true;
  }
}

function ms_isNull(a) {
  return (a != "undefined" && a != null) ? false : true;
}

function ms_getEmails(a) {
  var c = new ms_QueueItem(ms_baseStandard + "user.api", "get");
  c.addParam("action", "getEmails");
  c.addParam("callback", a);
  var b = c.getQueueItem();
  msQueueManager.addRequest(b);
}

function ms_uiGetEmails(d) {
  msQueueManager.requestReceived();
  var c = (typeof d.errors == "undefined") ? false : true;
  if (c == false) {
    msStorage.emails = d.emails;
    var b = true;
    for (var f = 0; f < d.emails.length; f++) {
      if (d.emails[f].isPrimary == "true" && d.emails[f].status != "confirmed") {
        b = false;
      }
    }
    if (b == false) {
      var e = $("cnnConnectWelcomeNotConfirmed");
      var a = $("cnnConnectBreakNewsEmails");
      if (e && a) {
        $("cnnConnectWelcomeNotConfirmed").style.display = "block";
        $("cnnConnectBreakNewsEmails").style.display = "none";
      }
    }
  } else {}
}
window.msReload = function () {
  if (window.location.href.indexOf("?") > -1) {
    window.location.href = window.location.href.substr(0, window.location.href.indexOf("?"));
  } else {
    window.location.href = window.location.href;
  }
};

function utilSelectOption(c, b) {
  for (var a = 0; a < c.options.length; a++) {
    if (c.options[a].value == b) {
      c.selectedIndex = a;
      return;
    }
  }
}

function utilGetSelectValue(a) {
  return a.options[a.selectedIndex].value;
}

function validateEmail(b) {
  var a = /^([a-zA-Z0-9_\.\'\-\+])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/;
  return a.test(b);
}

function ms_init() {
  ms_getEmails("ms_uiGetEmails");
}

function ms_initProfile() {
  if (ms_isLoggedIn() == true) {} else {}
}
Event.observe(window, "load", function () {
  ms_init();
});
String.prototype.trim = function () {
  return this.replace(/^\s+|\s+$/g, "");
};

function ms_initOverlay() {
  checkUrlForParams();
  generateCaptchaImage();
  if (ms_isLoggedIn() == true) {} else {}
}

function cnn_formConnectLogin(f) {
  var d = $(f).email.value;
  var c = $(f).password.value;
  var g = $(f).rememberme.checked;
  var e = true;
  var a = "Registration isn't complete without your ";
  var b = [];
  if (validateEmail(d) == false) {
    e = false;
    b[b.length] = "e-mail address";
    $("psigninp2_email").addClassName("redtexterror");
    $(f).email.className = "redinput_error";
  }
  if (c == "") {
    e = false;
    $("psigninp2_password").addClassName("redtexterror");
    b[b.length] = "password";
    $(f).password.className = "redinput_error";
  }
  if (e) {
    ms_doLogin(d, c, g, "ms_uiDoLogin");
  } else {
    cnnConnectOverlayLoginValidationError("clear");
    if (b.length == 2) {
      cnnConnectOverlayLoginValidationError("add", "We need your " + b[0] + " and " + b[1] + " to log in.");
    } else {
      if (b[0] == "e-mail address" && validateEmail(d) == false && d != "") {
        cnnConnectOverlayLoginValidationError("add", "You entered an invalid e-mail address.");
      } else {
        if (b[0] == "e-mail address" && d == "") {
          cnnConnectOverlayLoginValidationError("add", "We need your " + b[0] + " to log in.");
        } else {
          cnnConnectOverlayLoginValidationError("add", "We need your " + b[0] + " to log in.");
        }
      }
    }
    cnnConnectOverlayLoginValidationError("show");
  }
}
var cnn_screenname = "";

function ms_formEnterScreenname(b) {
  cnn_screenname = $("cnnscreenname").value;
  var c = /^\w+$/;
  var a = true;
  $("cnnConnectScreennameErrors").innerHTML = "";
  if (cnn_screenname == "") {
    a = false;
    $("cnnConnectScreennameErrors").innerHTML = "You need to enter a screen name.";
    $("cnnscreenname").addClassName("redinput_error");
    $("cnnConnectScreennameErrors").addClassName("redtexterror");
    $("screenname_label").addClassName("redtexterror");
    return;
  } else {
    if (cnn_screenname.length < 3) {
      a = false;
      $("cnnConnectScreennameErrors").innerHTML = "The screen name that you entered is too short.";
      $("cnnscreenname").addClassName("redinput_error");
      $("cnnConnectScreennameErrors").addClassName("redtexterror");
      $("screenname_label").addClassName("redtexterror");
      return;
    } else {
      if (cnn_screenname.length > 12) {
        a = false;
        $("cnnConnectScreennameErrors").innerHTML = "Your screen name must be 3-12 characters; numbers and letters only.";
        $("cnnscreenname").addClassName("redinput_error");
        $("cnnConnectScreennameErrors").addClassName("redtexterror");
        $("screenname_label").addClassName("redtexterror");
        return;
      } else {
        if (c.test(cnn_screenname) == false) {
          a = false;
          $("cnnConnectScreennameErrors").innerHTML = "Your screen name includes invalid characters";
          $("cnnscreenname").addClassName("redinput_error");
          $("cnnConnectScreennameErrors").addClassName("redtexterror");
          $("screenname_label").addClassName("redtexterror");
          return;
        } else {
          $("cnnscreenname").removeClassName("redinput_error");
          $("cnnConnectScreennameErrors").removeClassName("redtexterror");
          $("screenname_label").removeClassName("redtexterror");
        }
      }
    }
  }
  if (a == true) {
    ms_getProfile("ms_addScreenName");
  } else {}
}

function ms_addScreenName(d) {
  msQueueManager.requestReceived();
  var c = (typeof d.errors == "undefined") ? false : true;
  var b = (typeof d.warnings == "undefined") ? false : true;
  if (c == false && b == false) {
    var f = d.profile;
    f["screenName"] = cnn_screenname;
    var a = f["monthOfBirth"];
    var e = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
    f["monthOfBirth"] = e.indexOf(a) + 1;
    ms_updateProfile(f, "ms_uiAddScreenName");
  } else {
    $("cnnConnectScreennameErrors").innerHTML = "There was an error registering your screen name.  Please try again.";
    $("cnnscreenname").addClassName("redinput_error");
    $("cnnConnectScreennameErrors").addClassName("redtexterror");
    $("screenname_label").addClassName("redtexterror");
  }
}

function ms_uiAddScreenName(c) {
  msQueueManager.requestReceived();
  var b = (typeof c.errors == "undefined") ? false : true;
  var a = (typeof c.warnings == "undefined") ? false : true;
  if (b == false && a == false) {
    ms_doGetUser("ms_uiDoGetUser");
  } else {
    $("cnnConnectScreennameErrors").innerHTML = "There was an error registering your screen name.  Please try again.";
    $("cnnscreenname").addClassName("redinput_error");
    $("cnnConnectScreennameErrors").addClassName("redtexterror");
    $("screenname_label").addClassName("redtexterror");
  }
}

function ms_getProfile(a) {
  var c = new ms_QueueItem(ms_baseStandard + "user.api", "get");
  c.addParam("action", "getProfile");
  c.addParam("callback", a);
  var b = c.getQueueItem();
  msQueueManager.addRequest(b);
}

function ms_updateProfile(c, a) {
  var d = new ms_QueueItem(ms_baseStandard + "user.api", "post");
  d.addParam("action", "updateProfile");
  for (key in c) {
    d.addParam(key, c[key]);
  }
  d.addParam("callback", a);
  var b = d.getQueueItem();
  msQueueManager.addRequest(b);
}

function ms_doGetUser(a) {
  var c = new ms_QueueItem(ms_baseStandard + "user.api", "get");
  c.addParam("action", "getUser");
  c.addParam("echourl", ms_echoURL);
  c.addParam("callback", a);
  var b = c.getQueueItem();
  msQueueManager.addRequest(b);
}

function ms_uiDoGetUser(b) {
  msQueueManager.requestReceived();
  var a = (typeof b.warnings == "undefined") ? false : true;
  var c = (typeof b.user.screenName == null) ? false : true;
  if (a == false && c == true) {
    CNN_setCookie("displayname", b.user.screenName, 854400, "/", document.domain);
    closeOverlay("profile_enter_screenname");
    window.msReload();
  } else {
    $("cnnConnectScreennameErrors").innerHTML = "There was an error registering your screen name.  Please try again.";
    $("cnnConnectFormScreenname").screenname.addClassName("redinput_error");
    $("cnnConnectScreennameErrors").addClassName("redtexterror");
    $("screenname_label").addClassName("redtexterror");
  }
}

function clearInputErrors() {
  $("cnnOverlayEmail1l").removeClassName("redinput_error");
  $("cnnOverlayEmail1l").value = "";
  $("cnnOverlayPwd").removeClassName("redinput_error");
  $("cnnOverlayPwd").value = "";
  $("psigninp2_email").removeClassName("redtexterror");
  $("psigninp2_password").removeClassName("redtexterror");
  $("cnnConnectLoginErrors").update("");
  $("cnnConnectLoginErrors").hide();
}
var newuser = false;

function ms_formRegister(l) {
  newuser = true;
  var f = $(l).email.value.trim();
  var m = $(l).password.value;
  var h = $(l).screenName.value.trim();
  var c = $(l).facebookID.value;
  $(l).screenName.value = h;
  var g = $(l).captcha.value;
  var b = "domestic_version";
  var o = "";
  if ($(l).specialOffers.checked == true) {
    o = "member_services";
  }
  var k = true;
  var e = "A required field is missing! Registration isn't complete without your ";
  var n = [];
  if (f == "" || validateEmail(f) == false) {
    k = false;
    n[n.length] = "e-mail address";
    cnnConnectOverlayRegisterError("email");
  } else {
    $("cnnConnectFormRegister").email.className = "cnnConnectFormbg1 cnn_connectoverlay_email2";
    $("signup_email").previous("p").removeClassName("redtexterror");
  }
  if (m == "") {
    k = false;
    n[n.length] = "password";
    cnnConnectOverlayRegisterError("password");
  } else {
    if (m.length < 6 || m.indexOf(" ") != -1 || m.length > 10) {
      k = false;
      cnnConnectOverlayRegisterError("password");
      cnnConnectOverlayError("errorText", "You entered an invalid password.");
      return;
    } else {
      $("cnnConnectFormRegister").password.className = "cnnConnectFormbg2 cnn_connectoverlay_password2";
      $("signup_password").previous("p").removeClassName("redtexterror");
    }
  }
  var a = /^\w+$/;
  if (h == "") {
    k = false;
    n[n.length] = "screen name";
    cnnConnectOverlayRegisterError("screenName");
  } else {
    if (h.length < 3) {
      k = false;
      cnnConnectOverlayRegisterError("screenName");
      cnnConnectOverlayError("errorText", "The screen name that you entered is too short.");
      return;
    } else {
      if (h.length > 12) {
        k = false;
        cnnConnectOverlayRegisterError("screenName");
        cnnConnectOverlayError("errorText", "Your screen name must be 3-12 characters; numbers and letters only.");
        return;
      } else {
        if (a.test(h) == false) {
          k = false;
          cnnConnectOverlayRegisterError("screenName");
          cnnConnectOverlayError("errorText", "Your screen name includes invalid characters.");
          return;
        } else {
          $("cnnConnectFormRegister").screenName.className = "cnnConnectFormbg3 cnn_connectoverlay_screenname";
          $("signup_screenname").previous("p").removeClassName("redtexterror");
        }
      }
    }
  }
  if (g == "") {
    k = false;
    generateCaptchaImage();
    n[n.length] = "security word";
    cnnConnectOverlayRegisterError("captcha");
    cnnConnectOverlayError("errorText", "You must enter a security word.");
  } else {
    $("cnnConnectFormRegister").captcha.className = "cnnConnectFormbg4 cnn_connectoverlay_enterit";
    $("signup_kaptcha_p1").removeClassName("redtexterror");
  }
  if (k == true) {
    ms_doRegister(f, m, h, g, b, o, c, "ms_uiDoRegister");
  } else {
    switch (n.length) {
      case 1:
        if (n[0] == "e-mail address" && validateEmail(f) == false && f != "") {
          e = "You entered an invalid e-mail address.";
        } else {
          if (n[0] == "e-mail address" && f == "") {
            e += n[0];
          } else {
            e += n[0];
          }
        }
        break;
      case 2:
        e += n[0] + " and " + n[1];
        break;
      default:
        for (var d = 0; d < n.length; d++) {
          e += (d == (n.length - 1)) ? "and " + n[d] + "." : n[d] + ", ";
        }
        break;
    }
    cnnConnectOverlayError("errorText", e);
  }
}

function ms_formResetUserPassword(b) {
  var a = $(b).email.value;
  if (validateEmail(a) == false) {
    cnnConnectOverlayForgotValidationError("clear");
    cnnConnectOverlayForgotValidationError("add", "You must enter your e-mail address to reset your password.");
    cnnConnectOverlayForgotValidationError("show");
  } else {
    ms_resetUserPassword(a, "ms_uiResetUserPassword");
  }
}

function ms_formSetUserPassword(f) {
  var d = $(f).email.value;
  var e = $(f).resetCode.value;
  var h = $(f).newPassword.value;
  var a = h;
  var g = true;
  var c = "Reset Password isn't complete without your ";
  var k = [];
  if (validateEmail(d) == false || d == "Email Address") {
    g = false;
    k[k.length] = "e-mail address";
    cnnConnectOverlayResetError("email");
  } else {
    $("new_password_email").previous("p").removeClassName("redtexterror");
    $("cnnConnectFormReset").email.className = "cnn_connectoverlay_email3 cnnredtxt";
  }
  if (e == "" || e == "Reset Code") {
    g = false;
    k[k.length] = "reset code";
    cnnConnectOverlayResetError("resetCode");
  } else {
    $("reset_code").previous("p").removeClassName("redtexterror");
    $("cnnConnectFormReset").resetCode.className = "cnn_connectoverlay_password3 cnnredtxt";
  }
  if (h == "" || h == "New Password") {
    g = false;
    k[k.length] = "new password";
    cnnConnectOverlayResetError("newPassword");
  } else {
    $("new_password").previous("p").removeClassName("redtexterror");
    $("cnnConnectFormReset").newPassword.className = "cnn_connectoverlay_password4 cnnredtxt";
  }
  if (g == true) {
    ms_setUserPassword(e, d, h, a, "ms_uiSetUserPassword");
  } else {
    cnnConnectOverlayResetValidationError("clear");
    switch (k.length) {
      case 1:
        c += k[0] + ".";
        break;
      case 2:
        c += k[0] + " and " + k[1] + ".";
        break;
      default:
        for (var b = 0; b < k.length; b++) {
          c += (b == (k.length - 1)) ? "and " + k[b] + "." : k[b] + ", ";
        }
        break;
    }
    cnnConnectOverlayResetValidationError("add", c);
    cnnConnectOverlayResetValidationError("show");
  }
}

function ms_doLogout() {
  CNN_removeCookie("the_forum", "/", "cnn.com");
  CNN_removeCookie("authid", "/", "cnn.com");
  CNN_removeCookie("authpass", "/", "cnn.com");
  CNN_removeCookie("displayname", "/", "cnn.com");
  CNN_removeCookie("firstName", "/", "cnn.com");
  var b = new ms_QueueItem(ms_baseStandard + "logout.api", "post");
  b.addParam("callback", "ms_uiDoLogout");
  var a = b.getQueueItem();
  msQueueManager.addRequest(a);
  document.location = "http://www.disqus.com/saml/cnn/logout/?target=" + document.location;
}

function ms_doLogin(c, b, f, a) {
  var e = new ms_QueueItem(ms_baseStandard + "login.api", "post");
  e.addParam("email", c);
  e.addParam("password", b);
  e.addParam("keepMeLoggedIn", f);
  e.addParam("echourl", ms_echoURL);
  e.addParam("callback", a);
  var d = e.getQueueItem();
  msQueueManager.addRequest(d);
}

function createLoginIframe() {
  var a = "disqus_login";
  iframeDivId = a;
  iframeId = a + "_iframe";
  var c = location.href;
  c = c.split("/");
  c = "http://" + c[2] + "/.element/ssi/www/misc/3.0/connect/connect-disqus-target.html";
  iframeBlankUrl = ms_baseStandard + "gsso?assertionConsumerUrl=http://www.disqus.com/saml/cnn/postback/&target=" + c;
  var d = document.getElementsByTagName("body")[0];
  var b = document.createElement("iframe");
  b.setAttribute("id", iframeId);
  b.setAttribute("name", iframeId);
  b.style.position = "absolute";
  b.style.bottom = "0";
  b.style.left = "-600px";
  d.appendChild(b);
  frames[iframeId].location.replace(iframeBlankUrl);
}

function createLogoutIframe() {
  var a = "disqus_logout";
  iframeDivId = a;
  iframeId = a + "_iframe";
  var c = location.href;
  c = c.split("/");
  c = "http://" + c[2] + "/.element/ssi/www/misc/3.0/connect/connect-disqus-target.html";
  iframeBlankUrl = "http://www.disqus.com/saml/cnn/logout/?target=" + c;
  var d = document.getElementsByTagName("body")[0];
  var b = document.createElement("iframe");
  b.setAttribute("id", iframeId);
  b.setAttribute("name", iframeId);
  b.style.position = "absolute";
  b.style.bottom = "0";
  b.style.left = "-600px";
  d.appendChild(b);
  frames[iframeId].location.replace(iframeBlankUrl);
}

function ms_doRegister(d, k, h, e, a, l, c, g) {
  var b = new ms_QueueItem(ms_baseStandard + "register.api", "post");
  b.addParam("email", d);
  b.addParam("password", k);
  b.addParam("displayname", h);
  b.addParam("kaptcha", e);
  b.addParam("privacy", a);
  b.addParam("newsletters", l);
  b.addParam("echourl", ms_echoURL);
  b.addParam("facebookUserID", c);
  b.addParam("callback", g);
  if (location.hostname.indexOf("edition") != -1) {
    b.addParam("pid", "intl.default");
  }
  var f = b.getQueueItem();
  msQueueManager.addRequest(f);
}

function ms_resetUserPassword(b, a) {
  var d = new ms_QueueItem(ms_baseStandard + "passwordRecovery.api", "post");
  d.addParam("action", "sendResetPasswordCode");
  d.addParam("email", b);
  d.addParam("callback", a);
  var c = d.getQueueItem();
  msQueueManager.addRequest(c);
}

function ms_setUserPassword(e, d, c, b, a) {
  var g = new ms_QueueItem(ms_baseStandard + "passwordRecovery.api", "post");
  g.addParam("action", "changePassword");
  g.addParam("email", d);
  g.addParam("resetCode", e);
  g.addParam("password", c);
  g.addParam("confirmPassword", b);
  g.addParam("callback", a);
  var f = g.getQueueItem();
  msQueueManager.addRequest(f);
}

function ms_sendConfirmEmailAgain(b, a) {
  var d = new ms_QueueItem(ms_baseStandard + "emailConfirm.api", "post");
  d.addParam("action", "resendEmailConfirmation");
  d.addParam("email", b);
  d.addParam("callback", a);
  var c = d.getQueueItem();
  msQueueManager.addRequest(c);
}

function ms_uiDoLogout(b) {
  msQueueManager.requestReceived();
  var a = (typeof b.errors == "undefined") ? false : true;
  if (a == false) {
    CNN_updateHeaderOptions();
    window.msReload();
  } else {
    window.msReload();
  }
}

function ms_uiDoLogin(c) {
  msQueueManager.requestReceived();
  var b = (typeof c.errors == "undefined") ? false : true;
  if (b == false) {
    $("profile_overlaybg").hide();
    $("profile_signin_overlay").hide();
    var a = true;
    CNN_updateHeaderOptions();
    createLoginIframe();
  } else {
    cnnConnectOverlayLoginValidationError("clear");
    cnnConnectOverlayLoginValidationError("add", "Your email address or password doesn't match our records. Please try again.");
    cnnConnectOverlayLoginValidationError("show");
  }
}

function ms_uiDoRegister(b) {
  msQueueManager.requestReceived();
  var a = (typeof b.errors == "undefined") ? false : true;
  if (a == false) {
    closeOverlay("profile_signup_overlay");
    showOverlay("profile_followtopic11_overlay");
  } else {
    cnnConnectOverlayError("clearErrorText");
    generateCaptchaImage();
    for (var c = 0; c < b.errors.length; c++) {
      switch (b.errors[c]) {
        case "email address not available":
          cnnConnectOverlayRegisterError("email");
          cnnConnectOverlayError("addErrorText", "That e-mail address is already taken.<br/>");
          break;
        case "missing email address":
          cnnConnectOverlayRegisterError("email");
          cnnConnectOverlayError("addErrorText", "You forgot to enter your e-mail address.<br/>");
          break;
        case "bad email address":
          cnnConnectOverlayRegisterError("email");
          cnnConnectOverlayError("addErrorText", "You entered an invalid e-mail address.<br/>");
          break;
        case "missing password":
          cnnConnectOverlayRegisterError("password");
          cnnConnectOverlayError("addErrorText", "You forgot to enter your password.<br/>");
          break;
        case "bad password":
          cnnConnectOverlayRegisterError("password");
          cnnConnectOverlayError("addErrorText", "You entered an invalid password.<br/>");
          break;
        case "missing screen name":
          cnnConnectOverlayRegisterError("screenName");
          cnnConnectOverlayError("addErrorText", "You forgot to enter your screen name.<br/>");
          break;
        case "screen name not available":
          cnnConnectOverlayRegisterError("screenName");
          cnnConnectOverlayError("addErrorText", "That screen name is already taken. Please choose another.<br/>");
          break;
        case "missing captcha":
          cnnConnectOverlayRegisterError("captcha");
          cnnConnectOverlayError("addErrorText", "You forgot to type in the security word in the grey box.<br/>");
          break;
        case "bad captcha":
          cnnConnectOverlayRegisterError("captcha");
          cnnConnectOverlayError("addErrorText", "You entered the security word in the grey box incorrectly.<br/>");
          break;
        case "missing privacy policy":
          cnnConnectOverlayError("addErrorText", "You must agree to the privacy policy.<br/>");
          break;
        default:
          break;
      }
    }
    cnnConnectOverlayError("showErrorText");
  }
}

function ms_uiResetUserPassword(b) {
  msQueueManager.requestReceived();
  var d = "cnnConnectFormForgot";
  var e = "cnnConnectFormReset";
  var a = (typeof b.errors == "undefined") ? false : true;
  var c = "";
  if (a == false) {
    cnnConnectOverlayUpdate("forgot2reset");
  } else {
    cnnConnectOverlayForgotValidationError("clear");
    cnnConnectOverlayForgotValidationError("add", "Your e-mail address doesn't match our records. Please try again.");
    cnnConnectOverlayForgotValidationError("show");
  }
}

function ms_uiSetUserPassword(b) {
  msQueueManager.requestReceived();
  var a = (typeof b.errors == "undefined") ? false : true;
  if (a == false) {
    cnnConnectOverlayUpdate("reset2loginsuccess");
  } else {
    cnnConnectOverlayResetValidationError("clear");
    for (var c = 0; c < b.errors.length; c++) {
      switch (b.errors[c]) {
        case "missing email address":
          cnnConnectOverlayResetError("email");
          cnnConnectOverlayResetValidationError("add", "You forgot to enter your e-mail address.<br/>");
          break;
        case "profile not found":
          cnnConnectOverlayResetError("email");
          cnnConnectOverlayResetValidationError("add", "Your e-mail address or reset code doesn't match our records. Please try again.<br/>");
          break;
        case "missing new password":
          cnnConnectOverlayResetError("newPassword");
          cnnConnectOverlayResetValidationError("add", "You forgot to enter your new password.<br/>");
          break;
        case "missing confirm new password":
          cnnConnectOverlayResetError("confirmNewPassword");
          cnnConnectOverlayResetValidationError("add", "You forgot to confirm your new password.<br/>");
          break;
        case "confirm password did not match":
          cnnConnectOverlayResetError("newPassword");
          cnnConnectOverlayResetError("confirmNewPassword");
          cnnConnectOverlayResetValidationError("add", "Your passwords do not match.<br/>");
          break;
        case "reset code has expired":
          cnnConnectOverlayResetError("resetCode");
          cnnConnectOverlayResetValidationError("add", "Your reset code has expired. <a href=\"javascript: void(0);\" onclick=\"closeOverlay('profile_forgotpass2_overlay');showOverlay('profile_forgotpass_overlay');\">Send another e-mail</a> with an updated link and reset code to reset your password.<br/>");
          break;
        default:
          cnnConnectOverlayResetError("default");
          cnnConnectOverlayResetValidationError("add", "We're sorry! This service is temporarily unavailable. Please try again soon.");
          break;
      }
    }
    cnnConnectOverlayResetValidationError("show");
  }
}

function ms_uiSendConfirmEmailAgain(b) {
  msQueueManager.requestReceived();
  var a = (typeof b.errors == "undefined") ? false : true;
  if (a == false) {} else {}
}

function cnnConnectOverlayUpdate(a) {
  switch (a) {
    case "login2forgot":
      cnnConnectOverlayResetGetEmailFromLogin();
      cnnConnectOverlayHideLogin();
      cnnConnectOverlayShowForgot();
      cnnConnectOverlayClearLogin();
      break;
    case "forgot2reset":
      cnnConnectOverlayHideForgot();
      cnnConnectOverlayGetEmailFromForgot();
      cnnConnectOverlayClearForgot();
      cnnConnectOverlayShowReset();
      break;
    case "all2login":
      cnnConnectOverlayHideForgot();
      cnnConnectOverlayHideReset();
      cnnConnectOverlayClearRegister();
      cnnConnectOverlayShowLogin();
      break;
    case "forgot2login":
      cnnConnectOverlayHideForgot();
      cnnConnectOverlayShowLogin();
      cnnConnectOverlayClearForgot();
      break;
    case "reset2login":
      cnnConnectOverlayHideReset();
      cnnConnectOverlayLoginShowText1();
      cnnConnectOverlayShowLogin();
      cnnConnectOverlayClearReset();
      break;
    case "2resetWithCode":
      cnnConnectOverlayShowResetWithPasscode("test1@test.com", "asdf");
      cnnConnectOverlayHideLogin();
      cnnConnectOverlayShowReset();
      break;
    case "forgot2resetWithoutCode":
      cnnConnectOverlayShowMsg2();
      cnnConnectOverlayHideForgot();
      cnnConnectOverlayShowReset();
      break;
    case "reset2loginsuccess":
      cnnConnectOverlayHideReset();
      cnnConnectOverlayLoginShowText2();
      cnnConnectOverlayShowLogin();
      cnnConnectOverlayClearReset();
      break;
  }
}

function cnnConnectOverlayShowOverlay() {
  $("cnnConnectOverlayBox").show();
}

function cnnConnectOverlayHideOverlay() {
  cnnConnectOverlayUpdate("all2login");
  $("cnnConnectOverlayBox").hide();
}

function cnnConnectOverlayShowLogin() {
  showOverlay("profile_signin_overlay");
}

function cnnConnectOverlayHideLogin() {
  closeOverlay("profile_signin_overlay");
}

function cnnConnectOverlayClearLogin() {
  cnnConnectOverlayLoginShowText1();
  $("cnnConnectLoginErrors").hide();
  $("cnnConnectFormLogin").email.value = "";
  $("cnnConnectFormLogin").password.value = "";
  $("cnnConnectFormLogin").email.className = "cnnConnectFormbg5 cnn_connectoverlay_email";
  $("cnnConnectFormLogin").password.className = "cnnConnectFormbg6 cnn_connectoverlay_password";
  $("psigninp2_email").removeClassName("redtexterror");
  $("psigninp2_password").removeClassName("redtexterror");
}

function cnnConnectOverlayLoginShowText1() {}

function cnnConnectOverlayLoginShowText2() {}

function cnnConnectOverlayLoginValidationError(a, b) {
  switch (a) {
    case "clear":
      $("cnnConnectLoginErrors").hide();
      $("cnnConnectLoginErrors").innerHTML = "<br/>";
      $("cnnConnectFormLogin").email.removeClassName("redinput_error");
      $("cnnConnectFormLogin").password.removeClassName("redinput_error");
      $("psigninp2_email").removeClassName("redtexterror");
      $("psigninp2_password").removeClassName("redtexterror");
      break;
    case "add":
      $("psigninp2_email").addClassName("redtexterror");
      $("psigninp2_password").addClassName("redtexterror");
      $("cnnConnectLoginErrors").innerHTML += b;
      break;
    case "show":
      $("cnnConnectFormLogin").email.className = "redinput_error";
      $("cnnConnectFormLogin").password.className = "redinput_error";
      $("cnnConnectLoginErrors").className = "redtexterror";
      $("cnnConnectLoginErrors").show();
      break;
  }
}

function cnnConnectOverlayShowForgot() {
  showOverlay("profile_forgotpass_overlay");
}

function cnnConnectOverlayHideForgot() {
  closeOverlay("profile_forgotpass_overlay");
}

function cnnConnectOverlayClearForgot() {
  $("cnnConnectForgotErrors").hide();
  $("cnnConnectFormForgot").email.value = "";
  $("cnnConnectFormForgot").email.className = "cnnConnectFormbg5 cnn_connectoverlay_email";
}

function cnnConnectOverlayForgotShowErrors() {
  $("cnnConnectFormForgot").email.className = "cnn_connectoverlay_email cnnredtxt redinput_error";
  $("cnnConnectForgotErrors").className = "redtexterror";
  $("forgotpass_email").addClassName("redtexterror");
  $("cnnConnectForgotErrors").show();
}

function cnnConnectOverlayResetGetEmailFromLogin() {
  if ($("cnnConnectFormLogin").email.value != "") {
    $("cnnConnectFormForgot").email.value = $("cnnConnectFormLogin").email.value;
    $("cnnConnectFormForgot").email.className = "cnnConnectFormbgnone cnn_connectoverlay_email";
  }
}

function cnnConnectOverlayForgotValidationError(a, b) {
  switch (a) {
    case "clear":
      $("forgotpass_email").removeClassName("redtexterror");
      $("cnnConnectForgotErrors").hide();
      $("cnnConnectForgotErrors").innerHTML = "<br/>";
      break;
    case "add":
      $("forgotpass_email").addClassName("redtexterror");
      $("cnnConnectForgotErrors").innerHTML += b;
      break;
    case "show":
      $("cnnConnectFormForgot").email.className = "cnn_connectoverlay_email cnnredtxt redinput_error";
      $("cnnConnectForgotErrors").className = "redtexterror";
      $("forgotpass_email").addClassName("redtexterror");
      $("cnnConnectForgotErrors").show();
      break;
  }
}

function cnnConnectOverlayShowReset() {
  showOverlay("profile_forgotpass2_overlay");
}

function cnnConnectOverlayHideReset() {
  closeOverlay("profile_forgotpass2_overlay");
}

function cnnConnectOverlayClearReset() {
  cnnConnectOverlayResetValidationError("clear");
}

function cnnConnectOverlayGetEmailFromForgot() {
  $("cnnConnectFormReset").email.value = $("cnnConnectFormForgot").email.value;
  $("cnnConnectFormReset").email.className = "cnnblacktxt cnn_connectoverlay_email3";
  showOverlay("profile_forgotpass2_overlay");
  cnnConnectOverlayShowMsg1();
}

function cnnConnectOverlayShowResetWithPasscode(a, b) {}

function cnnConnectOverlayShowMsg1() {
  showOverlay("profile_forgotpass2_overlay");
}

function cnnConnectOverlayShowMsg2() {
  showOverlay("profile_forgotpass2_overlay");
}

function cnnConnectOverlayResetValidationError(a, b) {
  switch (a) {
    case "clear":
      $("cnnConnectResetErrors").hide();
      $("cnnConnectResetErrors").innerHTML = "<br/>";
      break;
    case "add":
      $("cnnConnectResetErrors").innerHTML += b;
      break;
    case "show":
      $("cnnConnectResetErrors").className = "redtexterror";
      $("cnnConnectResetErrors").show();
      break;
  }
}

function cnnConnectOverlayResetError(a) {
  switch (a) {
    case "email":
      $("cnnConnectFormReset").email.className = "cnn_connectoverlay_email3 cnnredtxt redinput_error";
      $("new_password_email").previous("p").addClassName("redtexterror");
      break;
    case "resetCode":
      $("cnnConnectFormReset").resetCode.className = "cnn_connectoverlay_password3 cnnredtxt redinput_error";
      $("reset_code").previous("p").addClassName("redtexterror");
      break;
    case "newPassword":
      $("cnnConnectFormReset").newPassword.className = "cnn_connectoverlay_password4 cnnredtxt redinput_error";
      $("new_password").previous("p").addClassName("redtexterror");
      break;
    case "confirmNewPassword":
      $("cnnConnectFormReset").confirmNewPassword.className = "cnn_connectoverlay_password5 cnnredtxt redinput_error";
      break;
    default:
      $("new_password_email").previous("p").addClassName("redtexterror");
      $("cnnConnectFormReset").email.className = "cnn_connectoverlay_email3 cnnredtxt redinput_error";
      $("reset_code").previous("p").addClassName("redtexterror");
      $("cnnConnectFormReset").resetCode.className = "cnn_connectoverlay_password3 cnnredtxt redinput_error";
      $("new_password").previous("p").addClassName("redtexterror");
      $("cnnConnectFormReset").newPassword.className = "cnn_connectoverlay_password4 cnnredtxt redinput_error";
      break;
  }
}

function cnnConnectOverlayShowRegister() {
  $("cnnConnectResetContainer").show();
}

function cnnConnectOverlayHideRegister() {
  $("cnnConnectResetContainer").hide();
}

function cnnConnectOverlayClearRegister() {
  if ($("signup_email")) {
    $("signup_email").previous("p").removeClassName("redtexterror");
  }
  if ($("signup_password")) {
    $("signup_password").previous("p").removeClassName("redtexterror");
  }
  if ($("signup_screenname")) {
    $("signup_screenname").previous("p").removeClassName("redtexterror");
  }
  if ($("signup_kaptcha_p1")) {
    $("signup_kaptcha_p1").removeClassName("redtexterror");
  }
  generateCaptchaImage();
}

function cnnConnectOverlayError(b, a) {
  switch (b) {
    case "email":
      if ($("cnnConnectFormRegister").email.value != "") {
        $("cnnConnectFormRegister").email.className = "cnnConnectFormbgnone cnn_connectoverlay_email2 cnnredtxt redinput_error";
      }
      break;
    case "password":
      if ($("cnnConnectFormRegister").password.value != "") {
        $("cnnConnectFormRegister").password.className = "cnnConnectFormbgnone cnn_connectoverlay_password2 cnnredtxt redinput_error";
      }
      break;
    case "errorText":
      $("cnnConnectRegisterErrors").hide();
      $("cnnConnectRegisterErrors").innerHTML = a;
      $("cnnConnectRegisterErrors").className = "redtexterror";
      $("cnnConnectRegisterErrors").show();
      break;
    case "clearErrorText":
      $("cnnConnectRegisterErrors").hide();
      $("cnnConnectRegisterErrors").className = "";
      $("cnnConnectRegisterErrors").innerHTML = "";
      break;
    case "addErrorText":
      $("cnnConnectRegisterErrors").innerHTML += a;
      $("cnnConnectRegisterErrors").className = "redtexterror";
      break;
    case "showErrorText":
      $("cnnConnectRegisterErrors").className = "redtexterror";
      $("cnnConnectRegisterErrors").show();
      break;
  }
}

function cnnConnectOverlayRegisterError(a) {
  switch (a) {
    case "email":
      $("cnnConnectFormRegister").email.className = "cnnConnectFormbgnone cnn_connectoverlay_email2 cnnredtxt redinput_error";
      $("signup_email").previous("p").addClassName("redtexterror");
      break;
    case "password":
      $("cnnConnectFormRegister").password.className = "cnnConnectFormbgnone cnn_connectoverlay_password2 cnnredtxt redinput_error";
      $("signup_password").previous("p").addClassName("redtexterror");
      break;
    case "screenName":
      $("cnnConnectFormRegister").displayname.className = "cnnConnectFormbgnone cnn_connectoverlay_screenname cnnredtxt redinput_error";
      $("signup_displayname").previous("p").addClassName("redtexterror");
      break;
    case "captcha":
      $("cnnConnectFormRegister").captcha.className = "cnnConnectFormbgnone cnn_connectoverlay_enterit cnnredtxt redinput_error";
      $("signup_kaptcha_p1").addClassName("redtexterror");
      $("cnnConnectRegisterErrors").className = "redtexterror";
      break;
  }
}

function getRandomId() {
  var a = Math.round(Math.random() * 9999999999);
  return a;
}

function generateCaptchaImage() {
  var a = getRandomId();
  $("cnnConnectCaptchaImage").src = ms_baseStandard + "kaptcha?challenge_id=" + a;
  $("cnnConnectCaptchaImage").width = "200";
  $("cnnConnectCaptchaImage").height = "50";
  $("cnnConnectFormRegister").captcha.value = "";
}

function showToggleOverlay() {
  var a = "cnnConnectOverlayBox";
  if ($(a).style.display == "none") {
    $(a).style.display = "block";
    centerDivOfPage("cnnConnectOverlayBox");
    cnnConnectOverlayClearLogin();
  } else {
    $(a).style.display = "none";
  }
}

function checkUrlForParams() {
  if (location.href.indexOf("code=") != -1) {
    var a = location.href.toQueryParams();
    CNN_handleOverlay("profile_forgotpass2_overlay");
  } else {
    if (location.href.indexOf("emailConfirmed=success") > -1) {
      showOverlayMessage(1);
    } else {
      if (location.href.indexOf("emailConfirmed=error") > -1) {
        showOverlayMessage(2);
      }
    }
  }
}

function showOverlayMessage(a) {
  if (a == "hide") {
    $("cnnConnectMessageContent").innerHTML = "";
    $("cnnConnectMessageContainer").style.display = "none";
  } else {
    var b = [];
    if (typeof (msStorage.profile) == "undefined") {
      b[0] = "<h1>Thanks! You are a CNN.com member</h1>";
    } else {
      if (msStorage.profile.firstName != "") {
        b[0] = '<h1>Thanks, <span id="cnnConnectThankYouName">' + msStorage.profile.firstName + "</span>! You are a CNN.com member</h1>";
      } else {
        if (msStorage.profile.screenName != "") {
          b[0] = '<h1>Thanks, <span id="cnnConnectThankYouName">' + msStorage.profile.screenName + "</span>! You are a CNN.com member</h1>";
        } else {
          b[0] = "<h1>Thanks! You are a CNN.com member</h1>";
        }
      }
    }
    b[0] += '<p class="connectptxt3">You are ready to participate in all activities and conversations on this site. Enjoy!</p>';
    b[0] += '<p class="connectptxt4"><div class="cnnConnectReturnLink" onclick="window.msReload();">Go to Your Profile Page</div></p>';
    b[1] = "<h1>Thank you for confirming your email address.</h1>";
    b[1] += '<p class="connectptxt3">You are ready to participate in all activities and conversations on this site. Enjoy!</p>';
    if (ms_isLoggedIn() == true) {
      b[1] += '<p class="connectptxt4"><div class="cnnConnectReturnLink" onclick="window.msReload();">Go to Your Profile Page</div></p>';
    }
    b[2] = "<h1>There was an error confirming your e-mail address.</h1>";
    if (ms_isLoggedIn() == true) {
      b[2] += '<p class="connectptxt3">In order to correct this problem, please resend your confirmation e-mail by <a href="javascript:void(0);" onclick="showOverlayMessage(\'hide\');showToggleProfile();">going to Your Profile Page</a>.';
    } else {
      b[2] += '<p class="connectptxt3">In order to correct this problem, please resend your confirmation e-mail by logging in and then going to edit my details.';
    }
    $("cnnConnectMessageContainer").style.display = "block";
    $("cnnConnectMessageContent").innerHTML = b[a];
    centerDivOfPage("cnnConnectMessageContainer");
  }
}

function disqusConnectStatus(e) {
  var d = window.location.href;
  var c = window.location.hash.length;
  var a = d.length - c;
  if (c > 0) {
    var b = d.substr(0, a);
    window.location.href = b;
  }
  if (e === false) {
    window.msReload();
  } else {
    window.msReload();
  }
}

function closeOverlay(a) {
  $("profile_overlaybg").hide();
  $(a).hide();
}

function showOverlay(g) {
  var b = document.viewport.getHeight();
  var d = document.viewport.getWidth();
  var f = Math.max(document.documentElement["clientHeight"], document.body["scrollHeight"], document.documentElement["scrollHeight"], document.body["offsetHeight"], document.documentElement["offsetHeight"]);
  var c = Math.max(document.documentElement["clientWidth"], document.body["scrollWidth"], document.documentElement["scrollWidth"], document.body["offsetWidth"], document.documentElement["offsetWidth"]);
  var e = (f > b) ? f : b;
  var a = (c > d) ? c : d;
  switch (g) {
    case "profile_signup_overlay":
      generateCaptchaImage();
      break;
    default:
  }
  if (g == "profile_signin_overlay") {
    clearInputErrors();
  }
  $("profile_overlaybg").setStyle({
    width: a + "px",
    height: e + "px"
  });
  $("profile_overlaybg").show();
  $(g).show();
  centerDivOfPage(g);
  globalDiv = g;
  Event.observe(window, "resize", function () {
    centerDivOfPage(globalDiv);
  });
}

function showOrHide(a) {
  $(a).toggleClassName("displayon");
}

function hideDiv(a) {
  $(a).hide();
}

function getScrollOffset() {
  var b = 0,
    a = 0;
  if (typeof (window.pageYOffset) == "number") {
    a = window.pageYOffset;
    b = window.pageXOffset;
  } else {
    if (document.body && (document.body.scrollLeft || document.body.scrollTop)) {
      a = document.body.scrollTop;
      b = document.body.scrollLeft;
    } else {
      if (document.documentElement && (document.documentElement.scrollLeft || document.documentElement.scrollTop)) {
        a = document.documentElement.scrollTop;
        b = document.documentElement.scrollLeft;
      }
    }
  }
  return [b, a];
}

function centerDivOfPage(k) {
  var e = getScrollOffset();
  var a = $(k).getWidth();
  var c = $(k).getHeight();
  var m = document.viewport.getHeight();
  var b = document.viewport.getWidth();
  var n = Math.max(document.documentElement["clientHeight"], document.body["scrollHeight"], document.documentElement["scrollHeight"], document.body["offsetHeight"], document.documentElement["offsetHeight"]);
  var d = Math.max(document.documentElement["clientWidth"], document.body["scrollWidth"], document.documentElement["scrollWidth"], document.body["offsetWidth"], document.documentElement["offsetWidth"]);
  var o = (n > m) ? n : m;
  var g = (d > b) ? d : b;
  $("profile_overlaybg").setStyle({
    width: g + "px",
    height: o + "px"
  });
  var h = e[1];
  var l = Math.floor((b / 2) - (a / 2));
  var f = Math.floor((h + (m / 2)) - (c / 2));
  if ((f + c) > n) {
    f = ((n - c) - 100);
  }
  f = (f <= 110) ? 110 : f;
  l = (f <= 9) ? 10 : l;
  $(k).style.top = f + "px";
  $(k).style.left = l + "px";
}

function stringTrim(a) {
  return (a.replace(/^\s+|\s+$/g, ""));
}

function submitenter(c, b) {
  var a;
  if (window.event) {
    a = window.event.keyCode;
  } else {
    if (b) {
      a = b.which;
    } else {
      return true;
    }
  }
  if (a == 13) {
    $("cnnConnectFormLogin").email.value = stringTrim($("cnnConnectFormLogin").email.value);
    cnn_formConnectLogin("cnnConnectFormLogin");
    return false;
  } else {
    return true;
  }
}

function cnnUpdateFBLogin() {
  var a = " ";
  if (Member.isLoggedIn("facebook") && !Member.isConnected() && !Member.isLoggedIn("cnn")) {
    a = '<a href="javascript:FB.login();" title="Connect your Facebook account to CNN">Connect your Facebook account to CNN</a>';
  } else {
    if (!Member.isConnected()) {
      a = '<a href="javascript:CNN_handleOverlay(\'fb_profile_signin_init_overlay\');" title="Connect your CNN &amp; Facebook accounts">Connect your CNN &amp; Facebook accounts</a>';
    } else {
      if ((Member.isLoggedIn("cnn") && !Member.isLoggedIn("facebook")) || (Member.isLoggedIn("facebook") && !Member.isLoggedIn("cnn")) && !Member.isConnected()) {
        a = '<a href="javascript:CNN_handleOverlay(\'fb_profile_signin_init_overlay\');" title="Log in with Facebook">Log in with Facebook</a>';
      }
    }
  }
  $("fbLoginOptions").update(a);
}
var allCookies = CNN_getCookies();

function CNN_updateHeaderOptions() {
  var d = document.location.host;
  if (d.indexOf("ireport") > -1) {
    d = "www.cnn.com";
  }
  var c = d.split(".");
  if (c[0] == "newspulse") {
    c.splice(0, 1);
  }
  d = c.join(".");
  var e = $("hdr-auth");
  if (e) {
    if (Member.isLoggedIn("cnn") || (Member.isLoggedIn("facebook") && Member.isConnected())) {
      if ($("user_avatar")) {
        if ((Member.isConnected() && CNN_FB_user.avatar === "fb") || (Member.isConnected() && !Member.isLoggedIn("cnn"))) {
          if (!$("fbAvatar")) {
            var g = new Element("div", {
              id: "fbAvatar"
            });
            $("user_avatar").appendChild(g);
          }
        }
      }
      var a = (Member.isLoggedIn("facebook") && Member.isConnected()) ? CNN_FB_user.accounts[CNN_FB_user.namePref].displayName : CNN_FB_user.accounts.cnn.displayName;
      if (Member.isLoggedIn("facebook") && Member.isConnected() && Member.isLoggedIn("cnn")) {
        a = CNN_FB_user.accounts[CNN_FB_user.namePref].displayName;
      } else {
        if (Member.isLoggedIn("facebook") && Member.isConnected() && !Member.isLoggedIn("cnn")) {
          a = CNN_FB_user.accounts.fb.displayName;
        } else {
          a = (CNN_FB_user.accounts[CNN_FB_user.namePref].displayName != "") ? CNN_FB_user.accounts[CNN_FB_user.namePref].displayName : CNN_FB_user.accounts.cnn.displayName;
        }
      }
      if (a == "") {
        return;
      }
      var b = "<ul>";
      var f = "";
      b += '<li><a href="http://' + d + '/profile/" title="">' + a + "'s profile</a></li>";
      b += '<li class="no-border no-pad-right"><a href="javascript:Member.fullLogout();" title="">Log out</a></li>';
      b += "</ul>";
      $("hdr-auth").innerHTML = b;
    } else {
      var b = "<ul>";
      b += '<li><a href="javascript:CNN_handleOverlay(\'profile_signup_overlay\');" title="">Sign up</a></li>';
      b += '<li class="no-border no-pad-right"><a href="javascript:CNN_handleOverlay(\'profile_signin_overlay\');" title="">Log in</a></li>';
      b += "</ul>";
      $("hdr-auth").innerHTML = b;
    }
    if ($("displayname")) {
      if (Member.isLoggedIn("facebook") && !Member.isLoggedIn("cnn")) {
        if (Member.isConnected()) {
          $("displayname").update(a);
        } else {
          $("displayname").update("Hi!");
        }
        $("cnnLoginOptions").update('<a href="javascript:CNN_handleOverlay(\'profile_signin_overlay\');" title="Log in">Log in</a>&nbsp;or&nbsp;<a href="javascript:CNN_handleOverlay(\'profile_signup_overlay\');" title="sign up">sign up</a> with CNN to get personalized features such as breaking news alerts and newsletters.');
        $("user_profile").select(".welcome_details")[0].hide();
        $("user_profile").select(".user_details_box")[0].style.display = "block";
      }
      cnnUpdateFBLogin();
    }
  } else {} if ($("loading_overlay") && !is_loadedOvly) {
    closeOverlay("loading_overlay");
    is_loadedOvly = 1;
    checkUrlForParams();
  }
}

function onUserInfoLoadComplete(a) {}
Event.observe(window, "load", function () {
  if ($("cnnConnectFormForgot")) {
    $("cnnConnectFormForgot").observe("keyup", function (a) {
      if (a.keyCode == Event.KEY_RETURN) {
        ms_formResetUserPassword("cnnConnectFormForgot");
        Event.stop(a);
      }
    });
  }
  if ($("cnnConnectFormReset")) {
    $("cnnConnectFormReset").observe("keyup", function (a) {
      if (a.keyCode == Event.KEY_RETURN) {
        ms_formSetUserPassword("cnnConnectFormReset");
        Event.stop(a);
      }
    });
  }
  if ($("cnnConnectFormRegister")) {
    $("cnnConnectFormRegister").observe("keyup", function (a) {
      if (a.keyCode == Event.KEY_RETURN) {
        ms_formRegister("cnnConnectFormRegister");
        Event.stop(a);
      }
    });
  }
  if ($("cnnConnectFormLogin")) {
    $("cnnConnectFormLogin").observe("keyup", function (a) {
      if (a.keyCode == Event.KEY_RETURN) {
        $("cnnConnectFormLogin").email.value = stringTrim($("cnnConnectFormLogin").email.value);
        cnn_formConnectLogin("cnnConnectFormLogin");
        Event.stop(a);
      }
    });
  }
  if ($("cnnConnectFormScreenname")) {
    $("cnnConnectFormScreenname").observe("keyup", function (a) {
      if (a.keyCode == Event.KEY_RETURN) {
        ms_formEnterScreenname("cnnConnectFormScreenname");
        Event.stop(a);
      }
    });
  }
});
Ajax.JSONRequest = Class.create(Ajax.Base, (function () {
  var b = 0,
    a = document.getElementsByTagName("head")[0];
  return {
    initialize: function ($super, d, c) {
      $super(c);
      this.options.url = d;
      this.options.callbackParamName = this.options.callbackParamName || "callback";
      this.options.timeout = this.options.timeout || 3;
      this.options.invokeImmediately = (!Object.isUndefined(this.options.invokeImmediately)) ? this.options.invokeImmediately : true;
      if (this.options.invokeImmediately) {
        this.request();
      }
    },
    _cleanup: function () {
      if (this.timeout) {
        clearTimeout(this.timeout);
        this.timeout = null;
      }
      if (this.transport && Object.isElement(this.transport)) {
        this.transport.remove();
      }
    },
    request: function () {
      var d = new Ajax.JSONResponse(this);
      var g = this.options.callbackParamName,
        f = "_prototypeJSONPCallback_" + (b++),
        c = function () {
          if (Object.isFunction(this.options.onComplete)) {
            this.options.onComplete.call(this, d);
          }
        }.bind(this);
      this.options.params[g] = f;
      var e = this.options.url + ((this.options.url.include("?") ? "&" : "?") + Object.toQueryString(this.options.params));
      window[f] = function (h) {
        this._cleanup();
        window[f] = undefined;
        if (h.status == "error" && Object.isFunction(this.options.onError)) {
          d.status = 200;
          d.statusText = "ERROR";
          d.setResponseContent(h);
          this.options.onError.call(this, d);
        } else {
          if (Object.isFunction(this.options.onSuccess)) {
            d.status = 200;
            d.statusText = "OK";
            d.setResponseContent(h);
            this.options.onSuccess.call(this, d);
          }
        }
        c();
      }.bind(this);
      this.transport = new Element("script", {
        type: "text/javascript",
        src: e
      });
      if (Object.isFunction(this.options.onCreate)) {
        this.options.onCreate.call(this, d);
      }
      a.appendChild(this.transport);
      this.timeout = setTimeout(function () {
        this._cleanup();
        window[f] = Prototype.emptyFunction;
        if (Object.isFunction(this.options.onFailure)) {
          d.status = 504;
          d.statusText = "Gateway Timeout";
          this.options.onFailure.call(this, d);
        }
        c();
      }.bind(this), this.options.timeout * 1000);
    },
    toString: function () {
      return "[object Ajax.JSONRequest]";
    }
  };
})());
Ajax.JSONResponse = Class.create({
  initialize: function (a) {
    this.request = a;
  },
  request: undefined,
  status: 0,
  statusText: "",
  responseJSON: undefined,
  responseText: undefined,
  setResponseContent: function (a) {
    this.responseJSON = a;
    this.responseText = Object.toJSON(a);
  },
  getTransport: function () {
    if (this.request) {
      return this.request.transport;
    }
  },
  toString: function () {
    return "[object Ajax.JSONResponse]";
  }
});
var ms_isLoggedIn = function () {
  var a = allCookies["authid"] || null;
  if (a == null) {
    return false;
  } else {
    return true;
  }
};
if (!ms_isLoggedIn && allCookies["CNN_memberID"]) {
  CNN_removeCookie("CNN_memberID", "/", document.domain);
}
var CNN_FB_user = (ms_isLoggedIn && allCookies["CNN_memberID"]) ? allCookies["CNN_memberID"].evalJSON(true) : {
  accounts: {
    cnn: {
      displayName: allCookies["displayname"] || ""
    },
    fb: {
      displayName: ""
    }
  },
  namePref: "cnn",
  avatar: "cnn",
  prefs: false
};
var CNN_FB_data = {
  cnn: {
    "loginStatus": false
  },
  fb: {
    "loginStatus": false,
    "connectedStatus": false
  }
};
var CNN_IsFBInit = false;
var CNN_IsMemInit = false;
var CNN_memberInit = true;
Event.observe(window, "load", function () {
  if (navigator.userAgent.toLowerCase().indexOf("msie 6") == -1) {
    Member.init();
  } else {
    if ($("hdr-auth")) {
      $("hdr-auth").hide();
    }
    if ($("pmUserPanel")) {
      $("pmUserPanel").hide();
    }
    if ($("pmFacebookTab")) {
      var a = CSIManager.getInstance();
      var b = {
        url: "/.element/ssi/auto/3.0/sect/MAIN/facebook_rec.wrapper.html",
        args: "",
        domId: "pmFacebookTab",
        funcObj: false,
        breakCache: false
      };
      CSIManager.getInstance().callObject(b);
    }
  }
});
var Member = function () {
  var b;
  var n = "CNN_memberAccnts_dev";
  var q = "CNN_member_dev";
  var k = "CNN_memberExpires_dev";
  var o = false;
  var d = "http://audience.cnn.com/services/cnn/flow/";
  var p = "http://audience.cnn.com/services/cnn/";
  var g = (window.location.href.indexOf("?") > -1) ? window.location.href.substr(0, window.location.href.indexOf("?")) : window.location.href;
  var a = false;
  var l = function () {
    var u = new Array;
    if (document.cookie) {
      var t = document.cookie.split("; ");
      for (var s = 0; s < t.length; s++) {
        var r = t[s].split("=");
        u[r[0]] = unescape(r[1]) || null;
      }
    }
    return u;
  };
  var f = function (t) {
    var s = l();
    t.params.format = t.format || "jsonp";
    t.params = t.params || {};
    var r = d;
    if (t.legacy) {
      r = p + t.legacy;
    } else {
      r += t.flow;
    }
    new Ajax.JSONRequest(r, t);
  };
  var e = function (v, w) {
    var r = {};
    r.params = {};
    var v = typeof (v) != "undefined" ? v : r;
    var s = w.requiredParams || [];
    var t = 0;
    for (i = 0; i < s.length; i++) {
      if (!v.params[s[i]] && (v.params[s[i]] != "")) {
        var u = "The api call is missing the required parameter: " + s[i];
        throw u;
      } else {
        t++;
      }
    }
    if (t == s.length) {
      if (w.legacy) {
        v.legacy = w.legacy;
      } else {
        v.flow = w.flow;
      }
      v.params.action = w.action;
      return v;
    } else {
      return false;
    }
  };
  var c = "Error in api method: ";
  var m = function (r) {
    throw r;
  };
  var h = {
    init: function () {
      if (!CNN_memberInit) {}
      CNN_memberInit = false;
      CNN_IsMemInit = true;
      if (CNN_IsMemInit && CNN_IsFBInit) {
        if (typeof (cnn_memfbini) === "function") {
          cnn_memfbini();
        }
      }
      window.fbAsyncInit = function () {
        FB.init({
          appId: "80401312489",
          status: true,
          cookie: true,
          xfbml: false,
          oauth: true
        });
        var w = true;
        if (($("cnnStryRcmndBtn") || $("cnnStryRcmndBtnBtm")) && w) {
          var u = "";
          var s = $("cnnStryRcmndBtn");
          var v = $("cnnStryRcmndBtnBtm");
          var y = document.getElementsByTagName("link");
          for (var t = 0; t < y.length; t++) {
            if (y[t].rel == "canonical") {
              u = y[t].href;
            }
          }
          if (u == "") {
            u = "http://www.cnn.com" + location.pathname;
          }
          if (s && s.innerHTML == "") {
            if (Member.hasDisconnected()) {
              $("cnnStryRcmndBtn").update('<fb:like action="recommend" show_faces="false" layout="button_count" href="' + u + '" width="336"></fb:like>');
              $("cnnStryRcmndBtn").style.width = "260px";
            } else {
              $("cnnStryRcmndBtn").update('<fb:like action="recommend" show_faces="true" layout="standard" href="' + u + '" width="336"></fb:like>');
            }
            FB.XFBML.parse(s);
          }
          if (v && v.innerHTML == "") {
            if (Member.hasDisconnected()) {
              $("cnnStryRcmndBtnBtm").update('<fb:like action="recommend" width="420" show_faces="false" layout="button_count" href="' + u + '"></fb:like>');
            } else {
              $("cnnStryRcmndBtnBtm").update('<fb:like action="recommend" width="420" show_faces="true" layout="standard" href="' + u + '"></fb:like>');
            }
            FB.XFBML.parse(v);
          }
          FB.Event.subscribe("edge.create", function (z, A) {});
          w = false;
        }
        var r = null;
        FB.getLoginStatus(function (z) {
          r = 1;
          Member.setFBStatus(z);
          CNN_IsFBInit = true;
          if (Member.isLoggedIn("cnn") && allCookies["CNN_memberID"]) {
            CNN_FB_user = allCookies["CNN_memberID"].evalJSON(true);
          } else {
            if (allCookies["CNN_memberID"] && !Member.isLoggedIn("cnn")) {
              Member.removeIDCookie();
            }
          }
          if (Member.isConnected() && !(Member.isLoggedIn("cnn"))) {
            FB.api({
              method: "fql.query",
              query: "SELECT name, pic_square FROM user WHERE uid=" + FB.getAuthResponse().userID
            }, function (B) {
              var A = B[0];
              Member.setUserDataFB(A, FB.getAuthResponse().userID);
            });
          }
          if (CNN_IsMemInit && CNN_IsFBInit) {
            if (typeof (cnn_memfbini) === "function") {
              cnn_memfbini();
            }
          }
        }, true);
        FB.Event.subscribe("auth.login", Member.setFBStatus);
        FB.Event.subscribe("auth.logout", Member.setFBStatus);
      };
      (function () {
        var u = document.getElementsByTagName("body")[0];
        var s = document.createElement("div");
        s.setAttribute("id", "fb-root");
        var t = document.createElement("div");
        t.setAttribute("id", "cnn_mOvrlycntr");
        u.insertBefore(s, u.firstChild);
        u.insertBefore(t, u.firstChild);
        var r = document.createElement("script");
        r.setAttribute("type", "text/javascript");
        r.setAttribute("src", "http://connect.facebook.net/en_US/all.js");
        r.setAttribute("async", "true");
        document.getElementsByTagName("head")[0].appendChild(r);
      }());
    },
    setRememberMe: function (r) {
      a = r;
    },
    getRememberMe: function () {
      return a;
    },
    setFBStatus: function (r) {
      switch (r.status) {
        case "connected":
          CNN_FB_data.fb.loginStatus = true;
          CNN_FB_data.fb.connectedStatus = true;
          break;
        case "notConnected":
          CNN_FB_data.fb.loginStatus = true;
          CNN_FB_data.fb.connectedStatus = false;
          break;
        default:
          CNN_FB_data.fb.loginStatus = false;
          CNN_FB_data.fb.connectedStatus = false;
      }
      if (ms_isLoggedIn() === true) {
        CNN_FB_data.cnn.loginStatus = true;
      }
      if (typeof MainLocalObj !== "undefined" && typeof MainLocalObj.showIdentity === "function") {
        MainLocalObj.showIdentity();
      } else {
        CNN_updateHeaderOptions();
      }
    },
    clearStoredDataAll: function () {
      Member.removeIDCookie();
    },
    clearStoredDataIdentities: function () {
      Member.removeIDCookie();
    },
    clearStoredPrefs: function () {
      Member.removeIDCookie();
    },
    removeIDCookie: function () {
      CNN_removeCookie("CNN_memberID", "/", document.domain);
    },
    getReturnURL: function () {
      return g;
    },
    setReturnURL: function (r) {
      g = r;
    },
    setUserDataFB: function (s, t, r) {
      CNN_FB_user.accounts.fb.displayName = s.name;
      CNN_updateHeaderOptions();
      CNN_setCookie("CNN_memberID", Object.toJSON(CNN_FB_user), 854400, "/", document.domain);
      if (r) {
        if (!CNN_FB_user.prefs) {
          CNN_handleOverlay("fb_choose_identity_overlay");
        } else {
          location.reload();
        }
      }
    },
    setUserDataCNN: function (s, r) {
      CNN_setCookie("displayname", s.profile.screenName, 854400, "/", document.domain);
      CNN_FB_user.accounts.cnn.displayName = s.profile.screenName;
      CNN_FB_user.accounts.fb.displayName = s.profile.fb_userName;
      CNN_FB_user.prefs = s.profile.prefChosen;
      CNN_FB_user.namePref = s.profile.id_pref;
      CNN_FB_user.avatar = s.profile.avatar_pref;
      CNN_setCookie("CNN_memberID", Object.toJSON(CNN_FB_user), 854400, "/", document.domain);
      if (r || (Member.isConnected() && Member.isLoggedIn("cnn") && CNN_FB_user.prefs == "false")) {
        CNN_handleOverlay("fb_choose_identity_overlay");
      } else {
        Member.executeCookieCopy();
      }
    },
    setUserAvatarPref: function (r) {
      CNN_FB_user.avatar = r;
      CNN_setCookie("CNN_memberID", Object.toJSON(CNN_FB_user), 854400, "/", document.domain);
    },
    setUserNamePref: function (r) {
      CNN_FB_user.prefs = true;
      CNN_FB_user.namePref = r;
      CNN_setCookie("CNN_memberID", Object.toJSON(CNN_FB_user), 854400, "/", document.domain);
    },
    setDisconnectPrefs: function () {
      CNN_FB_user.prefs = false;
      CNN_FB_user.namePref = "cnn";
      for (var r in CNN_FB_user.accounts.fb) {
        CNN_FB_user.accounts.fb[r] = "";
      }
      CNN_setCookie("profile.lastNewsID", "fbfriends", 24 * 30 * 12, "/", document.domain);
      CNN_setCookie("CNN_memberID", Object.toJSON(CNN_FB_user), 854400, "/", document.domain);
      if (Member.isLoggedIn("cnn")) {
        Member.cnnDisconnectFB();
      } else {
        CNN_setCookie("cnnfb.hasDisconnected", 1, 24 * 30 * 12, "/", document.domain);
        window.location.reload();
      }
    },
    setActivityFlag: function () {
      if (Member.hasDisconnected()) {
        CNN_setCookie("cnnfb.hasDisconnected", 0, 24 * 30 * 12, "/", document.domain);
        window.location.reload();
      } else {
        CNN_handleOverlay("fb_turn_off_overlay");
        CNN_setCookie("cnnfb.hasDisconnected", 1, 24 * 30 * 12, "/", document.domain);
      }
    },
    getProfile: function (t) {
      var s = (t) ? true : false;
      var r = {
        params: {
          "format": "jsonp"
        },
        onSuccess: function (u) {
          var v = u.responseJSON;
          if (v && v.errors) {} else {
            if (v && v.status == "success") {
              Member.setUserDataCNN(u.responseJSON, s);
            }
          }
        }
      };
      Member.getID(r);
    },
    getProfileJSON: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "getProfileJSON",
        requiredParams: []
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in getProfileJSON method");
    },
    updateProfile: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "updateProfile",
        requiredParams: []
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in updateProfile method");
    },
    getID: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "getID",
        requiredParams: []
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in updateProfile method");
    },
    getData: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "getData",
        requiredParams: ["name"]
      };
      var r = e(s, t);
      (r) ? f(r) : m(c + arguments.callee);
      return r;
    },
    setData: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "setData",
        requiredParams: ["name", "data"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in setData method");
    },
    appendData: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "appendData",
        requiredParams: ["name", "data"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in appendData method");
    },
    prependData: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "prependData",
        requiredParams: ["name", "data"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in prependData method");
    },
    getEmails: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "getEmails",
        requiredParams: []
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in getEmails method");
    },
    deleteEmail: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "setData",
        requiredParams: ["email"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in deleteEmail method");
    },
    changePrimaryEmail: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "changePrimaryEmail",
        requiredParams: ["email"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in changePrimaryEmail method");
    },
    addEmail: function (s) {
      var t = {
        flow: "cnn-user-api",
        action: "addEmail",
        requiredParams: ["email"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in api method");
    },
    sendResetPasswordCode: function (s) {
      var t = {
        flow: "cnn-passwordRecovery-api",
        action: "sendResetPasswordCode",
        requiredParams: ["email"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in api method");
    },
    changePassword: function (s) {
      var t = {
        flow: "cnn-passwordRecovery-api",
        action: "changePassword",
        requiredParams: ["email", "resetCode", "password"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in api method");
    },
    getNewsletter: function (s) {
      var t = {
        flow: "cnn-newsletter-api",
        action: "getNewsletter",
        requiredParams: ["name"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in api method");
    },
    getNewsletters: function (s) {
      var t = {
        flow: "cnn-newsletter-api",
        action: "getNewsletters",
        requiredParams: []
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in api method");
    },
    removeNewsletter: function (s) {
      var t = {
        flow: "cnn-newsletter-api",
        action: "removeNewsletter",
        requiredParams: ["email", "newsletter"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in api method");
    },
    addNewsletter: function (s) {
      var t = {
        flow: "cnn-newsletter-api",
        action: "addNewsletter",
        requiredParams: ["email", "newsletter"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in api method");
    },
    getActiveAndPendingNewsletters: function (s) {
      var t = {
        flow: "cnn-newsletter-api",
        action: "getActiveAndPendingNewsletters",
        requiredParams: []
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in api method");
    },
    getAlerts: function (s) {
      var t = {
        flow: "cnn-alert-api",
        action: "getAlerts",
        requiredParams: []
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    removeAlerts: function (s) {
      var t = {
        flow: "cnn-alert-api",
        action: "removeAlerts",
        requiredParams: ["alertId"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    getAlert: function (s) {
      var t = {
        flow: "cnn-alert-api",
        action: "getAlert",
        requiredParams: ["alertId"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    addAlert: function (s) {
      var t = {
        flow: "cnn-alert-api",
        action: "addAlert",
        requiredParams: ["email", "name", "include", "exclude", "format", "frequency"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    suspendAlerts: function (s) {
      var t = {
        flow: "cnn-alert-api",
        action: "suspendAlerts",
        requiredParams: ["alertId"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    updateAlert: function (s) {
      var t = {
        flow: "cnn-alert-api",
        action: "updateAlert",
        requiredParams: ["email", "name", "include", "exclude", "format", "frequency"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    activateAlerts: function (s) {
      var t = {
        flow: "cnn-alert-api",
        action: "activateAlerts",
        requiredParams: ["alertId"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    fb_login: function (u) {
      var s = CSIManager.getInstance();
      var r = Object.toQueryString(u) + "&callback=Member.loginCallbackFB";
      var t = {
        url: d + "facebook-link-external-account-on-login",
        args: r,
        domId: false,
        breakCache: true
      };
      s.callObject(t);
    },
    register: function (t) {
      var r = CSIManager.getInstance();
      var s = {
        url: p + "register.api",
        args: t,
        domId: false,
        breakCache: true
      };
      r.callObject(s);
    },
    fb_register: function (t) {
      var r = CSIManager.getInstance();
      var s = {
        url: d + "fb-register-api",
        args: t,
        domId: false,
        breakCache: true
      };
      r.callObject(s);
    },
    fullLogout: function () {
      if (Member.isLoggedIn("facebook") && Member.isConnected()) {
        CNN_handleOverlay("fb_signedout_overlay");
      } else {
        Member.executeFullLogout();
      }
    },
    executeFullLogout: function () {
      if (Member.isLoggedIn("facebook") && Member.isConnected()) {
        FB.logout(function (r) {
          Member.clearStoredDataIdentities("all");
          if (Member.isLoggedIn("cnn")) {
            Member.logout();
          }
        });
      } else {
        if (Member.isLoggedIn("cnn")) {
          Member.logout();
        }
      }
    },
    isConnected: function () {
      return CNN_FB_data.fb.connectedStatus;
    },
    logout: function () {
      var r = CSIManager.getInstance();
      var s = {
        url: d + "cnn-logout-api",
        args: "callback=Member.logoutCallback&doSso=false",
        domId: false,
        breakCache: true
      };
      r.callObject(s);
    },
    logoutCallback: function (r) {
      var v = r || false;
      if (v) {
        Member.clearStoredDataIdentities("all");
        var t = CSIManager.getInstance();
        var u = "assertionConsumerUrl=http://www.disqus.com/saml/cnn/logout/";
        u += "&target=http://audience.cnn.com/services/cnn/blank.api?callback=Member.logoutCallback";
        var s = {
          url: "http://audience.cnn.com/services/cnn/flow/cnn-sso",
          args: u,
          domId: false,
          breakCache: true
        };
        t.callObject(s);
      } else {
        Member.executeCookieCopy(true);
      }
    },
    facebookLinkExternalAccountOnLogin: function (s) {
      var t = {
        flow: "facebook-link-external-account-on-login",
        action: "",
        requiredParams: ["facebookUserId", "principalType"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    facebookLinkExternalAccountLoggedIn: function (s) {
      var t = {
        flow: "facebook-link-external-account-loggedin",
        action: "",
        requiredParams: ["facebookUserId", "principalType"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    facebookLinkExternalAccount: function (s) {
      var t = {
        flow: "facebook-link-external-account",
        action: "",
        requiredParams: ["facebookUserId", "principalType"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    fbConnect: function (s) {
      var t = {
        flow: "fb-connect",
        action: "",
        requiredParams: ["facebookUserId"]
      };
      var r = e(s, t);
      (r) ? f(r) : m("error in method");
    },
    connectAppOnly: function (r) {
      location.reload();
    },
    facebookDiscAccount: function (r) {
      FB.api({
        method: "auth.revokeAuthorization",
        uid: FB.getAuthResponse().userID
      }, function (s) {
        Member.setDisconnectPrefs("cnn");
      });
    },
    cnnDisconnectFB: function () {
      var t = CSIManager.getInstance();
      if (CNN_FB_user.avatar === "fb") {
        function s(v) {
          var w = v;
          if (w.contentWindow) {
            w = w.contentWindow;
          }
          if (w.contentDocument) {
            w = w.contentDocument;
          }
          if (w.document) {
            w = w.document;
          }
          return w;
        }
        var u = s($("avatarRemoveFrame")).getElementById("uploadForm");
        u.submit();
      }
      var r = {
        params: {
          "avatarPref": "cnn",
          "idPref": "cnn",
          "fbName": "",
          "prefChosen": false
        },
        onSuccess: function (v) {
          var w = v.responseJSON;
          if (w && w.errors) {} else {
            if (w && w.status == "success") {
              var y = {
                url: d + "ma-remove",
                args: "authorityTypeToRemove=3",
                domId: false,
                breakCache: false
              };
              t.callObject(y);
              CNN_setCookie("cnnfb.hasDisconnected", 1, 24 * 30 * 12, "/", document.domain);
              window.location.reload();
            }
          }
        }
      };
      Member.updateProfile(r);
    },
    reloadPage: function () {
      if (window.location.href.indexOf("?") > -1) {
        window.location.href = window.location.href.substr(0, window.location.href.indexOf("?"));
      } else {
        window.location.href = window.location.href;
      }
    },
    executeCookieCopy: function (r) {
      allCookies = CNN_getCookies();
      var w = allCookies["authid"] || null;
      var y = allCookies["CNNid"] || null;
      var v = allCookies["authpass"] || null;
      var t = allCookies["firstName"] || null;
      var s = allCookies["displayname"] || null;
      var u = (r) ? "http://audience.ireport.com/services/cnn/cookiecopy.api?drop=true&url=" + escape(CNN.Page.getRefURL({
        "is_LR": "1"
      })) : "http://audience.ireport.com/services/cnn/cookiecopy.api?cnnid=" + y + "&authid=" + w + "&authpass=" + v + "&displayname=" + s + "&firstName=" + t + "&url=" + escape(CNN.Page.getRefURL({
        "is_LR": "1"
      })) + "&keepMeLoggedIn=" + Member.getRememberMe();
      window.location.href = u;
    },
    login: function (t) {
      var s = CSIManager.getInstance();
      var r = Object.toQueryString(t) + "&callback=Member.loginCallback";
      var u = {
        url: d + "cnn-login-api",
        args: r,
        domId: false,
        breakCache: true
      };
      s.callObject(u);
    },
    loginCallbackFB: function (r) {
      CNN_setCookie("profile.lastNewsID", "fbfriends", 24 * 30 * 12, "/", document.domain);
      CNN_setCookie("cnnfb.hasDisconnected", 0, 24 * 30 * 12, "/", document.domain);
      Member.loginCallback(r, true);
    },
    loginCallback: function (s, t) {
      var y = s || false;
      var r = (t) ? true : false;
      if (s && s.status) {
        if (s.status == "error") {
          for (i in s.errors) {
            switch (s.errors[i]) {
              case "invalid password":
                cnnConnectOverlayLoginValidationError("clear");
                cnnConnectOverlayLoginValidationError("add", "Your email address or password doesn't match our records. Please try again.");
                cnnConnectOverlayLoginValidationError("show");
                break;
            }
          }
          return;
        }
      }
      if (y) {
        var w = CSIManager.getInstance();
        var v = "assertionConsumerUrl=http://www.disqus.com/saml/cnn/postback/";
        if (r) {
          v += "&target=" + d + "cnn-blank-api?callback=Member.loginCallbackFB";
        } else {
          v += "&target=" + d + "cnn-blank-api?callback=Member.loginCallback";
        }
        var u = {
          url: "http://audience.cnn.com/services/cnn/flow/cnn-sso",
          args: v,
          domId: false,
          breakCache: true
        };
        w.callObject(u);
      } else {
        Member.getProfile(r);
      }
    },
    loginCallbackFbCnctRec: function () {
      Member.getProfile(true);
    },
    loginCallbackFBCnct: function () {
      CNN_setCookie("cnnfb.hasDisconnected", 0, 24 * 30 * 12, "/", document.domain);
      Member.setRememberMe(true);
      var t = CSIManager.getInstance();
      var s = "assertionConsumerUrl=http://www.disqus.com/saml/cnn/postback/";
      s += "&target=" + d + "cnn-blank-api?callback=Member.loginCallback";
      var r = {
        url: "http://audience.cnn.com/services/cnn/flow/cnn-sso",
        args: s,
        domId: false,
        breakCache: true
      };
      t.callObject(r);
    },
    hasDisconnected: function () {
      allCookies = CNN_getCookies();
      return (allCookies["cnnfb.hasDisconnected"] == 1) ? true : false;
    },
    isLoggedIn: function (r) {
      allCookies = CNN_getCookies();
      switch (r) {
        case "facebook":
          return CNN_FB_data.fb.loginStatus;
          break;
        case "cnn":
          var s = allCookies["authid"] || null;
          if (s == null) {
            return false;
          } else {
            return true;
          }
          break;
      }
    }
  };
  return h;
}();

function fbSessionHandler(a) {
  if (!a.session) {
    return;
  }
  if (a.status == "connected") {
    if (typeof Dsq !== "undefined") {
      if (Dsq.CNN !== undefined && Dsq.CNN.authenticateFacebookUser !== undefined) {
        Dsq.CNN.authenticateFacebookUser(FB.getAuthResponse().userID);
      }
    }
  }
  var b = {
    params: {
      facebookUserId: FB.getAuthResponse().userID,
      principalType: "FACEBOOK"
    },
    onSuccess: function (f) {
      var e = f.responseJSON.status;
      if (e == "need register") {
        if (allCookies["CNN_member"]) {
          var h = new Overlay("fb_profile_signin_overlay");
          h.load();
        } else {
          var g = new Overlay("fb_profile_signup_overlay");
          g.load();
        }
      } else {
        if (e == "existing user") {
          Member.loginCallbackFBCnct();
        } else {
          if (e == "unavailable") {
            var d = new Overlay("fb_merge_error1_overlay");
            d.load();
          } else {
            if (e == "external authorization failed") {
              var c = new Overlay("fb_error_external");
              c.load();
            } else {
              var c = new Overlay("fb_error_general");
              c.load();
            }
          }
        }
      }
    }
  };
  if (Member.isLoggedIn("cnn")) {
    Member.facebookLinkExternalAccountLoggedIn(b);
  } else {
    Member.fbConnect(b);
  }
}

function CNN_handleOverlay(b, e) {
  if (Member.isLoggedIn("facebook")) {
    switch (b) {
      case "profile_signin_overlay":
        var d = new Overlay("fb_profile_signin_init_overlay");
        d.load();
        break;
      case "profile_signup_overlay":
        var a = new Overlay("fb_profile_signup_init_overlay");
        a.load();
        break;
      default:
        var c = new Overlay(b);
        c.load();
    }
  } else {
    switch (b) {
      case "profile_signin_overlay":
        var d = new Overlay("profile_signin_overlay_videxp");
        d.load();
        break;
      case "profile_signup_overlay":
        var a = new Overlay("profile_signup_overlay");
        a.load();
        break;
      default:
        var c = new Overlay(b);
        c.load();
    }
  }
}

function Overlay(r) {
  var o = r,
    q = [],
    s = false;
  var h = "http://" + location.host + "/.element/js/3.0/overlay/data/2.0/" + o + ".html";
  var n;
  var b = "cnnDimmer";
  var p = $(b);
  if (!p) {
    var k = new Element("div", {
      "id": "cnnDimmer"
    });
    k.setStyle({
      "backgroundColor": "#000000",
      "position": "absolute",
      "z-index": 2146483646,
      "top": "0px",
      "left": "0px",
      "opacity": "0.5",
      "display": "none",
      "z-index": "11"
    });
    document.body.appendChild(k);
  }
  var e = function () {
    return Math.max(document.documentElement["clientHeight"], document.body["scrollHeight"], document.documentElement["scrollHeight"], document.body["offsetHeight"], document.documentElement["offsetHeight"]);
  };
  var a = function () {
    return Math.max(document.documentElement["clientWidth"], document.body["scrollWidth"], document.documentElement["scrollWidth"], document.body["offsetWidth"], document.documentElement["offsetWidth"]);
  };
  var l = function () {
    return Math.max(document.viewport.getHeight(), e());
  };
  var t = function () {
    return Math.max(document.viewport.getWidth(), a());
  };
  var g = function () {
    var v = 0,
      u = 0;
    if (typeof (window.pageYOffset) == "number") {
      u = window.pageYOffset;
      v = window.pageXOffset;
    } else {
      if (document.body && (document.body.scrollLeft || document.body.scrollTop)) {
        u = document.body.scrollTop;
        v = document.body.scrollLeft;
      } else {
        if (document.documentElement && (document.documentElement.scrollLeft || document.documentElement.scrollTop)) {
          u = document.documentElement.scrollTop;
          v = document.documentElement.scrollLeft;
        }
      }
    }
    return [v, u];
  };
  var f = function () {
    var u = l() + "px";
    var v = t() + "px";
    $(b).setStyle({
      "width": v,
      "height": u
    });
  };
  var m = function () {
    if ($(o)) {
      var y = g();
      var v = $(o).getWidth();
      var w = $(o).getHeight();
      var C = document.viewport.getHeight();
      var A = document.viewport.getWidth();
      var z = y[1];
      var u = Math.floor((A / 2) - (v / 2));
      var B = Math.floor((z + (C / 2)) - (w / 2));
      if ((B + w) > e()) {
        B = ((e() - w) - 100);
      }
      B = (B <= 110) ? 110 : B;
      u = (B <= 9) ? 10 : u;
      $(o).style.top = B + "px";
      $(o).style.left = u + "px";
    }
  };
  var d = function (v, u) {
    var w = "";
    cnn_mOverlayObj = v;
    cnn_mOverlayObj.init_overlay(n);
    w = cnn_mOverlayObj.overlay_html;
    $("cnn_mOvrlycntr").update(w);
    m();
    $(o).show();
    cnn_mOverlayObj.init_events(n);
  };
  var c = function () {
    f();
    $(b).show();
    var u = "";
    u += '<div style="top: 312px; left: 356px;" class="overlay_content" id="' + o + '"><div class="cnnConnBox"><div onclick="closeOverlay(\'' + o + '\');return false;" class="overlay_close"></div><div class="signup_cont"><div class="profileoverlay_bdy p_signup"><h1>Loading...</h1><div id="facebookInfo"><p class="psigninp2" id=""></p></div></div></div></div><div class="clear"></div></div>';
    $("cnn_mOvrlycntr").update(u);
    CSIManager.getInstance().call(h, "", false, d);
  };
  return {
    load: function (u) {
      $("cnn_mOvrlycntr").update("");
      Event.observe(window, "resize", function () {
        f();
        m();
      });
      u = u || {};
      n = u;
      c();
    },
    close: function () {
      $("cnn_mOvrlycntr").update("");
      $(b).hide();
    },
    loadHLDR: function (u) {
      $("cnn_mOvrlycntr").update("");
      Event.observe(window, "resize", function () {
        f();
        m();
      });
      f();
      $(b).show();
      var v = "";
      v += '<div class="overlay_content cnn_fbcntorly cnn_fbcntstryorly" id="' + o + '"><div class="cnnConnBox"><div onclick="closeOverlay(\'' + o + '\');return false;" class="overlay_close"></div><div class="signup_cont"><div id="' + u + '"><div class="profileoverlay_bdy p_signup"><h1>Loading...</h1><div id="facebookInfo"><p class="psigninp2" id=""></p></div></div></div></div></div><div class="clear"></div></div>';
      $("cnn_mOvrlycntr").update(v);
      m();
    },
    addToQueue: function () {
      if (storage) {
        storage.dataObjects.overlayQueue.unshift(o);
        storage.put("overlayQueue", storage.dataObjects.overlayQueue);
        storage.save();
      } else {}
    },
    removeFromQueue: function (u) {}
  };
}
var cnn_OvrlyIEvents = {};

function CNN_FBpsnlzdOO() {
  allCookies = CNN_getCookies();
  var a = Member.hasDisconnected();
  var b = "";
  if (Member.isLoggedIn("facebook") && !a) {
    b += 'Using Facebook, you can now see what your friends are recommending and sharing on CNN. To learn more, or to disable this feature, go to <a href="/profile/?setTab=mysettings">settings</a>.';
  } else {
    b += "Using Facebook, you can now see the most recommended CNN stories. Facebook user? If so, <a href=\"javascript:CNN_handleOverlay('profile_signin_overlay');\">log in</a> to see your friends' activity on CNN.";
  }
  $("cnn_FBawOLYM").update(b);
  $("cnn_FBawDIM").removeClassName("cnn_dynone");
  $("cnn_FBawOLY").removeClassName("cnn_dynone");
}

function CNN_FBpsnlzdOC() {
  $("cnn_FBawOLY").addClassName("cnn_dynone");
  $("cnn_FBawDIM").addClassName("cnn_dynone");
}

function closeOverlay(a) {
  $("cnn_mOvrlycntr").update("");
  $("cnnDimmer").hide();
}

function showOverlay(b) {
  $("cnn_mOvrlycntr").update("");
  var a = new Overlay(b);
  a.load();
}

function closeCSIOverlay(a) {
  $("cnn_mOvrlycntr").update("");
  $("cnnDimmer").hide();
}

function showCSIOverlay(b) {
  $("cnn_mOvrlycntr").update("");
  var a = new Overlay(b);
  a.load();
}

function validateEmail(b) {
  var a = /^([a-zA-Z0-9_\.\'\-\+])+\@(([a-zA-Z0-9\-])+\.)+([a-zA-Z0-9]{2,4})+$/;
  return a.test(b);
}

function validate_signin() {
  var c = $("cnnConnectFormLogin").serialize(true);
  var h = "cnnConnectFormLogin";
  var e = $(h).email.value;
  var d = $(h).password.value;
  var g = $(h).cnnRememberMe.checked;
  var f = true;
  var a = "Registration isn't complete without your ";
  var b = [];
  if (validateEmail(e) == false) {
    f = false;
    b[b.length] = "e-mail address";
    $("psigninp2_email").addClassName("redtexterror");
    $(h).email.className = "redinput_error";
  }
  if (d == "") {
    f = false;
    $("psigninp2_password").addClassName("redtexterror");
    b[b.length] = "password";
    $(h).password.className = "redinput_error";
  }
  if (f) {
    if (c.cnnRememberMe === "on") {
      document.cnnConnectFormLogin.keepMeLoggedIn.value = true;
      Member.setRememberMe(true);
    } else {
      document.cnnConnectFormLogin.keepMeLoggedIn.value = false;
      Member.setRememberMe(false);
    }
    c.doSso = false;
    document.cnnConnectFormLogin.submit();
  } else {
    cnnConnectOverlayLoginValidationError("clear");
    if (b.length == 2) {
      cnnConnectOverlayLoginValidationError("add", "We need your " + b[0] + " and " + b[1] + " to log in.");
    } else {
      if (b[0] == "e-mail address" && validateEmail(e) == false && e != "") {
        cnnConnectOverlayLoginValidationError("add", "You entered an invalid e-mail address.");
      } else {
        if (b[0] == "e-mail address" && e == "") {
          cnnConnectOverlayLoginValidationError("add", "We need your " + b[0] + " to log in.");
        } else {
          cnnConnectOverlayLoginValidationError("add", "We need your " + b[0] + " to log in.");
        }
      }
    }
    cnnConnectOverlayLoginValidationError("show");
  }
}

function validate_signinFB() {
  var c = $("cnnConnectFormLogin").serialize(true);
  var h = "cnnConnectFormLogin";
  var e = $(h).email.value;
  var d = $(h).password.value;
  var g = $(h).cnnRememberMe.checked;
  var f = true;
  var a = "Registration isn't complete without your ";
  var b = [];
  if (validateEmail(e) == false) {
    f = false;
    b[b.length] = "e-mail address";
    $("psigninp2_email").addClassName("redtexterror");
    $(h).email.className = "redinput_error";
  }
  if (d == "") {
    f = false;
    $("psigninp2_password").addClassName("redtexterror");
    b[b.length] = "password";
    $(h).password.className = "redinput_error";
  }
  if (f) {
    if (c.cnnRememberMe === "on") {
      document.cnnConnectFormLogin.keepMeLoggedIn.value = true;
      Member.setRememberMe(true);
    } else {
      document.cnnConnectFormLogin.keepMeLoggedIn.value = false;
      Member.setRememberMe(false);
    }
    c.doSso = false;
    document.cnnConnectFormLogin.submit();
  } else {
    cnnConnectOverlayLoginValidationError("clear");
    if (b.length == 2) {
      cnnConnectOverlayLoginValidationError("add", "We need your " + b[0] + " and " + b[1] + " to log in.");
    } else {
      if (b[0] == "e-mail address" && validateEmail(e) == false && e != "") {
        cnnConnectOverlayLoginValidationError("add", "You entered an invalid e-mail address.");
      } else {
        if (b[0] == "e-mail address" && e == "") {
          cnnConnectOverlayLoginValidationError("add", "We need your " + b[0] + " to log in.");
        } else {
          cnnConnectOverlayLoginValidationError("add", "We need your " + b[0] + " to log in.");
        }
      }
    }
    cnnConnectOverlayLoginValidationError("show");
  }
}

function registerHandler(b) {
  if (b.status == "success") {
    if (Member.isConnected()) {
      FB.api({
        method: "fql.query",
        query: "SELECT name, pic_square FROM profile WHERE id=" + FB.getAuthResponse().userID
      }, function (d) {
        var c = d[0];
        var e = {
          params: {
            facebookUserId: FB.getAuthResponse().userID,
            principalType: "FACEBOOK"
          },
          onSuccess: function (g) {
            if (g.responseJSON.status == "existing user") {
              Member.loginCallbackFBCnct();
            }
            if (g.responseJSON.status == "unavailable") {
              var f = new Overlay("fb_merge_error1_overlay");
              f.load();
            }
            if (g.responseJSON.status == "need register") {
              if (allCookies["CNN_member"]) {
                var k = new Overlay("fb_profile_signin_overlay");
                k.load();
              } else {
                var h = new Overlay("fb_profile_signup_overlay");
                h.load();
              }
            }
          }
        };
        Member.facebookLinkExternalAccountLoggedIn(e);
      });
    } else {
      Member.getProfile();
    }
  } else {
    if (b.errors) {
      cnnConnectOverlayError("clearErrorText");
      if ($("cnnConnectKaptchaImage")) {
        generateKaptchaImage();
      }
      for (var a = 0; a < b.errors.length; a++) {
        switch (b.errors[a]) {
          case "email address not available":
            cnnConnectOverlayRegisterError("email");
            cnnConnectOverlayError("addErrorText", "That e-mail address is already taken.<br/>");
            break;
          case "missing email address":
            cnnConnectOverlayRegisterError("email");
            cnnConnectOverlayError("addErrorText", "You forgot to enter your e-mail address.<br/>");
            break;
          case "bad email address":
            cnnConnectOverlayRegisterError("email");
            cnnConnectOverlayError("addErrorText", "You entered an invalid e-mail address.<br/>");
            break;
          case "missing password":
            cnnConnectOverlayRegisterError("password");
            cnnConnectOverlayError("addErrorText", "You forgot to enter your password.<br/>");
            break;
          case "bad password":
            cnnConnectOverlayRegisterError("password");
            cnnConnectOverlayError("addErrorText", "You entered an invalid password.<br/>");
            break;
          case "missing screen name":
            cnnConnectOverlayRegisterError("screenName");
            cnnConnectOverlayError("addErrorText", "You forgot to enter your screen name.<br/>");
            break;
          case "screen name not available":
            cnnConnectOverlayRegisterError("screenName");
            cnnConnectOverlayError("addErrorText", "That screen name is already taken. Please choose another.<br/>");
            break;
          case "missing captcha":
            cnnConnectOverlayRegisterError("captcha");
            cnnConnectOverlayError("addErrorText", "You forgot to type in the security word in the grey box.<br/>");
            break;
          case "bad captcha":
            cnnConnectOverlayRegisterError("captcha");
            cnnConnectOverlayError("addErrorText", "You entered the security word in the grey box incorrectly.<br/>");
            break;
          case "missing privacy policy":
            cnnConnectOverlayError("addErrorText", "You must agree to the privacy policy.<br/>");
            break;
          default:
            break;
        }
      }
      cnnConnectOverlayError("showErrorText");
    }
  }
}

function validate_register2() {
  newuser = true;
  var h = "cnnConnectFormRegister";
  var e = $(h).email.value.trim();
  var l = $(h).password.value;
  var c = $(h).displayname.value.trim();
  $(h).displayname.value = c;
  var a = "domestic_version";
  var n = "";
  var k = true;
  var d = "A required field is missing! Registration isn't complete without your ";
  var m = [];
  if (e == "" || validateEmail(e) == false) {
    k = false;
    m[m.length] = "e-mail address";
    cnnConnectOverlayRegisterError("email");
  } else {
    $("cnnConnectFormRegister").email.className = "cnnConnectFormbg1 cnn_connectoverlay_email2";
    $("signup_email").previous("p").removeClassName("redtexterror");
  }
  if (l == "") {
    k = false;
    m[m.length] = "password";
    cnnConnectOverlayRegisterError("password");
  } else {
    if (l.length < 6 || l.indexOf(" ") != -1 || l.length > 10) {
      k = false;
      cnnConnectOverlayRegisterError("password");
      cnnConnectOverlayError("errorText", "You entered an invalid password.");
      return;
    } else {
      $("cnnConnectFormRegister").password.className = "cnnConnectFormbg2 cnn_connectoverlay_password2";
      $("signup_password").previous("p").removeClassName("redtexterror");
    }
  }
  var g = /^\w+$/;
  if (c == "") {
    k = false;
    m[m.length] = "screen name";
    cnnConnectOverlayRegisterError("screenName");
  } else {
    if (c.length < 3) {
      k = false;
      cnnConnectOverlayRegisterError("screenName");
      cnnConnectOverlayError("errorText", "The screen name that you entered is too short.");
      return;
    } else {
      if (c.length > 12) {
        k = false;
        cnnConnectOverlayRegisterError("screenName");
        cnnConnectOverlayError("errorText", "Your screen name must be 3-12 characters; numbers and letters only.");
        return;
      } else {
        if (g.test(c) == false) {
          k = false;
          cnnConnectOverlayRegisterError("screenName");
          cnnConnectOverlayError("errorText", "Your screen name includes invalid characters.");
          return;
        } else {
          $("cnnConnectFormRegister").displayname.className = "cnnConnectFormbg3 cnn_connectoverlay_displayname";
          $("signup_displayname").previous("p").removeClassName("redtexterror");
        }
      }
    }
  }
  if (k == true) {
    var f = $("cnnConnectFormRegister").serialize();
    document.cnnConnectFormRegister.submit();
  } else {
    switch (m.length) {
      case 1:
        if (m[0] == "e-mail address" && validateEmail(e) == false && e != "") {
          d = "You entered an invalid e-mail address.";
        } else {
          if (m[0] == "e-mail address" && e == "") {
            d += m[0];
          } else {
            d += m[0];
          }
        }
        break;
      case 2:
        d += m[0] + " and " + m[1];
        break;
      default:
        for (var b = 0; b < m.length; b++) {
          d += (b == (m.length - 1)) ? "and " + m[b] + "." : m[b] + ", ";
        }
        break;
    }
    cnnConnectOverlayError("errorText", d);
  }
}

function validate_register() {
  newuser = true;
  var h = "cnnConnectFormRegister";
  var e = $(h).email.value.trim();
  var l = $(h).password.value;
  var c = $(h).displayname.value.trim();
  $(h).displayname.value = c;
  var m = $(h).kaptcha.value;
  var a = "domestic_version";
  var o = "";
  if ($(h).specialOffers.checked == true) {
    o = "member_services";
  }
  var k = true;
  var d = "A required field is missing! Registration isn't complete without your ";
  var n = [];
  if (e == "" || validateEmail(e) == false) {
    k = false;
    n[n.length] = "e-mail address";
    cnnConnectOverlayRegisterError("email");
  } else {
    $("cnnConnectFormRegister").email.className = "cnnConnectFormbg1 cnn_connectoverlay_email2";
    $("signup_email").previous("p").removeClassName("redtexterror");
  }
  if (l == "") {
    k = false;
    n[n.length] = "password";
    cnnConnectOverlayRegisterError("password");
  } else {
    if (l.length < 6 || l.indexOf(" ") != -1 || l.length > 10) {
      k = false;
      cnnConnectOverlayRegisterError("password");
      cnnConnectOverlayError("errorText", "You entered an invalid password.");
      return;
    } else {
      $("cnnConnectFormRegister").password.className = "cnnConnectFormbg2 cnn_connectoverlay_password2";
      $("signup_password").previous("p").removeClassName("redtexterror");
    }
  }
  var g = /^\w+$/;
  if (c == "") {
    k = false;
    n[n.length] = "screen name";
    cnnConnectOverlayRegisterError("screenName");
  } else {
    if (c.length < 3) {
      k = false;
      cnnConnectOverlayRegisterError("screenName");
      cnnConnectOverlayError("errorText", "The screen name that you entered is too short.");
      return;
    } else {
      if (c.length > 12) {
        k = false;
        cnnConnectOverlayRegisterError("screenName");
        cnnConnectOverlayError("errorText", "Your screen name must be 3-12 characters; numbers and letters only.");
        return;
      } else {
        if (g.test(c) == false) {
          k = false;
          cnnConnectOverlayRegisterError("screenName");
          cnnConnectOverlayError("errorText", "Your screen name includes invalid characters.");
          return;
        } else {
          $("cnnConnectFormRegister").displayname.className = "cnnConnectFormbg3 cnn_connectoverlay_displayname";
          $("signup_displayname").previous("p").removeClassName("redtexterror");
        }
      }
    }
  }
  if (m == "") {
    k = false;
    generateKaptchaImage();
    n[n.length] = "security word";
    cnnConnectOverlayRegisterError("kaptcha");
    cnnConnectOverlayError("errorText", "You must enter a security word.");
  } else {
    $("cnnConnectFormRegister").kaptcha.className = "cnnConnectFormbg4 cnn_connectoverlay_enterit";
    $("signup_kaptcha_p1").removeClassName("redtexterror");
  }
  if (k == true) {
    var f = $("cnnConnectFormRegister").serialize();
    document.cnnConnectFormRegister.submit();
  } else {
    switch (n.length) {
      case 1:
        if (n[0] == "e-mail address" && validateEmail(e) == false && e != "") {
          d = "You entered an invalid e-mail address.";
        } else {
          if (n[0] == "e-mail address" && e == "") {
            d += n[0];
          } else {
            d += n[0];
          }
        }
        break;
      case 2:
        d += n[0] + " and " + n[1];
        break;
      default:
        for (var b = 0; b < n.length; b++) {
          d += (b == (n.length - 1)) ? "and " + n[b] + "." : n[b] + ", ";
        }
        break;
    }
    cnnConnectOverlayError("errorText", d);
  }
}

function validateResetEmail() {
  var c = "cnnConnectFormForgot";
  var b = $(c).email.value;
  if (validateEmail(b) == false) {
    cnnConnectOverlayForgotValidationError("clear");
    cnnConnectOverlayForgotValidationError("add", "You must enter your e-mail address to reset your password.");
    cnnConnectOverlayForgotValidationError("show");
  } else {
    var a = {
      params: {
        "email": b
      },
      onSuccess: function (d) {
        var f = d.responseJSON;
        if (f && f.errors) {
          cnnConnectOverlayForgotValidationError("clear");
          for (var e = 0; e < f.errors.length; e++) {
            switch (f.errors[e]) {
              case "User not found":
                cnnConnectOverlayForgotValidationError("add", "Your e-mail address doesn't match our records. Please try again.");
                break;
              case "You have recently requested to reset your password.  You must wait before requesting another reset.":
                cnnConnectOverlayForgotValidationError("add", "You have recently requested to reset your password.  You must wait before requesting another reset.");
                break;
              default:
                cnnConnectOverlayForgotValidationError("add", f.errors[e]);
                break;
            }
          }
          cnnConnectOverlayForgotValidationError("show");
        } else {
          if (f && f.status == "success") {
            cnnConnectOverlayUpdate("forgot2reset");
          }
        }
      }
    };
    Member.sendResetPasswordCode(a);
  }
}

function validateSetUserPassword() {
  var g = "cnnConnectFormReset";
  var e = $(g).email.value;
  var f = $(g).resetCode.value;
  var k = $(g).newPassword.value;
  var a = k;
  var h = true;
  var d = "Reset Password isn't complete without your ";
  var l = [];
  if (validateEmail(e) == false || e == "Email Address") {
    h = false;
    l[l.length] = "e-mail address";
    cnnConnectOverlayResetError("email");
  } else {
    $("new_password_email").previous("p").removeClassName("redtexterror");
    $("cnnConnectFormReset").email.className = "cnn_connectoverlay_email3 cnnredtxt";
  }
  if (f == "" || f == "Reset Code") {
    h = false;
    l[l.length] = "reset code";
    cnnConnectOverlayResetError("resetCode");
  } else {
    $("reset_code").previous("p").removeClassName("redtexterror");
    $("cnnConnectFormReset").resetCode.className = "cnn_connectoverlay_password3 cnnredtxt";
  }
  if (k == "" || k == "New Password") {
    h = false;
    l[l.length] = "new password";
    cnnConnectOverlayResetError("newPassword");
  } else {
    $("new_password").previous("p").removeClassName("redtexterror");
    $("cnnConnectFormReset").newPassword.className = "cnn_connectoverlay_password4 cnnredtxt";
  }
  if (h == true) {
    var c = {
      params: {
        "email": e,
        "resetCode": f,
        "password": k,
        "confirmPassword": a
      },
      onSuccess: function (m) {
        var o = m.responseJSON;
        if (o && o.errors) {
          cnnConnectOverlayResetValidationError("clear");
          for (var n = 0; n < o.errors.length; n++) {
            switch (o.errors[n]) {
              case "missing email address":
                cnnConnectOverlayResetError("email");
                cnnConnectOverlayResetValidationError("add", "You forgot to enter your e-mail address.<br/>");
                break;
              case "profile not found":
                cnnConnectOverlayResetError("email");
                cnnConnectOverlayResetValidationError("add", "Your e-mail address or reset code doesn't match our records. Please try again.<br/>");
                break;
              case "missing new password":
                cnnConnectOverlayResetError("newPassword");
                cnnConnectOverlayResetValidationError("add", "You forgot to enter your new password.<br/>");
                break;
              case "missing confirm new password":
                cnnConnectOverlayResetError("confirmNewPassword");
                cnnConnectOverlayResetValidationError("add", "You forgot to confirm your new password.<br/>");
                break;
              case "confirm password did not match":
                cnnConnectOverlayResetError("newPassword");
                cnnConnectOverlayResetError("confirmNewPassword");
                cnnConnectOverlayResetValidationError("add", "Your passwords do not match.<br/>");
                break;
              case "reset code has expired":
                cnnConnectOverlayResetError("resetCode");
                cnnConnectOverlayResetValidationError("add", "Your reset code has expired. <a href=\"javascript: void(0);\" onclick=\"closeOverlay('profile_forgotpass2_overlay');showOverlay('profile_forgotpass_overlay');\">Send another e-mail</a> with an updated link and reset code to reset your password.<br/>");
                break;
              case "The reset code does not match our records":
                cnnConnectOverlayResetError("resetCode");
                cnnConnectOverlayResetValidationError("add", "Your reset code does not match our records. <a href=\"javascript: void(0);\" onclick=\"closeOverlay('profile_forgotpass2_overlay');showOverlay('profile_forgotpass_overlay');\">Send another e-mail</a> with an updated link and reset code to reset your password.<br/>");
                break;
              default:
                cnnConnectOverlayResetError("default");
                cnnConnectOverlayResetValidationError("add", "We're sorry! This service is temporarily unavailable. Please try again soon.");
                break;
            }
          }
          cnnConnectOverlayResetValidationError("show");
        } else {
          if (o && o.status == "success") {
            cnnConnectOverlayUpdate("reset2loginsuccess");
          }
        }
      }
    };
    Member.changePassword(c);
  } else {
    cnnConnectOverlayResetValidationError("clear");
    switch (l.length) {
      case 1:
        d += l[0] + ".";
        break;
      case 2:
        d += l[0] + " and " + l[1] + ".";
        break;
      default:
        for (var b = 0; b < l.length; b++) {
          d += (b == (l.length - 1)) ? "and " + l[b] + "." : l[b] + ", ";
        }
        break;
    }
    cnnConnectOverlayResetValidationError("add", d);
    cnnConnectOverlayResetValidationError("show");
  }
}

function generateKaptchaImage() {
  var a = getRandomId();
  $("cnnConnectKaptchaImage").src = ms_baseStandard + "kaptcha?challenge_id=" + a;
  $("cnnConnectKaptchaImage").width = "200";
  $("cnnConnectKaptchaImage").height = "50";
  $("cnnConnectFormRegister").kaptcha.value = "";
}
if (Object.isUndefined(CNNO)) {
  var CNNO = Class.create({
    "chars": "0123456789ABCDEFGHIJKLMNOPQRSTUVWXTZabcdefghiklmnopqrstuvwxyz",
    "randomStr": function (a) {
      var d = "";
      for (var c = 0; c < a; c++) {
        var b = Math.floor(Math.random() * this.chars.length);
        d += this.chars.substring(b, b + 1);
      }
      return d;
    },
    "Page": {
      "cleanURL": (window.location.href.indexOf("?") > -1) ? window.location.href.substr(0, window.location.href.indexOf("?")) : window.location.href,
      "urlArgs": "",
      "refresh": function (b, a) {
        location.href = this.getRefURL(b, a);
      },
      "getRefURL": function (h, b) {
        if (Object.isUndefined(h)) {
          h = {};
        }
        if (Object.isUndefined(b)) {
          b = {};
        }
        b.cnncb = 1;
        b.cnnqueue = 1;
        var a = this.urlNameVals();
        var g = "";
        var e = [];
        for (var d in a) {
          if (!b[d] && !h[d] && a[d]) {
            e.push(d + "=" + a[d]);
          }
        }
        for (var d in h) {
          if (h[d]) {
            e.push(d + "=" + h[d]);
          }
        }
        g = e.join("&");
        var c = this.cleanURL + "?";
        if (g) {
          c += g;
        }
        var f = CNNO.prototype.Overlay.queue.join("_");
        if (f) {
          if (g) {
            c += "&";
          }
          c += "cnnqueue=" + f;
        }
        return c;
      },
      "urlNameVals": function () {
        var b = new Object();
        var f = location.search.substring(1);
        var e = f.split("&");
        for (var c = 0; c < e.length; c++) {
          var g = e[c].indexOf("=");
          if (g == -1) {
            continue;
          }
          var a = e[c].substring(0, g);
          var d = e[c].substring(g + 1);
          b[a] = unescape(d);
        }
        this.urlArgs = b;
        return b;
      }
    }
  });
}
CNNO.addMethods({
  "Profile": {
    "is_loaded": 0,
    "emails": null,
    "init": function () {},
    "loadFrames": function (b) {
      if (b == "l") {
        var a;
        try {
          a = document.createElement('<iframe name="loginFrame">');
        } catch (c) {
          a = document.createElement("iframe");
        }
        a.setAttribute("name", "loginFrame");
        a.setAttribute("height", "1");
        a.setAttribute("width", "1");
        a.setAttribute("id", "loginFrame");
        a.setAttribute("style", "height:1px;width:1px;");
        $$("body")[0].appendChild(a);
      } else {
        var d;
        try {
          d = document.createElement('<iframe name="registerFrame">');
        } catch (c) {
          d = document.createElement("iframe");
        }
        d.setAttribute("name", "registerFrame");
        d.setAttribute("height", "1");
        d.setAttribute("width", "1");
        d.setAttribute("id", "registerFrame");
        d.setAttribute("style", "height:1px;width:1px;");
        $$("body")[0].appendChild(d);
      }
    }
  }
});
CNNO.addMethods({
  "Overlay": {
    "app_dim": 0,
    "queue": [],
    "active": null,
    "t_q": null,
    "setDim": function (b) {
      if (!this.app_dim) {
        var a = document.createElement("div");
        a.id = "cnn_overlaydim";
        a.className = "cnn_overlaydim";
        $$("body")[0].appendChild(a);
        $("cnn_overlaydim").setStyle({
          "display": "none"
        });
        Event.observe(window, "resize", function () {
          CNNO.prototype.Overlay.sizeDim();
        });
        this.app_dim = 1;
      }
      CNNO.prototype.Overlay.sizeDim();
      if (b) {
        $("cnn_overlaydim").show();
      } else {
        $("cnn_overlaydim").hide();
      }
    },
    "sizeDim": function () {
      var b = document.viewport.getHeight();
      var d = document.viewport.getWidth();
      var f = Math.max(document.documentElement["clientHeight"], document.body["scrollHeight"], document.documentElement["scrollHeight"], document.body["offsetHeight"], document.documentElement["offsetHeight"]);
      var c = Math.max(document.documentElement["clientWidth"], document.body["scrollWidth"], document.documentElement["scrollWidth"], document.body["offsetWidth"], document.documentElement["offsetWidth"]);
      var e = (f > b) ? f : b;
      var a = (c > d) ? c : d;
      $("cnn_overlaydim").setStyle({
        "width": a + "px",
        "height": e + "px"
      });
    },
    "center": function (h) {
      var e = this.getsoffset();
      var a = $(h).getWidth();
      var c = $(h).getHeight();
      var l = document.viewport.getHeight();
      var b = document.viewport.getWidth();
      var m = Math.max(document.documentElement["clientHeight"], document.body["scrollHeight"], document.documentElement["scrollHeight"], document.body["offsetHeight"], document.documentElement["offsetHeight"]);
      var d = Math.max(document.documentElement["clientWidth"], document.body["scrollWidth"], document.documentElement["scrollWidth"], document.body["offsetWidth"], document.documentElement["offsetWidth"]);
      var g = e[1];
      var k = Math.floor((b / 2) - (a / 2));
      var f = Math.floor((g + (l / 2)) - (c / 2));
      if ((f + c) > m) {
        f = ((m - c) - 100);
      }
      f = (f <= 110) ? 110 : f;
      k = (f <= 9) ? 10 : k;
      $(h).style.top = f + "px";
      $(h).style.left = k + "px";
    },
    "getsoffset": function () {
      var b = 0,
        a = 0;
      if (typeof (window.pageYOffset) == "number") {
        a = window.pageYOffset;
        b = window.pageXOffset;
      } else {
        if (document.body && (document.body.scrollLeft || document.body.scrollTop)) {
          a = document.body.scrollTop;
          b = document.body.scrollLeft;
        } else {
          if (document.documentElement && (document.documentElement.scrollLeft || document.documentElement.scrollTop)) {
            a = document.documentElement.scrollTop;
            b = document.documentElement.scrollLeft;
          }
        }
      }
      return [b, a];
    },
    "close": function (a) {
      $("cnn_overlaycntnt").update();
      this.setDim(0);
    },
    "checkQ": function () {
      var a = CNNO.prototype.Page.urlNameVals();
      if (a.cnnqueue) {
        var b = a.cnnqueue.split("_");
        var c = b.shift();
        this.load(c, "auto");
      }
    },
    "data": {
      "newsletters": {
        "j_loaded": 0,
        "h_loaded": 0,
        "js": null,
        "html": null
      }
    },
    "keys": {
      "news-am": {
        "ref_name": "American Morning",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-prime": {
        "ref_name": "Prime News",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-pol": {
        "ref_name": "Politics Alerts",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-breaking": {
        "ref_name": "Breaking News Alert",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-intl-amanpour": {
        "ref_name:": "Amanpour",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-member_services": {
        "ref_name": "Marketing",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-bia": {
        "ref_name": "Black in America",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-intl-htmlasiaheadlines": {
        "ref_name": "CNN Asia editorial note",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-intl-htmleuheadlines": {
        "ref_name": "CNN Europe editorial note",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-heroes": {
        "ref_name": "CNN Heroes",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-intl-htmltravel": {
        "ref_name": "CNN Partner Hotel specials",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-health": {
        "ref_name": "Health News",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-intl-insideafrica": {
        "ref_name": "Inside Africa",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-larryking": {
        "ref_name": "Larry King Live",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-loudobbs": {
        "ref_name": "Lou Dobbs Tonight",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-rcshow": {
        "ref_name": "Morning Express",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-morninggrind": {
        "ref_name": "Political Ticker - weekday edition",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-sundaysotu": {
        "ref_name": "Political Ticker - Sunday, State of the Union edition",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-showbiz": {
        "ref_name": "Showbiz Tonight",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-situationroom": {
        "ref_name": "Situation Room",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-computing": {
        "ref_name": "Tech News",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-dailytop10": {
        "ref_name": "Todays Top Video",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-cnn-primetime": {
        "ref_name": "Tonight on CNN",
        "j_file": "newsletters",
        "h_file": "newsletters"
      },
      "news-intl-vitalsigns": {
        "ref_name": "Vital Signs",
        "j_file": "newsletters",
        "h_file": "newsletters"
      }
    },
    "qOverlay": function (a) {
      this.queue.push(a);
    },
    "clearQ": function () {
      this.queue = [];
    },
    "qRefresh": function () {
      var a = this.queue.join("_");
      CNNO.prototype.Page.refresh({
        "cnnqueue": a
      });
    },
    "callback": function (a, b) {
      if (a == "json") {
        this.data[this.keys[b].j_file].j_loaded = 1;
      }
      if (a == "html") {
        this.data[this.keys[b].h_file].h_loaded = 1;
      }
      if (this.data[this.keys[b].j_file].j_loaded && this.data[this.keys[b].h_file].h_loaded) {
        this.data[this.keys[b].j_file].js.init();
      }
    },
    "callbackCSI": function (a) {
      CNNO.prototype.Overlay.data[a.key].html = a;
      CNNO.prototype.Overlay.callback("html", CNNO.prototype.Overlay.active);
    },
    "callbackJSON": function (a) {
      this.data[a.key].js = a;
      this.callback("json", CNNO.prototype.Overlay.active);
    },
    "init": function () {
      Event.observe(document, "dom:loaded", function () {
        var a = document.createElement("div");
        a.id = "cnn_overlaycntnt";
        $$("body")[0].appendChild(a);
      });
      CNNO.prototype.Overlay.checkQ();
    },
    "load": function (a, b) {
      if (typeof (b) == "undefined") {
        b = "manual";
      }
      this.active = a;
      if (b == "auto") {
        this.t_q = a;
      } else {
        this.setDim(1);
        $("cnn_overlaycntnt").update('<div id="cnn_overlay_load" class="cnn_overlaybox cnn_overlayloading"><p align="center"><img src="http://i.cdn.turner.com/cnn/.e/img/3.0/global/misc/loading.gif">loading</p></div>');
        CNNO.prototype.Overlay.center("cnn_overlay_load");
        CNNO.prototype.Overlay.loadJSONP(a);
        CNNO.prototype.Overlay.loadHCSI(a);
      }
    },
    "triggerQ": function () {
      if (CNNO.prototype.Overlay.t_q) {
        CNNO.prototype.Overlay.setDim(1);
        $("cnn_overlaycntnt").update('<div id="cnn_overlay_load" class="cnn_overlaybox cnn_overlayloading"><p align="center"><img src="http://i.cdn.turner.com/cnn/.e/img/3.0/global/misc/loading.gif">loading</p></div>');
        CNNO.prototype.Overlay.center("cnn_overlay_load");
        CNNO.prototype.Overlay.loadJSONP(CNNO.prototype.Overlay.t_q);
        CNNO.prototype.Overlay.loadHCSI(CNNO.prototype.Overlay.t_q);
      }
    },
    "loadJSONP": function (c) {
      if (!this.data[this.keys[c].j_file].j_loaded) {
        var a = $$("head")[0];
        var b = document.createElement("script");
        b.setAttribute("src", "http://www.cnn.com/.element/js/3.0/overlay/data/js/" + this.keys[c].j_file + ".js");
        b.setAttribute("type", "text/javascript");
        a.appendChild(b);
      } else {
        this.callback("json", c);
      }
    },
    "loadHCSI": function (a) {
      if (!this.data[this.keys[a].h_file].h_loaded) {
        CSIManager.getInstance().call("http://www.cnn.com/.element/js/3.0/overlay/data/html/" + this.keys[a].j_file + ".html", "", "", CNNO.prototype.Overlay.callbackCSI);
      } else {
        this.callback("html", a);
      }
    },
    "update": function (a, b) {
      $("cnn_overlaycntnt").update(CNNO.prototype.Overlay.data[CNNO.prototype.Overlay.keys[a].j_file].html.data[b]);
      CNNO.prototype.Overlay.center("cnn_overlay_" + CNNO.prototype.Overlay.keys[a].j_file);
      CNNO.prototype.Overlay.data[CNNO.prototype.Overlay.keys[a].j_file].js.html_prep(b);
    }
  }
});
if ("undefined" === typeof (window.CNN)) {
  var CNN = {};
}

function init_CNNO() {
  var a = new CNNO();
  window["CNN"] = Object.extend(a, window["CNN"] || {});
}
init_CNNO();

function cnn_memfbini() {
  if (!CNN.Profile.is_loaded) {
    if (typeof (cnn_onMemFBinit) === "function") {
      cnn_onMemFBinit();
    }
    CNN.Profile.is_loaded = 1;
    CNN.Overlay.triggerQ();
  }
}
CNN.Overlay.init();
var MainLocalObj = {
  data: {
    weatherLoc: {
      locCode: "",
      zip: "",
      name: "",
      city: "",
      state: ""
    },
    sports: {},
    stockSymbols: [],
    prevStockSymbols: [],
    maxSymbols: 3
  },
  init: function (e) {
    this.internationalUser = (location.hostname.indexOf("edition.") > -1) ? true : false;
    this.isProfilePage = false;
    this.isUSPage = false;
    this.isPoliticsPage = false;
    this.useAccordions = false;
    this.allCookies = allCookies;
    if (typeof e !== "undefined") {
      this.disableSymbolLookup = e;
    } else {
      this.disableSymbolLookup = false;
    }
    if (this.allCookies["last5stocks"] != null) {
      var a = {};
      var b = this.allCookies["last5stocks"].split("+");
      for (var f = 0; f < b.length; f++) {
        a[b[f]] = b[f];
      }
      var d = 0;
      for (var c in a) {
        this.data.stockSymbols.push(a[c]);
        if ((++d) >= this.data.maxSymbols) {
          break;
        }
      }
      this.data.stockSymbols.reverse();
    }
    MainLocalObj.expDate = new Date(1640926800000);
    this.msUrl = "http://audience.cnn.com/services/cnn/user.api";
    this.StorageManagerInstance = StorageManager.getInstance();
    this.localDataKey = this.allCookies.CNNid + "localData2010";
    var g = [];
    var h = this.StorageManagerInstance.availableStores;
    h.each(function (k) {
      if (k.name !== "IEStorage") {
        g.push(k);
      }
    });
    this.StorageManagerInstance.availableStores = g;
    this.StorageManager = this.StorageManagerInstance.getStorage();
    this.StorageManager.load();
    if (location.hostname.indexOf("cnn.com") > 0) {
      document.domain = "cnn.com";
    }
    if (location.hostname.indexOf("turner.com") > 0) {
      document.domain = "turner.com";
    }
    this.CSIManager = CSIManager.getInstance();
    this.loadDefaultData();
  },
  initMod: function () {
    MainLocalObj.Markets.init();
    MainLocalObj.Weather.init();
  },
  setUserSpecificData: function (a) {
    this.data.userSpecificData = a;
  },
  setInternationalUser: function (a) {
    this.internationalUser = a;
  },
  setLocationZip: function (b, a) {
    this.data.weatherLoc.zip = a;
  },
  setLocationName: function (b, a) {
    this.data.weatherLoc.name = a;
  },
  setLocationLocCode: function (a, b) {
    if (a == "weather") {
      this.data.weatherLoc.locCode = b;
    }
  },
  setLocationCity: function (a, b) {
    this.data.weatherLoc.city = b;
  },
  setLocationState: function (a, b) {
    this.data.weatherLoc.state = b;
  },
  parseMSData: function (a) {
    if (typeof a.status !== "undefined" && a.status === "success" && a.data !== "") {
      this.data = a.data.evalJSON(true);
      this.data.lastMemberServicesFetch = new Date().getTime();
      this.StorageManager.put(this.localDataKey, this.data, MainLocalObj.expDate);
      this.StorageManager.save();
    } else {
      if (a.data == "") {
        this.loadDefaultData(true);
      } else {
        this.data = this.storedData;
      }
    }
    this.saveWeatherCookie();
    this.initMod();
  },
  parseWeatherCookie: function () {
    var c = this.allCookies["lwp.weather"] || null;
    var d = false;
    var e = false;
    if (c) {
      var b = unescape(c).split("|");
      var f = b[0];
      if (c.indexOf("~") == -1) {
        f = c.replace("|", "~");
      }
      var a = b[0].split("~");
      return a;
    } else {
      return [false, false];
    }
  },
  loadDefaultData: function (h) {
    if (typeof h === "undefined") {
      h = false;
    }
    this.storedData = false;
    var a = this.parseWeatherCookie();
    var f = a[0];
    var e = a[1];
    if (ms_isLoggedIn() && !h) {
      if (this.StorageManager.contains(this.localDataKey)) {
        this.storedData = this.StorageManager.get(this.localDataKey);
      }

      function g(l) {
        if (l === null || typeof l === "undefined" || (new Date().getTime() - l) > 1800000) {
          return true;
        } else {
          return false;
        }
      }
      if (g(this.storedData.lastMemberServicesFetch)) {
        var b = {
          params: {
            name: "teams"
          },
          onSuccess: function (l) {
            MainLocalObj.parseMSData(l.responseJSON);
          }
        };
        Member.getData(b);
      } else {
        if (this.storedData) {
          this.data = this.storedData;
          this.initMod();
          this.saveWeatherCookie();
        }
      }
      this.data.userSpecificData = true;
    } else {
      if (e) {
        if (this.checkZip(e)) {
          this.data.userSpecificData = true;
          this.setLocationZip("all", e);
          this.setLocationLocCode("all", f);
        } else {
          this.Weather.requestInternationalCityLookup(e, f, "all");
        }
        this.initMod();
      } else {
        if (!this.internationalUser) {
          var k = [{
            name: "Atlanta, GA",
            zip: "30303"
          }];
          var c = Math.floor(Math.random() * k.length);
          var d = k[c];
          this.setLocationZip("all", d.zip);
          this.setLocationName("all", d.name);
          this.initMod();
        } else {
          if (this.internationalUser) {
            this.setLocationZip("all", "336736767676");
            this.setLocationName("all", "London, England");
            this.initMod();
          } else {
            this.initMod();
          }
        }
      }
    }
  },
  saveWeatherCookie: function () {
    var c = this.allCookies["lwp.weather"] || null;
    var d = "";
    if (this.data) {
      d = this.data.weatherLoc.locCode + "~" + this.data.weatherLoc.zip;
    }
    var f;
    var b = "";
    if (c) {
      var a = unescape(c).split("|");
      a.unshift(d);
      for (var e = 0; e < a.length; e++) {
        if (a[e] !== d && (b.indexOf(a[e]) === -1) || e === 0) {
          b += a[e];
          if (e < (a.length - 1)) {
            b += "|";
          }
        }
      }
    } else {
      b = d;
    }
    CNN_setCookie("lwp.weather", b, 24 * 30 * 12, "/", document.domain);
  },
  saveData: function (a) {
    var d;
    var b;
    if (typeof a === "undefined") {
      a = false;
    }
    this.saveWeatherCookie();
    if (typeof cnnWeather === "object" && a !== true) {
      cnnWeather.init();
    }
    if (ms_isLoggedIn()) {
      this.StorageManager.put(this.localDataKey, this.data, MainLocalObj.expDate);
      this.StorageManager.save();
      var c = {
        params: {
          "action": "setData",
          "name": "teams",
          "data": Object.toJSON(this.data)
        },
        onSuccess: function (e) {}
      };
      Member.setData(c);
    }
  },
  monitorMSSave: function (a) {
    if (typeof a.status !== "undefined" && a.status === "success") {
      msQueueManager.requestReceived();
    }
  },
  trimWS: function (a) {
    a = a.replace(/,/g, " ");
    a = a.replace(/^\s*(\S+)*\s*$/, "$1");
    a = a.replace(/(\s{1})\s*/g, "$1");
    return a;
  },
  urlEncode: function (a) {
    a = this.trimWS(a);
    a = a.replace(/st\./i, "saint");
    a = a.replace(/mt\./i, "mount");
    a = escape(a);
    return a;
  },
  ucwords: function (a) {
    return (a + "").replace(/^(.)|\s(.)/g, function (b) {
      return b.toUpperCase();
    });
  },
  truncateString: function (b, a) {
    if (b.length >= a) {
      b = b.substring(0, a);
      b = b.replace(/\s+$/, "");
      b = b + "&hellip;";
    }
    return b;
  },
  daysInMonth: function (c, b) {
    var a = new Date(b, c, 0);
    return a.getDate();
  },
  urlDecode: function (a) {
    return unescape(a);
  },
  checkZip: function (b) {
    b = this.trimWS(b.toString());
    var a = ((b.match(/^\d{5}$/) !== null || b.match(/^\d{12}$/) !== null) && b != "00000" ? true : false);
    return a;
  }
};
MainLocalObj.Weather = {
  omnitureStr: "jsmd.trackMetrics('dynamic-impressions',cnn_outsideindata,'cnn-impressions');",
  weatherURL: (location.hostname.indexOf("ref") > 0) ? "http://teg8fref1.cnn.com/weather/getForecast" : "http://svcs.cnn.com/weather/getForecast",
  init: function () {
    this.defaultMsg = "Enter a U.S. Zip or Intl city";
    if (typeof MainLocalObj.Weather.isInitialized === "undefined") {
      MainLocalObj.Weather.requestLocalAll();
    }
    MainLocalObj.Weather.isInitialized = true;
  },
  inputFocus: function (a) {
    if (a.value === MainLocalObj.Weather.defaultMsg) {
      a.value = "";
    }
    a.removeClassName("pmWeatherHollow");
  },
  inputBlur: function (a) {
    if (a.value === "") {
      a.value = MainLocalObj.Weather.defaultMsg;
      a.addClassName("pmWeatherHollow");
    }
  },
  requestLocalAll: function () {
    var a = MainLocalObj.data;
    MainLocalObj.Weather.displayElements();
    MainLocalObj.Weather.requestLocalWeather(a);
    if (!MainLocalObj.internationalUser) {
      MainLocalObj.Weather.requestLocalNews(a);
    }
  },
  localUpdateData: function (a, c, d, b) {
    MainLocalObj.setLocationZip(b, c);
    MainLocalObj.setLocationName(b, a);
    MainLocalObj.setLocationLocCode(b, d);
    MainLocalObj.setUserSpecificData(true);
    MainLocalObj.saveData();
    MainLocalObj.Weather.requestLocalAll();
  },
  requestLocalWeather: function (c) {
    var a = "mode=json_html&zipCode=" + c.weatherLoc.zip;
    if (c.weatherLoc.locCode) {
      a += "&locCode=" + c.weatherLoc.locCode;
    }
    if (MainLocalObj.internationalUser || MainLocalObj.allCookies["default.temp.units"] == "true") {
      a += "&celcius=true";
    }
    var b = {
      url: MainLocalObj.Weather.weatherURL,
      args: a,
      domId: false,
      funcObj: MainLocalObj.Weather.updateLocalWeather,
      breakCache: true
    };
    MainLocalObj.CSIManager.callObject(b, "requestLocalWeather_");
  },
  requestLocalNews: function (e) {
    if (MainLocalObj.checkZip(e.weatherLoc.zip)) {
      var d;
      var f;
      if (MainLocalObj.isProfilePage || MainLocalObj.isUSPage) {
        d = 4;
        f = 2;
      } else {
        d = 3;
        f = 1;
      }
      var c = (!MainLocalObj.isPoliticsPage) ? "http://local.cnn.com/oi/v1.0/publications/1094/zipcodes/" + e.weatherLoc.zip + "/stories.cnnhtml" : "http://local.cnn.com/oi/v1.1/zipcodes/" + e.weatherLoc.zip + "/publications/1094/stories.cnnhtml";
      var a = (!MainLocalObj.isPoliticsPage) ? "limit=" + d + "&min=" + d + "&min_pref=" + f + "&max_age=3d&max_pref_age=3d&dev_key=wxctrr8nme2pjzpt2dpf89p5" : "limit=" + d + "&min=" + d + "&max_age=2d&dev_key=wxctrr8nme2pjzpt2dpf89p5&keyword=Democrat&keyword=Republican&keyword=Governor&keyword=Senate&keyword=Congress&keyword=Rep&keyword=Dem&keyword=politics";
      var b = {
        url: c,
        args: a,
        domId: false,
        funcObj: MainLocalObj.Weather.updateLocalNews,
        breakCache: true
      };
      MainLocalObj.CSIManager.callObject(b, "requestLocalNews");
    }
  },
  displayElements: function (a) {
    if (typeof a === "undefined") {
      a = false;
    }
    switch (a) {
      case "changeLoc":
        if ($("cnnGetLocalBox")) {
          $("cnnGetLocalBox").show();
        }
        if ($("changeLocLink")) {
          $("changeLocLink").hide();
        }
        if ($("pmLocResultsContainer")) {
          $("pmLocResultsContainer").hide();
        }
        if (!MainLocalObj.internationalUser) {}
        if ($("weatherLoc")) {
          MainLocalObj.Weather.inputBlur($("weatherLoc"));
        }
        break;
      case "intlChangeLoc":
        if ($("cnnGetLocalBox")) {
          $("cnnGetLocalBox").show();
        }
        if ($("changeLocLink")) {
          $("changeLocLink").hide();
        }
        if ($("pmLocResultsContainer")) {
          $("pmLocResultsContainer").hide();
        }
        if ($("pmWeatherTom")) {
          $("pmWeatherTom").hide();
        }
        if ($("weatherLoc")) {
          MainLocalObj.Weather.inputBlur($("weatherLoc"));
        }
        break;
      case "displayResults":
        if ($("cnnGetLocalBox")) {
          $("cnnGetLocalBox").show();
        }
        if ($("changeLocLink")) {
          $("changeLocLink").hide();
        }
        if ($("pmLocResultsContainer")) {
          $("pmLocResultsContainer").show();
        }
        break;
      default:
        if (!MainLocalObj.data.userSpecificData) {
          MainLocalObj.Weather.displayElements("changeLoc");
        } else {
          if (MainLocalObj.data.userSpecificData) {
            if ($("cnnGetLocalBox")) {
              $("cnnGetLocalBox").hide();
            }
            if ($("pmLocResultsContainer")) {
              $("pmLocResultsContainer").hide();
            }
            if ($("changeLocLink")) {
              $("changeLocLink").show();
            }
            if ($("pmWeatherTom")) {
              $("pmWeatherTom").show();
            }
            if (!MainLocalObj.internationalUser) {} else {
              if ($("curConditionsWeatherDay")) {
                $("curConditionsWeatherDay").show();
              }
            }
          }
        }
        break;
    }
  },
  updateLocalWeather: function (l) {
    if (!l[0].invalid) {
      var e = "http://weather.cnn.com/weather/";
      if (MainLocalObj.internationalUser) {
        e = "http://weather.edition.cnn.com/weather/intl/";
      }
      e += "forecast.jsp?zipCode=" + MainLocalObj.data.weatherLoc.zip;
      if (MainLocalObj.data.weatherLoc.locCode) {
        e += "&locCode=" + MainLocalObj.data.weatherLoc.locCode;
      }
      var h = MainLocalObj.data.weatherLoc.name;
      var f = "";
      var o = "";
      var c = "";
      if (MainLocalObj.internationalUser) {
        var b = "intlChangeLoc";
      } else {
        var b = "changeLoc";
      }
      var n = (MainLocalObj.internationalUser || MainLocalObj.allCookies["default.temp.units"] == "true" ? "C" : "F");
      if (l.length > -1) {
        h = l[0].location.city;
        if (l[0].location.stateOrCountry) {
          h += ", " + l[0].location.stateOrCountry;
        }
      }
      for (var a = 0; a < l.length; a++) {
        if (l[a] && l[a].forecast && l[a].forecast.days) {
          if (l[a].forecast.days.length > -1) {
            var p = l[a].forecast.days[0];
            var d = l[a].currentConditions;
            if (d.valid == false) {
              d.temperature = "--";
            }
            var h = l[0].location.city;
            if (l[0].location.stateOrCountry) {
              h += ", " + l[0].location.stateOrCountry;
            }
            f += '<p id="pmSelectedWeather">' + "	<span>" + h + '</span><span id="changeLocLink">';
            if (MainLocalObj.data.userSpecificData) {
              f += ' <span style="color: #999;">&nbsp;(</span><a id="pmEditWeatherLoc" href="javascript:MainLocalObj.Weather.displayElements(\'' + b + '\')">Edit location</a><span style="color: #999;">)</span>';
            }
            f += "</span></p>";
            var m = "";
            if (d.temperature.length > 2) {
              m = ' style="font-size: 24px;"';
            }
            var g = "";
            if (d.feelsLikeTemperature.length > 2) {
              g = ' style="font-size: 9px;"';
            }
            var s = '			<span id="pmCurrTempNum">' + d.temperature + "</span>&deg;";
            if (d.temperature_S == "N/A") {
              s = '			<span id="pmCurrTempNum"><span style="font-size: 50%;">N/A</span></span>';
            }
            var r = '			Feels like&nbsp;<span id="pmFeelTemp">' + d.feelsLikeTemperature + "</span>&deg;";
            if (d.feelsLikeTemperature_S == "N/A" || d.feelsLikeTemperature_S == "") {
              r = "";
            }
            if (!MainLocalObj.isProfilePage || MainLocalObj.internationalUser) {
              var q = (typeof (d.shortDescription) == "undefined") ? d.description : d.shortDescription;
              f += '<div class="pmWrapper">' + '	<p id="curConditionsWeatherDay" class="weatherDay">Current conditions</p>' + '	<div id="pmWeatherIcon">' + '		<a href="' + e + '"><img class="cnn_ie6png" src="http://i.cdn.turner.com/cnn/.e/img/3.0/weather/03/' + d.icon + ".png" + '" alt="your weather"></a>' + "	</div>" + '	<div id="pmCurrentWeather">' + '		<div id="pmCurrTemp"' + m + ">" + s + "		</div>" + "	</div>" + '	<div id="pmWeatherDetails">' + '		<p id="pmWeatherDesc">' + q + "		</p>" + '		<p id="pmWeatherHiLo">' + '			Hi&nbsp;<span id="pmHiTemp">' + p.high + '</span>&deg;&nbsp;&nbsp;<span style="color: #999; font-size: 10px;">|</span>&nbsp;&nbsp;Lo&nbsp;<span id="pmLoTemp">' + p.low + "</span>&deg;" + "		</p>" + "	</div>" + '	<div id="pmMoreWeather">' + '		<a id="pm10DayBtn" href="' + e + '">&nbsp;</a>' + "		<p" + g + ">";
              if (d.valid != false) {
                f += r;
              }
              f += "		</p>" + "	</div>" + "</div>";
              c += '<div class="cnn_ftrwthr1"><a href="' + e + '">' + '<img class="cnn_ie6png" src="http://i.cdn.turner.com/cnn/.e/img/3.0/weather/03/' + d.icon + '.png" alt="your weather" width="54" height="47" border="0"></a></div>';
              c += '<div class="cnn_ftrwthr2"><div class="cnn_ftrwthr3">' + s + '</div><div class="cnn_ftrwthr4">' + "<div>HI " + p.high + '&deg;<span style="padding-left:7px">LO ' + p.low + "&deg;</span></div>" + '<div style="clear:left; line-height: 13px"><span style="padding-right:6px"><strong>' + h + '</strong></span><a href="' + e + '">Weather forecast</a></div></div></div></div>';
            }
          }
          if (l[a].forecast.days.length > 0 && MainLocalObj.internationalUser && MainLocalObj.data.userSpecificData) {
            var k = l[a].forecast.days[1];
            o += '<p class="weatherDay">Tomorrow</p>' + '<div class="pmWrapper">' + '	<div id="pmWeatherIcon">' + '		<img class="cnn_ie6png" src="http://i.cdn.turner.com/cnn/.e/img/3.0/weather/03/' + k.icon.replace(/gif/, "png") + '" alt="your weather">' + "	</div>" + '	<div id="pmCurrentWeather">' + "	</div>" + '	<div id="pmWeatherDetails">' + '		<p id="pmWeatherDesc">' + k.description + "</p>" + '		<p id="pmWeatherHiLo">' + '			Hi&nbsp;<span id="pmHiTemp">' + k.high + '</span>&deg;&nbsp;&nbsp;<span style="color: #999; font-size: 10px;">|</span>&nbsp;&nbsp;Lo&nbsp;<span id="pmLoTemp">' + k.low + "</span>&deg;" + "		</p>" + "	</div>" + "</div>";
            $("pmWeatherTom").update(o);
            $("pmWeatherTom").show();
          }
        }
      }
      if ($("cnn_hppsnlhdrwthr") !== null) {
        $("cnn_hppsnlhdrwthr").show();
      }
      if ($("pmWeatherTab") !== null) {
        $("pmWeatherTab").update(f);
        $("pmWeatherTab").show();
      }
      if ($("pmWeatherFooter") !== null) {
        $("pmWeatherFooter").update(c);
        $("pmWeatherFooter").show();
      }
    } else {
      MainLocalObj.Weather.displayElements("changeLoc");
    }
    return f;
  },
  updateLocalNews: function (a) {
    MainLocalObj.Weather.displayElements();
    return "";
  },
  requestInternationalCityLookup: function (c, e, b) {
    var a = "mode=json_html&zipCode=" + c;
    if (e) {
      a += "&locCode=" + e;
    }
    if (MainLocalObj.internationalUser) {
      a += "&celcius=true";
    }
    var d = {
      url: MainLocalObj.Weather.weatherURL,
      args: a,
      domId: false,
      funcObj: MainLocalObj.Weather.updateInternationalCityData,
      breakCache: true
    };
    MainLocalObj.CSIManager.callObject(d, "requestInternationalCityLookup");
  },
  updateInternationalCityData: function (e, d) {
    var a = "";
    var c = "";
    var b = "";
    if (e && (e.length > -1) && e[0].location && e[0].location.city) {
      a = e[0].location.locCode;
      b = e[0].location.city;
      if (e[0].location.stateOrCountry) {
        b += ", " + e[0].location.stateOrCountry;
      }
      c = e[0].location.zip;
    }
    if (c && b) {
      MainLocalObj.setLocationZip(d, c);
      MainLocalObj.setLocationName(d, b);
      MainLocalObj.setLocationLocCode(d, a);
      MainLocalObj.setUserSpecificData(true);
      MainLocalObj.Weather.requestLocalAll();
    }
  },
  checkInput: function (f, d) {
    d = d.replace(/<[^>]*?>/g, "");
    var e = d.toUpperCase();
    var b = "http://weather.cnn.com/weather/citySearch";
    var a = "search_term=" + MainLocalObj.urlEncode(e) + "&mode=json_html&filter=true";
    var c = {
      url: b,
      args: a,
      domId: MainLocalObj.urlEncode(f + "|" + d),
      funcObj: MainLocalObj.Weather.updateValidationData,
      breakCache: true
    };
    MainLocalObj.CSIManager.callObject(c, "checkInput");
  },
  updateValidationData: function (m, c) {
    var b = MainLocalObj.urlDecode(c).split("|");
    var g = MainLocalObj.trimWS(b[1]);
    var q = " " + g.toUpperCase() + " ";
    var d = "";
    if (m.length > 1) {
      var k = m.length;
      var n = false;
      var s = true;
      var p = [];
      if (k > 50) {
        k = 50;
      }
      for (var l = 0; l < k; l++) {
        var o = m[l].city + ", " + m[l].stateOrCountry;
        var a = m[l].zip.toString();
        var e = m[l].locCode;
        var r = {};
        var f = " " + MainLocalObj.trimWS(o.toUpperCase()) + " ";
        if ((MainLocalObj.checkZip(g) && g == a) || (q == f)) {
          r.zip = a;
          r.locCode = e;
          r.name = o;
          p.push(r);
          s = false;
          n = r;
          l = k;
        } else {
          if (f.indexOf(q) != -1) {
            r.zip = a;
            r.locCode = e;
            r.name = o;
            p.push(r);
            s = false;
          }
        }
      }
      if (s) {
        MainLocalObj.Weather.displayNoMatch(b[0], g);
      } else {
        if (p.length == 1 || n) {
          if (!n) {
            n = p[0];
          }
          d = {};
          d.name = n.city + ", " + n.stateOrCountry;
          d.zip = n.zip.toString();
          d.locCode = n.locCode;
          MainLocalObj.Weather.localUpdateData(d.name, d.zip, d.locCode, b[0]);
          MainLocalObj.Weather.displayElements(b[0]);
        } else {
          MainLocalObj.Weather.displayMultipleMatches(p, MainLocalObj.urlDecode(b[1]), b[0]);
        }
      }
    } else {
      if ((m.length == 1) && (m[0] && m[0].locCode && m[0].locCode != "")) {
        var h = m[0];
        d = {};
        d.name = h.city + ", " + h.stateOrCountry;
        d.zip = h.zip.toString();
        d.locCode = h.locCode;
        MainLocalObj.Weather.localUpdateData(d.name, d.zip, d.locCode, b[0]);
        MainLocalObj.Weather.displayElements(b[0]);
      } else {
        MainLocalObj.Weather.displayNoMatch(b[0], g);
      }
    }
    return "";
  },
  displayMultipleMatches: function (e, g, l) {
    var f = [];
    var k = [];
    var h = [];
    e.each(function (m) {
      if (m.zip.length > 5) {
        h.push(m);
      } else {
        k.push(m);
      }
    });
    f = h.concat(k);
    var c = $F("weatherLoc");
    var b = "pmLocResultsContainer";
    var a = '<p id="pmWeatherResultMeta">We Found ' + f.length + ' Results for &quot;<span id="resultLoc">' + g + "</span>&quot;</p>";
    a += '<ul id="pmWeatherResult">';
    for (var d = 0; d < f.length; d++) {
      a += '<li><a href="javascript:void(0)" onclick="MainLocalObj.Weather.resetSearch(\'' + l + "');" + "MainLocalObj.Weather.localUpdateData('" + f[d].name + "','" + f[d].zip + "','" + f[d].locCode + "','" + l + '\');"><span class="pmHLBullet">&bull;</span>' + f[d].name + "</a></li>";
    }
    a += "</ul>";
    MainLocalObj.Weather.displayElements("displayResults");
    Element.update(b, a);
  },
  displayNoMatch: function (b, d) {
    var a = "pmLocResultsContainer";
    var c = '<p id="pmWeatherResultMeta">We didn\'t find results  for &quot;<span id="resultLoc">' + d + "</span>&quot;</p>" + '<ul id="pmWeatherResult">' + '	<li><span class="pmHLBullet">&bull;</span><span>Check the spelling of your city name</span></li>' + '	<li><span class="pmHLBullet">&bull;</span><span>Make sure the U.S. ZIP code is accurate</span></li>' + '	<li><span class="pmHLBullet">&bull;</span><span>Use USPS for U.S. ZIP codes / city name</span></li>' + "</ul>";
    MainLocalObj.Weather.displayElements("displayResults");
    Element.update(a, c);
  },
  resetSearch: function (b) {
    var c = "weatherLoc";
    var a = "pmLocResultsContainer";
    Element.update(a, "");
    $(c).value = MainLocalObj.Weather.defaultMsg;
  }
};
MainLocalObj.Markets = {
  redirectSymbol: false,
  init: function () {
    var b;
    this.defaultMsg = "Enter Symbol";
    this.errorMsg = "No match. Please enter a new symbol.";
    if (MainLocalObj.internationalUser) {
      b = "/cnnintl_adspaces/3.0/homepage/spon.88x31_worldbiz.ad";
    } else {
      b = "/cnn_adspaces/3.0/homepage/spon2.126x31.ad";
    }
    new Ajax.Updater("moneySponsor", b, {
      method: "get",
      evalScripts: true
    });
    var c = null;
    if ($("pmMarkets") !== null) {
      MainLocalObj.Markets.togBtns = $("pmMarkets").select("a.toggle");
      c = MainLocalObj.allCookies["pm.markets.lastIndex"] || null;
      if (c !== null && $(c)) {
        if (c === "myQuotesBtn" && !ms_isLoggedIn()) {
          var c = "defIndexBtn";
        }
        MainLocalObj.Markets.setActiveIndex($(c), MainLocalObj.Markets.togBtns);
      }
      MainLocalObj.Markets.togBtns.each(function (d) {
        d.observe("click", function () {
          MainLocalObj.Markets.setActiveIndex(d, MainLocalObj.Markets.togBtns);
        });
      });
    }
    if (typeof MainLocalObj.Markets.isInitialized === "undefined") {
      if (!MainLocalObj.internationalUser) {
        MainLocalObj.Markets.fetchStockQuotes();
      }
    }
    if (!MainLocalObj.internationalUser && $("searchQuote") !== null) {
      var a = $("searchQuote");
      a.addClassName("pmWeatherHollow");
      a.value = "Enter Symbol";
      if (!MainLocalObj.disableSymbolLookup) {
        MainLocalObj.Markets.symbLookup = new AutoComplete("searchQuote", "http://markets.money.cnn.com/services/cnndotcom/lookup.asp");
      }
    }
    if ($("pmMarkets") !== null) {
      $("pmMarkets").show();
    }
    if ($("cnn_personalloading") !== null) {
      $("cnn_personalloading").hide();
    }
    MainLocalObj.Markets.isInitialized = true;
  },
  setActiveIndex: function (b, a) {
    a.each(function (c) {
      var d;
      if (c.id === "myQuotesBtn") {
        d = "pmMyQuotes";
      } else {
        if (c.id === "defIndexBtn") {
          d = "pmDefaultIndecies";
        } else {
          d = c.id.replace("Btn", "");
        }
      }
      if (c.id === b.id) {
        c.removeClassName("togOff").addClassName("togOn");
        $(d).removeClassName("pmOff").addClassName("pmOn");
        CNN_setCookie("pm.markets.lastIndex", b.id, 24 * 30 * 12, "/", document.domain);
      } else {
        c.removeClassName("togOn").addClassName("togOff");
        $(d).removeClassName("pmOn").addClassName("pmOff");
      }
    });
    MainLocalObj.data.prevStockSymbols = MainLocalObj.data.stockSymbols.slice();
    if ($("searchQuote")) {
      if ($("searchQuote").hasClassName("errorColor")) {
        $("searchQuote").removeClassName("errorColor");
      }
      $("searchQuote").value = "";
    }
    if (!MainLocalObj.internationalUser) {
      MainLocalObj.Markets.inputBlur($("searchQuote"));
    }
  },
  lookupStockSymbol: function () {
    var b = $F("searchQuote");
    if (b === MainLocalObj.Markets.defaultMsg) {
      MainLocalObj.Markets.inputBlur($("searchQuote"));
    } else {
      if (b !== "") {
        this.redirectSymbol = true;
        var a = [];
        MainLocalObj.Markets.setActiveIndex($("myQuotesBtn"), MainLocalObj.Markets.togBtns);
        b = b.replace(/[^a-zA-Z 0-9]+/g, "");
        b = b.toUpperCase();
        if (MainLocalObj.data.stockSymbols.indexOf(b) != "-1") {
          a = MainLocalObj.data.stockSymbols.without(b);
        } else {
          a = MainLocalObj.data.stockSymbols.slice();
        }
        a.push(b);
        a.reverse();
        a = a.slice(0, 3);
        a.reverse();
        MainLocalObj.Markets.fetchStockQuotes(a);
      }
    }
  },
  fetchStockQuotes: function (a) {
    var c;
    if (typeof a === "undefined") {
      a = false;
    }
    if (!MainLocalObj.Markets.redirectSymbol && $("pmMyQuotes") !== null) {
      $("pmMyQuotes").update("");
    }
    if ($("searchQuote")) {
      $("searchQuote").blur();
    }
    if (a) {
      c = a.join();
    } else {
      if (typeof MainLocalObj.data.stockSymbols === "object" && MainLocalObj.data.stockSymbols.length > 0) {
        c = MainLocalObj.data.stockSymbols.join();
      } else {
        MainLocalObj.data.stockSymbols = [];
        c = "";
      }
    }
    if (c.length > 0) {
      var b = {
        url: "http://markets.money.cnn.com/services/cnndotcom/quote.asp",
        args: "symbols=" + c.replace(/,/g, "|") + "&domains=cnn.com|turner.com",
        domId: false,
        funcObj: MainLocalObj.Markets.parseQuotes,
        breakCache: true
      };
      MainLocalObj.CSIManager.callObject(b, "requestMyQuotes");
    } else {
      MainLocalObj.Markets.inputBlur($("searchQuote"));
    }
  },
  parseQuotes: function (e) {
    var l, g;
    var d = [];
    var a = false;
    var m = $("searchQuote");
    var h = e.quotes.quote;
    if (!MainLocalObj.Markets.redirectSymbol) {
      $("pmMyQuotes").update("<ul></ul>");
    }
    var o = $("pmMyQuotes").select("ul")[0];
    var f = new Template(' 			<li class="market-#{index}"> 			    <div class="marketInfo-left"> <!-- left side --> 			        <span class="marketName"><a href="http://money.cnn.com/quote/quote.html?symb=#{symbol}">#{symbol}</a></span>&nbsp;&nbsp; 			        <span class="marketIndex">#{last}</span> 			        <a class="removeSymbLookup" href="javascript:MainLocalObj.Markets.removeQuote(#{index})" title="Remove">Remove</a> 			    </div> 			    <div class="marketNums-right #{plusMinClass}"> 			        <div class="percentDiff"> 			            <span>(<span class="plusMinus">#{plusMin}</span>#{changePct} &#37;)</span> 			        </div> 			        <div class="numDiff"> 			            <span><span class="plusMinus">#{plusMin}</span>#{change}</span> 			        </div> 			    </div> 			</li> 		');

    function c(t, s) {
      var q = t.toString();
      var u = q.indexOf(".");
      if (u == -1) {
        decimalPartLength = 0;
        q += s > 0 ? "." : "";
      } else {
        decimalPartLength = q.length - u - 1;
      }
      var p = s - decimalPartLength;
      if (p > 0) {
        for (var r = 1; r <= p; r++) {
          q += "0";
        }
      }
      return q;
    }

    function k(p) {
      var q = Math.round(p * 100) / 100;
      q = c(q, 2);
      q = q.replace("-", "");
      return q;
    }

    function b(p) {
      var q = {};
      if (p.change.indexOf("-") > -1) {
        q.plusMin = "-";
        q.plusMinClass = "down";
      } else {
        if (parseInt(p.last) === 0) {
          q.plusMin = "";
          q.plusMinClass = "";
        } else {
          q.plusMin = "+";
          q.plusMinClass = "up";
        }
      }
      return q;
    }
    if (MainLocalObj.Markets.redirectSymbol) {
      if (h[h.length - 1].status !== "-1") {
        location.href = "http://money.cnn.com/quote/quote.html?symb=" + h[h.length - 1].cnnSymbol;
        return;
      }
    }
    for (var n in h) {
      if (typeof (h[n].change) == "undefined") {
        continue;
      }
      if (h[n].status === "-1" || h[n].cnnSymbol === "undefined") {
        a = true;
      } else {
        if (!MainLocalObj.Markets.redirectSymbol) {
          g = b(h[n]);
          l = f.evaluate({
            index: (parseInt(n) + 1),
            symbol: h[n].cnnSymbol,
            last: k(h[n].last),
            changePct: k(h[n].changePct),
            change: k(h[n].change),
            plusMin: g.plusMin,
            plusMinClass: g.plusMinClass
          });
          o.insert({
            top: l
          });
          d.push(h[n].cnnSymbol);
        }
      }
    }
    if (a) {
      m.addClassName("errorColor");
      m.value = MainLocalObj.Markets.errorMsg;
      MainLocalObj.Markets.redirectSymbol = false;
      MainLocalObj.Markets.fetchStockQuotes(MainLocalObj.data.prevStockSymbols);
    } else {
      MainLocalObj.data.stockSymbols = d;
      MainLocalObj.saveData(true);
    }
    MainLocalObj.Markets.symbLookup.hide();
    MainLocalObj.Markets.symbLookup.stopLookup = true;
    MainLocalObj.Markets.fixBorders();
  },
  inputFocus: function (a) {
    if (a.value === MainLocalObj.Markets.defaultMsg || a.value === MainLocalObj.Markets.errorMsg) {
      if (a.hasClassName("errorColor")) {
        a.removeClassName("errorColor");
      }
      a.value = "";
    }
    a.removeClassName("pmWeatherHollow");
  },
  inputBlur: function (a) {
    if (a !== null && a.value === "") {
      a.value = MainLocalObj.Markets.defaultMsg;
      a.addClassName("pmWeatherHollow");
    }
  },
  fixBorders: function () {
    var a = $("pmMyQuotes").select("li");
    if (a.length) {
      a[a.length - 1].addClassName("last");
    }
  },
  removeQuote: function (a) {
    var b = $("pmMyQuotes").select("li.market-" + a)[0];
    b.remove();
    MainLocalObj.Markets.fixBorders();
    MainLocalObj.data.stockSymbols = MainLocalObj.data.stockSymbols.without(MainLocalObj.data.stockSymbols[a - 1]);
    MainLocalObj.saveData();
  }
};
var AutoComplete = Class.create({
  selector: null,
  input: null,
  _timeout: null,
  visible: false,
  drawn: false,
  _hideTimeout: null,
  options: null,
  stopLookup: false,
  initialize: function (a, c, b) {
    this.action = c;
    this.input = $(a);
    this.input.autocomplete = "off";
    this.options = new AutoComplete.Options(b || {});
    this.selector = document.createElement("select");
    Event.observe(this.input, "focus", this._onInputFocus.bindAsEventListener(this));
    Event.observe(this.input, "keydown", this._onInputKeyDown.bindAsEventListener(this));
    Event.observe(this.input, "blur", this._onInputBlur.bindAsEventListener(this));
    Event.observe(this.selector, "blur", this._onSelectorBlur.bindAsEventListener(this));
    Event.observe(this.selector, "focus", this._onSelectorFocus.bindAsEventListener(this));
    Event.observe(this.selector, "change", this._onSelectorChange.bindAsEventListener(this));
    Event.observe(window, "resize", this._reposition.bind(this));
    Event.observe(window, "scroll", this._reposition.bind(this));
  },
  _onInputFocus: function (a) {
    this._onSelectorFocus(a);
    MainLocalObj.Markets.inputFocus(this.input);
  },
  _onSelectorBlur: function (a) {
    this._onInputBlur(a);
  },
  _onInputBlur: function (a) {
    this._hideTimeout = setTimeout(this._checkOnBlur.bind(this), 100);
  },
  _checkOnBlur: function () {
    this._hideTimeout = null;
    this.hide();
  },
  _onInputKeyUp: function (a) {
    this._suggest(a) && Event.stop(a);
  },
  _onInputKeyDown: function (a) {
    this._suggest(a) && Event.stop(a);
  },
  _onSelectorFocus: function (a) {
    if (this._hideTimeout) {
      clearTimeout(this._hideTimeout);
      this._hideTimeout = null;
    }
  },
  _onSelectorChange: function (a) {
    this.select();
  },
  draw: function () {
    if (this.drawn) {
      return;
    }
    if (this.options.cssClass) {
      this.selector.className = this.options.cssClass;
    }
    Element.setStyle(this.selector, {
      display: "none",
      position: "absolute"
    });
    this.selector.size = this.options.size;
    document.body.appendChild(this.selector);
    this.input.autocomplete = "off";
    this.drawn = true;
  },
  hide: function () {
    if (!this.drawn || !this.visible) {
      return;
    }
    this.visible = false;
    if (window.Scriptaculous) {
      new Effect.BlindUp(this.selector, {
        duration: this.options.delay,
        queue: "end",
        afterFinish: function (a) {
          Element.setStyle(this.selector, {
            display: "none"
          });
          this.selector.options.length = 0;
          setTimeout(this._restoreFocus.bind(this), 50);
        }.bind(this)
      });
    } else {
      Element.setStyle(this.selector, {
        display: "none"
      });
      this.selector.options.length = 0;
      setTimeout(this._restoreFocus.bind(this), 50);
    }
  },
  _restoreFocus: function () {
    this.input.focus();
  },
  show: function () {
    if (!this.drawn) {
      this.draw();
    }
    var a = null;
    if (this.selector.options.length) {
      if (window.Scriptaculous) {
        new Effect.BlindDown(this.selector, {
          duration: this.options.delay,
          queue: "end"
        });
      } else {
        Element.setStyle(this.selector, {
          display: "inline"
        });
      }
      this._reposition();
      this.visible = true;
    }
  },
  _cancelTimeout: function () {
    if (this._timeout) {
      clearTimeout(this._timeout);
      this._timeout = null;
    }
  },
  _suggest: function (c) {
    this._cancelTimeout();
    var b = Event.keyPressed(c);
    var a = [20, 16, 17, 91, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 45, 36, 35, 33, 34, 144, 145, 44, 19, 93, ];
    if (a.indexOf(b) > -1) {
      return false;
    }
    switch (b) {
      case Event.KEY_LEFT:
      case Event.KEY_RIGHT:
        return false;
        break;
      case Event.KEY_TAB:
      case Event.KEY_BACKSPACE:
      case 46:
        this.cancel();
        return false;
        break;
      case Event.KEY_RETURN:
        if (this.visible && this.selector.selectedIndex != "-1") {
          this.select();
          return true;
        } else {
          return false;
        }
        break;
      case Event.KEY_ESC:
        this.cancel();
        return true;
        break;
      case Event.KEY_UP:
      case Event.KEY_DOWN:
        this._interact(c);
        return true;
        break;
      default:
        break;
    }
    if (this.input.value.length >= this.options.threshold - 1) {
      this._timeout = setTimeout(this._sendRequest.bind(this), 1000 * this.options.delay);
    }
    return false;
  },
  _sendRequest: function () {
    var a = {
      url: this.action,
      args: "symbol=" + this.input.value + "&domains=cnn.com|turner.com",
      domId: false,
      funcObj: this._process.bind(this),
      breakCache: true
    };
    MainLocalObj.CSIManager.callObject(a);
  },
  _reposition: function () {
    if (!this.drawn) {
      return;
    }
    var a = Position.cumulativeOffset(this.input);
    a.push(a[0] + this.input.offsetWidth);
    a.push(a[1] + this.input.offsetHeight);
    Element.setStyle(this.selector, {
      left: a[0] + "px",
      top: a[3] + "px"
    });
  },
  _getPadding: function (a) {
    var c = "";
    var d = 8 - a;
    for (var b = 0; b < d; b++) {
      c += "\xa0";
    }
    return c;
  },
  _process: function (d) {
    if (this.stopLookup) {
      this.hide();
      this.cancel();
      this.stopLookup = false;
      return;
    }
    this.selector.options.length = 0;
    var c;
    var b;
    for (var a in d.data) {
      for (var e in d.data[a]) {
        if (typeof (d.data[a][e].s) != "undefined") {
          c = d.data[a][e].s;
          b = c + this._getPadding(c.length) + d.data[a][e].n;
          this._addOption(b, c);
        }
      }
    }
    if (this.selector.options.length > (this.options.size)) {
      this.selector.size = this.options.size;
    } else {
      this.selector.size = this.selector.options.length > 1 ? this.selector.options.length : 2;
    }
    if (this.selector.options.length) {
      this.selector.selectedIndex = -1;
      this.show();
    } else {
      this.cancel();
    }
  },
  _addOption: function (a, c) {
    var b = new Option(a, c);
    Prototype.Browser.IE ? this.selector.add(b) : this.selector.add(b, null);
  },
  cancel: function () {
    this.hide();
  },
  select: function () {
    if (this.selector.options.length) {
      this.input.value = this.selector.options[this.selector.selectedIndex].value;
      MainLocalObj.Markets.lookupStockSymbol();
    }
    this.cancel();
    if (typeof this.options.onSelect == "function") {
      this.options["onSelect"](this.input);
    }
  },
  _interact: function (b) {
    if (!this.visible) {
      return;
    }
    var a = Event.keyPressed(b);
    if (a != Event.KEY_UP && a != Event.KEY_DOWN) {
      return;
    }
    var c = this.selector.options.length;
    if (a == Event.KEY_UP) {
      if (this.selector.selectedIndex == 0) {
        this.selector.selectedIndex = this.selector.options.length - 1;
      } else {
        this.selector.selectedIndex--;
      }
    } else {
      if (this.selector.selectedIndex == this.selector.options.length - 1) {
        this.selector.selectedIndex = 0;
      } else {
        this.selector.selectedIndex++;
      }
    }
  }
});
AutoComplete.Options = Class.create({
  size: 3,
  cssClass: "symbolLookup",
  onSelect: null,
  threshold: 1,
  delay: 0.15,
  requestMethod: "GET",
  initialize: function (a) {
    Object.extend(this, a || {});
  }
});
Object.extend(Event, {
  KEY_BACKSPACE: 8,
  KEY_TAB: 9,
  KEY_RETURN: 13,
  KEY_ESC: 27,
  KEY_LEFT: 37,
  KEY_UP: 38,
  KEY_RIGHT: 39,
  KEY_DOWN: 40,
  KEY_DELETE: 46,
  KEY_SHIFT: 16,
  KEY_CONTROL: 17,
  KEY_CAPSLOCK: 20,
  KEY_SPACE: 32,
  keyPressed: function (a) {
    return Prototype.Browser.IE ? window.event.keyCode : a.which;
  }
});
var fwLib = {
  version: 1,
  loadComplete: false,
  currentSwapIndex: 0,
  fwJSLibsLoaded: function () {
    return true;
  },
  flIntegration: {
    testFn: function () {
      alert("FL Integration");
    },
    getElementsByClass: function (a, m, e) {
      var b = (m == "*" && a.all) ? a.all : a.getElementsByTagName(m);
      var l = new Array();
      var n = new Array();
      if (typeof e == "object") {
        for (var f = 0; f < e.length; f++) {
          n.push(new RegExp("(^|\\s)" + e[f].replace(/\-/g, "\\-") + "(\\s|$)"));
        }
      } else {
        n.push(new RegExp("(^|\\s)" + e.replace(/\-/g, "\\-") + "(\\s|$)"));
      }
      var g;
      var h;
      for (var d = 0; d < b.length; d++) {
        g = b[d];
        h = true;
        for (var c = 0; c < n.length; c++) {
          if (!n[c].test(g.className)) {
            h = false;
            break;
          }
        }
        if (h) {
          l.push(g);
        }
      }
      return l;
    },
    findPageSlots: function () {
      var c = new Array();
      var e = "";
      var a = this.getElementsByClass(document, "span", "_fwph");
      for (var d = 0; d < a.length; ++d) {
        e = a[d].getAttribute("id");
        c.push(e);
        var b = document.getElementById("_fw_input_" + e);
        c.push(b.getAttribute("value"));
      }
      return c;
    },
    savedSlots: [],
    replacePageSlotInnerHtml: function (innerHTML, safeId, saveOrigin) {
      var parentContainer = document.getElementById(safeId);
      var originalContainer = document.getElementById("_fw_container_" + safeId);
      var adContainer = document.createElement("span");
      var isIE = navigator.appVersion.match(/\bMSIE\b/);
      if (document.getElementById("_fw_container_" + safeId + "_new_" + fwLib.currentSwapIndex)) {
        this.restorePageSlot(safeId);
      }
      var newSpanId = "_fw_container_" + safeId;
      if (saveOrigin) {
        newSpanId += "_new_" + fwLib.currentSwapIndex;
      }
      var attrs = originalContainer.attributes;
      for (var i = 0; i < attrs.length; i++) {
        var name = attrs[i].name || attrs[i].nodeName;
        var value = attrs[i].value || attrs[i].nodeValue;
        if (isIE && (!name || value === "null" || value === "false" || !value)) {
          continue;
        }
        if (name == "id") {
          value = newSpanId;
        }
        adContainer.setAttribute(name, value);
      }
      if (isIE) {
        for (var i in originalContainer.style) {
          try {
            if (i == "content") {
              continue;
            }
            adContainer.style[i] = originalContainer.style[i];
          } catch (e) {}
        }
      }
      if (saveOrigin) {
        originalContainer.style.display = "none";
        parentContainer.appendChild(adContainer);
      } else {
        originalContainer.parentNode.replaceChild(adContainer, originalContainer);
      }
      adContainer.innerHTML = innerHTML;
      var fw_js = document.getElementById("_fw_container_js_" + safeId);
      if (fw_js) {
        eval(fw_js.innerHTML);
      }
    },
    restorePageSlot: function (a) {
      if (!a || !document.getElementById("_fw_container_" + a + "_new_" + fwLib.currentSwapIndex)) {
        return;
      }
      var c = document.getElementById("_fw_container_" + a + "_new_" + fwLib.currentSwapIndex++);
      document.getElementById(a).removeChild(c);
      var b = document.getElementById("_fw_container_" + a);
      b.style.display = "inline";
    },
    clearSavedPageSlots: function () {
      for (var a in fwLib.flIntegration.savedSlots) {
        fwLib.flIntegration.savedSlots[a] = null;
      }
    },
    isPageLoaded: function () {
      return fwLib.loadComplete;
    },
    onLoadComplete: function () {
      fwLib.loadComplete = true;
    },
    addLoadEvent: function (a) {
      var b = window.onload;
      if (typeof window.onload != "function") {
        window.onload = a;
      } else {
        window.onload = function () {
          if (b) {
            b();
          }
          a();
        };
      }
    }
  }
};
fwLib.flIntegration.addLoadEvent(fwLib.flIntegration.onLoadComplete);

function CNN_extractHost(a) {
  var b = /^(?:[^:\/?#]+):\/\/([^\/?#]+)(?::\d+)?(?:[^?#]*)\//i.exec(a);
  if (b && typeof b === "object") {
    return b[1];
  } else {
    return "";
  }
}

function CNN_bustFrame() {
  var a = ["digg.com"];
  if (top.location != window.location) {
    var c = CNN_extractHost(document.referrer);
    if (c) {
      for (var b = 0; b < a.length; b++) {
        if (c.indexOf(a[b]) != -1) {
          top.location.replace(window.location);
          return;
        }
      }
    }
  }
}
CNN_bustFrame();
var adHeadOffset, adHeadClass, allCookies, adHeadCookie, isClassAndOffsetValid, alreadySwappedTargetImage, alreadySwappedCookieCrumb, adHeadHash, validClassesAndOffsets, i, alreadySwappedDETargetImage, cnnDEadDEonCookie, cnnU_Country, cnnAdDE_UVal;

function CNN_getCookies() {
  var d, c, b, a;
  d = [];
  if (document.cookie) {
    c = document.cookie.split("; ");
    for (b = 0; b < c.length; b += 1) {
      a = c[b].split("=");
      d[a[0]] = unescape(a[1]) || null;
    }
  }
  return d;
}

function CNN_parseCookieData(a) {
  var d, e, b, c;
  d = {};
  e = a.split("&");
  for (b = 0; b < e.length; b += 1) {
    c = e[b].split(":");
    d[c[0]] = c[1] || null;
  }
  return d;
}
adHeadOffset = 0;
adHeadClass = "us.low";
allCookies = new CNN_getCookies();
adHeadCookie = allCookies.hasOwnProperty("Target") ? allCookies.Target : null;
isClassAndOffsetValid = false;
alreadySwappedTargetImage = false;
alreadySwappedCookieCrumb = false;
if (adHeadCookie) {
  adHeadHash = new CNN_parseCookieData(adHeadCookie);
  if (adHeadHash.o && adHeadHash["class"]) {
    validClassesAndOffsets = ["us.low", 0, "us.high", 1, "intl", 2, "intl", 3, "us.edu", 0, "us.gov", 0, "us.mil", 0, "us.org", 0];
    for (i = 0; i < validClassesAndOffsets.length; i += 2) {
      if (validClassesAndOffsets[i] === adHeadHash["class"] && validClassesAndOffsets[i + 1] === adHeadHash.o) {
        isClassAndOffsetValid = true;
        break;
      }
    }
  }
  if (isClassAndOffsetValid) {
    adHeadOffset = adHeadHash.o;
    adHeadClass = adHeadHash["class"];
  }
}

function getCookieCrumb(b) {
  var a;
  a = allCookies.CNNid;
  if (!alreadySwappedCookieCrumb && !("G" === a && a.charAt(0))) {
    b.src = "http://cnn.dyn.cnn.com/cookie.crumb";
    alreadySwappedCookieCrumb = true;
  }
}
document.adoffset = adHeadOffset;

function getAdHeadCookie(b) {
  var a;
  a = "http://cnn.dyn.cnn.com/1.gif?" + new Date().getTime();
  if (!alreadySwappedTargetImage && !isClassAndOffsetValid && ("undefined" !== typeof WM_browserAcceptsCookies) && (new WM_browserAcceptsCookies())) {
    b.src = a;
    alreadySwappedTargetImage = true;
  }
}
alreadySwappedDETargetImage = false;
cnnDEadDEonCookie = false;
cnnU_Country = "";
cnnAdDE_UVal = "R00";

function WM_readCookie(b) {
  var d, c, a, e;
  if ("" === document.cookie) {
    return false;
  } else {
    a = document.cookie;
    d = a.indexOf(b);
    e = d + b.length;
    if ((-1 !== d) && "=" === (a.charAt(e))) {
      d += b.length + 1;
      c = a.indexOf(";", d);
      if (-1 === c) {
        c = a.length;
      }
      return unescape(a.substring(d, c));
    } else {
      return false;
    }
  }
}

function getDEAdHeadCookie(b) {
  var a;
  cnnDEadDEonCookie = allCookies.adDEon;
  a = "http://gdyn.cnn.com/1.1/1.gif?" + new Date().getTime();
  if (!alreadySwappedDETargetImage && !cnnDEadDEonCookie) {
    b.src = a;
    alreadySwappedDETargetImage = true;
  }
}
var cnnad_tileID = cnnad_getID();
var cnnad_enabled = true;
var cnnad_adIframes = new Array();
var cnnad_adVault = new Array();
var cnnad_adCache = new Array();
var cnnad_interstitialPID = null;
var cnnad_interstitialPlaying = false;
var cnnad_transactionID = null;
var alreadySwappedDETargetImage = false;
var cnnDEadDEonCookie = false;
var cnnDocDomain = cnnad_getTld(location.hostname);
if (cnnDocDomain) {
  document.domain = cnnDocDomain;
}
var cnnad_pageMode = 1;
var cnnad_calledURLs = new Array();
var cnnad_successfulSend = 0;
var cnnad_resultArray = new Array();
var cnnad_ADMSizes = new Array();
cnnad_ADMSizes = ["728x90", "300x250", "336x280", "160x600", "336x850", "300x600"];

function cnnad_setADMSizes(a) {
  cnnad_ADMSizes = a;
}

function cnnad_parseReferrer(b) {
  if (!b) {
    return null;
  }
  var c = b.substring(0, b.indexOf("/", 7));
  if (c.indexOf(":", 5) > 0) {
    c = c.substring(0, b.indexOf(":", 5));
  }
  c = c.substring(c.lastIndexOf("/") + 1);
  var a = c.split(".");
  return (a[a.length - 2] + "." + a[a.length - 1]);
}

function cnnad_sendADMData() {
  var g = "";
  for (as = 0; as < cnnad_ADMSizes.length; as++) {
    var c = cnnad_calledURLs[cnnad_ADMSizes[as]];
    if (c && cnnad_successfulSend == 0) {
      if (cnnad_pageMode != 3) {
        g += "<scr" + "ipt> \n ";
        if (cnnad_pageMode == 1) {
          g += '	A09801.DM_cat("';
          var b = cnnad_getParamValue(c, "site=", "&");
          var d = cnnad_getParamValue(c, "_rollup=", "&");
          var f = cnnad_getParamValue(c, "_section=", "&");
          var e = cnnad_getParamValue(c, "_subsection=", "&");
          var a = cnnad_parseReferrer(document.referrer);
          g += b;
          if ((b != "") && ((d != "") || (f != "") || (e != ""))) {
            g += " > ";
          }
          g += d;
          if ((d != "") && ((f != "") || (e != ""))) {
            g += " > ";
          }
          g += f;
          if ((f != "") && (e != "")) {
            g += " > ";
          }
          g += e;
          g += '"); \n ';
          if (a) {
            g += ' A09801.DM_addEncToLoc("refer", "' + a + '"); \n ';
          } else {
            g += " A09801.DM_addEncToLoc(); \n ";
          }
        }
        g += "	A09801.DM_tag(); \n ";
        g += "</scr" + "ipt> \n ";
        document.write(g);
      }
      cnnad_successfulSend = 1;
      break;
    }
  }
}

function cnnad_getParamValue(e, f, c) {
  if (e.match(f)) {
    var a = e.indexOf(f) + f.length;
    var b = e.indexOf(c, a);
    var d = e.substring(a, b);
    return d;
  } else {
    return "";
  }
}
var cnnad_adTileIDGroup = new Array();
var cnnad_newTileIDIteration = 0;
var cnnad_tileExemptions = new Array();

function cnnad_addExemptCriteria() {
  var a = cnnad_tileExemptions.length;
  if (arguments.length % 2 != 0) {
    return;
  }
  cnnad_tileExemptions[a] = new Array();
  for (var b = 0; b < arguments.length; b += 2) {
    cnnad_tileExemptions[a][arguments[b]] = arguments[b + 1];
  }
}

function cnnad_checkTileExempt(c) {
  var a;
  for (var b = 0; b < cnnad_tileExemptions.length; b++) {
    a = true;
    for (adKey in cnnad_tileExemptions[b]) {
      adValue = cnnad_getParamValue(c, adKey + "=", "&");
      if (cnnad_tileExemptions[b][adKey] != adValue) {
        a = false;
        break;
      }
    }
    if (a) {
      return true;
    }
  }
  return false;
}

function cnnad_newTileIDGroup(c) {
  var b = (cnnad_tileID * 1 + 4 * (++cnnad_newTileIDIteration));
  for (var a = 0; a < c.length; a++) {
    cnnad_adTileIDGroup[cnnad_adTileIDGroup.length] = {
      tileID: b,
      adName: c[a]
    };
  }
}

function cnnad_getDynamicTileID(c) {
  var b = cnnad_tileID;
  if (cnnad_checkTileExempt(c)) {
    return b;
  }
  if (cnnad_adTileIDGroup.length > 0) {
    var e;
    if (c.match("_position=")) {
      e = cnnad_getParamValue(c, "_position=", "&");
    } else {
      if (c.match("_pos=")) {
        e = cnnad_getParamValue(c, "_pos=", "&");
      } else {
        e = "";
      }
    }
    for (var a = 0; a < cnnad_adTileIDGroup.length; a++) {
      var d = cnnad_adTileIDGroup[a].adName;
      if (e == d) {
        b = cnnad_adTileIDGroup[a].tileID;
        break;
      }
    }
  }
  return b;
}

function cnnad_debug(a) {
  if (typeof (console) != "undefined" && typeof (console.debug) != "undefined") {
    console.debug(a);
  }
}

function cnnad_error(a) {
  if (typeof (console) != "undefined" && typeof (console.error) != "undefined") {
    console.error(a);
  }
}

function cnnad_reverseString(b) {
  b = "" + b;
  var a = "";
  if (b.length) {
    var c;
    for (c = b.length; c > 0; c--) {
      a += b.charAt(c - 1);
    }
  }
  return (a);
}

function cnnad_getID() {
  return (cnnad_reverseString(new Date().getTime()));
}

function cnnad_renderAd(a) {
  a = cnnad_preview(a);
  a = cnnad_statusCodeQA(a);
  if (cnnad_enabled == true) {
    document.write('<script type="text/javascript"');
    document.write(' src="' + a + "&tile=" + cnnad_getDynamicTileID(a) + "&transactionID=" + cnnad_getTransactionID() + '"></scr');
    document.write("ipt>");
  }
}

function cnnad_preview(b) {
  if (location.host.indexOf("turner.com") > -1) {
    b = b.replace(new RegExp("ads..*?.com", "gi"), "ads.turner.com");
    b = b.replace(new RegExp("ads..*?.tv", "gi"), "ads.turner.com");
  }
  var a = cnnad_readCookie("ug");
  if (a) {
    b = b + "&Params.User.UserID=" + a;
  } else {
    b = b + "&Params.User.UserID=";
  }
  return b;
}

function cnnad_getTransactionID() {
  if (cnnad_transactionID == null) {
    cnnad_transactionID = "";
    cnnad_transactionID = Math.floor(Math.random() * 9007199254740992);
  }
  return cnnad_transactionID;
}

function cnnad_isBlocking(b) {
  var a = false;
  if (document.getElementById("ad-" + b) != null && document.getElementById("ad-" + b).style.display === "none") {
    a = true;
  } else {
    if (cnnad_interstitialPlaying === true) {
      a = true;
    }
  }
  return a;
}

function cnnad_createIframe(c, b) {
  var a = document.createElement("iframe");
  a.id = c;
  a.name = c;
  a.width = 0;
  a.height = 0;
  a.style.position = "absolute";
  a.style.top = "-20px";
  a.style.left = "-20px";
  a.marginWidth = 0;
  a.marginHeight = 0;
  a.frameBorder = 0;
  a.scrolling = "no";
  a.allowTransparency = "true";
  a.src = b;
  return a;
}

function cnnad_createAdHelper(a, e, c, b, f) {
  if (cnnad_isBlocking(a)) {
    window.setTimeout(function () {
      cnnad_createAdHelper(a, e, c, b, f);
    }, 1000);
  } else {
    var g = document.getElementById("ad-" + a);
    if (g) {
      g.appendChild(cnnad_createIframe(a, e));
    } else {
      if (!f) {
        document.write('<iframe ALLOWTRANSPARENCY="true" hspace="0" vspace="0" marginHeight="0" marginWidth="0" src="' + e + '" border="0" frameBorder="0" height="0" width="0" scrolling="no"  id="' + a + '" style="position: absolute; top: -20px; left: -20px;" ></iframe>');
      } else {
        document.getElementById(f).innerHTML = '<iframe ALLOWTRANSPARENCY="true" hspace="0" vspace="0" marginHeight="0" marginWidth="0" src="' + e + '" border="0" frameBorder="0" height="0" width="0" scrolling="no"  id="' + a + '" style="position: absolute; top: -20px; left: -20px;" ></iframe>';
      }
    }
  }
}

function cnnad_createAdNoTileId(a, d, c, b, e) {
  d = cnnad_preview(d);
  d = cnnad_statusCodeQA(d);
  d += "&transactionID=" + cnnad_getTransactionID();
  d += "&domId=" + a;
  cnnad_createAdHelper(a, d, c, b, e, false);
}

function cnnad_createAd(b, f, e, d, g) {
  try {
    if (SKIP_AD_CREATION !== "undefined" && SKIP_AD_CREATION == true) {
      return;
    }
  } catch (c) {}
  f = cnnad_preview(f);
  f = cnnad_statusCodeQA(f);
  f += "&transactionID=" + cnnad_getTransactionID();
  f += "&tile=" + cnnad_getDynamicTileID(f) + "&domId=" + b;
  cnnad_createAdHelper(b, f, e, d, g, false);
  var a = new String();
  if (f.match("_position=")) {
    a = cnnad_getParamValue(f, "_position=", "_");
  } else {
    if (f.match("_pos=")) {
      a = cnnad_getParamValue(f, "_pos=", "_");
    } else {
      a = "";
    }
  }
  cnnad_calledURLs[a] = f;
}

function cnnad_writeAd(b, a) {
  if (cnnad_enabled == true) {
    document.write('<script id="' + b + '" type="text/javascript" onload="cnnSendData();"');
    document.write(' src="' + a + "&tile=" + cnnad_getDynamicTileID(a) + '"></scr');
    document.write("ipt>");
  }
}

function cnnad_showAd(a) {
  var b = document.getElementById(a);
  if (b) {
    b.style.position = "relative";
    b.style.left = "0px";
    b.style.top = "0px";
    if (b.style.visibility === "hidden") {
      b.style.visibility = "visible";
    }
    if (b.style.display === "none") {
      b.style.display = "block";
    }
  } else {
    cnnad_error("Could not find element by id: " + a);
  }
}

function cnnad_setAdSize(c, a, d) {
  var b = document.getElementById(c);
  if (b) {
    b.height = a;
    b.width = d;
    b.className += " adunit_" + d + "x" + a;
  } else {
    cnnad_error("Could not find element by id: " + cnnad_id);
  }
}

function cnnad_readCookie(b) {
  if (document.cookie == "") {
    return null;
  } else {
    var a = document.cookie.split(";");
    var e = b + "=";
    for (var d = 0; d < a.length; d++) {
      var f = a[d];
      while (f.charAt(0) == " ") {
        f = f.substring(1, f.length);
      }
      if (f.indexOf(e) == 0) {
        return f.substring(e.length, f.length);
      }
    }
    return null;
  }
}

function cnnad_getTld(a) {
  var b = a.split(".");
  if (b.length >= 2) {
    return (b[b.length - 2] + "." + b[b.length - 1]);
  }
  return (null);
}

function cnnad_refreshAds(c) {
  if (!cnnad_adIframes) {
    return;
  }
  for (var b = 0; b < cnnad_adIframes.length; b++) {
    var d = cnnad_adIframes[b];
    var a = cnnad_findAd(c, d.getWidth(), d.getHeight());
    cnnad_swapAd(d.getId(), a);
  }
}

function cnnad_swapAd(g, b) {
  var d = document.getElementById(g);
  if (d) {
    d.width = 0;
    d.height = 0;
    d.style.display = "none";
    if (cnnad_adCache[b]) {
      for (var c = 0; c < window.frames.length; c++) {
        try {
          if (window.frames[c].location.href.indexOf("domId=" + g) > -1) {
            window.frames[c].location.replace(cnnad_adCache[b]);
          }
        } catch (f) {}
      }
      return;
    }
    if ((typeof Ajax != "undefined") && (typeof Ajax.Request != "undefined")) {
      var a = new Ajax.Request(b, {
        method: "get",
        onSuccess: function (l) {
          var k = cnnad_parseResponse(l.responseText, g);
          k = cnnad_preview(k);
          k = cnnad_statusCodeQA(k);
          k += "&transactionID=" + cnnad_getTransactionID();
          if (k) {
            cnnad_adCache[b] = k;
            for (var h = 0; h < window.frames.length; h++) {
              try {
                if (window.frames[h].location.href.indexOf("domId=" + g) > -1) {
                  window.frames[h].location.replace(k);
                }
              } catch (m) {}
            }
            return;
          }
        }
      });
    } else {
      if (typeof dojo != "undefined") {
        if (typeof dojo.io == "undefined") {
          dojo.require("dojo.io.*");
        }
        dojo.io.bind({
          url: b,
          load: function (k, l, e) {
            var h = cnnad_parseResponse(l, g);
            h = cnnad_preview(h);
            h = cnnad_statusCodeQA(h);
            h += "&transactionID=" + cnnad_getTransactionID();
            if (h) {
              cnnad_adCache[b] = h;
              d.src = h;
            }
          }
        });
      } else {}
    }
  }
}

function cnnad_parseResponse(e, g) {
  var b = "<!-- CALLOUT|";
  var c = "|CALLOUT -->";
  var f = e.indexOf(b);
  var a = e.indexOf(c);
  var d = null;
  if (f >= 0 && a > f) {
    d = e.substring(f + b.length, a);
  }
  if (d) {
    return (d + "&tile=" + cnnad_getDynamicTileID(d) + "&domId=" + g);
  } else {
    return null;
  }
}

function cnnad_findAd(f, e, a) {
  var b = null;
  for (var c = 0; c < cnnad_adVault.length; c++) {
    var d = cnnad_adVault[c];
    if (d.getType() == f && d.getHeight() == a && d.getWidth() == e) {
      b = d.getUrl();
      break;
    }
  }
  return b;
}

function cnnad_getDEAdHeadCookie(b) {
  if (typeof (cnnad_readCookie) != "undefined") {
    cnnDEadDEonCookie = cnnad_readCookie("adDEon");
  }
  var a = "http://gdyn." + cnnad_getTld(location.hostname) + "/1.1/1.gif?" + new Date().getTime();
  if (!alreadySwappedDETargetImage && !cnnDEadDEonCookie) {
    b.src = a;
    alreadySwappedDETargetImage = true;
  }
}

function cnnad_registerAd(e, d, a, b) {
  var c = new cnnad_AdObject(null, d, a, e, b);
  cnnad_adVault[cnnad_adVault.length] = c;
}

function cnnad_registerSpace(d, c, a) {
  var b = new cnnad_AdObject(d, c, a, null, null);
  cnnad_adIframes[cnnad_adIframes.length] = b;
}

function cnnad_endInterstitial(c) {
  var b = document.getElementById("interstitial" + c);
  if (b && b.parentNode) {
    b.parentNode.removeChild(b);
  }
  var d = document.getElementById("interstitialcss" + c);
  if (d && d.parentNode) {
    d.parentNode.removeChild(d);
  }
  if (typeof (document.createStyleSheet) != "undefined") {
    var a = document.createStyleSheet();
    a.addRule("table", "{display:inline}");
  }
  cnnad_interstitialPlaying = false;
}

function cnnad_startInterstitial(a, c, d) {
  cnnad_interstitialPlaying = true;
  var b = c + "&tile=" + cnnad_getDynamicTileID(c) + "&domId=" + a;
  document.write('<div id="interstitial' + a + '" class="interstitial" align="center"><iframe ALLOWTRANSPARENCY="true" hspace="0" vspace="0" marginHeight="0" marginWidth="0" src="' + b + '" border="0" frameBorder="0" height="0" width="0" scrolling="no" id="' + a + '"></iframe></div>');
  if (!d) {
    d = 1500;
  }
  cnnad_interstitialPID = window.setTimeout('cnnad_endInterstitial("' + a + '");', d);
}

function cnnad_resetInterstitial(a, c) {
  cnnad_interstitialPlaying = true;
  var b = document.getElementById(a);
  if (null != b && b.height > 20 && b.width > 20) {
    if (cnnad_interstitialPID) {
      window.clearTimeout(cnnad_interstitialPID);
    }
    if (!c) {
      c = 15000;
    }
    cnnad_interstitialPID = window.setTimeout('cnnad_endInterstitial("' + a + '");', c);
  }
}

function cnnad_getUrlParam(b) {
  b = b.replace(/[\[]/, "\\[").replace(/[\]]/, "\\]");
  var a = "[\\?&]" + b + "=([^&#]*)";
  var d = new RegExp(a);
  var c = d.exec(window.location.href);
  if (c == null) {
    return "";
  } else {
    return c[1];
  }
}

function cnnad_statusCodeQA(b) {
  var a = cnnad_getUrlParam("adsqa");
  if (a) {
    b = b + "&" + a.replace("%3D", "=");
  }
  return b;
}

function cnnad_updateIframeSource(b, a) {
  a = cnnad_preview(a);
  a = cnnad_statusCodeQA(a);
  a += "&transactionID=" + cnnad_getTransactionID();
  document.getElementById(b).contentWindow.location.replace(a + "&tile=" + cnnad_tileID + "&domId=" + b);
}

function cnnad_showAdByKey(a, b) {
  cnnad_swapAd(b, cnnad_adUrls[a]);
}

function cnnad_haveCookie(a) {
  return document.cookie && (-1 < document.cookie.indexOf("; " + a + "=") || document.cookie.indexOf(a + "=") == 0);
}

function cnnad_ugsync() {
  if (!cnnad_haveCookie("ug")) {
    document.write("<scr" + 'ipt src="http://www.ugdt' + 'urner.com/xd.sjs"></scr' + "ipt>");
  } else {
    if (!cnnad_haveCookie("ugs")) {
      document.write("<scr" + 'ipt src="http://www.ugdt' + 'urner.com/xd.sjs"></scr' + "ipt>");
    }
  }
}

function cnnad_AdObject(e, d, a, c, b) {
  this.id = e;
  this.width = d;
  this.height = a;
  this.type = c;
  this.url = b;
  this.getId = function () {
    return this.id;
  };
  this.setId = function (f) {
    this.id = f;
  };
  this.getWidth = function () {
    return this.width;
  };
  this.setWidth = function (f) {
    this.width = f;
  };
  this.getHeight = function () {
    return this.height;
  };
  this.setHeight = function (f) {
    this.height = f;
  };
  this.getType = function () {
    return this.type;
  };
  this.setType = function (f) {
    this.type = f;
  };
  this.getUrl = function () {
    return this.url;
  };
  this.setUrl = function (f) {
    this.url = f;
  };
  this.toString = function () {
    return "[AD|ID=" + this.id + "|WIDTH=" + this.width + "|HEIGHT=" + this.height + "]";
  };
}

function refreshAdsByDivId(n, o) {
  var a = document.getElementsByTagName("div");
  for (var e = 0; e < a.length; e++) {
    var b = a[e].id;
    if (b.indexOf(n) >= 0) {
      if (a[e].parentNode) {
        var m = a[e].parentNode;
        var f = m.innerHTML;
        var h = "&amp;tile=";
        var k = f.indexOf(h);
        if (k > 0) {
          var l = f.indexOf("&amp;", k + h.length);
          var g = parseInt(f.substring(k + h.length, l));
          var d = g + o;
          var h = "tile=" + g;
          var c = "tile=" + d;
          f = f.replace(h, c);
        }
        m.innerHTML = f;
      }
    }
  }
}
String.prototype.format = function () {
  var c = this,
    a, b;
  for (a = 0; a < arguments.length;
  (a += 1)) {
    b = new RegExp("\\{" + a + "\\}", "gi");
    c = c.replace(b, arguments[a]);
  }
  return c;
};
var CNNHP = CNNHP || {};
CNNHP.initFlipperTicker = function () {
  var c, b = CNNHP,
    a = document.getElementById("cnnFlipperTicker");
  if (b.hasOwnProperty("FlipperTickerApp") && "undefined" !== typeof a) {
    c = new b.FlipperTickerApp(a, {
      "clientConfig": {
        "host": "http://data.cnn.com/",
        "path": "jsonp/ELECTION/2012/meta/clientConfig.intl.json"
      }
    });
    c.initialize();
  }
};
var CNNHMPAGE = {
  "pmod": {
    "cnntv": {
      "tmo": null,
      "tmintvl": 5000,
      "ready": 0,
      "h_pos": 0,
      "slidecnt": 0,
      "slideintvl": 214,
      "prev": function () {
        if (CNNHMPAGE.pmod.cnntv.tmo) {
          clearTimeout(CNNHMPAGE.pmod.cnntv.tmo);
        }
        CNNHMPAGE.pmod.cnntv.slide((CNNHMPAGE.pmod.cnntv.h_pos + CNNHMPAGE.pmod.cnntv.slideintvl));
      },
      "next": function () {
        if (CNNHMPAGE.pmod.cnntv.tmo) {
          clearTimeout(CNNHMPAGE.pmod.cnntv.tmo);
        }
        CNNHMPAGE.pmod.cnntv.slide((CNNHMPAGE.pmod.cnntv.h_pos - CNNHMPAGE.pmod.cnntv.slideintvl));
      },
      "auto": function () {
        if (CNNHMPAGE.pmod.cnntv.h_pos <= (-1 * (CNNHMPAGE.pmod.cnntv.slidecnt - 1) * CNNHMPAGE.pmod.cnntv.slideintvl)) {
          clearTimeout(CNNHMPAGE.pmod.cnntv.tmo);
        } else {
          CNNHMPAGE.pmod.cnntv.slide((CNNHMPAGE.pmod.cnntv.h_pos - CNNHMPAGE.pmod.cnntv.slideintvl));
          CNNHMPAGE.pmod.cnntv.tmo = setTimeout(CNNHMPAGE.pmod.cnntv.auto, CNNHMPAGE.pmod.cnntv.tmintvl);
        }
      },
      "slide": function (a) {
        $j("#cnn_pmtvmodslidecntnt").animate({
          "left": a + "px"
        });
        CNNHMPAGE.pmod.cnntv.h_pos = a;
        CNNHMPAGE.pmod.cnntv.enblbtns();
      },
      "enblbtns": function () {
        if (CNNHMPAGE.pmod.cnntv.slidecnt >= 1) {
          if (CNNHMPAGE.pmod.cnntv.h_pos === 0) {
            $j("#cnn_pmtvmodnlft").unbind("click").addClass("cnn_pmtvmodnavoff");
          } else {
            $j("#cnn_pmtvmodnlft").unbind("click");
            $j("#cnn_pmtvmodnlft").click(function () {
              CNNHMPAGE.pmod.cnntv.prev();
            });
            $j("#cnn_pmtvmodnlft").removeClass("cnn_pmtvmodnavoff");
          }
          if (CNNHMPAGE.pmod.cnntv.h_pos <= (-1 * (CNNHMPAGE.pmod.cnntv.slidecnt - 1) * CNNHMPAGE.pmod.cnntv.slideintvl)) {
            $j("#cnn_pmtvmodnrgt").unbind("click").addClass("cnn_pmtvmodnavoff");
          } else {
            $j("#cnn_pmtvmodnrgt").unbind("click");
            $j("#cnn_pmtvmodnrgt").click(function () {
              CNNHMPAGE.pmod.cnntv.next();
            });
            $j("#cnn_pmtvmodnrgt").removeClass("cnn_pmtvmodnavoff");
          }
        }
      },
      "init": function (a) {
        CNNHMPAGE.pmod.cnntv.tmintvl = a;
        $j(".cnn_pmtvmodslide").each(function (b) {
          CNNHMPAGE.pmod.cnntv.slidecnt += 1;
        });
        $j("#cnn_pmtvmodslidecntnt").css({
          "width": (CNNHMPAGE.pmod.cnntv.slidecnt * CNNHMPAGE.pmod.cnntv.slideintvl) + "px"
        });
        CNNHMPAGE.pmod.cnntv.enblbtns();
        CNNHMPAGE.pmod.cnntv.ready = 1;
        if (CNNHMPAGE.pmod.cnntv.slidecnt > 1) {
          CNNHMPAGE.pmod.cnntv.tmo = setTimeout(CNNHMPAGE.pmod.cnntv.auto, CNNHMPAGE.pmod.cnntv.tmintvl);
        }
        $j("#cnn_pmtvmodcntr").removeClass("cnn_pmtvmoddisabled");
      }
    }
  }
};

function cvpSearchTheClient(theObj, thePath) {
  var index = thePath.indexOf("."),
    objName = "",
    subPath = "",
    childObj;
  if (theObj === null) {
    theObj = window;
  }
  if (index === -1) {
    if (thePath.indexOf("(") !== -1 && thePath.indexOf(")") !== -1) {
      return eval("theObj." + thePath);
    } else {
      return theObj[thePath];
    }
  }
  objName = thePath.substring(0, index);
  subPath = thePath.substring(index + 1);
  childObj = theObj[objName];
  if (objName.indexOf("(") !== -1 && objName.indexOf(")") !== -1) {
    childObj = eval("theObj." + objName);
  }
  if (childObj === null) {
    return "";
  }
  if (subPath.length < 1) {
    return childObj.toString();
  }
  return cvpSearchTheClient(childObj, subPath);
}(function () {
  var CVP = {};
  var CVPconstructor = function (options) {
    return CVP.createPlayer(options);
  };
  if ("CVP" in window) {
    if (typeof window.console !== "undefined" && typeof window.console.log === "function") {
      console.log("WARNING - window.CVP was already defined, adding/overriding functionality");
    }
  }
  var VERSION = "2.7.8";
  var FLASH_VERSION = "10.1.0.0";
  var HTML5 = "html5";
  var FLASH = "flash";
  var MAPPING_PATH = "http://i.cdn.turner.com/xslo/cvp/config/{site}/";
  var MAPPING_FILE = "mapping.xml";
  var OMNITURE_JS_URL = "";
  var AD_MANAGER_URL = "http://i.cdn.turner.com/xslo/cvp/ads/freewheel/js/AdManager.js";
  var AD_DFP_URL = "http://www.google.com/uds/api/ima/1.7/9fd415db3bb953707e811e4827fe957b/default.IN.js";
  var EXPRESS_INSTALL_URL = "http://i.cdn.turner.com/xslo/cvp/assets/flash/expressInstall.swf";
  var debug = /\bdmtdebug\b/.test([this.location.search, this.location.hash].join());
  var site = "cvp";
  var property = "cvp";
  var Class = (function () {
    var initializing = false,
      fnTest = /xyz/.test(function () {
        xyz;
      }) ? /\b_super\b/ : /.*/;
    var Class = function () {};
    Class.extend = function (prop) {
      var _super = this.prototype;
      initializing = true;
      var prototype = new this();
      initializing = false;
      for (var name in prop) {
        prototype[name] = typeof prop[name] == "function" && typeof _super[name] == "function" && fnTest.test(prop[name]) ? (function (name, fn) {
          return function () {
            var tmp = this._super;
            this._super = _super[name];
            var ret = fn.apply(this, arguments);
            this._super = tmp;
            return ret;
          };
        })(name, prop[name]) : prop[name];
      }

      function Class() {
        if (!initializing && this.init) {
          this.init.apply(this, arguments);
        }
      }
      Class.prototype = prototype;
      Class.constructor = Class;
      Class.extend = arguments.callee;
      return Class;
    };
    return Class;
  })();

  function createCallbackHandler(id) {
    var funcName = id + "_callback_handler";
    if (typeof window[funcName] !== "undefined") {
      return false;
    }
    window[funcName] = function () {
      var ret = CVP.onCallback(id, arguments);
      if (typeof ret !== "undefined") {
        return ret;
      }
    };
    return true;
  }

  function validateFlashVersion(embedVersion) {
    var f1 = "",
      f2 = "",
      f1V = 0,
      f2V = 0,
      i = 0,
      endi = 0;
    embedVersion = embedVersion.toString();
    if (embedVersion === FLASH_VERSION) {
      return embedVersion;
    }
    if (typeof embedVersion === "undefined" || embedVersion === null) {
      return FLASH_VERSION;
    }
    f1 = FLASH_VERSION.split(".");
    f2 = embedVersion.split(".");
    for (endi = f1.length; i < endi; ++i) {
      f1V = +f1[i];
      f2V = +f2[i];
      if (isNaN(f2V) || f1V > f2V) {
        return FLASH_VERSION;
      } else {
        if (f2V > f1V) {
          return embedVersion;
        }
      }
    }
    return FLASH_VERSION;
  }

  function addBeforeUnLoadEvent(func) {
    var oldfunc = window.onbeforeunload;
    if (typeof window.onbeforeunload !== "function") {
      window.onbeforeunload = func;
    } else {
      window.onbeforeunload = function () {
        if (oldfunc) {
          oldfunc();
        }
        func();
      };
    }
  }
  var CVPObject = function (options) {
    this.options = extend({
      id: "cvp_player",
      width: "320",
      height: "240",
      flashVars: {},
      playerType: FLASH,
      freewheelJsUrl: AD_MANAGER_URL,
      initialize: function () {}
    }, options || {});
    this.options.embed = extend({
      containerSwf: "",
      expressInstallSwf: EXPRESS_INSTALL_URL,
      flashVersion: FLASH_VERSION
    }, this.options.embed || {});
    this.options.embed.options = extend({
      quality: "high",
      bgcolor: "#000000",
      allowFullScreen: "true",
      allowScriptAccess: "always"
    }, this.options.embed.options || {});
    if (!this.options.embed.containerSwf) {
      log("Invalid containerSwf...exiting");
      throw new Error("Invalid containerSwf");
    }
    this.options.initialize();
    var id = this.options.id,
      width = this.options.width,
      height = this.options.height,
      flashVars = this.options.flashVars,
      embed = this.options.embed;
    this._playerType = this.options.playerType;
    var player = null;
    if (this._playerType === HTML5 || CVP.Browser.apple_mobile) {
      if (flashVars.site && flashVars.profile) {
        log("instantiating the HTML5 player");
        this._playerType = HTML5;
        player = new CVP.Players.HTML5(this.options);
      } else {
        log("invalid HTML5 params...instantiating null player");
        this._playerType = false;
        player = new CVP.Players.NullPlayer(this.options);
      }
      this.getDOMPlayer = function () {
        return player;
      };
    } else {
      log("instantiating the Flash player");
      this._playerType = FLASH;
    }
    if (CVP.findInstance(id) || byId(id)) {
      log(id + " is already in use...exiting");
      throw new Error(id + " is already in use");
    }
    this.getId = function () {
      return id;
    };
    this.getWidth = function () {
      return width;
    };
    this.getHeight = function () {
      return height;
    };
    this.getFlashVars = function () {
      return flashVars;
    };
    this.getEmbed = function () {
      return embed;
    };
    this.getPlayerType = function () {
      return this._playerType;
    };
    if (!createCallbackHandler(id)) {
      log('callback handler for id "' + id + '" could not be created...exiting');
      throw new Error('callback handler for id "' + id + '" could not be created...exiting');
    }
    this.callbacks = {};
    delete this.options.initialize;
    var p, pfn;
    for (p in this.options) {
      if (hasOwn(this.options, p)) {
        pfn = this.options[p];
        if (isFunc(pfn)) {
          this.callbacks[p] = pfn;
        }
      }
    }
    this.handleCallBack = function () {
      var ret = null;
      if (arguments.length) {
        var funcName = arguments[0],
          args = Array.prototype.slice.call(arguments, 1),
          fn;
        fn = this[funcName];
        if (isFunc(fn)) {
          try {
            ret = fn.apply(this, args);
          } catch (internalCBException) {
            log("Warning - exception on internal CB " + funcName);
            log("Exception - " + internalCBException.message);
          }
        }
        fn = this.callbacks[funcName];
        if (isFunc(fn)) {
          try {
            ret = fn.apply(this, args);
          } catch (userCBException) {
            log("Warning - exception on user CB " + funcName);
            log("Exception - " + userCBException.message);
          }
        }
      }
      return ret;
    };
    var contentId = this.options.flashVars.contentId || "",
      contentUrl = this.options.flashVars.contentUrl || "",
      playlistId = this.options.flashVars.playlistId || "",
      context = this.options.flashVars.context || "",
      playerInstance = context,
      contentWidth = 0,
      contentHeight = 0,
      duration = 0,
      playhead = 0,
      absolutePlayhead = -1,
      buffering = false,
      paused = false,
      fullscreen = false;
    this.getDOMPlayerInstance = function () {
      return playerInstance;
    };
    this.getContentId = function () {
      return contentId;
    };
    this.getContentUrl = function () {
      return contentUrl;
    };
    this.playlistId = function () {
      return playlistId;
    };
    this.getContext = function () {
      return context;
    };
    this.getContentWidth = function () {
      return contentWidth;
    };
    this.getContentHeight = function () {
      return contentHeight;
    };
    this.getDuration = function () {
      return duration;
    };
    this.getPlayhead = function () {
      return playhead;
    };
    this.getAbsolutePlayhead = function () {
      return absolutePlayhead;
    };
    this.isBuffering = function () {
      return buffering;
    };
    this.isPaused = function () {
      return paused;
    };
    this.isFullscreen = function () {
      return fullscreen;
    };
    this.onContentMetadata = function (pPlayerId, pContentId, pDuration, pWidth, pHeight) {
      contentId = pContentId;
      playhead = 0;
      duration = pDuration;
      contentWidth = pWidth;
      contentHeight = pHeight;
    };
    this.onContentBegin = function (pPlayerId, pContentId) {
      contentId = pContentId;
    };
    this.onContentBuffering = function (pPlayerId, pContentId, pBuffering) {
      buffering = pBuffering;
    };
    this.onContentPlayhead = function (pPlayerId, pContentId, pPlayhead, pTotalDuration, pCurrentTime) {
      playhead = pPlayhead;
      absolutePlayhead = pCurrentTime || -1;
    };
    this.onContentPause = function (pPlayerId, pContentId, pPaused) {
      paused = pPaused;
    };
    this.onContentResize = function (pPlayerId, pWidth, pHeight, pFullscreen) {
      fullscreen = pFullscreen;
    };
    this.onPlayerReady = function () {
      playerInstance = this.getDOMPlayerInstance();
    };
    CVP.registerInstance(id, this);
    return this;
  };
  CVPObject.prototype = {
    getDOMPlayer: (navigator.appName.indexOf("Microsoft") !== -1 ? function () {
      return window[this.getId()];
    } : function () {
      return document[this.getId()];
    }),
    getPlayer: function (id) {
      if (this._playerType === HTML5 || CVP.Browser.apple_mobile) {
        return this.getDOMPlayer();
      } else {
        this.getDOMPlayer().getPlayerJS(id);
        return this;
      }
    },
    setDefaultPlayer: function (id) {
      this.getDOMPlayer().setDefaultPlayer(id);
      return this;
    },
    embedSWF: function (containerElementId) {
      return this.embed.apply(this, arguments);
    },
    embed: function (containerElementId) {
      var self = this;
      if (this._playerType === FLASH) {
        var flashvars = this.getFlashVars();
        flashvars.domId = this.getId();
        flashvars.cvpSessionToken = CVP.getSessionToken();
        var embed = this.getEmbed();
        var container = embed.containerSwf;
        var params = embed.options;
        var express = embed.expressInstallSwf;
        var version = validateFlashVersion(embed.flashVersion);
        var attributes = {
          id: this.getId(),
          name: this.getId()
        };
        if (!CVP.swfobject.hasFlashPlayerVersion("1.0.0")) {
          this.handleCallBack("onNoFlashDetected");
        }
        CVP.swfobject.embedSWF(container, containerElementId, this.getWidth(), this.getHeight(), version, express, flashvars, params, attributes);
      } else {
        if (this.getPlayer().embed) {
          CVP.Events.onReady(function () {
            self.getPlayer().embed(containerElementId);
          });
        }
      }
      return this;
    },
    removeSWF: function () {
      return this.remove.apply(this, arguments);
    },
    remove: function () {
      if (this._playerType === FLASH) {
        if (CVP.swfobject && CVP.swfobject.removeSWF) {
          CVP.swfobject.removeSWF(this.getId());
        }
      } else {
        if (isFunc(this.getPlayer().remove)) {
          this.getPlayer().remove();
        }
      }
      return this;
    },
    play: function (id, options) {
      this.getDOMPlayer().playContent(id, options || {});
      return this;
    },
    playFromObject: function (object, options) {
      this.getDOMPlayer().playFromObject(object, options || {});
      return this;
    },
    reportAnalytics: function (eventName, data) {
      this.getDOMPlayer().reportAnalytics(eventName, data);
      return this;
    },
    replay: function () {
      this.getDOMPlayer().replayContent();
      return this;
    },
    playNextInQueue: function () {
      this.getDOMPlayer().playNextInQueue();
      return this;
    },
    pause: function () {
      this.getDOMPlayer().pause();
      return this;
    },
    resume: function () {
      this.getDOMPlayer().resume();
      return this;
    },
    stop: function () {
      this.getDOMPlayer().stopContent();
      return this;
    },
    queue: function (id, options, index) {
      if (typeof index === "undefined") {
        index = -1;
      }
      this.getDOMPlayer().queue(id, options || {}, index);
      return this;
    },
    queueFromObject: function (object, options, index) {
      if (typeof index === "undefined") {
        index = -1;
      }
      this.getDOMPlayer().queueFromObject(object, options || {}, index);
      return this;
    },
    dequeue: function (id) {
      this.getDOMPlayer().dequeue(id);
      return this;
    },
    emptyQueue: function () {
      this.getDOMPlayer().emptyQueue();
      return this;
    },
    setQueueAutoplay: function (autoplay) {
      this.getDOMPlayer().setQueueAutoplay(autoplay);
      return this;
    },
    getQueue: function () {
      return this.getDOMPlayer().getQueue();
    },
    seek: function (time) {
      this.getDOMPlayer().seek(time);
      return this;
    },
    mute: function () {
      this.getDOMPlayer().mute();
      return this;
    },
    unmute: function () {
      this.getDOMPlayer().unmute();
      return this;
    },
    setVolume: function (volume) {
      this.getDOMPlayer().setVolume(volume);
      return this;
    },
    getVolume: function () {
      return this.getDOMPlayer().getVolume();
    },
    isMuted: function () {
      return this.getDOMPlayer().isMuted();
    },
    getContentEntry: function (id) {
      return this.getDOMPlayer().getContentEntry(id);
    },
    goFullscreen: function () {
      this.getDOMPlayer().goFullscreen();
      return this;
    },
    resize: function (width, height, duration) {
      this.getDOMPlayer().resize(width, height, duration);
      return this;
    },
    setMaxBitrate: function (bitrate) {
      this.getDOMPlayer().setMaxBitrate(bitrate);
      return this;
    },
    switchBitrateId: function (id) {
      this.getDOMPlayer().switchBitrateId(id);
      return this;
    },
    setAutoBitrateSwitch: function (auto) {
      this.getDOMPlayer().setAutoBitrateSwitch(auto);
      return this;
    },
    getAvailableBitrates: function (playMode) {
      return this.getDOMPlayer().getAvailableBitrates(playMode);
    },
    getBitrateId: function () {
      return this.getDOMPlayer().getBitrateId();
    },
    setGroupOrder: function (order) {
      this.getDOMPlayer().setGroupOrder(order);
      return this;
    },
    getShareOptions: function () {
      return this.getDOMPlayer().getShareOptions();
    },
    setClosedCaptions: function (on, trackId) {
      this.getDOMPlayer().setClosedCaptions(on, trackId);
      return this;
    },
    setAdSection: function (section) {
      this.getDOMPlayer().setAdSection(section);
      return this;
    },
    setAdKeyValue: function (key, value) {
      this.getDOMPlayer().setAdKeyValue(key, value);
      return this;
    },
    setAdVisibility: function (adsObject) {
      this.getDOMPlayer().setAdVisibility(adsObject);
      return this;
    },
    switchAdContext: function (context) {
      this.getDOMPlayer().switchAdContext(context);
      return this;
    },
    switchTrackingContext: function (context) {
      this.getDOMPlayer().switchTrackingContext(context);
      return this;
    },
    setDataSrc: function (src) {
      this.getDOMPlayer().setDataSrc(src);
      return this;
    },
    setFileKey: function (key) {
      this.getDOMPlayer().setFileKey(key);
      return this;
    },
    sendUIMessage: function (message, data) {
      this.getDOMPlayer().sendUIMessage(message, data);
      return this;
    }
  };
  CVP.HTML5 = HTML5;
  CVP.FLASH = FLASH;
  CVP.version = VERSION;
  CVP.VIDEO_NOT_FOUND_ERROR = "video not found";
  CVP.VIDEO_XML_NOT_FOUND_ERROR = "cms error";
  CVP.instances = {};
  CVP.registerInstance = function (id, instance) {
    CVP.instances[id] = instance;
  };
  CVP.unregisterInstance = function (id) {
    CVP.instances[id] = null;
  };
  CVP.findInstance = function (id) {
    return CVP.instances[id];
  };
  CVP.onCallback = function (id, args) {
    var instance = CVP.findInstance(id);
    if (instance) {
      return instance.handleCallBack.apply(instance, args);
    } else {
      log("Error - onCallback - unable to find instance " + id);
    }
  };
  CVP.cleanup = function () {
    var inst;
    for (inst in CVP.instances) {
      if (hasOwn(CVP.instances, inst)) {
        window[inst + "_callback_handler"] = null;
        CVP.instances[inst] = null;
      }
    }
  };
  CVP.createPlayer = function (options) {
    return new CVPObject(options);
  };
  CVP.Events = {};
  CVP.Events.onReady = function (handler) {
    if (!CVP.swfobject) {
      throw new Error("swfobject is required for onReady functionality");
    }
    CVP.swfobject.addDomLoadEvent(handler);
  };
  CVP.Events.addListener = function (element, type, handler) {
    if (element.addEventListener) {
      element.addEventListener(type, handler, false);
    } else {
      if (!handler.$$guid) {
        handler.$$guid = CVP.Events.addListener.guid++;
      }
      if (!element.events) {
        element.events = {};
      }
      var handlers = element.events[type];
      if (!handlers) {
        handlers = element.events[type] = {};
        if (element["on" + type]) {
          handlers[0] = element["on" + type];
        }
        element["on" + type] = CVP.Events._handleEvent;
      }
      handlers[handler.$$guid] = handler;
    }
  };
  CVP.Events.addListener.guid = 1;
  CVP.Events.removeListener = function (element, type, handler) {
    if (element.removeEventListener) {
      element.removeEventListener(type, handler, false);
    } else {
      if (element.events && element.events[type] && handler.$$guid) {
        delete element.events[type][handler.$$guid];
      }
    }
  };
  CVP.Events._handleEvent = function (event) {
    event = event || CVP.Events._fixEvent(window.event);
    var returnValue = true;
    var handlers = this.events[event.type];
    var i;
    for (i in handlers) {
      if (hasOwn(handlers, i)) {
        this.$$handler = handlers[i];
        if (this.$$handler(event) === false) {
          returnValue = false;
        }
      }
    }
    if (this.$$handler) {
      this.$$handler = null;
    }
    return returnValue;
  };
  CVP.Events._fixEvent = function (event) {
    event.preventDefault = CVP.Events._fixEvent._preventDefault;
    event.stopPropagation = CVP.Events._fixEvent._stopPropagation;
    return event;
  };
  CVP.Events._fixEvent._preventDefault = function () {
    this.returnValue = false;
  };
  CVP.Events._fixEvent._stopPropagation = function () {
    this.cancelBubble = true;
  };
  CVP.Events.CustomEvent = Class.extend({
    init: function (type) {
      this._type = type;
      this._listeners = [];
    },
    addListener: function (fn, scope) {
      this._listeners.push({
        fn: fn,
        scope: scope
      });
    },
    removeListener: function (fn, scope) {
      var i = 0,
        len = this._listeners.length,
        o;
      for (; i < len; i += 1) {
        o = this._listeners[i];
        if (o.fn === fn && o.scope === scope) {
          this._listeners.splice(i, 1);
          break;
        }
      }
    },
    dispatch: function () {
      var i = 0,
        len = this._listeners.length,
        o;
      for (; i < len; ++i) {
        o = this._listeners[i];
        o.fn.apply(o.scope, arguments);
      }
    }
  });
  CVP.Utils = {
    undef: function (obj) {
      return typeof obj === "undefined";
    },
    isNull: function (obj) {
      return CVP.Utils.undef(obj) || obj === null;
    },
    empty: function (str) {
      return CVP.Utils.isNull(str) || str === "";
    },
    isFunc: function (f) {
      return typeof f === "function";
    },
    isObject: function (obj) {
      return typeof obj === "object";
    },
    isString: function (obj) {
      return typeof obj === "string";
    },
    isFlagActive: function (str, bDefault) {
      if (CVP.Utils.empty(str)) {
        return bDefault;
      }
      switch (str.toLowerCase()) {
        case "yes":
        case "true":
        case "on":
          return true;
        default:
          return false;
      }
    },
    extend: function (target, source) {
      var p;
      if (!target) {
        target = {};
      }
      for (p in source) {
        target[p] = source[p];
      }
      return target;
    },
    byId: function (id) {
      return document.getElementById(id);
    },
    slice: function (arr, index) {
      return Array.prototype.slice.call(arr, index || 0);
    },
    hasOwn: (typeof Object.prototype.hasOwnProperty === "function" ? function (object, property) {
      return Object.prototype.hasOwnProperty.call(object, property);
    } : function (object, property) {
      return object[property] !== Object.prototype[property];
    }),
    bind: function (func, scope, argv) {
      var args = CVP.Utils.slice(arguments, 2);
      return function () {
        var a = args.concat(CVP.Utils.slice(arguments));
        return func.apply(scope, a);
      };
    },
    template: function (template, values) {
      var matches = template.match(/\{[^{}]*\}/g),
        i = 0,
        len = 0,
        args = CVP.Utils.slice(arguments, 1),
        argc = args.length;
      if (!matches) {
        log("No {placeholders} present in template: ", template);
      } else {
        for (i = 0, len = matches.length; i < len && i < argc; ++i) {
          template = template.replace(matches[i], args[i]);
        }
      }
      return template;
    },
    joinKeys: function (obj, delimiter) {
      var arr = [],
        p;
      if (nil(delimiter)) {
        delimiter = ",";
      }
      for (p in obj) {
        if (hasOwn(obj, p)) {
          arr.push(p + "=" + obj[p]);
        }
      }
      return arr.join(delimiter);
    },
    getQueryParams: function (str) {
      var params = {}, source = str || location.href,
        data = [],
        i = 0,
        endi = 0,
        pair = [];
      try {
        data = (source.split("?", 2)[1] || "").split("#")[0].split("&") || [];
        for (endi = data.length; i < endi; ++i) {
          pair = data[i].split("=");
          if (pair[0]) {
            params[pair[0]] = unescape(pair[1]);
          }
        }
      } catch (e) {
        CVP.Utils.log("unable to get url params");
      }
      return params;
    },
    getQueryParam: function (key) {
      return CVP.Utils.getQueryParams()[key];
    },
    isRelativePath: function (url) {
      if (url && url.indexOf("://") === -1) {
        return true;
      }
      return false;
    },
    log: function () {
      if (window.console && window.console.log && debug) {
        window.console.log(CVP.Utils.slice(arguments).join(" | "));
      }
    },
    print: function (obj, str) {
      var o;
      if (str !== "nested") {
        CVP.Utils.log("\nPrint all values for ", str);
      }
      for (o in obj) {
        if (hasOwn(obj, o)) {
          if (!o) {
            continue;
          }
          if (CVP.Utils.isObject(obj[o])) {
            CVP.Utils.log("Printing nested object value", o);
            CVP.Utils.print(obj[o], "nested");
          } else {
            CVP.Utils.log(str === "nested" ? "\t" : "", "key:", o, "value:", obj[o]);
          }
        }
      }
      if (str !== "nested") {
        CVP.Utils.log("End Print all values for ", str);
        CVP.Utils.log("\n");
      }
    },
    now: (typeof Date.now === "function" ? Date.now : function () {
      return (new Date()).getTime();
    }),
    getRandomInt: function (min, max) {
      return (arguments.length === 1 ? Math.floor(Math.random() * min) : Math.floor(Math.random() * (max - min + 1)) + min);
    },
    randomString: function (length) {
      var str = "";
      var i;
      var chars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXTZabcdefghiklmnopqrstuvwxyz".split("");
      if (!length) {
        length = CVP.Utils.getRandomInt(chars.length);
      }
      for (i = 0; i < length; i++) {
        str += chars[CVP.Utils.getRandomInt(chars.length)];
      }
      return str;
    }
  };
  CVP.Utils.CommandQueue = Class.extend({
    init: function () {
      this._queue = [];
    },
    push: function (fn, scope, args) {
      this._queue.push({
        fn: fn,
        scope: scope,
        args: args
      });
    },
    remove: function (index) {
      index = typeof index !== "number" ? this._queue.length - 1 : index;
      this._queue.splice(index, 1);
    },
    execute: function () {
      var i = 0,
        len = this._queue.length,
        cmd;
      for (; i < len; ++i) {
        cmd = this._queue[i];
        cmd.fn.apply(cmd.scope, cmd.args);
      }
    }
  });
  CVP.Utils.Asset = Class.extend({
    init: function (url, type) {
      this._firedSuccess = false;
      this._url = url;
      this._type = CVP.Utils.empty(type) ? this._determineType() : type;
      this.id = "cvp_asset_" + Math.round(Math.random() * 1000);
      this.eSuccess = new CVP.Events.CustomEvent();
      this.eFailure = new CVP.Events.CustomEvent();
    },
    _determineType: function () {
      var ext = (CVP.Utils.empty(this._url)) ? "" : this._url.substring(this._url.lastIndexOf(".") + 1);
      return ext;
    },
    load: function () {
      log("Asset", "loading type", this._type);
      switch (this._type) {
        case "js":
          this._loadJs();
          break;
        case "css":
          this._loadCss();
          break;
        default:
          this._failure();
      }
    },
    _success: function () {
      log("Asset", "successfully loaded asset", this._url);
      this.eSuccess.dispatch();
      this._firedSuccess = true;
    },
    _failure: function () {
      log("Asset", "failed to load asset", this._url);
      this.eFailure.dispatch();
    },
    _loadJs: function () {
      var head = document.getElementsByTagName("head")[0];
      if (!head) {
        this._failure();
        return;
      }
      var script = document.createElement("script");
      script.id = this.id;
      script.type = "text/javascript";
      var successCB = CVP.Utils.bind(function () {
        if (this._firedSuccess) {
          return;
        }
        this._success();
        script.onload = script.onreadystatechange = null;
        head.removeChild(script);
      }, this);
      script.onload = successCB;
      script.onerror = CVP.Utils.bind(this._failure, this);
      script.onreadystatechange = function () {
        if (this.readyState === "loaded" || this.readyState === "complete") {
          successCB();
        }
      };
      script.src = this._url;
      head.appendChild(script);
    },
    _loadCss: function () {
      var node, head = document.getElementsByTagName("head")[0];
      if (!head) {
        this._failure();
        return;
      }
      node = document.createElement("link");
      node.type = "text/css";
      node.rel = "stylesheet";
      node.href = src;
      node.media = "screen";
      head.appendChild(node);
      this._success();
    }
  });
  CVP.Utils.JsonConverter = {
    ESCAPE_MATCH: /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
    ESCAPE_MAPPING: {
      '"': '\\"',
      "\\": "\\\\",
      "/": "\\/",
      "\b": "\\b",
      "\f": "\\f",
      "\n": "\\n",
      "\r": "\\r",
      "\t": "\\t"
    },
    ESCAPE_REPLACER: function (a) {
      var map = CVP.Utils.JsonConverter.ESCAPE_MAPPING;
      return a in map ? map[a] : "\\u" + ("0000" + a.charCodeAt(0).toString(16)).slice(-4);
    },
    _validateEscape: (/\bdmtdebug\b/.test([window.location.search, window.location.hash].join()) && typeof JSON === "object" && typeof JSON.parse === "function"),
    escapeString: function (string) {
      var escaped = "",
        test = null,
        validate = CVP.Utils.JsonConverter._validateEscape,
        match = CVP.Utils.JsonConverter.ESCAPE_MATCH,
        replacer = CVP.Utils.JsonConverter.ESCAPE_REPLACER;
      match.lastIndex = 0;
      escaped = '"' + (match.test(string) ? string.replace(match, replacer) : string) + '"';
      if (validate) {
        try {
          test = JSON.parse('{"test": ' + escaped + "}");
          if (test.test !== string) {
            throw new Error("JsonConverter::escapeString failed to return a value that could be reconstituted into the original string");
          }
        } catch (e) {
          throw e;
        }
      }
      return escaped;
    },
    convertNode: function (xml, ident, nodeType) {
      var json = "",
        first = false,
        i = 0,
        endi = 0,
        undef = CVP.Utils.undef,
        empty = CVP.Utils.empty;
      if (empty(ident)) {
        ident = "";
      }
      if (empty(nodeType)) {
        nodeType = "";
      }
      json = ident;
      if (nodeType === "") {
        json += "{";
      }
      ident = ident + "\t";
      first = true;
      if (!undef(xml.attributes)) {
        var removeAttributes = [];
        for (endi = xml.attributes.length; i < endi; ++i) {
          var attribute = xml.attributes[i];
          if (!undef(attribute.nodeName) && attribute.nodeName.indexOf("xmlns") === -1) {
            if (first) {
              first = false;
              json += "\n";
            } else {
              json += ",\n";
            }
            if (nodeType === "array") {
              json += ident + "{";
            } else {
              json += ident;
            }
            json += '"' + attribute.nodeName + '":' + CVP.Utils.JsonConverter.escapeString(attribute.nodeValue);
            if (nodeType === "array") {
              json += "}";
            }
          } else {
            if (!undef(attribute.nodeName)) {
              removeAttributes.push(attribute.nodeName);
            }
          }
        }
        for (i = 0, endi = removeAttributes.length; i < endi; ++i) {
          xml.removeAttribute(removeAttributes[0]);
        }
      }
      var type;
      var name;
      if (!undef(xml.childNodes)) {
        for (i = 0, endi = xml.childNodes.length; i < endi; ++i) {
          var node = xml.childNodes[i];
          if (!undef(node.tagName)) {
            if (first) {
              first = false;
              json += "\n";
            } else {
              json += ",\n";
            }
            name = node.tagName;
            if (empty(name)) {
              name = "text";
            }
            json += ident;
            if (nodeType === "array") {
              json += "{";
            }
            if ((empty(node.childNodes) || node.childNodes.length <= 1) && (empty(node.attributes) || node.attributes.length === 0) && !(node.childNodes.length > 0 && node.childNodes[0].nodeType === 1)) {
              if (node.childNodes.length > 0) {
                json += '"' + name + '":' + CVP.Utils.JsonConverter.escapeString(node.childNodes[0].nodeValue);
              } else {
                json += '"' + name + '":' + '""';
              }
            } else {
              var isArray = CVP.Utils.JsonConverter.isNodeAnArray(node);
              json += '"' + name + '":' + (isArray ? "[" : "{") + "\n";
              if (node.childNodes.length > 0 && !empty(node.childNodes[0].nodeValue)) {
                json += '"text":' + CVP.Utils.JsonConverter.escapeString(node.childNodes[0].nodeValue) + ",";
              }
              type = isArray ? "array" : "object";
              json += CVP.Utils.JsonConverter.convertNode(node, ident, type);
            }
            if (nodeType === "array") {
              json += "}";
            }
          }
        }
      }
      ident = ident.substr(0, ident.length - 1);
      json += "\n" + ident;
      json += (nodeType === "array") ? "]" : "}";
      return json;
    },
    isNodeAnArray: function (node) {
      var names = {}, i = 0,
        endi = 0,
        undef = CVP.Utils.undef,
        empty = CVP.Utils.empty;
      if (!undef(node.childNodes)) {
        for (endi = node.childNodes.length; i < endi; ++i) {
          var element = node.childNodes[i];
          if (!empty(element.tagName)) {
            if (!empty(names[element.tagName])) {
              return true;
            } else {
              names[element.tagName] = "exists";
            }
          }
        }
      }
      return false;
    },
    encodeXmlObject: function (xmlObj) {
      var json = CVP.Utils.JsonConverter.convertNode(xmlObj);
      return json;
    }
  };
  CVP.Browser = (function () {
    var ua = navigator.userAgent.toLowerCase(),
      chrome = /\bchrome\b/.test(ua),
      iphone = /\biphone\b/.test(ua),
      ipod = /\bipod\b/.test(ua),
      ipad = /\bipad\b/.test(ua),
      apple_mobile = (iphone || ipod || ipad),
      matches = null,
      toVersionNum = function (str) {
        return str ? parseInt(str, 10) : NaN;
      }, version = {
        raw: NaN,
        major: NaN,
        minor: NaN,
        revision: NaN
      };
    if (apple_mobile) {
      matches = / os ((\d+)(?:\D(\d+))?(?:\D(\d+))?)/.exec(ua);
      if (matches) {
        version.raw = matches[1].replace(/\D/g, ".");
        version.major = toVersionNum(matches[2]);
        version.minor = toVersionNum(matches[3]);
        version.revision = toVersionNum(matches[4]);
      } else {
        CVP.Utils.log("Unable to parse apple mobile version");
      }
    }
    return {
      version: version,
      chrome: chrome,
      iphone: iphone,
      ipod: ipod,
      ipad: ipad,
      apple_mobile: apple_mobile
    };
  }());
  CVP.Players = {};
  CVP.Players.NullPlayer = Class.extend({
    init: function () {
      var functions = "play replay playNextInQueue pause resume stop queue dequeue emptyQueue setQueueAutoplay getQueue seek mute unmute setVolume getVolume isMuted getContentEntry goFullscreen resize setMaxBitrate setGroupOrder getShareOptions setAdSection setAdKeyValue switchAdContext switchTrackingContext".split(" "),
        f = 0,
        endf = functions.length,
        noop = function () {}, fn;
      for (; f < endf; ++f) {
        fn = functions[f];
        if (!this[fn]) {
          this[fn] = noop;
        }
      }
    }
  });
  CVP.Players.HTML5 = CVP.Players.NullPlayer.extend({
    init: function (options) {
      this._super();
      this._options = options;
      this._instance = null;
      this._loadQ = new CVP.Utils.CommandQueue();
      this._loaded = false;
      this._load();
    },
    _load: function () {
      if (CVP.Players._HTML5Player) {
        this._onLoaded();
      } else {
        log("HTML5 player not found");
      }
    },
    _onLoaded: function () {
      if (CVP.Players._HTML5Player) {
        this._instance = new CVP.Players._HTML5Player(this._options);
        this._instance.ePlayerLoaded.addListener(this._onPlayerLoaded, this);
        this._instance.ePlayerLoadError.addListener(this._onPlayerLoadError, this);
        this._instance.ePlayerReady.addListener(this._onPlayerReady, this);
        this._instance.ePlayerReady.addListener(this._onCVPReady, this);
        this._instance.ePlayerReady.addListener(bind(this._onCallBack, this, "onPlayerReady"));
        this._instance.ePlayerReady.addListener(bind(this._onCallBack, this, "onCVPReady"));
        this._instance.eContentBegin.addListener(bind(this._onCallBack, this, "onContentBegin"));
        this._instance.eContentPlay.addListener(bind(this._onCallBack, this, "onContentPlay"));
        this._instance.eContentPause.addListener(bind(this._onCallBack, this, "onContentPause"));
        this._instance.eContentEnd.addListener(bind(this._onCallBack, this, "onContentEnd"));
        this._instance.eContentComplete.addListener(bind(this._onCallBack, this, "onContentComplete"));
        this._instance.eContentMetadata.addListener(bind(this._onCallBack, this, "onContentMetadata"));
        this._instance.eContentPlayhead.addListener(bind(this._onCallBack, this, "onContentPlayhead"));
        this._instance.eContentBuffering.addListener(bind(this._onCallBack, this, "onContentBuffering"));
        this._instance.eContentResize.addListener(bind(this._onCallBack, this, "onContentResize"));
        this._instance.eContentVolume.addListener(bind(this._onCallBack, this, "onContentVolume"));
        this._instance.eContentError.addListener(bind(this._onCallBack, this, "onContentError"));
        this._instance.eAdPlayhead.addListener(bind(this._onCallBack, this, "onAdPlayhead"));
        this._instance.eAdPlay.addListener(bind(this._onCallBack, this, "onAdPlay"));
        this._instance.eAdEnd.addListener(bind(this._onCallBack, this, "onAdEnd"));
        this._instance.eAdError.addListener(bind(this._onCallBack, this, "onAdError"));
        this._instance.eTrackingAdStart.addListener(bind(this._onCallBack, this, "onTrackingAdStart"));
        this._instance.eTrackingAdComplete.addListener(bind(this._onCallBack, this, "onTrackingAdComplete"));
        this._instance.eTrackingAdCountdown.addListener(bind(this._onCallBack, this, "onTrackingAdCountdown"));
        this._instance.eTrackingContentPlay.addListener(bind(this._onCallBack, this, "onTrackingContentPlay"));
        this._instance.eTrackingContentBegin.addListener(bind(this._onCallBack, this, "onTrackingContentBegin"));
        this._instance.eTrackingContentComplete.addListener(bind(this._onCallBack, this, "onTrackingContentComplete"));
        this._instance.eTrackingContentSeek.addListener(bind(this._onCallBack, this, "onTrackingContentSeek"));
        this._instance.eTrackingFullscreen.addListener(bind(this._onCallBack, this, "onTrackingFullscreen"));
        this._instance.eTrackingMuted.addListener(bind(this._onCallBack, this, "onTrackingMuted"));
        this._instance.eTrackingPaused.addListener(bind(this._onCallBack, this, "onTrackingPaused"));
      } else {
        log("HTML5 player not found");
      }
    },
    _onPlayerLoaded: function () {
      log("_onPlayerLoaded");
      this._loaded = true;
      this._loadQ.execute();
    },
    _onPlayerLoadError: function () {
      log("HTML5 load error");
      this._onCallBack("onPlayerLoadError");
    },
    _onPlayerReady: function () {
      log("_onPlayerReady");
    },
    _onCVPReady: function () {
      log("_onCVPReady");
    },
    embed: function (containerElement) {
      if (!this._loaded) {
        log("queuing embed");
        this._loadQ.push(this.embed, this, arguments);
        return;
      }
      log("executing embed");
      this._instance.render(containerElement);
    },
    remove: function () {
      this._instance.remove();
    },
    playContent: function (contentId, options) {
      this._instance.play(contentId, options);
    },
    queue: function (contentId, options) {
      this._instance.queue(contentId, options);
    },
    pause: function () {
      this._instance.pause();
    },
    resume: function () {
      this._instance.resume();
    },
    resize: function (width, height) {
      this._instance.resize(width, height);
    },
    goFullscreen: function (fullscreen) {
      this._instance.goFullscreen(fullscreen);
    },
    setVolume: function (v) {
      this._instance.setVolume(v);
    },
    getVolume: function () {
      return this._instance.getVolume();
    },
    mute: function () {
      this._instance.mute();
    },
    unmute: function () {
      this._instance.unmute();
    },
    getContentEntry: function (id) {
      return this._instance.getContentEntry(id);
    },
    setAdSection: function (ssid) {
      this._instance.setAdSection(ssid);
    },
    _onCallBack: function () {
      CVP.onCallback(this._options.id, arguments);
    },
    instance: function () {
      return this._instance;
    },
    supported: function () {
      return !!document.createElement("video").canPlayType;
    }
  });
  CVP.Ajax = {
    get: function (obj) {
      obj.type = "GET";
      this._request(obj);
    },
    getXml: function (obj) {
      obj.dataType = "xml";
      this.get(obj);
    },
    getJSONP: function (obj) {
      this.JSONP._request(obj);
    },
    post: function (obj) {
      obj.type = "POST";
      this._request(obj);
    },
    _request: function (obj) {
      var request = new XMLHttpRequest();
      request.onreadystatechange = function () {
        if (request.readyState === 4) {
          if (request.status <= 200 && request.status < 400) {
            if (obj.success) {
              obj.success(request.responseText);
            }
          } else {
            if (obj.error) {
              obj.error(request);
            }
          }
          request = null;
        }
      };
      request.open(obj.type, obj.url, true);
      request.send(obj.type === "POST" ? obj.data : null);
    }
  };
  CVP.Ajax.JSONP = {
    requestTimeout: 5000,
    maxRetries: 0,
    _externalRoutes: {},
    requestMap: {},
    _counter: 0,
    _request: function (obj) {
      var self = this;
      obj = extend({
        timeout: this.requestTimeout,
        maxRetries: this.maxRetries
      }, obj || {});
      obj.tries = 0;
      log("JSONP - creating request with timeout ", obj.timeout, " and maxRetries ", obj.maxRetries);
      this._sendRequest(obj);
    },
    _sendRequest: function (obj) {
      var self = this;
      var requestId = this._createCallback(obj);
      var script = this._createScript(requestId);
      if (!script) {
        log("JSONP - unable to create script for request ", obj.url);
        throw new Error("JSONP - unable to create script for request " + obj.url);
      }
      script.src = obj.url;
      if (obj.timeout) {
        setTimeout(function () {
          self._onError(requestId, obj);
        }, obj.timeout);
      }
    },
    _onSuccess: function (id, obj, data) {
      if (!this.requestMap[id]) {
        return;
      }
      this._destroyRequest(id, obj);
      if (isString(data)) {
        try {
          data = JSON.parse(data);
        } catch (e1) {
          log("JSON.parse failed - falling back to eval");
          try {
            data = eval("(" + data + ")");
          } catch (e2) {
            log("eval data failed");
          }
        }
      }
      if (obj.success) {
        log("JSONP", "success");
        obj.success(data);
      }
    },
    _onError: function (id, obj) {
      if (!this.requestMap[id]) {
        return;
      }
      this._destroyRequest(id, obj);
      ++obj.tries;
      if (obj.maxRetries && obj.tries < obj.maxRetries) {
        log("Request failed - resending");
        this._sendRequest(obj);
        return;
      }
      if (obj.error) {
        log("JSONP", "error");
        obj.error(obj.url);
      }
    },
    _destroyRequest: function (id, obj) {
      this._deregisterExternalCallback(obj.jsonpCallback, id);
      delete this.requestMap[id];
      this._counter--;
      var script = document.getElementById(this._getScriptName(id));
      if (script) {
        script.parentNode.removeChild(script);
        script = null;
      }
    },
    _createScript: function (id) {
      var head, script;
      head = document.getElementsByTagName("head")[0];
      if (!head) {
        return false;
      }
      script = document.createElement("script");
      script.type = "text/javascript";
      if (id) {
        script.id = this._getScriptName(id);
      }
      head.appendChild(script);
      return script;
    },
    _getScriptName: function (id) {
      return "cvp_jsonp_" + id;
    },
    _createCallback: function (obj) {
      var self = this;
      if (empty(obj.jsonpCallback)) {
        return null;
      }++this._counter;
      var id = "request_" + this._counter + "_" + now();
      this.requestMap[id] = function (data) {
        self._onSuccess(id, obj, data);
      };
      var cb = function (data) {
        log("JSONP", "Internal CB received for request:", id);
        if (self.requestMap[id]) {
          self.requestMap[id](data);
        } else {
          log("Request response came in after allotted time: ", id);
        }
      };
      this._registerExternalCallback(obj.jsonpCallback, id, cb);
      return id;
    },
    _registerExternalCallback: function (name, id, cb) {
      if (!window[name]) {
        this._createExternalCallback(name, this._routeExternalCallback(name));
      }
      if (!this._externalRoutes[name]) {
        this._externalRoutes[name] = [];
      }
      this._externalRoutes[name].push({
        id: id,
        cb: cb
      });
    },
    _routeExternalCallback: function (name) {
      var self = this;
      return function (data) {
        log("JSONP", "routing:", name);
        if (!self._externalRoutes) {
          log("JSONP", "error - routes haven't been initialized");
          return;
        }
        if (!self._externalRoutes[name]) {
          log("JSONP", "error - routing hasn't been initialized for:", name);
          return;
        }
        if (!self._externalRoutes[name].length) {
          log("JSONP", "error - no waiting requests for route:", name);
          return;
        }
        var request = self._externalRoutes[name].shift();
        log("JSONP", "request retrieved - id: ", request.id, "cb:", typeof request.cb);
        if (request.cb) {
          request.cb(data);
        }
      };
    },
    _createExternalCallback: function (name, cb) {
      window[name] = cb;
    },
    _deregisterExternalCallback: function (name, id) {
      for (var i = 0, len = this._externalRoutes[name].length; i < len; i++) {
        var request = this._externalRoutes[name][i];
        if (request.id === id) {
          log("JSONP", "removing request from route:", name, "with id:", id);
          this._externalRoutes[name].splice(i, 1);
          return;
        }
      }
    }
  };
  CVP.swfobject = function () {
    var UNDEF = "undefined",
      OBJECT = "object",
      SHOCKWAVE_FLASH = "Shockwave Flash",
      SHOCKWAVE_FLASH_AX = "ShockwaveFlash.ShockwaveFlash",
      FLASH_MIME_TYPE = "application/x-shockwave-flash",
      EXPRESS_INSTALL_ID = "SWFObjectExprInst",
      ON_READY_STATE_CHANGE = "onreadystatechange",
      win = window,
      doc = document,
      nav = navigator,
      plugin = false,
      domLoadFnArr = [main],
      regObjArr = [],
      objIdArr = [],
      listenersArr = [],
      storedAltContent, storedAltContentId, storedCallbackFn, storedCallbackObj, isDomLoaded = false,
      isExpressInstallActive = false,
      dynamicStylesheet, dynamicStylesheetMedia, autoHideShow = true,
      ua = function () {
        var w3cdom = typeof doc.getElementById != UNDEF && typeof doc.getElementsByTagName != UNDEF && typeof doc.createElement != UNDEF,
          u = nav.userAgent.toLowerCase(),
          p = nav.platform.toLowerCase(),
          windows = p ? /win/.test(p) : /win/.test(u),
          mac = p ? /mac/.test(p) : /mac/.test(u),
          webkit = /webkit/.test(u) ? parseFloat(u.replace(/^.*webkit\/(\d+(\.\d+)?).*$/, "$1")) : false,
          ie = !+"\v1",
          playerVersion = [0, 0, 0],
          d = null;
        if (typeof nav.plugins != UNDEF && typeof nav.plugins[SHOCKWAVE_FLASH] == OBJECT) {
          d = nav.plugins[SHOCKWAVE_FLASH].description;
          if (d && !(typeof nav.mimeTypes != UNDEF && nav.mimeTypes[FLASH_MIME_TYPE] && !nav.mimeTypes[FLASH_MIME_TYPE].enabledPlugin)) {
            plugin = true;
            ie = false;
            d = d.replace(/^.*\s+(\S+\s+\S+$)/, "$1");
            playerVersion[0] = parseInt(d.replace(/^(.*)\..*$/, "$1"), 10);
            playerVersion[1] = parseInt(d.replace(/^.*\.(.*)\s.*$/, "$1"), 10);
            playerVersion[2] = /[a-zA-Z]/.test(d) ? parseInt(d.replace(/^.*[a-zA-Z]+(.*)$/, "$1"), 10) : 0;
          }
        } else {
          if (typeof win.ActiveXObject != UNDEF) {
            try {
              var a = new ActiveXObject(SHOCKWAVE_FLASH_AX);
              if (a) {
                d = a.GetVariable("$version");
                if (d) {
                  ie = true;
                  d = d.split(" ")[1].split(",");
                  playerVersion = [parseInt(d[0], 10), parseInt(d[1], 10), parseInt(d[2], 10)];
                }
              }
            } catch (e) {}
          }
        }
        return {
          w3: w3cdom,
          pv: playerVersion,
          wk: webkit,
          ie: ie,
          win: windows,
          mac: mac
        };
      }(),
      onDomLoad = function () {
        if (!ua.w3) {
          return;
        }
        if ((typeof doc.readyState != UNDEF && doc.readyState == "complete") || (typeof doc.readyState == UNDEF && (doc.getElementsByTagName("body")[0] || doc.body))) {
          callDomLoadFunctions();
        }
        if (!isDomLoaded) {
          if (typeof doc.addEventListener != UNDEF) {
            doc.addEventListener("DOMContentLoaded", callDomLoadFunctions, false);
          }
          if (ua.ie && ua.win) {
            doc.attachEvent(ON_READY_STATE_CHANGE, function () {
              if (doc.readyState == "complete") {
                doc.detachEvent(ON_READY_STATE_CHANGE, arguments.callee);
                callDomLoadFunctions();
              }
            });
            if (win == top) {
              (function () {
                if (isDomLoaded) {
                  return;
                }
                try {
                  doc.documentElement.doScroll("left");
                } catch (e) {
                  setTimeout(arguments.callee, 0);
                  return;
                }
                callDomLoadFunctions();
              })();
            }
          }
          if (ua.wk) {
            (function () {
              if (isDomLoaded) {
                return;
              }
              if (!/loaded|complete/.test(doc.readyState)) {
                setTimeout(arguments.callee, 0);
                return;
              }
              callDomLoadFunctions();
            })();
          }
          addLoadEvent(callDomLoadFunctions);
        }
      }();

    function callDomLoadFunctions() {
      if (isDomLoaded) {
        return;
      }
      try {
        var t = doc.getElementsByTagName("body")[0].appendChild(createElement("span"));
        t.parentNode.removeChild(t);
      } catch (e) {
        return;
      }
      isDomLoaded = true;
      var dl = domLoadFnArr.length;
      for (var i = 0; i < dl; i++) {
        domLoadFnArr[i]();
      }
    }

    function addDomLoadEvent(fn) {
      if (isDomLoaded) {
        fn();
      } else {
        domLoadFnArr[domLoadFnArr.length] = fn;
      }
    }

    function addLoadEvent(fn) {
      if (typeof win.addEventListener != UNDEF) {
        win.addEventListener("load", fn, false);
      } else {
        if (typeof doc.addEventListener != UNDEF) {
          doc.addEventListener("load", fn, false);
        } else {
          if (typeof win.attachEvent != UNDEF) {
            addListener(win, "onload", fn);
          } else {
            if (typeof win.onload == "function") {
              var fnOld = win.onload;
              win.onload = function () {
                fnOld();
                fn();
              };
            } else {
              win.onload = fn;
            }
          }
        }
      }
    }

    function main() {
      if (plugin) {
        testPlayerVersion();
      } else {
        matchVersions();
      }
    }

    function testPlayerVersion() {
      var b = doc.getElementsByTagName("body")[0];
      var o = createElement(OBJECT);
      o.setAttribute("type", FLASH_MIME_TYPE);
      var t = b.appendChild(o);
      if (t) {
        var counter = 0;
        (function () {
          if (typeof t.GetVariable != UNDEF) {
            var d = t.GetVariable("$version");
            if (d) {
              d = d.split(" ")[1].split(",");
              ua.pv = [parseInt(d[0], 10), parseInt(d[1], 10), parseInt(d[2], 10)];
            }
          } else {
            if (counter < 10) {
              counter++;
              setTimeout(arguments.callee, 10);
              return;
            }
          }
          b.removeChild(o);
          t = null;
          matchVersions();
        })();
      } else {
        matchVersions();
      }
    }

    function matchVersions() {
      var rl = regObjArr.length;
      if (rl > 0) {
        for (var i = 0; i < rl; i++) {
          var id = regObjArr[i].id;
          var cb = regObjArr[i].callbackFn;
          var cbObj = {
            success: false,
            id: id
          };
          if (ua.pv[0] > 0) {
            var obj = getElementById(id);
            if (obj) {
              if (hasPlayerVersion(regObjArr[i].swfVersion) && !(ua.wk && ua.wk < 312)) {
                setVisibility(id, true);
                if (cb) {
                  cbObj.success = true;
                  cbObj.ref = getObjectById(id);
                  cb(cbObj);
                }
              } else {
                if (regObjArr[i].expressInstall && canExpressInstall()) {
                  var att = {};
                  att.data = regObjArr[i].expressInstall;
                  att.width = obj.getAttribute("width") || "0";
                  att.height = obj.getAttribute("height") || "0";
                  if (obj.getAttribute("class")) {
                    att.styleclass = obj.getAttribute("class");
                  }
                  if (obj.getAttribute("align")) {
                    att.align = obj.getAttribute("align");
                  }
                  var par = {};
                  var p = obj.getElementsByTagName("param");
                  var pl = p.length;
                  for (var j = 0; j < pl; j++) {
                    if (p[j].getAttribute("name").toLowerCase() != "movie") {
                      par[p[j].getAttribute("name")] = p[j].getAttribute("value");
                    }
                  }
                  showExpressInstall(att, par, id, cb);
                } else {
                  displayAltContent(obj);
                  if (cb) {
                    cb(cbObj);
                  }
                }
              }
            }
          } else {
            setVisibility(id, true);
            if (cb) {
              var o = getObjectById(id);
              if (o && typeof o.SetVariable != UNDEF) {
                cbObj.success = true;
                cbObj.ref = o;
              }
              cb(cbObj);
            }
          }
        }
      }
    }

    function getObjectById(objectIdStr) {
      var r = null;
      var o = getElementById(objectIdStr);
      if (o && o.nodeName == "OBJECT") {
        if (typeof o.SetVariable != UNDEF) {
          r = o;
        } else {
          var n = o.getElementsByTagName(OBJECT)[0];
          if (n) {
            r = n;
          }
        }
      }
      return r;
    }

    function canExpressInstall() {
      return !isExpressInstallActive && hasPlayerVersion("6.0.65") && (ua.win || ua.mac) && !(ua.wk && ua.wk < 312);
    }

    function showExpressInstall(att, par, replaceElemIdStr, callbackFn) {
      isExpressInstallActive = true;
      storedCallbackFn = callbackFn || null;
      storedCallbackObj = {
        success: false,
        id: replaceElemIdStr
      };
      var obj = getElementById(replaceElemIdStr);
      if (obj) {
        if (obj.nodeName == "OBJECT") {
          storedAltContent = abstractAltContent(obj);
          storedAltContentId = null;
        } else {
          storedAltContent = obj;
          storedAltContentId = replaceElemIdStr;
        }
        att.id = EXPRESS_INSTALL_ID;
        if (typeof att.width == UNDEF || (!/%$/.test(att.width) && parseInt(att.width, 10) < 310)) {
          att.width = "310";
        }
        if (typeof att.height == UNDEF || (!/%$/.test(att.height) && parseInt(att.height, 10) < 137)) {
          att.height = "137";
        }
        doc.title = doc.title.slice(0, 47) + " - Flash Player Installation";
        var pt = ua.ie && ua.win ? "ActiveX" : "PlugIn",
          fv = "MMredirectURL=" + win.location.toString().replace(/&/g, "%26") + "&MMplayerType=" + pt + "&MMdoctitle=" + doc.title;
        if (typeof par.flashvars != UNDEF) {
          par.flashvars += "&" + fv;
        } else {
          par.flashvars = fv;
        }
        if (ua.ie && ua.win && obj.readyState != 4) {
          var newObj = createElement("div");
          replaceElemIdStr += "SWFObjectNew";
          newObj.setAttribute("id", replaceElemIdStr);
          obj.parentNode.insertBefore(newObj, obj);
          obj.style.display = "none";
          (function () {
            if (obj.readyState == 4) {
              obj.parentNode.removeChild(obj);
            } else {
              setTimeout(arguments.callee, 10);
            }
          })();
        }
        createSWF(att, par, replaceElemIdStr);
      }
    }

    function displayAltContent(obj) {
      if (ua.ie && ua.win && obj.readyState != 4) {
        var el = createElement("div");
        obj.parentNode.insertBefore(el, obj);
        el.parentNode.replaceChild(abstractAltContent(obj), el);
        obj.style.display = "none";
        (function () {
          if (obj.readyState == 4) {
            obj.parentNode.removeChild(obj);
          } else {
            setTimeout(arguments.callee, 10);
          }
        })();
      } else {
        obj.parentNode.replaceChild(abstractAltContent(obj), obj);
      }
    }

    function abstractAltContent(obj) {
      var ac = createElement("div");
      if (ua.win && ua.ie) {
        ac.innerHTML = obj.innerHTML;
      } else {
        var nestedObj = obj.getElementsByTagName(OBJECT)[0];
        if (nestedObj) {
          var c = nestedObj.childNodes;
          if (c) {
            var cl = c.length;
            for (var i = 0; i < cl; i++) {
              if (!(c[i].nodeType == 1 && c[i].nodeName == "PARAM") && !(c[i].nodeType == 8)) {
                ac.appendChild(c[i].cloneNode(true));
              }
            }
          }
        }
      }
      return ac;
    }

    function createSWF(attObj, parObj, id) {
      var r, el = getElementById(id);
      if (ua.wk && ua.wk < 312) {
        return r;
      }
      if (el) {
        if (typeof attObj.id == UNDEF) {
          attObj.id = id;
        }
        if (ua.ie && ua.win) {
          var att = "";
          for (var i in attObj) {
            if (attObj[i] != Object.prototype[i]) {
              if (i.toLowerCase() == "data") {
                parObj.movie = attObj[i];
              } else {
                if (i.toLowerCase() == "styleclass") {
                  att += ' class="' + attObj[i] + '"';
                } else {
                  if (i.toLowerCase() != "classid") {
                    att += " " + i + '="' + attObj[i] + '"';
                  }
                }
              }
            }
          }
          var par = "";
          for (var j in parObj) {
            if (parObj[j] != Object.prototype[j]) {
              par += '<param name="' + j + '" value="' + parObj[j] + '" />';
            }
          }
          el.outerHTML = '<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"' + att + ">" + par + "</object>";
          objIdArr[objIdArr.length] = attObj.id;
          r = getElementById(attObj.id);
        } else {
          var o = createElement(OBJECT);
          o.setAttribute("type", FLASH_MIME_TYPE);
          for (var m in attObj) {
            if (attObj[m] != Object.prototype[m]) {
              if (m.toLowerCase() == "styleclass") {
                o.setAttribute("class", attObj[m]);
              } else {
                if (m.toLowerCase() != "classid") {
                  o.setAttribute(m, attObj[m]);
                }
              }
            }
          }
          for (var n in parObj) {
            if (parObj[n] != Object.prototype[n] && n.toLowerCase() != "movie") {
              createObjParam(o, n, parObj[n]);
            }
          }
          el.parentNode.replaceChild(o, el);
          r = o;
        }
      }
      return r;
    }

    function createObjParam(el, pName, pValue) {
      var p = createElement("param");
      p.setAttribute("name", pName);
      p.setAttribute("value", pValue);
      el.appendChild(p);
    }

    function removeSWF(id) {
      var obj = getElementById(id);
      if (obj && obj.nodeName == "OBJECT") {
        if (ua.ie && ua.win) {
          obj.style.display = "none";
          (function () {
            if (obj.readyState == 4) {
              removeObjectInIE(id);
            } else {
              setTimeout(arguments.callee, 10);
            }
          })();
        } else {
          obj.parentNode.removeChild(obj);
        }
      }
    }

    function removeObjectInIE(id) {
      var obj = getElementById(id);
      if (obj) {
        for (var i in obj) {
          if (typeof obj[i] == "function") {
            obj[i] = null;
          }
        }
        obj.parentNode.removeChild(obj);
      }
    }

    function getElementById(id) {
      var el = null;
      try {
        el = doc.getElementById(id);
      } catch (e) {}
      return el;
    }

    function createElement(el) {
      return doc.createElement(el);
    }

    function addListener(target, eventType, fn) {
      target.attachEvent(eventType, fn);
      listenersArr[listenersArr.length] = [target, eventType, fn];
    }

    function hasPlayerVersion(rv) {
      var pv = ua.pv,
        v = rv.split(".");
      v[0] = parseInt(v[0], 10);
      v[1] = parseInt(v[1], 10) || 0;
      v[2] = parseInt(v[2], 10) || 0;
      return (pv[0] > v[0] || (pv[0] == v[0] && pv[1] > v[1]) || (pv[0] == v[0] && pv[1] == v[1] && pv[2] >= v[2])) ? true : false;
    }

    function createCSS(sel, decl, media, newStyle) {
      if (ua.ie && ua.mac) {
        return;
      }
      var h = doc.getElementsByTagName("head")[0];
      if (!h) {
        return;
      }
      var m = (media && typeof media == "string") ? media : "screen";
      if (newStyle) {
        dynamicStylesheet = null;
        dynamicStylesheetMedia = null;
      }
      if (!dynamicStylesheet || dynamicStylesheetMedia != m) {
        var s = createElement("style");
        s.setAttribute("type", "text/css");
        s.setAttribute("media", m);
        dynamicStylesheet = h.appendChild(s);
        if (ua.ie && ua.win && typeof doc.styleSheets != UNDEF && doc.styleSheets.length > 0) {
          dynamicStylesheet = doc.styleSheets[doc.styleSheets.length - 1];
        }
        dynamicStylesheetMedia = m;
      }
      if (ua.ie && ua.win) {
        if (dynamicStylesheet && typeof dynamicStylesheet.addRule == OBJECT) {
          dynamicStylesheet.addRule(sel, decl);
        }
      } else {
        if (dynamicStylesheet && typeof doc.createTextNode != UNDEF) {
          dynamicStylesheet.appendChild(doc.createTextNode(sel + " {" + decl + "}"));
        }
      }
    }

    function setVisibility(id, isVisible) {
      if (!autoHideShow) {
        return;
      }
      var v = isVisible ? "visible" : "hidden";
      if (isDomLoaded && getElementById(id)) {
        getElementById(id).style.visibility = v;
      } else {
        createCSS("#" + id, "visibility:" + v);
      }
    }

    function urlEncodeIfNecessary(s) {
      var regex = /[\\\"<>\.;]/;
      var hasBadChars = regex.exec(s) != null;
      return hasBadChars && typeof encodeURIComponent != UNDEF ? encodeURIComponent(s) : s;
    }
    var cleanup = function () {
      if (ua.ie && ua.win) {
        window.attachEvent("onunload", function () {
          var ll = listenersArr.length;
          for (var i = 0; i < ll; i++) {
            listenersArr[i][0].detachEvent(listenersArr[i][1], listenersArr[i][2]);
          }
          var il = objIdArr.length;
          for (var j = 0; j < il; j++) {
            removeSWF(objIdArr[j]);
          }
          for (var k in ua) {
            ua[k] = null;
          }
          ua = null;
          for (var l in CVP.swfobject) {
            CVP.swfobject[l] = null;
          }
          CVP.swfobject = null;
        });
      }
    }();
    return {
      registerObject: function (objectIdStr, swfVersionStr, xiSwfUrlStr, callbackFn) {
        if (ua.w3 && objectIdStr && swfVersionStr) {
          var regObj = {};
          regObj.id = objectIdStr;
          regObj.swfVersion = swfVersionStr;
          regObj.expressInstall = xiSwfUrlStr;
          regObj.callbackFn = callbackFn;
          regObjArr[regObjArr.length] = regObj;
          setVisibility(objectIdStr, false);
        } else {
          if (callbackFn) {
            callbackFn({
              success: false,
              id: objectIdStr
            });
          }
        }
      },
      getObjectById: function (objectIdStr) {
        if (ua.w3) {
          return getObjectById(objectIdStr);
        }
      },
      embedSWF: function (swfUrlStr, replaceElemIdStr, widthStr, heightStr, swfVersionStr, xiSwfUrlStr, flashvarsObj, parObj, attObj, callbackFn) {
        var callbackObj = {
          success: false,
          id: replaceElemIdStr
        };
        if (ua.w3 && !(ua.wk && ua.wk < 312) && swfUrlStr && replaceElemIdStr && widthStr && heightStr && swfVersionStr) {
          setVisibility(replaceElemIdStr, false);
          addDomLoadEvent(function () {
            widthStr += "";
            heightStr += "";
            var att = {};
            if (attObj && typeof attObj === OBJECT) {
              for (var i in attObj) {
                att[i] = attObj[i];
              }
            }
            att.data = swfUrlStr;
            att.width = widthStr;
            att.height = heightStr;
            var par = {};
            if (parObj && typeof parObj === OBJECT) {
              for (var j in parObj) {
                par[j] = parObj[j];
              }
            }
            if (flashvarsObj && typeof flashvarsObj === OBJECT) {
              for (var k in flashvarsObj) {
                if (typeof par.flashvars != UNDEF) {
                  par.flashvars += "&" + k + "=" + flashvarsObj[k];
                } else {
                  par.flashvars = k + "=" + flashvarsObj[k];
                }
              }
            }
            if (hasPlayerVersion(swfVersionStr)) {
              var obj = createSWF(att, par, replaceElemIdStr);
              if (att.id == replaceElemIdStr) {
                setVisibility(replaceElemIdStr, true);
              }
              callbackObj.success = true;
              callbackObj.ref = obj;
            } else {
              if (xiSwfUrlStr && canExpressInstall()) {
                att.data = xiSwfUrlStr;
                showExpressInstall(att, par, replaceElemIdStr, callbackFn);
                return;
              } else {
                setVisibility(replaceElemIdStr, true);
              }
            }
            if (callbackFn) {
              callbackFn(callbackObj);
            }
          });
        } else {
          if (callbackFn) {
            callbackFn(callbackObj);
          }
        }
      },
      switchOffAutoHideShow: function () {
        autoHideShow = false;
      },
      ua: ua,
      getFlashPlayerVersion: function () {
        return {
          major: ua.pv[0],
          minor: ua.pv[1],
          release: ua.pv[2]
        };
      },
      hasFlashPlayerVersion: hasPlayerVersion,
      createSWF: function (attObj, parObj, replaceElemIdStr) {
        if (ua.w3) {
          return createSWF(attObj, parObj, replaceElemIdStr);
        } else {
          return undefined;
        }
      },
      showExpressInstall: function (att, par, replaceElemIdStr, callbackFn) {
        if (ua.w3 && canExpressInstall()) {
          showExpressInstall(att, par, replaceElemIdStr, callbackFn);
        }
      },
      removeSWF: function (objElemIdStr) {
        if (ua.w3) {
          removeSWF(objElemIdStr);
        }
      },
      createCSS: function (selStr, declStr, mediaStr, newStyleBoolean) {
        if (ua.w3) {
          createCSS(selStr, declStr, mediaStr, newStyleBoolean);
        }
      },
      addDomLoadEvent: addDomLoadEvent,
      addLoadEvent: addLoadEvent,
      getQueryParamValue: function (param) {
        var q = doc.location.search || doc.location.hash;
        if (q) {
          if (/\?/.test(q)) {
            q = q.split("?")[1];
          }
          if (param == null) {
            return urlEncodeIfNecessary(q);
          }
          var pairs = q.split("&");
          for (var i = 0; i < pairs.length; i++) {
            if (pairs[i].substring(0, pairs[i].indexOf("=")) == param) {
              return urlEncodeIfNecessary(pairs[i].substring((pairs[i].indexOf("=") + 1)));
            }
          }
        }
        return "";
      },
      expressInstallCallback: function () {
        if (isExpressInstallActive) {
          var obj = getElementById(EXPRESS_INSTALL_ID);
          if (obj && storedAltContent) {
            obj.parentNode.replaceChild(storedAltContent, obj);
            if (storedAltContentId) {
              setVisibility(storedAltContentId, true);
              if (ua.ie && ua.win) {
                storedAltContent.style.display = "block";
              }
            }
            if (storedCallbackFn) {
              storedCallbackFn(storedCallbackObj);
            }
          }
          isExpressInstallActive = false;
        }
      }
    };
  }();
  CVP.authSessionToken = "";
  CVP.getSessionToken = function () {
    if (typeof Aspen !== "undefined" && typeof Aspen.initialized !== "undefined" && Aspen.sessionToken !== "") {
      CVP.authSessionToken = Aspen.sessionToken;
    } else {
      if (CVP.authSessionToken === "") {
        CVP.authSessionToken = CVP.Utils.randomString(25);
      }
    }
    return CVP.authSessionToken;
  };
  var bind = CVP.Utils.bind;
  var byId = CVP.Utils.byId;
  var empty = CVP.Utils.empty;
  var extend = CVP.Utils.extend;
  var hasOwn = CVP.Utils.hasOwn;
  var isFlagActive = CVP.Utils.isFlagActive;
  var isFunc = CVP.Utils.isFunc;
  var isString = CVP.Utils.isString;
  var joinKeys = CVP.Utils.joinKeys;
  var nil = CVP.Utils.isNull;
  var now = CVP.Utils.now;
  var print = CVP.Utils.print;
  var slice = CVP.Utils.slice;
  var template = CVP.Utils.template;
  var undef = CVP.Utils.undef;
  var isRelativePath = CVP.Utils.isRelativePath;
  var Asset = CVP.Utils.Asset;
  var CommandQueue = CVP.Utils.CommandQueue;
  var Event = CVP.Events.CustomEvent;
  var log = CVP.Utils.log;
  (function () {
    var ConditionalTask = function (condition, success, interval) {
      this._interval = nil(interval) ? 10 : interval;
      this._maxTries = 500;
      this._condition = condition;
      this._success = success;
      this._tries = 0;
      this.conditionWrapper = bind(function () {
        var ret = this._condition();
        if (ret) {
          clearInterval(this._timer);
          this._success();
        } else {
          if (this._tries > this._maxTries) {
            log("condition never met!");
            clearInterval(this._timer);
          }
        }++this._tries;
      }, this);
      this.start = function () {
        this._timer = setInterval(this.conditionWrapper, this._interval);
      };
    };
    var Utils = {
      replaceExtension: function (str, find, replace) {
        if (empty(str)) {
          return str;
        }
        return str.replace(new RegExp(find + "$", "i"), replace);
      }
    };
    var ConfigUtils = {
      stringReplace: function (str, entry, uriEncode) {
        var patterns = this.getReplacementPatterns(str),
          i = 0,
          endi = 0,
          pattern, replaceStr = "";
        if (!empty(patterns)) {
          for (endi = patterns.length; i < endi; ++i) {
            pattern = patterns[i];
            replaceStr = "";
            replaceStr = this.getReplacementText(pattern, entry);
            if (empty(replaceStr)) {
              replaceStr = "";
            } else {
              if (uriEncode) {
                replaceStr = encodeURI(replaceStr);
              }
            }
            str = str.replace(pattern, replaceStr);
          }
        }
        return str;
      },
      getReplacementPatterns: function (str) {
        return (str && str.match(/[$][{][^}]*[}]/g));
      },
      getReplacementText: function (pattern, entry) {
        var replaceStr = "",
          nodeName = "",
          array = [],
          objName = "";
        switch (pattern) {
          case "${page.domain}":
            if (player) {
              replaceStr = document.domain;
            }
            break;
          case "${page.url}":
            replaceStr = location.href;
            break;
          case "${videoId}":
          case "${video.id}":
            if (entry) {
              replaceStr = entry.getId();
            }
            break;
          default:
            nodeName = pattern.substr(2, pattern.length - 3);
            array = nodeName.split(".");
            objName = array[0];
            if (array.length > 1) {
              nodeName = nodeName.substr(objName.length + 1);
              switch (objName) {
                case "video":
                  if (entry) {
                    replaceStr = XMLUtils.getNodeValue(entry._xmlEntry, nodeName);
                  }
                  break;
                case "javascript":
                  if (window.cvpSearchTheClient) {
                    replaceStr = window.cvpSearchTheClient(null, nodeName);
                  }
                  break;
                default:
                  replaceStr = pattern;
                  break;
              }
            } else {
              replaceStr = pattern;
            }
        }
        return replaceStr;
      }
    };
    var Loader = Class.extend({
      init: function () {
        this.eLoaded = new Event("LoadedEvent");
        this.eLoadError = new Event("LoadErrorEvent");
      },
      load: function (url, options) {
        var self = this;
        options = extend({
          ajax: {}
        }, options || {});
        var success = function (data) {
          log("Loader", "success:", url);
          self.eLoaded.dispatch(data);
        };
        var error = function (requestObj, textStatus, errorThrown) {
          log("Loader", "error:", url, "text:", textStatus);
          self.eLoadError.dispatch(requestObj, textStatus, errorThrown);
        };
        var ajaxOptions = extend({
          success: success,
          error: error
        }, options.ajax);
        ajaxOptions.url = url;
        this._sendRequest(ajaxOptions);
      },
      _sendRequest: function (ajaxOptions) {
        CVP.Ajax.get(ajaxOptions);
      }
    });
    var JSONPLoader = Loader.extend({
      init: function () {
        this._super();
      },
      _sendRequest: function (ajaxOptions) {
        CVP.Ajax.getJSONP(ajaxOptions);
      }
    });
    var XMLLoader = Class.extend({
      init: function () {
        this._loader = new Loader();
        this._loader.eLoaded.addListener(this._onLoaded, this);
        this._loader.eLoadError.addListener(this._onLoadError, this);
        this.eLoaded = new Event();
        this.eLoadError = new Event();
      },
      load: function (url, options) {
        this._loader.load(url, options);
      },
      _onLoaded: function (xmlStr) {
        xmlStr = XMLUtils.clean(xmlStr);
        var xDoc = XMLUtils.createDoc(xmlStr);
        log("XMLLoader", "XML loaded");
        this.eLoaded.dispatch(xDoc);
      },
      _onLoadError: function (requestObj, textStatus, errorThrown) {
        log("XMLParser", "onLoadError:", textStatus);
        if (textStatus === "parsererror") {
          log("XMLParser", "ParseError...attempting to create an xml doc manually");
          var xmlStr = requestObj.responseText;
          xmlStr = XMLUtils.clean(xmlStr);
          var xDoc = XMLUtils.createDoc(xmlStr);
          if (xDoc) {
            this.eLoaded.dispatch(xDoc);
          } else {
            this.eLoadError.dispatch(requestObj, textStatus, errorThrown);
          }
        }
      }
    });
    var UberLoader = Class.extend({
      init: function () {
        this._loader = null;
        this.eLoaded = new Event();
        this.eLoadError = new Event();
      },
      load: function (url, options) {
        this._createLoader(url);
        this._loader.load(url, options);
      },
      _createLoader: function (url) {
        if (this._loader) {
          this._destroyLoader();
        }
        var ext = this._getFileType(url);
        switch (ext) {
          case "xml":
            this._loader = new XMLLoader();
            break;
          case "json":
            this._loader = new JSONPLoader();
            break;
          default:
            this._loader = new Loader();
            break;
        }
        this._loader.eLoaded.addListener(this._onLoaded, this);
        this._loader.eLoadError.addListener(this._onLoadError, this);
      },
      _getFileType: function (url) {
        var match = String(url).match(/\.([^.?#]+)(?:[?#]|$)/);
        var ext = match ? match[1] : "";
        return ext;
      },
      _destroyLoader: function () {
        this._loader.eLoaded.removeListener(this._onLoaded, this);
        this._loader.eLoadError.removeListener(this._onLoadError, this);
        this._loader = null;
      },
      _onLoaded: function (data) {
        this.eLoaded.dispatch(data);
      },
      _onLoadError: function (requestObj, textStatus, errorThrown) {
        this.eLoadError.dispatch(requestObj, textStatus, errorThrown);
      }
    });
    var Parser = Class.extend({
      init: function () {
        this._loader = this._createLoader();
        this._loader.eLoaded.addListener(this.onLoaded, this);
        this._loader.eLoadError.addListener(this.onLoadError, this);
        this.eParseCompleted = new Event();
        this.eParseError = new Event();
      },
      _createLoader: function () {
        return new UberLoader();
      },
      parse: function (url) {
        log("Parser", "Loading the file to parse", url);
        this.load(url);
      },
      load: function (url, options) {
        this._loader.load(url, options);
      },
      onLoaded: function (data) {
        log("Parser", "Data loaded");
        this.parseData(data);
      },
      onLoadError: function (requestObj, textStatus, errorThrown) {
        log("Parser", "onLoadError:", textStatus);
        this._fireLoadedFailure();
      },
      parseData: function (xml) {},
      _fireLoadedSuccess: function () {
        log("Parser", "successfully Loaded asset");
        this.eParseCompleted.dispatch();
      },
      _fireLoadedFailure: function () {
        log("Parser", "failed to Load asset");
        this.eParseError.dispatch();
      }
    });
    var XMLUtils = {
      createDoc: (undef(window.DOMParser) ? function (xmlString) {
        if (empty(xmlString)) {
          return null;
        }
        var xDoc = new ActiveXObject("MSXML2.DOMDocument");
        xDoc.async = false;
        xDoc.loadXML(xmlString);
        return xDoc;
      } : function (xmlString) {
        if (empty(xmlString)) {
          return null;
        }
        var parser = new DOMParser();
        var xDoc = parser.parseFromString(xmlString, "text/xml");
        return xDoc;
      }),
      clean: function (xmlString) {
        xmlString = xmlString.replace(/>\s+</g, "><");
        xmlString = xmlString.replace(/\t+/g, " ");
        xmlString = xmlString.replace(/[\r\n]+/g, " ");
        xmlString = xmlString.replace(/<!--(.*?)-->/g, "");
        xmlString = xmlString.replace(/&/g, "&amp;");
        while (xmlString.indexOf("xmlns") > -1) {
          var start = xmlString.indexOf("xmlns");
          var firstQuote = xmlString.indexOf('"', start);
          var endQuote = xmlString.indexOf('"', firstQuote + 1);
          xmlString = xmlString.slice(0, start) + xmlString.slice(endQuote + 1);
        }
        return xmlString;
      },
      getNodeValue: function (doc, nodeName) {
        if (doc) {
          if (!nodeName) {
            return (!nil(doc.firstChild) ? doc.firstChild.nodeValue : null);
          }
          var nodes = doc.getElementsByTagName(nodeName);
          if (nodes.length > 0 && nodes[0].firstChild) {
            return nodes[0].firstChild.nodeValue;
          }
        }
        return null;
      },
      getParamValue: function (doc, paramName) {
        var nodes, i = 0,
          endi = 0;
        if (doc) {
          if (!paramName) {
            return null;
          }
          nodes = doc.getElementsByTagName("param");
          for (endi = nodes.length; i < endi; ++i) {
            if (this.getAttribute(nodes[i], "name") === paramName) {
              return this.getAttribute(nodes[i], "value");
            }
          }
        }
        return null;
      },
      getAttribute: function (node, attrName) {
        if (node && node.attributes && !empty(attrName)) {
          var attr = node.attributes.getNamedItem(attrName);
          return attr ? attr.nodeValue : null;
        }
      },
      assignAttributes: function (obj, attributes) {
        var a = 0,
          end = (attributes && attributes.length) || 0,
          attr;
        for (; a < end; ++a) {
          attr = attributes[a];
          obj[attr.nodeName] = attr.nodeValue;
        }
      },
      toString: function (xmlDoc) {
        if (undef(window.XMLSerializer)) {
          this.toString = function (xmlDoc) {
            return xmlDoc.xml;
          };
        } else {
          this.toString = function (xmlDoc) {
            return new XMLSerializer().serializeToString(xmlDoc);
          };
        }
        return this.toString(xmlDoc);
      }
    };
    var DependencyMananger = Class.extend({
      init: function () {
        this._dependencies = [];
        this._currentDependency = null;
        this.eSuccess = new Event();
        this.eFailure = new Event();
        this.eDependencySuccess = new Event();
        this.eDependencyFailure = new Event();
      },
      addDependency: function (dependency) {
        dependency.setManager(this);
        this._dependencies.push(dependency);
      },
      load: function () {
        this._currentDependency = this._dependencies.shift();
        this._currentDependency.eSuccess.addListener(this._onDependencySuccess, this);
        this._currentDependency.eFailure.addListener(this._onDependencyFailure, this);
        var self = this;
        setTimeout(function () {
          self._currentDependency.load();
        }, 10);
      },
      _onDependencySuccess: function () {
        this.eDependencySuccess.dispatch(this._currentDependency.getDesc());
        this._next();
      },
      _onDependencyFailure: function () {
        this.eDependencyFailure.dispatch(this._currentDependency.getDesc());
        if (this._currentDependency.required) {
          this._onFailure(this._currentDependency.getDesc());
          return;
        }
        this._next();
      },
      _next: function () {
        if (this._dependencies.length) {
          this.load();
        } else {
          this._onSuccess();
        }
      },
      _onSuccess: function (desc) {
        this.eSuccess.dispatch(desc);
      },
      _onFailure: function (desc) {
        this.eFailure.dispatch(desc);
      }
    });
    var Dependency = Class.extend({
      init: function (assetUrl, required) {
        this._assetUrl = assetUrl;
        this.required = required;
        this._manager = null;
        this.eSuccess = new Event();
        this.eFailure = new Event();
      },
      load: function () {
        log("Dependency", "loading asset", this._assetUrl);
        var assetLoader = new Asset(this._assetUrl);
        assetLoader.eSuccess.addListener(this._success, this);
        assetLoader.eFailure.addListener(this._failure, this);
        assetLoader.load();
      },
      _success: function () {
        log("Dependency", "successfully loaded dependency", this._assetUrl);
        this.eSuccess.dispatch();
      },
      _failure: function () {
        log("Dependency", "failed to load dependency", this._assetUrl);
        this.eFailure.dispatch();
      },
      setManager: function (manager) {
        this._manager = manager;
      },
      getDesc: function () {
        return this._assetUrl;
      }
    });
    var BootStrapper = (function () {
      var _params = {}, _mapping = {}, _appConfig = {}, _containerInfo = {}, _configInfo = {
        omniture: {},
        share: {},
        embed: {}
      }, _adPolicy = {
        ads: {
          attr: {
            type: "NONE"
          }
        }
      };
      var MappingParser = Parser.extend({
        init: function () {
          this._super();
        },
        load: function (url) {
          var options = {
            ajax: {
              jsonpCallback: "cvp_onMappingReceived"
            }
          };
          this._super(url, options);
        },
        parseData: function (data) {
          var mappings, profile, map;
          if (undef(data) || undef(data.mappings)) {
            this.eParseError.dispatch();
            return;
          }
          mappings = data.mappings;
          profile = _params.profile;
          for (map in mappings) {
            if (mappings[map].profile === profile) {
              break;
            }
          }
          _mapping = mappings[map];
          this._fireLoadedSuccess();
        }
      });
      var AppConfigParser = Parser.extend({
        init: function () {
          this._super();
        },
        load: function (url) {
          var options = {
            ajax: {
              jsonpCallback: "cvp_onAppConfigReceived"
            }
          };
          this._super(url, options);
        },
        parseData: function (data) {
          _appConfig = data.appConfig;
          this._fireLoadedSuccess();
        }
      });
      var ContainerParser = Parser.extend({
        init: function () {
          this._super();
        },
        parseData: function (xml) {
          var self = this,
            i = 0,
            endi = 0,
            docElement = xml.documentElement,
            contextName = _params.context || "",
            elementName = _params.element || "",
            contexts = null,
            context = null,
            element = null,
            node = null,
            policies = null,
            adPolicySrc = null,
            adPolicyContext = null,
            playerWidth = null,
            playerHeight = null,
            playerX = null,
            playerY = null;
          defaultNode = docElement.getElementsByTagName("default");
          policies = (defaultNode.length && defaultNode[0].getElementsByTagName("policies")) || [];
          if (policies.length) {
            adPolicySrc = XMLUtils.getParamValue(policies[0], "adPolicySrc");
            adPolicyContext = XMLUtils.getParamValue(policies[0], "adPolicyContext");
          }
          _containerInfo.elementName = elementName;
          _containerInfo.adPolicySrc = adPolicySrc;
          _containerInfo.adPolicyContext = adPolicyContext;
          contexts = docElement.getElementsByTagName("context");
          for (endi = contexts.length; i < endi; ++i) {
            if (XMLUtils.getAttribute(contexts[i], "name") === contextName) {
              context = contexts[i];
              break;
            }
          }
          if (context) {
            var elements = context.getElementsByTagName("element");
            for (i = 0, endi = elements.length; i < endi; ++i) {
              if (XMLUtils.getAttribute(elements[i], "id") === elementName) {
                element = elements[i];
                break;
              }
            }
            if (!element) {
              element = elements[0];
            }
            if (element) {
              elementName = XMLUtils.getAttribute(element, "id");
              policies = element.getElementsByTagName("policies");
              if (policies.length > 0) {
                adPolicySrc = XMLUtils.getParamValue(policies[0], "adPolicySrc");
                adPolicyContext = XMLUtils.getParamValue(policies[0], "adPolicyContext");
              }
              var players = element.getElementsByTagName("player");
              var playerName = XMLUtils.getAttribute(players[players.length - 1], "playerInstance");
              if (empty(playerName)) {
                playerName = contextName;
              }
              _containerInfo.playerInstance = playerName;
            }
          }
          if (!empty(elementName)) {
            _containerInfo.elementName = elementName;
          }
          if (!empty(adPolicySrc)) {
            _containerInfo.adPolicySrc = adPolicySrc;
          }
          if (!empty(adPolicyContext)) {
            _containerInfo.adPolicyContext = adPolicyContext;
          }
          CVP.Utils.print(_containerInfo, "_containerInfo");
          this._fireLoadedSuccess();
        },
        parseParams: function (obj, name, value) {
          switch (name) {
            case "adPolicySrc":
              obj.adPolicySrc = value;
              break;
            case "adPolicyContext":
              obj.adPolicyContext = value;
              break;
            default:
              obj[name] = value;
          }
        }
      });
      var ConfigParser = Parser.extend({
        init: function () {
          this._super();
        },
        parseData: function (xml) {
          var self = this,
            docElement = xml.documentElement,
            playerInstanceName = _containerInfo.playerInstance || "",
            player = null,
            players = docElement.getElementsByTagName("player"),
            node, process;
          while (players.length) {
            node = players[players.length - 1];
            if (XMLUtils.getAttribute(node, "name") === playerInstanceName) {
              player = node.cloneNode(true);
            }
            docElement.removeChild(node);
          }
          process = function (xml, objToAssign) {
            if (nil(xml)) {
              return;
            }
            var childNodes = xml.childNodes,
              xmlLength = childNodes.length,
              childNode, obj, i = 0;
            for (; i < xmlLength; ++i) {
              childNode = childNodes[i];
              obj = self.findMapping(childNode.nodeName);
              if (!nil(obj)) {
                self.parseAttributes(obj, childNode);
                if (childNode.childNodes.length) {
                  process(childNode, obj);
                }
              } else {
                if (childNode.nodeName === "param") {
                  self.parseParams(objToAssign, XMLUtils.getAttribute(childNode, "name"), XMLUtils.getAttribute(childNode, "value"));
                }
              }
            }
          };
          defaultNode = docElement.getElementsByTagName("default");
          if (defaultNode.length > 0) {
            process(defaultNode[0], _configInfo);
          }
          if (!nil(player)) {
            process(player, _configInfo);
          }
          CVP.Utils.print(_configInfo, "_configInfo");
          players = player = childNodes = childNode = null;
          this._fireLoadedSuccess();
        },
        parseParams: function (obj, name, value) {
          switch (name) {
            default: obj[name] = value;
          }
        },
        parseAttributes: function (obj, node) {
          if (node.hasAttributes) {
            if (!obj.attr) {
              obj.attr = {};
            }
            XMLUtils.assignAttributes(obj.attr, node.attributes);
          }
        },
        findMapping: function (nodeName) {
          var obj = null;
          switch (nodeName) {
            default: obj = null;
          }
          return obj;
        }
      });
      var AdPolicyParser = Parser.extend({
        init: function () {
          this._super();
        },
        parseData: function (xml) {
          var self = this,
            i = 0,
            docElement = xml.documentElement,
            adContextName = _containerInfo.adPolicyContext || "",
            context = null,
            contexts = docElement.getElementsByTagName("context"),
            endi = contexts.length || 0,
            node, process, defaultNode;
          for (; i < endi; ++i) {
            if (XMLUtils.getAttribute(contexts[i], "name") === adContextName) {
              context = contexts[i];
              break;
            }
          }
          process = function (xml, objToAssign) {
            if (nil(xml)) {
              return;
            }
            var childNodes = xml.childNodes,
              xmlLength = childNodes.length,
              childNode, obj, i = 0;
            for (; i < xmlLength; ++i) {
              childNode = childNodes[i];
              obj = self.findMapping(childNode.nodeName);
              if (!nil(obj)) {
                self.parseAttributes(obj, childNode);
                if (childNode.childNodes.length) {
                  process(childNode, obj);
                }
              } else {
                if (childNode.nodeName === "param") {
                  self.parseParams(objToAssign, XMLUtils.getAttribute(childNode, "name"), XMLUtils.getAttribute(childNode, "value"));
                }
              }
            }
          };
          defaultNode = docElement.getElementsByTagName("default");
          if (defaultNode.length !== 0) {
            process(defaultNode[0], _adPolicy);
          }
          if (!nil(context)) {
            process(context, _adPolicy);
          }
          CVP.Utils.print(_adPolicy, "_adPolicy");
          contexts = context = childNodes = childNode = null;
          this._fireLoadedSuccess();
        },
        parseParams: function (obj, name, value) {
          switch (name) {
            case "adApi":
              obj.apiUrl = value;
              break;
            case "adManRootUrl":
              obj.adManRootUrl = value;
              break;
            case "adServerRootUrl":
              obj.adServerRootUrl = value;
              break;
            case "adVideoRootUrl":
              obj.adVideoRootUrl = value;
              break;
            case "adVideoExtension":
              obj.adVideoExtension = value;
              break;
            case "additionalVideoSegvars":
              obj.additionalVideoSegVars = value;
              break;
            case "additionalSyncSegvars":
              obj.additionalSyncSegVars = value;
              break;
            case "adSection":
              obj.adSection = value;
              break;
            case "adNetworkId":
              obj.adNetworkId = value;
              break;
            case "adVideoNetworkId":
              obj.adVideoNetworkId = value;
              break;
            case "adVideoAssetId":
              obj.adVideoAssetId = value;
              break;
            case "adPlayerProfile":
              obj.adPlayerProfile = value;
              break;
            case "renderersUrl":
              obj.renderersUrl = value;
              break;
            case "externalSlots":
              obj.externalSlots = isFlagActive(value, obj.externalSlots);
              break;
            case "adLiveContentDuration":
              obj.liveDuration = value;
              break;
            default:
              obj[name] = value;
          }
        },
        parseAttributes: function (obj, node) {
          if (node.hasAttributes) {
            if (!obj.attr) {
              obj.attr = {};
            }
            XMLUtils.assignAttributes(obj.attr, node.attributes);
          }
        },
        findMapping: function (nodeName) {
          var obj = null;
          switch (nodeName) {
            case "adServer":
              obj = _adPolicy.ads;
              break;
          }
          return obj;
        }
      });
      var MappingDependency = Dependency.extend({
        init: function () {
          this._super.apply(this, arguments);
          this.required = true;
          this._parser = new MappingParser();
          this._parser.eParseCompleted.addListener(this._onParseCompleted, this);
          this._parser.eParseError.addListener(this._onParseError, this);
        },
        load: function () {
          log("MappingDependency", "loading xml", this._assetUrl);
          this._parser.parse(this._assetUrl);
        },
        _onParseCompleted: function () {
          if (!_mapping || empty(_mapping.url)) {
            log("Unable to retrieve the mapping file.");
            this._failure();
            return;
          }
          var appConfigUrl = Utils.replaceExtension(_mapping.url, "xml", "json");
          this._manager.addDependency(new AppConfigDependency(appConfigUrl, true));
          this._success();
        },
        _onParseError: function () {
          this._failure();
        },
        getDesc: function () {
          return "MappingDependency: " + this._assetUrl;
        }
      });
      var AppConfigDependency = Dependency.extend({
        init: function () {
          this._super.apply(this, arguments);
          this.required = true;
          this._parser = new AppConfigParser();
          this._parser.eParseCompleted.addListener(this._onParseCompleted, this);
          this._parser.eParseError.addListener(this._onParseError, this);
        },
        load: function () {
          log("AppConfigDependency", "loading xml", this._assetUrl);
          this._parser.parse(this._assetUrl);
        },
        _onParseCompleted: function () {
          if (!_appConfig || empty(_appConfig.containerUrl) || empty(_appConfig.configUrl)) {
            log("Unable to retrieve the appConfig file.");
            this._failure();
            return;
          }
          this._manager.addDependency(new ContainerDependency(_appConfig.containerUrl, true));
          this._manager.addDependency(new ConfigDependency(_appConfig.configUrl, true));
          this._success();
        },
        _onParseError: function () {
          this._failure();
        },
        getDesc: function () {
          return "AppConfigDependency: " + this._assetUrl;
        }
      });
      var ContainerDependency = Dependency.extend({
        init: function () {
          this._super.apply(this, arguments);
          this.required = true;
          this._parser = new ContainerParser();
          this._parser.eParseCompleted.addListener(this._onParseCompleted, this);
          this._parser.eParseError.addListener(this._onParseError, this);
        },
        load: function () {
          log("ContainerDependency", "loading xml", this._assetUrl);
          this._parser.parse(this._assetUrl);
        },
        _onParseCompleted: function () {
          if (!empty(_containerInfo.adPolicySrc)) {
            this._manager.addDependency(new AdPolicyDependency(_containerInfo.adPolicySrc, true));
          }
          this._success();
        },
        _onParseError: function () {
          this._failure();
        },
        getDesc: function () {
          return "ContainerDependency: " + this._assetUrl;
        }
      });
      var ConfigDependency = Dependency.extend({
        init: function () {
          this._super.apply(this, arguments);
          this.required = true;
          this._parser = new ConfigParser();
          this._parser.eParseCompleted.addListener(this._onParseCompleted, this);
          this._parser.eParseError.addListener(this._onParseError, this);
        },
        load: function () {
          this._parser.parse(this._assetUrl);
        },
        _onParseCompleted: function () {
          if (this._manager) {
            if (!empty(_configInfo.omniture.omniture_account)) {
              log("ContainerDependency", "adding Omniture dependency");
            }
          }
          this._success();
        },
        _onParseError: function () {
          this._failure();
        },
        getDesc: function () {
          return "ConfigDependency: " + this._assetUrl;
        }
      });
      var AdPolicyDependency = Dependency.extend({
        init: function () {
          this._super.apply(this, arguments);
          this.required = true;
          this._parser = new AdPolicyParser();
          this._parser.eParseCompleted.addListener(this._onParseCompleted, this);
          this._parser.eParseError.addListener(this._onParseError, this);
        },
        load: function () {
          log("AdPolicyDependency", "loading xml", this._assetUrl);
          this._parser.parse(this._assetUrl);
        },
        _onParseCompleted: function () {
          var type = _adPolicy.ads.attr.type.toLowerCase();
          if (type === "freewheel") {
            log("ContainerDependency", "adding FW dependency");
            this._manager.addDependency(new Dependency(_params.freewheelJsUrl, true));
          } else {
            if (type === "dfp") {
              log("ContainerDependency", "adding DFP dependency");
              this._manager.addDependency(new Dependency(AD_DFP_URL, true));
            }
          }
          this._success();
        },
        _onParseError: function () {
          this._failure();
        },
        getDesc: function () {
          return "AdPolicyDependency: " + this._assetUrl;
        }
      });
      var BootStrapper = Class.extend({
        init: function (mappingUrl, params) {
          this._mappingUrl = mappingUrl;
          _params = params || {};
          this.eSuccess = new Event();
          this.eFailure = new Event();
        },
        load: function () {
          this._bootStrapper = new DependencyMananger();
          this._bootStrapper.addDependency(new MappingDependency(this._mappingUrl), true);
          this._bootStrapper.eSuccess.addListener(this._success, this);
          this._bootStrapper.eFailure.addListener(this._failure, this);
          this._bootStrapper.load();
        },
        _success: function () {
          var event = {
            data: {
              mapping: _mapping,
              appConfig: _appConfig,
              containerInfo: _containerInfo,
              configInfo: _configInfo,
              adPolicy: _adPolicy
            }
          };
          this.eSuccess.dispatch(event);
        },
        _failure: function () {
          this.eFailure.dispatch();
        }
      });
      return BootStrapper;
    })();
    var CMS = Class.extend({
      init: function () {
        this._catalogDataURL = "";
        this._mediaUrl = "";
        this._requestPendingQueue = [];
        this._videoCatalog = [];
        this._requests = {};
        this._loader = new XMLLoader();
        this._loader.eLoaded.addListener(this._onContentIdRequestComplete, this);
        this._loader.eLoadError.addListener(this._onContentIdRequestIOError, this);
        this.eRequestCompleted = new Event("CmsRequestCompletedEvent");
      },
      addContentId: function (contentId) {
        var entry = this.getContentId(contentId);
        if (nil(entry)) {
          this._requestPendingQueue.push(contentId);
        } else {
          var index = contentId.split("|")[1];
          contentId = contentId.split("|")[0];
          this._notifyListeners(contentId, contentId, index);
        }
        if (this._requestPendingQueue.length === 1) {
          this._processNextRequest();
        }
      },
      getContentId: function (contentId) {
        contentId = contentId.split("|")[0];
        var i = 0,
          ct = this._videoCatalog.length;
        for (; i < ct; ++i) {
          var entry = this._videoCatalog[i];
          if (entry.getId() === contentId) {
            return entry;
          }
        }
        return null;
      },
      clear: function () {
        this._videoCatalog = [];
      },
      setDataUrl: function (url) {
        this._catalogDataURL = url;
      },
      setMediaUrl: function (url) {
        this._mediaUrl = url;
      },
      _getRequestUrl: function (contentId) {
        var requestUrl;
        var start = this._catalogDataURL.substr(0).search(/\$\{/);
        if (start !== -1) {
          var end = this._catalogDataURL.substr(start).search(/\}/);
          if (end !== -1) {
            var pattern = this._catalogDataURL.substr(start, end + 1);
            requestUrl = this._catalogDataURL.replace(pattern, contentId);
          }
        } else {
          requestUrl = this._catalogDataURL + "/" + contentId + ".xml";
        }
        return requestUrl;
      },
      _createContentEntryFromRequestData: function (requestData, contentId) {
        try {
          var entry = new ContentCatalogEntry(requestData);
          entry.setMediaUrl(this._mediaUrl);
          return entry;
        } catch (e) {
          alert(this._getRequestUrl(contentId) + ": " + e.message);
        }
        return null;
      },
      _processNextRequest: function () {
        if (this._requestPendingQueue.length > 0) {
          var contentId = this._requestPendingQueue[0].split("|")[0];
          this._requestVideoWithId(contentId);
        }
      },
      _requestVideoWithId: function (contentId) {
        var url = this._getRequestUrl(contentId);
        this._loader.load(url);
      },
      _onContentIdRequestComplete: function (data) {
        var request = this._requestPendingQueue[0].split("|");
        var contentId = request[0];
        var requestIndex = request[1];
        if (data) {
          var entry = this._createContentEntryFromRequestData(data, contentId);
          if (!entry) {
            this._notifyListeners(contentId, contentId, requestIndex, "No URLLoader");
          } else {
            entry.requestId = contentId;
            this._videoCatalog.push(entry);
            this._notifyListeners(entry.getId(), entry.requestId, requestIndex, "");
          }
        } else {
          this._notifyListeners(contentId, contentId, requestIndex, "No URLLoader");
        }
        this._requestPendingQueue.shift();
        this._processNextRequest();
      },
      _onContentIdRequestIOError: function () {
        var request = this._requestPendingQueue[0].split("|");
        var contentId = request[0];
        var requestIndex = request[1];
        this._notifyListeners(contentId, contentId, "IOError : " + event.text);
        this._requestPendingQueue.shift();
        this._processNextRequest();
      },
      _notifyListeners: function (contentId, requestId, index, errorMsg) {
        this.eRequestCompleted.dispatch(contentId, requestId, index, errorMsg);
      }
    });
    var ContentCatalogEntry = Class.extend({
      init: function (xml) {
        var anchor, files, f, file, fKey, fFallback, fValue, path, ext, images, image, iWidth, iHeight, iKey, iValue, lastDot, ads, ad, adKey, adValue;
        anchor = document.createElement("a");
        this._xmlEntry = xml.documentElement;
        this._requestId = null;
        this._mediaUrl = "";
        this._name = XMLUtils.getNodeValue(this._xmlEntry, "slug");
        this._title = XMLUtils.getNodeValue(this._xmlEntry, "headline");
        this._category = XMLUtils.getNodeValue(this._xmlEntry, "category");
        this._trt = +XMLUtils.getNodeValue(this._xmlEntry, "trt");
        files = this._xmlEntry.getElementsByTagName("files");
        if (files.length) {
          files = files[0].childNodes;
          this._fileList = {};
          for (f in files) {
            file = files[f];
            if (file.nodeType !== 1 || file.nodeName !== "file") {
              continue;
            }
            fKey = XMLUtils.getAttribute(file, "bitrate");
            fFallback = XMLUtils.getAttribute(file, "fallback");
            fValue = XMLUtils.getNodeValue(file);
            ext = "";
            anchor.href = this.sanitizeUrl(fValue);
            path = anchor.pathname;
            lastDot = path.lastIndexOf(".");
            if (path && ~lastDot) {
              ext = path.substring(lastDot + 1);
            }
            anchor.href = "javascript:";
            log("ContentCatalogEntry", fKey, fValue, ext);
            this._fileList[fKey] = {
              url: fValue,
              fallback: fFallback,
              ext: ext
            };
          }
        } else {
          log("ContentCatalogEntry", "No file entries found!");
        }
        images = this._xmlEntry.getElementsByTagName("images");
        if (images.length) {
          images = images[0].childNodes;
          this._imageList = {};
          for (image in images) {
            if (images[image].nodeType !== 1) {
              continue;
            }
            iWidth = XMLUtils.getAttribute(images[image], "width");
            iHeight = XMLUtils.getAttribute(images[image], "height");
            iValue = XMLUtils.getNodeValue(images[image]);
            log("ContentCatalogEntry", "images", iWidth, iHeight, iValue);
            iKey = iWidth + "|" + iHeight;
            this._imageList[iKey] = {
              url: iValue,
              width: iWidth,
              height: iHeight
            };
          }
        }
        ads = this._xmlEntry.getElementsByTagName("ads");
        if (ads.length) {
          ads = ads[0].childNodes;
          this._adList = {};
          for (ad in ads) {
            if (ads[ad].nodeType !== 1) {
              continue;
            }
            adKey = XMLUtils.getAttribute(ads[ad], "type");
            adValue = XMLUtils.getNodeValue(ads[ad]);
            log("ContentCatalogEntry", "ad", adKey, adValue);
            this._adList[adKey] = {
              url: adValue
            };
          }
        }
      },
      setMediaUrl: function (url) {
        this._mediaUrl = url;
      },
      getId: function () {
        var attr = XMLUtils.getAttribute(this._xmlEntry, "id");
        if (!empty(attr)) {
          return attr;
        } else {
          return this._requestId;
        }
      },
      getName: function () {
        return this._name;
      },
      getTitle: function () {
        return this._title;
      },
      getCategory: function () {
        return this._category;
      },
      getTrt: function () {
        return this._trt;
      },
      sanitizeUrl: function (url) {
        if (url.indexOf("://") === -1) {
          url = this._mediaUrl + url;
        }
        return url;
      },
      getContentUrl: function (quality) {
        var url = null,
          dbgFound = false,
          bitrate;
        for (bitrate in this._fileList) {
          if (bitrate === quality) {
            url = this.sanitizeUrl(this._fileList[bitrate].url);
            dbgFound = true;
            break;
          }
        }
        if (!dbgFound) {
          log("Config XML specifies a " + quality + " bitrate entry, but there is no <file> node in video XML where bitrate attribute = " + quality + ".");
        } else {
          if (empty(url)) {
            log("text attribute is empty in the video XML for the <file> node whose quality is " + quality + ".");
          }
        }
        return url;
      },
      getContentUrlFromFallback: function (fallback) {
        var url = null,
          file = null,
          bitrate = "";
        for (bitrate in this._fileList) {
          file = this._fileList[bitrate];
          if (!(empty(file.fallback)) && fallback === file.fallback) {
            url = this.sanitizeUrl(file.url);
            break;
          }
        }
        return url;
      },
      getContentUrlFromType: function (ext) {
        var url = null,
          file = null,
          bitrate;
        for (bitrate in this._fileList) {
          file = this._fileList[bitrate];
          if (ext === file.ext) {
            url = this.sanitizeUrl(file.url);
            break;
          }
        }
        return url;
      },
      getThumbnailUrl: function (width, height) {
        var url = null,
          key = width + "|" + height,
          k;
        for (k in this._imageList) {
          if (k === key) {
            url = this._imageList[k].url;
            break;
          }
        }
        return url;
      },
      getAdUrl: function (type) {
        return ((this._adList && this._adList[type] && this._adList[type].url) || null);
      },
      getXML: function () {
        return this._xmlEntry;
      }
    });
    var PlayerInstance = (function () {
      var _params = {}, _mapping = {}, _appConfig = {}, _containerInfo = {}, _configInfo = {
        omniture: {},
        share: {},
        embed: {}
      }, _adPolicy = {
        ads: {
          attr: {
            type: "NONE"
          }
        }
      };
      var BasePlayer = Class.extend({
        init: function (options) {
          this.options = extend({
            containerElement: "",
            elementId: "",
            autoplay: true,
            controls: true,
            width: 0,
            height: 0
          }, options || {});
          this.containerElement = byId(this.options.containerElement);
          this.elementId = this.options.elementId;
          if (empty(this.elementId)) {
            log("Invalid element id...exiting");
            throw new Error("Invalid element id");
          }
          this.playerOptions = {};
          this.width = this.options.width;
          this.height = this.options.height;
          this.airplay = (!CVP.Browser.apple_mobile && (undef(_params.iosAirplay) || undef(_configInfo.iosAirplay))) ? "" : 'x-webkit-airplay="allow"';
          this.perVideoFallbacks = undef(_params.perVideoFallbacks) ? [] : _params.perVideoFallbacks;
          this.element = null;
          this.rendering = false;
          this.position = {
            top: null,
            right: null,
            bottom: null,
            left: null
          };
          this.eRendered = new Event();
          this.eContentMetadata = new Event();
          this.eContentPlay = new Event();
          this.eContentPause = new Event();
          this.eContentEnd = new Event();
          this.eContentPlayhead = new Event();
          this.eContentBuffering = new Event();
          this.eContentVolume = new Event();
          this.eContentError = new Event();
          this.eContentResize = new Event();
          this.eTrackingContentSeek = new Event();
          this.eFullscreenChange = new Event();
          this.eTrackingFullscreen = new Event();
          this.eTrackingMuted = new Event();
          this.eTrackingPaused = new Event();
        },
        getMarkup: function () {
          return "";
        },
        render: function (containerElement) {
          log("Player", "render");
          if (!empty(containerElement)) {
            this.containerElement = byId(containerElement);
          }
          if (nil(this.containerElement)) {
            log("Container element could not be found...cannot render...exiting");
            throw new Error("Container could not be found");
          }
          var markup = this.getMarkup();
          this.rendering = true;
          this.containerElement.innerHTML = markup;
          var self = this;
          new ConditionalTask(function () {
            if (!nil(byId(self.elementId))) {
              return true;
            }
          }, function () {
            self.rendering = false;
            self.element = byId(self.elementId);
            self.fireRendered();
          }).start();
        },
        rendered: function () {
          return this.element && this.element.parentNode === this.containerElement;
        },
        show: function () {
          if (this.element) {
            if (this.position.left) {
              this.element.style.left = this.position.left;
            }
          }
        },
        hide: function () {
          if (this.element) {
            this.position.left = this.element.style.left;
            this.element.style.left = "-5000px";
          }
        },
        remove: function () {
          log("Player", "remove");
          if (nil(this.containerElement)) {
            log("Container element could not be found .. cannot remove");
            throw new Error("Container element could not be found");
          }
          var element = byId(this.elementId);
          while (element.firstChild) {
            element.removeChild(element.firstChild);
          }
          element.parentNode.removeChild(element);
        },
        addPlayerListeners: function () {},
        removePlayerListeners: function () {},
        fireRendered: function () {
          this.eRendered.dispatch();
        },
        fireBegin: function () {},
        firePlay: function () {
          this.eContentPlay.dispatch(this._catalogEntry.getId());
        },
        fireEnded: function () {
          this.eContentEnd.dispatch(this._catalogEntry.getId());
        },
        fireCompleted: function () {}
      });
      var VideoPlayer = BasePlayer.extend({
        init: function (options) {
          this._super(options);
          this.playerOptions.controls = this.options.controls;
          this.playerOptions.autoplay = CVP.Browser.apple_mobile ? false : this.options.autostart;
          this._supportedFileTypes = this._determineSupportedFileTypes();
          this._firePlay = false;
          this._addedListeners = false;
          this._loaded = false;
          this._muted = false;
          this._paused = false;
          this._buffering = false;
          this._fullscreen = false;
          this._playheadTimer = null;
          this._playheadThrottling = false;
          this._mousedown = false;
          this._waitForMouseUp = false;
          this._onMouseDown = bind(function () {
            this._mousedown = true;
            this._timeAtUserAction = this.element.currentTime;
          }, this);
          this._onMouseUp = bind(function () {
            this._mousedown = false;
          }, this);
          this._setupMouseWatcher = function () {
            this.element.addEventListener("mousedown", this._onMouseDown);
            this.element.addEventListener("mouseup", this._onMouseUp);
          };
          this._breakdownMouseWatcher = function () {
            this.element.removeEventListener("mousedown", this._onMouseDown);
            this.element.removeEventListener("mouseup", this._onMouseUp);
          };
          this._onContentSeek = function () {
            if (this._playheadTimer) {
              window.clearTimeout(this._playheadTimer);
              this._playheadTimer = null;
            }
            this.element.removeEventListener("mouseup", this._onContentSeekBind);
            this._playheadThrottling = false;
            this._waitForMouseUp = false;
            if (!this._paused) {
              this.fireSeek();
              this.firePlayhead();
              this.element.addEventListener("mouseup", this._onContentSeekBind);
            } else {
              this.fireSeek();
              if (!this._waitForMouseUp) {
                this._waitForMouseUp = true;
                this.element.addEventListener("mouseup", this._onContentSeekBind);
              }
            }
          };
          this._onContentSeekBind = bind(this._onContentSeek, this);
          this._onLoadedMetaDataBind = bind(this._onLoadedMetaData, this);
          this._onContentPlayBind = bind(this._onContentPlay, this);
          this._onContentEndBind = bind(this._onContentEnd, this);
          this._onContentPauseBind = bind(this._onContentPause, this);
          this._onContentPlayingBind = bind(this._onContentPlaying, this);
          this._onContentErrorBind = bind(this._onContentError, this);
          this._onContentPlayheadBind = bind(this._onContentPlayhead, this);
          this._onContentBufferingBind = bind(this._onContentBuffering, this);
          this._onContentVolumeBind = bind(this._onContentVolume, this);
          this._onW3FullScreenChangeBind = bind(this._onW3FullScreenChange, this);
          this._onWebKitFullScreenChangeBind = bind(this._onWebKitFullScreenChange, this);
          this._onMozFullScreenChangeBind = bind(this._onMozFullScreenChange, this);
        },
        render: function (options) {
          this._super(options);
          this.eRendered.addListener(this._setupMouseWatcher, this);
        },
        firePause: function () {
          this.eTrackingPaused.dispatch({
            contentId: this._catalogEntry.getId(),
            paused: this._paused
          });
          this.eContentPause.dispatch(this._catalogEntry.getId(), this._paused);
        },
        fireBuffering: function () {
          this.eContentBuffering.dispatch(this._catalogEntry.getId(), this._buffering);
        },
        fireMetadata: function () {
          this.eContentMetadata.dispatch(this._catalogEntry.getId(), this.element.duration || this._catalogEntry.getTrt(), +(this.width), +(this.height));
        },
        firePlayhead: function () {
          this.eContentPlayhead.dispatch(this._catalogEntry.getId(), this.element.currentTime, this.element.duration);
        },
        fireSeek: function () {
          if (Math.abs(this.element.currentTime - this._timeAtUserAction) > 1) {
            this.eTrackingContentSeek.dispatch({
              contentId: this._catalogEntry.getId(),
              previousPlayhead: this._timeAtUserAction,
              newPlayhead: this.element.currentTime,
              duration: this.element.duration
            });
          }
        },
        getMarkup: function () {
          return template('<video id="{0}" width={1} height={2} controls {3}></video>', this.elementId, this.width, this.height, this.airplay);
        },
        play: (CVP.Browser.apple_mobile ? function (catalogEntry) {
          this._catalogEntry = catalogEntry;
          var url = this._getFileUrl(catalogEntry);
          this.setDefaultOptions();
          this._setThumbnail();
          if (!url) {
            url = "";
          }
          this.element.src = url;
          this.element.load();
          this.element.play();
          this._firePlay = true;
        } : function (catalogEntry) {
          this._catalogEntry = catalogEntry;
          var url = this._getFileUrl(catalogEntry);
          if (!this.playerOptions.autoplay) {
            this._setThumbnail();
          }
          if (!url) {
            url = "";
          }
          this.element.src = url;
          this.element.load();
        }),
        pause: function () {
          this.element.pause();
        },
        resume: function () {
          if (this._paused) {
            this.element.play();
          }
        },
        setVolume: function (v) {
          this.element.volume = v;
        },
        getVolume: function () {
          return this.element.volume;
        },
        mute: function () {
          this.element.muted = true;
        },
        unmute: function () {
          this.element.muted = false;
        },
        resize: function (width, height) {
          this.element.width = width;
          this.element.height = height;
          this._onContentResize();
        },
        setDefaultOptions: function () {
          this.setOptions(this.playerOptions);
        },
        setOptions: function (options) {
          options = options || {};
          var option;
          for (option in options) {
            if (hasOwn(options, option)) {
              this.element[option] = options[option];
            }
          }
        },
        _setThumbnail: function () {
          var image = this.getThumbnail();
          log("VideoPlayer", "_setThumbnail", image);
          if (image) {
            this.element.poster = image;
          }
        },
        getThumbnail: function () {
          return (this._catalogEntry ? this._catalogEntry.getThumbnailUrl(this.width, this.height) : "");
        },
        _onLoadedMetaData: function () {
          log("VideoPlayer", "_onLoadedMetaData");
          this._loaded = true;
          this.fireMetadata();
          if (!CVP.Browser.apple_mobile) {
            this._onLoaded();
          }
        },
        _onLoaded: function () {
          log("VideoPlayer", "_onLoaded");
          this.setDefaultOptions();
          this._firePlay = true;
          this.element.play();
        },
        _onReadyStateChange: function () {
          log("VideoPlayer", "_onReadyStateChange");
        },
        _onContentBegin: function () {},
        _onContentPlay: function () {
          log("VideoPlayer", "_onContentPlay");
          if (this._paused) {
            this._paused = false;
            this.firePause();
          }
          if (this._firePlay) {
            this.firePlay();
            this._firePlay = false;
          }
        },
        _onContentPlaying: function () {
          log("VideoPlayer", "_onContentPlaying");
          if (this._buffering) {
            this._buffering = false;
            this.fireBuffering();
          }
        },
        _onContentPause: function () {
          log("VideoPlayer", "_onContentPause");
          this._paused = true;
          if (this.element.currentTime !== this.element.duration) {
            this.firePause();
          }
        },
        _onContentPlayhead: function () {
          if (!this._mousedown) {
            this.firePlayhead();
          } else {
            if (!this._playheadThrottling) {
              this._playheadThrottling = true;
              this._playheadTimer = window.setTimeout(this._onContentSeekBind, 250);
            }
          }
        },
        _onContentEnd: function () {
          log("VideoPlayer", "_onContentEnd");
          this.fireEnded();
        },
        _onContentError: function (event) {
          var errorMessage = "Unknown error.";
          if (event.target && event.target.error) {
            switch (event.target.error.code) {
              case event.target.error.MEDIA_ERR_ABORTED:
                errorMessage = "The fetching process for the media resource was aborted by the user agent at the user's request.";
                break;
              case event.target.error.MEDIA_ERR_NETWORK:
                errorMessage = "A network error of some description caused the user agent to stop fetching the media resource, after the resource was established to be usable.";
                break;
              case event.target.error.MEDIA_ERR_DECODE:
                errorMessage = "An error of some description occurred while decoding the media resource, after the resource was established to be usable.";
                break;
              case event.target.error.MEDIA_ERR_SRC_NOT_SUPPORTED:
                errorMessage = "The media resource indicated by the src attribute was not suitable.";
                break;
            }
          }
          log("VideoPlayer", "_onContentError", errorMessage);
          this.eContentError.dispatch(this._catalogEntry.getId(), errorMessage);
        },
        _onContentBuffering: function () {
          log("VideoPlayer", "_onContentBuffering");
          if (!this._rendered) {
            return;
          }
          this._buffering = true;
          this.fireBuffering();
        },
        _onContentVolume: function () {
          var muteTransition = this._muted !== this.element.muted;
          log("VideoPlayer", "_onContentVolume");
          if (muteTransition) {
            this._muted = this.element.muted;
            this.eTrackingMuted.dispatch({
              contentId: this._catalogEntry.getId(),
              muted: this.element.muted
            });
          }
          this.eContentVolume.dispatch(this.element.muted, this.element.volume);
        },
        _onContentResize: function () {
          log("VideoPlayer", "_onContentResize");
          this.eContentResize.dispatch(this.element.width, this.element.height, this._fullscreen);
        },
        _onFullScreenChange: function (isFullscreen, fullscreenElement) {
          var fullscreenTransition = false;
          if (!isFullscreen || (isFullscreen && fullscreenElement === this.element)) {
            fullscreenTransition = this._fullscreen !== isFullscreen;
            if (fullscreenTransition) {
              this._fullscreen = isFullscreen;
              this.eTrackingFullscreen.dispatch({
                contentId: this._catalogEntry.getId(),
                fullscreen: this._fullscreen
              });
              this.eContentResize.dispatch(window.screen.width, window.screen.height, this._fullscreen);
            }
          }
        },
        _onW3FullScreenChange: function () {
          log("VideoPlayer", "_onW3FullScreenChange", document.fullscreen, document.fullscreenElement);
          this.eFullscreenChange.dispatch(document.fullscreen, document.fullscreenElement);
        },
        _onWebKitFullScreenChange: function () {
          log("VideoPlayer", "_onWebKitFullScreenChange", document.webkitIsFullScreen, document.webkitFullscreenElement);
          this.eFullscreenChange.dispatch(document.webkitIsFullScreen, document.webkitFullscreenElement);
        },
        _onMozFullScreenChange: function () {
          log("VideoPlayer", "_onMozFullScreenChange", document.mozFullScreen, document.mozFullScreenElement);
          this.eFullscreenChange.dispatch(document.mozFullScreen, document.mozFullScreenElement);
        },
        addPlayerListeners: function () {
          if (this.element && !this._addedListeners) {
            log("VideoPlayer", "addPlayerListeners");
            this.element.addEventListener("loadedmetadata", this._onLoadedMetaDataBind, false);
            this.element.addEventListener("play", this._onContentPlayBind, false);
            this.element.addEventListener("ended", this._onContentEndBind, false);
            this.element.addEventListener("playing", this._onContentPlayingBind, false);
            this.element.addEventListener("pause", this._onContentPauseBind, false);
            this.element.addEventListener("timeupdate", this._onContentPlayheadBind, false);
            this.element.addEventListener("error", this._onContentErrorBind, false);
            this.element.addEventListener("waiting", this._onContentBufferingBind, false);
            this.element.addEventListener("volumechange", this._onContentVolumeBind, false);
            this.eFullscreenChange.addListener(this._onFullScreenChange, this);
            document.addEventListener("fullscreenchange", this._onW3FullScreenChangeBind, false);
            document.addEventListener("webkitfullscreenchange", this._onWebKitFullScreenChangeBind, false);
            document.addEventListener("mozfullscreenchange", this._onMozFullScreenChangeBind, false);
            this._addedListeners = true;
          }
        },
        removePlayerListeners: function () {
          if (this.element && this._addedListeners) {
            log("VideoPlayer", "removePlayerListeners");
            this.element.removeEventListener("loadedmetadata", this._onLoadedMetaDataBind, false);
            this.element.removeEventListener("loadeddata", this._onLoadedMetaDataBind, false);
            this.element.removeEventListener("play", this._onContentPlayBind, false);
            this.element.removeEventListener("ended", this._onContentEndBind, false);
            this.element.removeEventListener("playing", this._onContentPlayingBind, false);
            this.element.removeEventListener("pause", this._onContentPauseBind, false);
            this.element.removeEventListener("timeupdate", this._onContentPlayheadBind, false);
            this.element.removeEventListener("error", this._onContentErrorBind, false);
            this.element.removeEventListener("waiting", this._onContentBufferingBind, false);
            this.element.removeEventListener("volumechange", this._onContentVolumeBind, false);
            this.eFullscreenChange.removeListener(this._onFullScreenChange, this);
            document.removeEventListener("fullscreenchange", this._onW3FullScreenChangeBind, false);
            document.removeEventListener("webkitfullscreenchange", this._onWebKitFullScreenChangeBind, false);
            document.removeEventListener("mozfullscreenchange", this._onMozFullScreenChangeBind, false);
            this._addedListeners = false;
          }
        },
        _getFileUrl: function (catalogEntry) {
          var url = "";
          url = this._getFileByParameterFallback(catalogEntry);
          if (!url) {
            url = this._getFileByFallback(catalogEntry);
          }
          if (!url) {
            url = catalogEntry.getContentUrl(_configInfo.lowBitrate);
            if (!this._isFileSupported(url)) {
              log("VideoPlayer", "File is not supported!", url);
              log("VideoPlayer", "Attempting to find a compatible file");
              url = this._getFileBySupportedType(catalogEntry);
              if (empty(url)) {
                url = this._getFileByConfigFallbackParam(catalogEntry);
              }
              log("VideoPlayer", "Found:", url);
            }
          } else {
            log("VideoPlayer", "Fallback file found", url);
          }
          if (!url) {
            log("VideoPlayer", "No valid media file found!", catalogEntry.getId());
          }
          return url;
        },
        _getFileByParameterFallback: function (catalogEntry) {
          var i = 0,
            endi = this.perVideoFallbacks.length,
            dvf, criteria;
          for (; i < endi; ++i) {
            dvf = this.perVideoFallbacks[i];
            criteria = ConfigUtils.stringReplace(dvf.criteria, catalogEntry, false);
            if (dvf.evaluate(criteria)) {
              return ConfigUtils.stringReplace(dvf.filter, catalogEntry, false);
            }
          }
          return null;
        },
        _getFileByConfigFallbackParam: function (catalogEntry) {
          var str = _configInfo.fallbackFilenameIOS;
          if (empty(str)) {
            return str;
          } else {
            str = ConfigUtils.stringReplace(str, catalogEntry, false);
          }
          return str;
        },
        _getFileByFallback: function (catalogEntry) {
          if (CVP.Browser.apple_mobile) {
            return catalogEntry.getContentUrlFromFallback("iOS");
          }
        },
        _getFileBySupportedType: function (catalogEntry) {
          var url = null,
            i = 0,
            len = this._supportedFileTypes.length;
          for (; i < len && empty(url); ++i) {
            url = catalogEntry.getContentUrlFromType(this._supportedFileTypes[i]);
          }
          return url;
        },
        _isFileSupported: function (url) {
          if (!empty(url)) {
            var ext = url.indexOf(".") > -1 ? url.substring(url.lastIndexOf(".") + 1) : url,
              i = 0,
              len = this._supportedFileTypes.length;
            for (; i < len; ++i) {
              if (ext === this._supportedFileTypes[i]) {
                return true;
              }
            }
          }
          return false;
        },
        _determineSupportedFileTypes: function () {
          if (CVP.Browser.apple_mobile) {
            return ["m3u8", "mp4"];
          } else {
            return ["mp4"];
          }
        }
      });
      var DummyPlayStartStrategy = Class.extend({
        init: function (element, poster) {
          this.eReady = new Event();
          this._element = element;
          this._poster = poster;
          this._elementSrc = "http://z.cdn.turner.com/xslo/cvp/assets/video/blank.mp4";
        },
        execute: function () {
          var self = this,
            fired = false,
            events = this._getEventList();
          var listeners = function (add, cb) {
            var method = add ? "addEventListener" : "removeEventListener";
            for (var i = 0, len = events.length; i < len; i++) {
              self._element[method](events[i], cb);
            }
          };
          var cb = function (event) {
            log("[StartStrategy] received: ", event.type);
            listeners(false, arguments.callee);
            if (!fired) {
              fired = true;
              self._element.controls = false;
              self._element.src = "";
              self._fireReady();
            }
          };
          listeners(true, cb);
          this._element.poster = this._poster;
          this._element.controls = true;
          this._element.src = this._elementSrc;
          this._element.load();
          this._element.play();
        },
        _getEventList: function () {
          var events = ["loadedmetadata"];
          var version = CVP.Browser.version;
          if (version.major > 4 || (version.major === 4 && version.minor > 1)) {
            events = events.concat(["play"]);
          }
          return events;
        },
        _fireReady: function () {
          this.eReady.dispatch();
        }
      });
      var AdServerProxy = Class.extend({
        init: function () {
          this.eAdPlay = new Event();
          this.eAdPlayhead = new Event();
          this.eAdEnd = new Event();
          this.eAdError = new Event();
          this.eTrackingAdStart = new Event();
          this.eTrackingAdComplete = new Event();
          this._adServerType = _adPolicy.ads.attr.type.toLowerCase();
          this._adServer = this._createImpl();
          if (!this._adServer) {
            log("AdServerProxy", "Unable to create ad server impl.");
            return;
          }
          this._adServer.eAdPlay.addListener(this._onAdPlay, this);
          this._adServer.eAdPlayhead.addListener(this._onAdPlayhead, this);
          this._adServer.eAdEnd.addListener(this._onAdEnd, this);
          this._adServer.eAdError.addListener(this._onAdError, this);
          this._adServer.eTrackingAdStart.addListener(this._onTrackingAdStart, this);
          this._adServer.eTrackingAdComplete.addListener(this._onTrackingAdComplete, this);
        },
        _createImpl: function () {
          var type = this._adServerType;
          if (type === "freewheel") {
            return new FreeWheelImpl();
          } else {
            if (type === "dfp") {
              return new DFPImpl();
            } else {
              return null;
            }
          }
        },
        setAdSection: function (adSection) {
          if (this._adServer) {
            this._adServer.setAdSection(adSection);
          }
        },
        setVideoDisplayBase: function (videoDisplayBase) {
          if (this._adServer) {
            this._adServer.setVideoDisplayBase(videoDisplayBase);
          }
        },
        isEnabled: function () {
          return this._adServer ? this._adServer.enabled : false;
        },
        playPreroll: function (catalogEntry) {
          if (this._adServer) {
            this._adServer.playPreroll(catalogEntry);
          }
        },
        playPostroll: function (catalogEntry) {
          if (this._adServer) {
            this._adServer.playPostroll(catalogEntry);
          }
        },
        loadAds: function (catalogEntry) {
          if (this._adServer) {
            if (this._adServerType === "dfp") {
              this._adServer.playPreroll(catalogEntry);
            } else {
              this._adServer.loadAds(catalogEntry);
            }
          }
        },
        getCurrentAdId: function () {
          return "";
        },
        getCurrentAdDuration: function () {
          return 0;
        },
        getCurrentAdType: function () {
          return this._convertAdType(this._adServer.currentAdType);
        },
        _convertAdType: function (adType) {
          var type = "";
          switch (this._adServerType) {
            case "freewheel":
              if (adType === FreeWheelImpl.PREROLL) {
                type = AdServerProxy.PREROLL;
              } else {
                if (adType === FreeWheelImpl.POSTOLL) {
                  type = AdServerProxy.POSTROLL;
                }
              }
              break;
            case "dfp":
              if (adType === DFPImpl.PREROLL) {
                type = AdServerProxy.PREROLL;
              } else {
                if (adType === DFPImpl.POSTROLL) {
                  type = AdServerProxy.POSTROLL;
                }
              }
              break;
          }
          return type;
        },
        _onAdPlay: function (event) {
          var data = {
            ads: [],
            token: "",
            mode: "standard",
            id: this.getCurrentAdId(),
            duration: this.getCurrentAdDuration(),
            blockId: "",
            adType: this.getCurrentAdType()
          };
          this.eAdPlay.dispatch(data);
        },
        _onAdPlayhead: function (playhead, duration) {
          this.eAdPlayhead.dispatch.apply(this.eAdPlayhead, arguments);
        },
        _onAdEnd: function (event) {
          var data = {
            token: "",
            mode: "standard",
            id: this.getCurrentAdId(),
            blockId: "",
            adType: this.getCurrentAdType()
          };
          log("AdServerProxy", "_onAdEnd", data.adType);
          this.eAdEnd.dispatch(data);
        },
        _onAdError: function (event) {
          var data = {
            id: this.getCurrentAdId(),
            adType: this.getCurrentAdType(),
            errors: []
          };
          this.eAdError.dispatch(data);
        },
        _onTrackingAdStart: function (event) {
          this.eTrackingAdStart.dispatch();
        },
        _onTrackingAdComplete: function (event) {
          this.eTrackingAdComplete.dispatch();
        }
      });
      AdServerProxy.PREROLL = "preroll";
      AdServerProxy.POSTROLL = "postroll";
      var AdImplBase = Class.extend({
        init: function () {
          this._adServerInfo = _adPolicy.ads;
        },
        getConfigProperty: function (key) {
          var value = null;
          var required = false;
          switch (key) {
            case "adApi":
              value = this._adServerInfo.apiUrl;
              required = true;
              break;
            case "adServerRootUrl":
              value = this._adServerInfo.adServerRootUrl;
              required = true;
              break;
            case "adNetworkId":
              value = this._adServerInfo.adNetworkId;
              required = true;
              break;
            case "adVideoNetworkId":
              value = this._adServerInfo.adVideoNetworkId;
              required = true;
              break;
            case "adVideoAssetId":
              value = this._adServerInfo.adVideoAssetId;
              required = true;
              break;
            case "adSection":
              value = this._adServerInfo.adSection;
              required = true;
              break;
            case "adPlayerProfile":
              value = this._adServerInfo.adPlayerProfile;
              required = true;
              break;
            case "renderersUrl":
              value = this._adServerInfo.renderersUrl;
              required = false;
              break;
            case "sensitiveFallbackId":
              value = this._adServerInfo.sensitiveFallbackId;
              required = false;
              break;
            case "adLiveContentDuration":
              value = this._adServerInfo.liveDuration;
              required = false;
              break;
          }
          if (empty(value)) {
            if (required) {
              log("the following required ad server config value is missing:", key);
            } else {
              log("the following optional ad server config value is missing:", key);
            }
          }
          return value;
        }
      });
      var FreeWheelImpl = AdImplBase.extend({
        init: function () {
          log("FreeWheelImpl", "Instantiating");
          this._super();
          this._freewheel = null;
          if (!undef(window.tv) && window.tv.freewheel) {
            if (!FreeWheelImpl.initialized) {
              FreeWheelImpl.PREROLL = tv.freewheel.SDK.TIME_POSITION_CLASS_PREROLL;
              FreeWheelImpl.POSTROLL = tv.freewheel.SDK.TIME_POSITION_CLASS_POSTROLL;
              FreeWheelImpl.initialized = true;
            }
          } else {
            this.enabled = false;
          }
          this.currentAdType = "";
          this.currentAdId = "";
          this.currentAdDuration = 0;
          this._adSection = this.getConfigProperty("adSection");
          this._adProgress = 0;
          this._adTimer = null;
          this._adTimerDelay = 1000;
          this._adIncrementor = bind(function () {
            this._adProgress = Math.floor(this._adProgress + (this._adTimerDelay / 1000));
            if (this._adProgress <= this.currentAdDuration) {
              this.onAdPlayhead(this._adProgress, this.currentAdDuration);
            }
          }, this);
          this.eAdPlayhead = new Event();
          this.eAdPlay = new Event();
          this.eAdEnd = new Event();
          this.eAdError = new Event();
          this.eTrackingAdStart = new Event();
          this.eTrackingAdComplete = new Event();
        },
        setAdSection: function (adSection) {
          this._adSection = adSection;
        },
        setVideoDisplayBase: function (videoDisplayBase) {
          if (!undef(window.tv) && !undef(window.tv.freewheel)) {
            this.displayBase = videoDisplayBase;
            this.enabled = true;
          }
        },
        loadAds: function (catalogEntry) {
          this._freewheel = new tv.freewheel.SDK.AdManager();
          var serverUrl = this.getConfigProperty("adServerRootUrl") + "/ad/g/1?nw=" + this.getConfigProperty("adNetworkId") + "&prof=" + this.getConfigProperty("adNetworkId") + ":turner_html5" + "&flag=+sltp+exvt+slcb+unka+unks;";
          this._freewheel.setServerURL(serverUrl);
          this._freewheel.registerVideoDisplayBase(this.displayBase);
          var duration = catalogEntry.getTrt();
          var adId = "";
          if (empty(this._adServerInfo.adVideoAssetId)) {
            adId = catalogEntry.getId();
          } else {
            adId = ConfigUtils.stringReplace(this._adServerInfo.adVideoAssetId, catalogEntry, false);
          }
          this._freewheel.setVideoAsset(adId, duration);
          this._freewheel.setSiteSection(this._adSection);
          this._freewheel.submitRequest(bind(this.playPreroll, this), 2000);
        },
        playPreroll: function (e) {
          log("FreeWheelImpl", "playPreroll");
          this.currentAdType = FreeWheelImpl.PREROLL;
          this._adPlay(FreeWheelImpl.PREROLL, bind(this.onPrerollCompleted, this), e);
        },
        onPrerollCompleted: function (e) {
          log("FreeWheelImpl", "onPrerollCompleted");
          this._adEnd(e);
        },
        playPostroll: function (e) {
          log("FreeWheelImpl", "playPostroll");
          this.currentAdType = FreeWheelImpl.POSTROLL;
          this._adPlay(FreeWheelImpl.POSTROLL, bind(this.onPostrollCompleted, this), e);
        },
        onPostrollCompleted: function (e) {
          log("FreeWheelImpl", "onPostrollCompleted");
          this._adEnd(e);
        },
        _adPlay: function (slot, cb, e) {
          var ads = e && e.success && e.response && e.response.ads && e.response.ads.ads;
          if (ads && ads.length !== 0) {
            this.currentAdId = ads[0].adId;
            this.currentAdDuration = +(ads[0].creatives[0].duration);
            this._adProgress = 0;
            this._adTimer = window.setInterval(this._adIncrementor, this._adTimerDelay);
            this.eTrackingAdStart.dispatch(e);
            this.eAdPlay.dispatch(e);
          } else {
            this.eAdError.dispatch(e);
          }
          this._freewheel.playSlots(slot, cb);
        },
        _adEnd: function (e) {
          if (this._adTimer !== null) {
            window.clearInterval(this._adTimer);
            this._adTimer = null;
            this.eTrackingAdComplete.dispatch(e);
          }
          this.eAdEnd.dispatch(e);
          this._freewheel.dispose();
          this.currentAdId = "";
        },
        onAdPlayhead: function (playhead, duration) {
          this.eAdPlayhead.dispatch.apply(this.eAdPlayhead, arguments);
        }
      });
      FreeWheelImpl.PREROLL = null;
      FreeWheelImpl.POSTROLL = null;
      var DFPImpl = AdImplBase.extend({
        init: function () {
          log("DFPImpl", "Instantiating");
          this._super();
          this.enabled = false;
          this._loader = new google.ima.AdsLoader();
          this._loader.addEventListener(google.ima.AdsLoadedEvent.Type.ADS_LOADED, bind(this._onAdsLoaded, this));
          this._loader.addEventListener(google.ima.AdErrorEvent.Type.AD_ERROR, bind(this._onAdLoadError, this));
          this.currentAdType = "";
          this.currentAdId = "";
          this.currentAdDuration = 0;
          this._adSection = this.getConfigProperty("adSection");
          this._keyValues = {};
          this.eAdPlayhead = new Event();
          this.eAdPlay = new Event();
          this.eAdEnd = new Event();
          this.eAdError = new Event();
          this.eTrackingAdStart = new Event();
          this.eTrackingAdComplete = new Event();
        },
        setAdSection: function (adSection) {
          this._adSection = adSection;
        },
        setVideoDisplayBase: function (videoDisplayBase) {
          log("DFP", "setVideoDisplayBase", videoDisplayBase);
          if (!undef(window.google) && !undef(window.google.ima.AdsLoader)) {
            this.displayBase = videoDisplayBase;
            this.enabled = true;
            log("DFP", "setVideoDisplayBase", "videoDisplayBase", "enabling");
          }
        },
        playPreroll: function (catalogEntry) {
          var preroll = catalogEntry.getAdUrl("preroll");
          var url = this._constructAdUrl(preroll, catalogEntry);
          this.currentAdType = DFPImpl.PREROLL;
          this.loadAds(url);
        },
        playPostroll: function (catalogEntry) {
          var postroll = catalogEntry.getAdUrl("postroll");
          var url = this._constructAdUrl(postroll, catalogEntry);
          this.currentAdType = DFPImpl.POSTROLL;
          this.loadAds(url);
        },
        loadAds: function (url) {
          log("DFP", "loadAds - adTag", url);
          var adsRequest = {
            adTagUrl: url,
            adType: "video"
          };
          this._loader.requestAds(adsRequest);
        },
        _constructAdUrl: function (entryAdTag, catalogEntry) {
          var adTag = "";
          var baseUrl = this.getConfigProperty("adServerRootUrl");
          if (empty(entryAdTag)) {
            adTag = baseUrl;
          } else {
            if (isRelativePath(entryAdTag)) {
              adTag = this._addToTag(baseUrl, entryAdTag);
            } else {
              adTag = entryAdTag;
            }
          }
          for (var key in this._keyValues) {
            var newPair = key + "=" + this._keyValues[key];
            adTag = addToTag(adTag, newPair);
          }
          adTag = ConfigUtils.stringReplace(adTag, catalogEntry);
          return adTag;
        },
        _addToTag: function (adTag, pair) {
          if (!adTag) {
            return pair;
          }
          var delimiter = ";";
          if (adTag.charAt(adTag.length - 1) == ";") {
            delimiter = "";
          }
          return adTag + delimiter + pair;
        },
        _onAdsLoaded: function (event) {
          log("DFP", "_onAdsLoaded");
          var adsManager = event.getAdsManager();
          adsManager.addEventListener(google.ima.AdErrorEvent.Type.AD_ERROR, bind(this._onAdError, this));
          adsManager.addEventListener(google.ima.AdEvent.Type.CONTENT_PAUSE_REQUESTED, bind(this._onPauseRequested, this));
          adsManager.addEventListener(google.ima.AdEvent.Type.CONTENT_RESUME_REQUESTED, bind(this._onResumeRequested, this));
          try {
            this.eAdPlay.dispatch();
            var playSettings = {
              restoreContentState: false
            };
            var element = document.getElementById(this.displayBase).getElementsByTagName("video")[0];
            adsManager.play(element, playSettings);
          } catch (adError) {
            log("DFP", "ad play error", adError.toString());
          }
        },
        _onAdLoadError: function () {
          log("DFP", "_onAdLoadError");
          this.eAdError.dispatch();
        },
        _onPauseRequested: function () {
          log("DFP", "_onPauseRequested");
        },
        _onResumeRequested: function () {
          log("DFP", "_onResumeRequested");
          this.eAdEnd.dispatch();
        },
        _onAdError: function (event) {
          log("DFP", "_onAdError", event.toString());
          this.eAdError.dispatch();
        }
      });
      DFPImpl.PREROLL = "dfpPreroll";
      DFPImpl.POSTROLL = "dfpPostroll";
      var PlayerController = Class.extend({
        init: function () {
          this._commandQ = new CommandQueue();
          this._videoPlayer = new VideoPlayer({
            containerElement: "player_container",
            elementId: _params.id || "cvp_videoPlayer_" + now(),
            width: _params.width,
            height: _params.height,
            controls: true,
            autostart: _params.autostart
          });
          this._videoPlayer.eRendered.addListener(this._onRendered, this);
          this._videoPlayer.eContentMetadata.addListener(this._onContentMetadata, this);
          this._videoPlayer.eContentPlay.addListener(this._onContentPlay, this);
          this._videoPlayer.eContentPause.addListener(this._onContentPause, this);
          this._videoPlayer.eContentEnd.addListener(this._onContentEnd, this);
          this._videoPlayer.eContentPlayhead.addListener(this._onContentPlayhead, this);
          this._videoPlayer.eContentBuffering.addListener(this._onContentBuffering, this);
          this._videoPlayer.eContentVolume.addListener(this._onContentVolume, this);
          this._videoPlayer.eContentError.addListener(this._onContentError, this);
          this._videoPlayer.eContentResize.addListener(this._onContentResize, this);
          this._adProxy = new AdServerProxy();
          this._adProxy.eAdPlayhead.addListener(this._onAdPlayhead, this);
          this._adProxy.eAdPlay.addListener(this._onAdPlay, this);
          this._adProxy.eAdEnd.addListener(this._onAdEnd, this);
          this._adProxy.eAdError.addListener(this._onAdError, this);
          this._adProxy.eTrackingAdStart.addListener(this._onTrackingAdStart, this);
          this._adProxy.eTrackingAdComplete.addListener(this._onTrackingAdComplete, this);
          this._videoPlayer.eContentPlay.addListener(this._onTrackingContentPlay, this);
          this._videoPlayer.eContentEnd.addListener(this._onTrackingContentEnd, this);
          this._videoPlayer.eTrackingContentSeek.addListener(this._onTrackingContentSeek, this);
          this._videoPlayer.eTrackingFullscreen.addListener(this._onTrackingFullscreen, this);
          this._videoPlayer.eTrackingMuted.addListener(this._onTrackingMuted, this);
          this._videoPlayer.eTrackingPaused.addListener(this._onTrackingPaused, this);
          this._currentContentId = "";
          this._contentQueue = [];
          this._firstPlay = true;
          this._delayPlayerControls = false;
          this._triggeredAd = false;
          this._currentAdDuration = 0;
          this._currentAdPlayhead = 0;
          this._totalAdPlayTime = 0;
          this._trackingAdStart = 0;
          this._trackingAdTimer = null;
          this._getElapsedTrackingAdTime = function () {
            return (this._trackingAdStart === 0 ? 0 : (now() - this._trackingAdStart) / 1000);
          };
          this._getTotalTrackingAdTime = function () {
            return this._totalAdPlayTime + this._getElapsedTrackingAdTime();
          };
          this._tallyTotalTrackingAdTime = function () {
            this._totalAdPlayTime += this._getElapsedTrackingAdTime();
          };
          this._startTrackingAdTimer = function () {
            if (this._trackingAdTimer !== null) {
              return;
            }
            this._trackingAdStart = now();
            this._trackingAdTimer = window.setInterval(bind(this._onTrackingAdProgress, this), 60000);
          };
          this._stopTrackingAdTimer = function () {
            if (this._trackingAdTimer === null) {
              return;
            }
            this._tallyTotalTrackingAdTime();
            window.clearInterval(this._trackingAdTimer);
            this._trackingAdTimer = null;
            this._trackingAdStart = 0;
          };
          this._currentContentDuration = 0;
          this._currentContentPlayhead = 0;
          this._totalContentPlayTime = 0;
          this._trackingContentStart = 0;
          this._trackingContentTimer = null;
          this._getElapsedTrackingContentTime = function () {
            return (this._trackingContentStart === 0 ? 0 : (now() - this._trackingContentStart) / 1000);
          };
          this._getTotalTrackingContentTime = function () {
            return this._totalContentPlayTime + this._getElapsedTrackingContentTime();
          };
          this._tallyTotalTrackingContentTime = function () {
            this._totalContentPlayTime += this._getElapsedTrackingContentTime();
          };
          this._startTrackingContentTimer = function () {
            if (this._trackingContentTimer !== null) {
              return;
            }
            this._trackingContentStart = now();
            this._trackingContentTimer = window.setInterval(bind(this._onTrackingContentProgress, this), 60000);
          };
          this._stopTrackingContentTimer = function () {
            if (this._trackingContentTimer === null) {
              return;
            }
            this._tallyTotalTrackingContentTime();
            window.clearInterval(this._trackingContentTimer);
            this._trackingContentTimer = null;
            this._trackingContentStart = 0;
          };
          this.eRendered = new Event();
          this.eContentMetadata = new Event();
          this.eContentBegin = new Event();
          this.eContentPlay = new Event();
          this.eContentPause = new Event();
          this.eContentEnd = new Event();
          this.eContentComplete = new Event();
          this.eContentPlayhead = new Event();
          this.eContentBuffering = new Event();
          this.eContentVolume = new Event();
          this.eContentError = new Event();
          this.eContentResize = new Event();
          this.eTrackingAdStart = new Event();
          this.eTrackingAdComplete = new Event();
          this.eTrackingAdProgress = new Event();
          this.eTrackingAdCountdown = new Event();
          this.eTrackingContentPlay = new Event();
          this.eTrackingContentBegin = new Event();
          this.eTrackingContentProgress = new Event();
          this.eTrackingContentComplete = new Event();
          this.eTrackingContentSeek = new Event();
          this.eTrackingFullscreen = new Event();
          this.eTrackingMuted = new Event();
          this.eTrackingPaused = new Event();
          this.eAdPlayhead = new Event();
          this.eAdPlay = new Event();
          this.eAdEnd = new Event();
          this.eAdError = new Event();
        },
        render: function (containerElement) {
          this._adProxy.setVideoDisplayBase(containerElement);
          this._videoPlayer.render(containerElement);
        },
        remove: function () {
          this._videoPlayer.remove();
        },
        _onRendered: function (type) {
          log("_onRendered", type);
          this._commandQ.execute();
          this.eRendered.dispatch();
        },
        play: function (catalogEntry) {
          log("PlayerController", "play", catalogEntry.getId());
          this._catalogEntry = catalogEntry;
          if (!this._videoPlayer.rendered()) {
            this._commandQ.push(this.play, this, arguments);
            return;
          }
          this._executePlayStrategy(bind(this._playMedia, this));
        },
        _executePlayStrategy: function (playFunc) {
          if (CVP.Browser.apple_mobile && this._firstPlay) {
            this._videoPlayer.removePlayerListeners();
            this._delayPlayerControls = true;
            var dummyStrategy = new DummyPlayStartStrategy(this._videoPlayer.element, this._catalogEntry.getThumbnailUrl(this._videoPlayer.width, this._videoPlayer.height));
            dummyStrategy.eReady.addListener(function () {
              playFunc();
              dummyStrategy = null;
            });
            dummyStrategy.execute();
          } else {
            playFunc();
          }
        },
        _playMedia: function () {
          this._firstPlay = false;
          this._onTrackingContentBegin(this._catalogEntry.getId());
          this._onContentBegin(this._catalogEntry.getId());
          if (this._adProxy.isEnabled()) {
            this._adProxy.loadAds(this._catalogEntry);
          } else {
            this._playContent();
          }
        },
        _playContent: function () {
          log("PlayerController", "_playContent");
          if (this._delayPlayerControls) {
            this._videoPlayer.playerOptions["controls"] = false;
          }
          this._videoPlayer.addPlayerListeners();
          this._videoPlayer.play(this._catalogEntry);
        },
        queue: function (catalogEntry) {
          log("PlayerController", "queue", catalogEntry.getId());
          this._contentQueue.push(catalogEntry);
        },
        emptyQueue: function () {
          this._contentQueue = [];
        },
        pause: function () {
          this._videoPlayer.pause();
        },
        resume: function () {
          this._videoPlayer.resume();
        },
        resize: function (width, height) {
          this._videoPlayer.resize(width, height);
        },
        setVolume: function (v) {
          this._videoPlayer.setVolume(v);
        },
        getVolume: function () {
          return this._videoPlayer.getVolume();
        },
        mute: function () {
          this._videoPlayer.mute();
        },
        unmute: function () {
          this._videoPlayer.unmute();
        },
        setAdSection: function (ssid) {
          this._adProxy.setAdSection(ssid);
        },
        _onContentMetadata: function (contentId, duration, width, height) {
          log("PlayerController", "_onContentMetadata");
          this._currentContentDuration = duration;
          this.eContentMetadata.dispatch.apply(this.eContentMetadata, arguments);
        },
        _onContentBegin: function (contentId) {
          log("PlayerController", "_onContentBegin");
          this._currentContentId = contentId;
          this.eContentBegin.dispatch.apply(this.eContentBegin, arguments);
        },
        _onContentPlay: function () {
          log("PlayerController", "_onContentPlay");
          if (this._delayPlayerControls) {
            this._videoPlayer.setOptions({
              controls: true
            });
          }
          this.eContentPlay.dispatch.apply(this.eContentPlay, arguments);
        },
        _onContentPause: function () {
          log("PlayerController", "_onContentPause");
          this.eContentPause.dispatch.apply(this.eContentPause, arguments);
        },
        _onContentEnd: function () {
          log("PlayerController", "_onContentEnd");
          this.eContentEnd.dispatch.apply(this.eContentEnd, arguments);
          if (this._adProxy.isEnabled()) {
            this._videoPlayer.setOptions({
              controls: false
            });
            this._adProxy.playPostroll(this._catalogEntry);
          } else {
            this._onContentComplete.apply(this, arguments);
          }
        },
        _onContentComplete: function () {
          log("PlayerController", "_onContentComplete");
          this._onTrackingContentComplete();
          this.eContentComplete.dispatch.call(this.eContentComplete, this._catalogEntry.getId());
          if (this._contentQueue.length) {
            this.play(this._contentQueue.shift());
          }
        },
        _onContentPlayhead: function (contentId, playhead, duration) {
          this._currentContentPlayhead = playhead;
          this.eContentPlayhead.dispatch.apply(this.eContentPlayhead, arguments);
        },
        _onContentBuffering: function () {
          log("PlayerController", "_onContentBuffering");
          this.eContentBuffering.dispatch.apply(this.eContentBuffering, arguments);
        },
        _onContentVolume: function () {
          log("PlayerController", "_onContentVolume");
          this.eContentVolume.dispatch.apply(this.eContentVolume, arguments);
        },
        _onContentError: function () {
          log("PlayerController", "_onContentError");
          this.eContentError.dispatch.apply(this.eContentError, arguments);
        },
        _onContentResize: function () {
          log("PlayerController", "_onContentResize");
          this.eContentResize.dispatch.apply(this.eContentResize, arguments);
        },
        _onTrackingAdStart: function () {
          log("PlayerController", "_onTrackingAdStart", arguments);
          this._startTrackingAdTimer();
          this.eTrackingAdStart.dispatch({
            "adTitle": this._adProxy.currentAdId,
            "adType": this._adProxy.currentAdType,
            "adDuration": this._adProxy.currentAdDuration,
            "adBlock": 0,
            "totalPlayTime": this._getTotalTrackingAdTime() + this._getTotalTrackingContentTime(),
            "adTotalPlayTime": this._getTotalTrackingAdTime()
          });
        },
        _onTrackingAdComplete: function () {
          log("PlayerController", "_onTrackingAdComplete", arguments);
          this._stopTrackingAdTimer();
          this.eTrackingAdComplete.dispatch({
            "adTitle": this._adProxy.currentAdId,
            "adType": this._adProxy.currentAdType,
            "adBlock": 0,
            "totalPlayTime": this._getTotalTrackingAdTime() + this._getTotalTrackingContentTime(),
            "adTotalPlayTime": this._getTotalTrackingAdTime()
          });
        },
        _onTrackingAdProgress: function () {
          log("PlayerController", "_onTrackingAdProgress", arguments);
          this.eTrackingAdProgress.dispatch({
            "totalPlayTime": this._getTotalTrackingAdTime() + this._getTotalTrackingContentTime(),
            "playheadTime": this._currentAdPlayhead,
            "grossProgressMarker": 0,
            "adType": this._adProxy.currentAdType,
            "adTotalPlaytime": this._getTotalTrackingAdTime()
          });
        },
        _onTrackingAdCountdown: function (secs) {
          log("PlayerController", "_onTrackingAdCountdown", arguments);
          this.eTrackingAdCountdown.dispatch({
            "adMode": "standard",
            "secs": secs
          });
        },
        _onTrackingContentPlay: function () {
          log("PlayerController", "_onTrackingContentPlay", arguments);
          this._startTrackingContentTimer();
          this.eTrackingContentPlay.dispatch({
            "contentId": this._catalogEntry.getId(),
            "length": this._catalogEntry.getTrt(),
            "grossLength": this._catalogEntry.getTrt(),
            "totalPlayTime": this._getTotalTrackingAdTime() + this._getTotalTrackingContentTime(),
            "adTotalPlayTime": this._getTotalTrackingAdTime()
          });
        },
        _onTrackingContentEnd: function () {
          log("PlayerController", "_onTrackingContentEnd", arguments);
          this._stopTrackingContentTimer();
        },
        _onTrackingContentBegin: function () {
          log("PlayerController", "_onTrackingContentBegin", arguments);
          this.eTrackingContentBegin.dispatch({
            "contentId": this._catalogEntry.getId(),
            "totalPlayTime": this._getTotalTrackingAdTime() + this._getTotalTrackingContentTime(),
            "adTotalPlayTime": this._getTotalTrackingAdTime()
          });
        },
        _onTrackingContentProgress: function () {
          log("PlayerController", "_onTrackingContentProgress", arguments);
          this.eTrackingContentProgress.dispatch({
            "contentId": this._catalogEntry.getId(),
            "percent": Math.floor(this._currentContentDuration / this._currentContentPlayhead * 100),
            "totalPlayTime": this._getTotalTrackingAdTime() + this._getTotalTrackingContentTime(),
            "playheadTime": this._currentContentPlayhead,
            "progressMarker": 0,
            "grossProgressMarker": 0,
            "adTotalPlayTime": this._getTotalTrackingAdTime()
          });
        },
        _onTrackingContentComplete: function () {
          log("PlayerController", "_onTrackingContentComplete", arguments);
          this.eTrackingContentComplete.dispatch({
            "contentId": this._catalogEntry.getId(),
            "percent": 100,
            "totalPlayTime": this._getTotalTrackingAdTime() + this._getTotalTrackingContentTime(),
            "playheadTime": this._currentContentPlayhead,
            "progressMarker": 0,
            "grossProgressMarker": 0,
            "adTotalPlayTime": this._getTotalTrackingAdTime()
          });
        },
        _onTrackingContentSeek: function () {
          log("PlayerController", "_onTrackingContentSeek");
          this.eTrackingContentSeek.dispatch.apply(this.eTrackingContentSeek, arguments);
        },
        _onTrackingFullscreen: function () {
          log("PlayerController", "_onTrackingFullscreen");
          this.eTrackingFullscreen.dispatch.apply(this.eTrackingFullscreen, arguments);
        },
        _onTrackingMuted: function () {
          log("PlayerController", "_onTrackingMuted");
          this.eTrackingMuted.dispatch.apply(this.eTrackingMuted, arguments);
        },
        _onTrackingPaused: function (dataObj) {
          log("PlayerController", "_onTrackingPaused");
          if (dataObj.paused) {
            this._stopTrackingContentTimer();
          } else {
            this._startTrackingContentTimer();
          }
          this.eTrackingPaused.dispatch.apply(this.eTrackingPaused, arguments);
        },
        _onAdPlayhead: function (playhead, duration) {
          this._currentAdPlayhead = playhead;
          this._currentAdDuration = duration;
          this._onTrackingAdCountdown(Math.ceil(duration - playhead));
          this.eAdPlayhead.dispatch.apply(this.eAdPlayhead, arguments);
        },
        _onAdPlay: function (event) {
          var ads = event.ads,
            token = event.token,
            mode = event.mode,
            id = event.id,
            duration = event.duration,
            blockId = event.blockId,
            adType = event.adType;
          log("PlayerController", "_onAdPlay");
          this._triggeredAd = true;
          this.eAdPlay.dispatch.call(this.eAdPlay, token, mode, id, duration, blockId, adType);
          this._videoPlayer.removePlayerListeners();
        },
        _onAdEnd: function (event) {
          var token = event.token,
            mode = event.mode,
            id = event.id,
            blockId = event.duration,
            adType = event.adType;
          log("PlayerController", "_onAdEnd", adType);
          if (this._triggeredAd) {
            this.eAdEnd.dispatch.call(this.eAdEnd, token, mode, id, blockId, adType);
          }
          this._onAdComplete(adType);
        },
        _onAdError: function (event) {
          var i = 0,
            endi = 0,
            error = null,
            adErrors = event.errors,
            errStack = [],
            severityLevel = {
              INFO: 1,
              WARN: 2,
              ERROR: 3,
              FATAL: 4
            }, adType = event.adType;
          log("PlayerController", "_onAdError");
          if (undef(event)) {
            errStack.push({
              severity: "WARN",
              name: "Received no params to callback, assuming no ad played"
            });
          } else {
            if (!event.success) {
              errStack.push({
                severity: "ERROR",
                name: "Did not receive successful response to ad request"
              });
            }
            if (adErrors && adErrors.length !== 0) {
              errStack.concat(adErrors);
            }
          }
          for (endi = errStack.length; i < endi; ++i) {
            error = errStack[i];
            severity = (error.severity && severityLevel[error.severity]) || severityLevel.INFO;
            log("PlayerController", "_onAdError", error.severity, error.name);
            if (severity > severityLevel.WARN) {
              this.eAdError.dispatch.call(this.eAdError, error.name);
            }
          }
          this._onAdComplete(adType);
        },
        _onAdComplete: function (adType) {
          this._triggeredAd = false;
          if (adType === AdServerProxy.PREROLL) {
            this._playContent();
          } else {
            this._onContentComplete(this._currentContentId);
          }
        }
      });
      var PlayerInstance = function (data) {
        var data = data || {}, configData = data.configData || {};
        _params = data.params || _params;
        _mapping = configData.mapping || _mapping;
        _appConfig = configData.appConfig || _appConfig;
        _containerInfo = configData.containerInfo || _containerInfo;
        _configInfo = configData.configInfo || _configInfo;
        _adPolicy = configData.adPolicy || _adPolicy;
        return new PlayerController();
      };
      return PlayerInstance;
    })();
    var CVPManager = Class.extend({
      init: function () {
        this._configData = {};
        this.ePlayerLoaded = new Event();
        this.ePlayerLoadError = new Event();
        this.ePlayerRendered = new Event();
        this.eContentMetadata = new Event();
        this.eContentBegin = new Event();
        this.eContentPlay = new Event();
        this.eContentPause = new Event();
        this.eContentEnd = new Event();
        this.eContentComplete = new Event();
        this.eContentPlayhead = new Event();
        this.eContentBuffering = new Event();
        this.eContentVolume = new Event();
        this.eContentError = new Event();
        this.eContentResize = new Event();
        this.eAdPlayhead = new Event();
        this.eAdPlay = new Event();
        this.eAdEnd = new Event();
        this.eAdError = new Event();
        this.eTrackingAdStart = new Event();
        this.eTrackingAdComplete = new Event();
        this.eTrackingAdProgress = new Event();
        this.eTrackingAdCountdown = new Event();
        this.eTrackingContentPlay = new Event();
        this.eTrackingContentBegin = new Event();
        this.eTrackingContentProgress = new Event();
        this.eTrackingContentComplete = new Event();
        this.eTrackingContentSeek = new Event();
        this.eTrackingFullscreen = new Event();
        this.eTrackingMuted = new Event();
        this.eTrackingPaused = new Event();
        this._params = {};
      },
      load: function (options) {
        this._params = this._options = options;
        this._params.site = this._params.flashVars && this._params.flashVars.site;
        this._params.profile = this._params.flashVars && this._params.flashVars.profile;
        this._params.context = this._params.flashVars && this._params.flashVars.context;
        this._params.contentId = this._params.flashVars && this._params.flashVars.contentId;
        this._params.autostart = this._params.flashVars && isFlagActive(this._params.flashVars.autostart, false);
        this._params.containerUrl = this._params.flashVars && this._params.flashVars.containerUrl;
        this._params.configUrl = this._params.flashVars && this._params.flashVars.configUrl;
        this._params.dt = this._params.flashVars && this._params.flashVars.superduperdevtime;
        this._params.requestTimeout = this._params.flashVars && +this._params.flashVars.requestTimeout;
        if (this._params.requestTimeout) {
          CVP.Ajax.JSONP.requestTimeout = this._params.requestTimeout;
        }
        this._params.requestRetries = this._params.flashVars && +this._params.flashVars.requestRetries;
        if (this._params.requestRetries) {
          CVP.Ajax.JSONP.maxRetries = this._params.requestRetries;
        }
        var mappingUrl = this._calculateMappingUrl(this._params.site);
        if (empty(mappingUrl)) {
          log("Unable to calculate mapping file url. Failing.");
          this._bootStrapFailure();
          return;
        }
        this._bootStrapper = new BootStrapper(mappingUrl, this._params);
        this._bootStrapper.eSuccess.addListener(this._bootStrapSuccess, this);
        this._bootStrapper.eFailure.addListener(this._bootStrapFailure, this);
        this._bootStrapper.load();
      },
      _calculateMappingUrl: function (site) {
        if (empty(site)) {
          return null;
        }
        var url = Utils.replaceExtension(MAPPING_FILE, "xml", "json");
        if (!this._params.dt) {
          url = template(MAPPING_PATH, site) + url;
        }
        return url;
      },
      _bootStrapSuccess: function (event) {
        if (!event || !event.data) {
          log("MainController", "Unable to retrieve config data - failing.");
          this._bootStrapFailure();
          return;
        }
        this._configData = event.data;
        log("MainController", "_bootStrapSuccess");
        this._playerController = new PlayerInstance({
          params: this._params,
          configData: this._configData
        });
        this._playerController.eRendered.addListener(this._onRendered, this);
        this._playerController.eContentMetadata.addListener(this._onContentMetadata, this);
        this._playerController.eContentBegin.addListener(this._onContentBegin, this);
        this._playerController.eContentPlay.addListener(this._onContentPlay, this);
        this._playerController.eContentPause.addListener(this._onContentPause, this);
        this._playerController.eContentEnd.addListener(this._onContentEnd, this);
        this._playerController.eContentComplete.addListener(this._onContentComplete, this);
        this._playerController.eContentPlayhead.addListener(this._onContentPlayhead, this);
        this._playerController.eContentBuffering.addListener(this._onContentBuffering, this);
        this._playerController.eContentVolume.addListener(this._onContentVolume, this);
        this._playerController.eContentError.addListener(this._onContentError, this);
        this._playerController.eContentResize.addListener(this._onContentResize, this);
        this._playerController.eAdPlayhead.addListener(this._onAdPlayhead, this);
        this._playerController.eAdPlay.addListener(this._onAdPlay, this);
        this._playerController.eAdEnd.addListener(this._onAdEnd, this);
        this._playerController.eAdError.addListener(this._onAdError, this);
        this._playerController.eTrackingAdStart.addListener(this._onTrackingAdStart, this);
        this._playerController.eTrackingAdComplete.addListener(this._onTrackingAdComplete, this);
        this._playerController.eTrackingAdProgress.addListener(this._onTrackingAdProgress, this);
        this._playerController.eTrackingAdCountdown.addListener(this._onTrackingAdCountdown, this);
        this._playerController.eTrackingContentPlay.addListener(this._onTrackingContentPlay, this);
        this._playerController.eTrackingContentBegin.addListener(this._onTrackingContentBegin, this);
        this._playerController.eTrackingContentProgress.addListener(this._onTrackingContentProgress, this);
        this._playerController.eTrackingContentComplete.addListener(this._onTrackingContentComplete, this);
        this._playerController.eTrackingContentSeek.addListener(this._onTrackingContentSeek, this);
        this._playerController.eTrackingFullscreen.addListener(this._onTrackingFullscreen, this);
        this._playerController.eTrackingMuted.addListener(this._onTrackingMuted, this);
        this._playerController.eTrackingPaused.addListener(this._onTrackingPaused, this);
        this._cms = new CMS();
        this._cms.setDataUrl(this._configData.configInfo.dataSrc);
        this._cms.setMediaUrl(this._configData.configInfo.mediaSrc);
        this._cms.eRequestCompleted.addListener(this._onCmsRequestCompleted, this);
        this._loadingEntryQueue = {};
        this.ePlayerLoaded.dispatch();
      },
      _bootStrapFailure: function () {
        log("MainController", "_bootStrapFailure");
        this.ePlayerLoadError.dispatch();
      },
      render: function (containerElement) {
        this._playerController.render(containerElement);
      },
      remove: function () {
        this._playerController.remove();
      },
      _onRendered: function () {
        if (!nil(this._params.contentId)) {
          this.playContentWithId(this._params.contentId);
        }
        this.ePlayerRendered.dispatch();
      },
      playContentWithId: function (id, options) {
        log("MainController", "playContentWithId", id);
        var index = this._getNextIndexForId(id);
        var key = id + "|" + index;
        log("MainController", "playContentWithId", "key", key);
        this._loadingEntryQueue[key] = {
          play: true,
          additionalParams: options
        };
        this._cms.addContentId(key, options);
      },
      queueContentWithId: function (id, options) {
        log("MainController", "queueContentWithId", id);
        var index = this._getNextIndexForId(id);
        var key = id + "|" + index;
        log("MainController", "queueContentWithId", "key", key);
        this._loadingEntryQueue[key] = {
          play: false,
          additionalParams: options
        };
        this._cms.addContentId(key, options);
      },
      pause: function () {
        this._playerController.pause();
      },
      resume: function () {
        this._playerController.resume();
      },
      resize: function (width, height) {
        this._playerController.resize(width, height);
      },
      setVolume: function (v) {
        this._playerController.setVolume(v);
      },
      getVolume: function () {
        return this._playerController.getVolume();
      },
      mute: function () {
        this._playerController.mute();
      },
      unmute: function () {
        this._playerController.unmute();
      },
      getContentEntry: function (id) {
        var catalogEntry = this._cms.getContentId(id);
        return CVP.Utils.JsonConverter.encodeXmlObject(catalogEntry.getXML());
      },
      setAdSection: function (ssid) {
        this._playerController.setAdSection(ssid);
      },
      getCurrentPlayer: function () {
        return this._configData.containerInfo.elementName;
      },
      _onContentMetadata: function () {
        this.eContentMetadata.dispatch.apply(this.eContentMetadata, arguments);
      },
      _onContentBegin: function () {
        this.eContentBegin.dispatch.apply(this.eContentBegin, arguments);
      },
      _onContentPlay: function () {
        this.eContentPlay.dispatch.apply(this.eContentPlay, arguments);
      },
      _onContentPause: function () {
        this.eContentPause.dispatch.apply(this.eContentPause, arguments);
      },
      _onContentEnd: function () {
        this.eContentEnd.dispatch.apply(this.eContentEnd, arguments);
      },
      _onContentComplete: function () {
        this.eContentComplete.dispatch.apply(this.eContentComplete, arguments);
      },
      _onContentPlayhead: function () {
        this.eContentPlayhead.dispatch.apply(this.eContentPlayhead, arguments);
      },
      _onContentBuffering: function () {
        this.eContentBuffering.dispatch.apply(this.eContentBuffering, arguments);
      },
      _onContentVolume: function () {
        this.eContentVolume.dispatch.apply(this.eContentVolume, arguments);
      },
      _onContentError: function () {
        this.eContentError.dispatch.apply(this.eContentError, arguments);
      },
      _onContentResize: function () {
        this.eContentResize.dispatch.apply(this.eContentResize, arguments);
      },
      _onAdPlayhead: function () {
        this.eAdPlayhead.dispatch.apply(this.eAdPlayhead, arguments);
      },
      _onAdPlay: function () {
        this.eAdPlay.dispatch.apply(this.eAdPlay, arguments);
      },
      _onAdEnd: function () {
        this.eAdEnd.dispatch.apply(this.eAdEnd, arguments);
      },
      _onAdError: function () {
        this.eAdError.dispatch.apply(this.eAdError, arguments);
      },
      _onTrackingAdStart: function () {
        this.eTrackingAdStart.dispatch.apply(this.eTrackingAdStart, arguments);
      },
      _onTrackingAdComplete: function () {
        this.eTrackingAdComplete.dispatch.apply(this.eTrackingAdComplete, arguments);
      },
      _onTrackingAdProgress: function () {
        this.eTrackingAdProgress.dispatch.apply(this.eTrackingAdProgress, arguments);
      },
      _onTrackingAdCountdown: function () {
        this.eTrackingAdCountdown.dispatch.apply(this.eTrackingAdCountdown, arguments);
      },
      _onTrackingContentPlay: function () {
        this.eTrackingContentPlay.dispatch.apply(this.eTrackingContentPlay, arguments);
      },
      _onTrackingContentBegin: function () {
        this.eTrackingContentBegin.dispatch.apply(this.eTrackingContentBegin, arguments);
      },
      _onTrackingContentProgress: function () {
        this.eTrackingContentProgress.dispatch.apply(this.eTrackingContentProgress, arguments);
      },
      _onTrackingContentComplete: function () {
        log("MainController", "onTrackingContentComplete");
        this.eTrackingContentComplete.dispatch.apply(this.eTrackingContentComplete, arguments);
      },
      _onTrackingContentSeek: function () {
        this.eTrackingContentSeek.dispatch.apply(this.eTrackingContentSeek, arguments);
      },
      _onTrackingFullscreen: function () {
        this.eTrackingFullscreen.dispatch.apply(this.eTrackingFullscreen, arguments);
      },
      _onTrackingMuted: function () {
        this.eTrackingMuted.dispatch.apply(this.eTrackingMuted, arguments);
      },
      _onTrackingPaused: function () {
        this.eTrackingPaused.dispatch.apply(this.eTrackingPaused, arguments);
      },
      _onCmsRequestCompleted: function (contentId, requestId, index, errorMsg) {
        log("_onCmsRequestCompleted", contentId, requestId, index, errorMsg);
        var key = requestId + "|" + index;
        var catalogEntry = this._cms.getContentId((contentId + "|" + index));
        if (this._loadingEntryQueue[key] !== null) {
          log("onCmsRequestCompleted", contentId, this._loadingEntryQueue[key].play);
          if (this._loadingEntryQueue[key].play) {
            this._playerController.emptyQueue();
            this._playerController.play(catalogEntry, this._loadingEntryQueue[key].additionalParams);
          } else {
            this._playerController.queue(catalogEntry, this._loadingEntryQueue[key].additionalParams);
          }
          delete this._loadingEntryQueue[key];
        }
      },
      _getNextIndexForId: function (contentId) {
        var index = 0,
          p, q;
        for (p in this._loadingEntryQueue) {
          q = p.split("|");
          if (q[0] === contentId && q[1] >= index) {
            index = q[1] + 1;
          }
        }
        return index;
      }
    });
    CVP.Players._HTML5Player = Class.extend({
      init: function (options) {
        this._manager = new CVPManager();
        this._manager.ePlayerLoaded.addListener(this._onPlayerLoaded, this);
        this._manager.ePlayerLoadError.addListener(this._onPlayerLoadError, this);
        this._manager.ePlayerRendered.addListener(this._onPlayerRendered, this);
        this._manager.eContentMetadata.addListener(this._onContentMetadata, this);
        this._manager.eContentBegin.addListener(this._onContentBegin, this);
        this._manager.eContentPlay.addListener(this._onContentPlay, this);
        this._manager.eContentPause.addListener(this._onContentPause, this);
        this._manager.eContentEnd.addListener(this._onContentEnd, this);
        this._manager.eContentComplete.addListener(this._onContentComplete, this);
        this._manager.eContentPlayhead.addListener(this._onContentPlayhead, this);
        this._manager.eContentBuffering.addListener(this._onContentBuffering, this);
        this._manager.eContentVolume.addListener(this._onContentVolume, this);
        this._manager.eContentError.addListener(this._onContentError, this);
        this._manager.eContentResize.addListener(this._onContentResize, this);
        this._manager.eAdPlayhead.addListener(this._onAdPlayhead, this);
        this._manager.eAdPlay.addListener(this._onAdPlay, this);
        this._manager.eAdEnd.addListener(this._onAdEnd, this);
        this._manager.eAdError.addListener(this._onAdError, this);
        this._manager.eTrackingAdStart.addListener(this._onTrackingAdStart, this);
        this._manager.eTrackingAdComplete.addListener(this._onTrackingAdComplete, this);
        this._manager.eTrackingAdProgress.addListener(this._onTrackingAdProgress, this);
        this._manager.eTrackingAdCountdown.addListener(this._onTrackingAdCountdown, this);
        this._manager.eTrackingContentPlay.addListener(this._onTrackingContentPlay, this);
        this._manager.eTrackingContentBegin.addListener(this._onTrackingContentBegin, this);
        this._manager.eTrackingContentProgress.addListener(this._onTrackingContentProgress, this);
        this._manager.eTrackingContentComplete.addListener(this._onTrackingContentComplete, this);
        this._manager.eTrackingContentSeek.addListener(this._onTrackingContentSeek, this);
        this._manager.eTrackingFullscreen.addListener(this._onTrackingFullscreen, this);
        this._manager.eTrackingMuted.addListener(this._onTrackingMuted, this);
        this._manager.eTrackingPaused.addListener(this._onTrackingPaused, this);
        this.ePlayerLoaded = new Event();
        this.ePlayerLoadError = new Event();
        this.ePlayerReady = new Event();
        this.eContentMetadata = new Event();
        this.eContentBegin = new Event();
        this.eContentPlay = new Event();
        this.eContentPause = new Event();
        this.eContentEnd = new Event();
        this.eContentComplete = new Event();
        this.eContentPlayhead = new Event();
        this.eContentBuffering = new Event();
        this.eContentVolume = new Event();
        this.eContentError = new Event();
        this.eContentResize = new Event();
        this.eAdPlayhead = new Event();
        this.eAdPlay = new Event();
        this.eAdEnd = new Event();
        this.eAdError = new Event();
        this.eTrackingAdStart = new Event();
        this.eTrackingAdComplete = new Event();
        this.eTrackingAdProgress = new Event();
        this.eTrackingAdCountdown = new Event();
        this.eTrackingContentPlay = new Event();
        this.eTrackingContentBegin = new Event();
        this.eTrackingContentProgress = new Event();
        this.eTrackingContentComplete = new Event();
        this.eTrackingContentSeek = new Event();
        this.eTrackingFullscreen = new Event();
        this.eTrackingMuted = new Event();
        this.eTrackingPaused = new Event();
        this._manager.load(options);
      },
      render: function (containerElement) {
        this._manager.render(containerElement);
      },
      remove: function () {
        this._manager.remove();
      },
      getDefaultPlayer: function () {
        return this._manager.getCurrentPlayer();
      },
      play: function (id, options) {
        this._manager.playContentWithId(id, options);
      },
      queue: function (id, options) {
        this._manager.queueContentWithId(id, options);
      },
      pause: function () {
        this._manager.pause();
      },
      resume: function () {
        this._manager.resume();
      },
      resize: function (width, height) {
        this._manager.resize(width, height);
      },
      setVolume: function (v) {
        this._manager.setVolume(v);
      },
      getVolume: function () {
        return this._manager.getVolume();
      },
      mute: function () {
        this._manager.mute();
      },
      unmute: function () {
        this._manager.unmute();
      },
      getContentEntry: function (id) {
        return this._manager.getContentEntry(id);
      },
      setAdSection: function (ssid) {
        this._manager.setAdSection(ssid);
      },
      _mungeArgs: function (argv) {
        var args = slice(argv);
        args.unshift(this.getDefaultPlayer());
        return args;
      },
      _onPlayerLoaded: function () {
        this.ePlayerLoaded.dispatch();
      },
      _onPlayerLoadError: function () {
        this.ePlayerLoadError.dispatch();
      },
      _onPlayerRendered: function () {
        this.ePlayerReady.dispatch.apply(this.ePlayerReady, this._mungeArgs(arguments));
      },
      _onContentMetadata: function () {
        this.eContentMetadata.dispatch.apply(this.eContentMetadata, this._mungeArgs(arguments));
      },
      _onContentBegin: function () {
        this.eContentBegin.dispatch.apply(this.eContentBegin, this._mungeArgs(arguments));
      },
      _onContentPlay: function () {
        this.eContentPlay.dispatch.apply(this.eContentPlay, this._mungeArgs(arguments));
      },
      _onContentPause: function () {
        this.eContentPause.dispatch.apply(this.eContentPause, this._mungeArgs(arguments));
      },
      _onContentEnd: function () {
        this.eContentEnd.dispatch.apply(this.eContentEnd, this._mungeArgs(arguments));
      },
      _onContentComplete: function () {
        this.eContentComplete.dispatch.apply(this.eContentComplete, this._mungeArgs(arguments));
      },
      _onContentPlayhead: function () {
        this.eContentPlayhead.dispatch.apply(this.eContentPlayhead, this._mungeArgs(arguments));
      },
      _onContentBuffering: function () {
        this.eContentBuffering.dispatch.apply(this.eContentBuffering, this._mungeArgs(arguments));
      },
      _onContentVolume: function () {
        this.eContentVolume.dispatch.apply(this.eContentVolume, this._mungeArgs(arguments));
      },
      _onContentError: function () {
        this.eContentError.dispatch.apply(this.eContentError, this._mungeArgs(arguments));
      },
      _onContentResize: function () {
        this.eContentResize.dispatch.apply(this.eContentResize, this._mungeArgs(arguments));
      },
      _onAdPlayhead: function () {
        this.eAdPlayhead.dispatch.apply(this.eAdPlayhead, this._mungeArgs(arguments));
      },
      _onAdPlay: function () {
        this.eAdPlay.dispatch.apply(this.eAdPlay, this._mungeArgs(arguments));
      },
      _onAdEnd: function () {
        this.eAdEnd.dispatch.apply(this.eAdEnd, this._mungeArgs(arguments));
      },
      _onAdError: function () {
        this.eAdError.dispatch.apply(this.eAdError, this._mungeArgs(arguments));
      },
      _onTrackingAdStart: function () {
        this.eTrackingAdStart.dispatch.apply(this.eTrackingAdStart, this._mungeArgs(arguments));
      },
      _onTrackingAdComplete: function () {
        this.eTrackingAdComplete.dispatch.apply(this.eTrackingAdComplete, this._mungeArgs(arguments));
      },
      _onTrackingAdProgress: function () {
        this.eTrackingAdProgress.dispatch.apply(this.eTrackingAdProgress, this._mungeArgs(arguments));
      },
      _onTrackingAdCountdown: function () {
        this.eTrackingAdCountdown.dispatch.apply(this.eTrackingAdCountdown, this._mungeArgs(arguments));
      },
      _onTrackingContentPlay: function () {
        this.eTrackingContentPlay.dispatch.apply(this.eTrackingContentPlay, this._mungeArgs(arguments));
      },
      _onTrackingContentBegin: function () {
        this.eTrackingContentBegin.dispatch.apply(this.eTrackingContentBegin, this._mungeArgs(arguments));
      },
      _onTrackingContentProgress: function () {
        this.eTrackingContentProgress.dispatch.apply(this.eTrackingContentProgress, this._mungeArgs(arguments));
      },
      _onTrackingContentComplete: function () {
        this.eTrackingContentComplete.dispatch.apply(this.eTrackingContentComplete, this._mungeArgs(arguments));
      },
      _onTrackingContentSeek: function () {
        this.eTrackingContentSeek.dispatch.apply(this.eTrackingContentSeek, this._mungeArgs(arguments));
      },
      _onTrackingFullscreen: function () {
        this.eTrackingFullscreen.dispatch.apply(this.eTrackingFullscreen, this._mungeArgs(arguments));
      },
      _onTrackingMuted: function () {
        this.eTrackingMuted.dispatch.apply(this.eTrackingMuted, this._mungeArgs(arguments));
      },
      _onTrackingPaused: function () {
        this.eTrackingPaused.dispatch.apply(this.eTrackingPaused, this._mungeArgs(arguments));
      }
    });
  }());
  addBeforeUnLoadEvent(CVP.cleanup);
  window.CVP = CVP.Utils.extend(CVPconstructor, CVP.Utils.extend(window.CVP || {}, CVP));
}());
(function () {
  if (window.Aspen) {
    return;
  }
  var o = "1.0.0";
  var l = [window.location.search, window.location.hash].join().search(/\bdmtdebug\b/) !== -1;
  var n = (function () {
    var w = false,
      y = /xyz/.test(function () {
        xyz;
      }) ? /\b_super\b/ : /.*/;
    var v = function () {};
    v.extend = function (D) {
      var C = this.prototype;
      w = true;
      var B = new this();
      w = false;
      for (var A in D) {
        B[A] = typeof D[A] == "function" && typeof C[A] == "function" && y.test(D[A]) ? (function (E, F) {
          return function () {
            var H = this._super;
            this._super = C[E];
            var G = F.apply(this, arguments);
            this._super = H;
            return G;
          };
        })(A, D[A]) : D[A];
      }

      function z() {
        if (!w && this.init) {
          this.init.apply(this, arguments);
        }
      }
      z.prototype = B;
      z.constructor = z;
      z.extend = arguments.callee;
      return z;
    };
    return v;
  })();
  (function (ap, ao, an) {
    function M() {
      var v = I;
      v.loader = {
        load: O,
        i: 0
      };
      return v;
    }

    function O(w, v, z) {
      var y = v == "c" ? V : X;
      ah = 0, v = v || "j", P(w) ? Q(y, w, v, this.i++, am, z) : (ai.splice(this.i++, 0, w), ai.length == 1 && S());
      return this;
    }

    function Q(F, E, D, C, B, A) {
      function v() {
        !y && aa(z.readyState) && (w.r = y = 1, !ah && Y(), z.onload = z.onreadystatechange = null, al(function () {
          ad.removeChild(z);
        }, 0));
      }
      var z = ao.createElement(F),
        y = 0,
        w = {
          t: D,
          s: E,
          e: A
        };
      z.src = z.data = E, !af && (z.style.display = "none"), z.width = z.height = "0", F != "object" && (z.type = D), z.onload = z.onreadystatechange = v, F == "img" ? z.onerror = v : F == "script" && (z.onerror = function () {
        w.e = w.r = 1, S();
      }), ai.splice(C, 0, w), ad.insertBefore(z, af ? null : ak), al(function () {
        y || (ad.removeChild(z), w.r = w.e = y = 1, Y());
      }, I.errorTimeout);
    }

    function S() {
      var v = ai.shift();
      ah = 1, v ? v.t ? al(function () {
        v.t == "c" ? U(v) : W(v);
      }, 0) : (v(), Y()) : ah = 0;
    }

    function U(v) {
      var z = ao.createElement("link"),
        y;
      z.href = v.s, z.rel = "stylesheet", z.type = "text/css";
      if (!v.e && (ab || ag)) {
        var w = function (A) {
          al(function () {
            if (!y) {
              try {
                A.sheet.cssRules.length ? (y = 1, Y()) : w(A);
              } catch (B) {
                B.code == 1000 || B.message == "security" || B.message == "denied" ? (y = 1, al(function () {
                  Y();
                }, 0)) : w(A);
              }
            }
          }, 0);
        };
        w(z);
      } else {
        z.onload = function () {
          y || (y = 1, al(function () {
            Y();
          }, 0));
        }, v.e && z.onload();
      }
      al(function () {
        y || (y = 1, Y());
      }, I.errorTimeout), !v.e && ak.parentNode.insertBefore(z, ak);
    }

    function W(v) {
      var y = ao.createElement("script"),
        w;
      y.src = v.s, y.onreadystatechange = y.onload = function () {
        !w && aa(y.readyState) && (w = 1, Y(), y.onload = y.onreadystatechange = null);
      }, al(function () {
        w || (w = 1, Y());
      }, I.errorTimeout), v.e ? y.onload() : ak.parentNode.insertBefore(y, ak);
    }

    function Y() {
      var w = 1,
        v = -1;
      while (ai.length - ++v) {
        if (ai[v].s && !(w = ai[v].r)) {
          break;
        }
      }
      w && S();
    }

    function aa(v) {
      return !v || v == "loaded" || v == "complete";
    }
    var am = ao.documentElement,
      al = ap.setTimeout,
      ak = ao.getElementsByTagName("script")[0],
      aj = {}.toString,
      ai = [],
      ah = 0,
      ag = "MozAppearance" in am.style,
      af = ag && !! ao.createRange().compareNode,
      ae = ag && !af,
      ad = af ? am : ak.parentNode,
      ac = ap.opera && aj.call(ap.opera) == "[object Opera]",
      ab = "webkitAppearance" in am.style,
      Z = ab && "async" in ao.createElement("script"),
      X = ag ? "object" : ac || Z ? "img" : "script",
      V = ab ? "img" : X,
      T = Array.isArray || function (v) {
        return aj.call(v) == "[object Array]";
      }, R = function (v) {
        return Object(v) === v;
      }, P = function (v) {
        return typeof v == "string";
      }, N = function (v) {
        return aj.call(v) == "[object Function]";
      }, L = [],
      K = {}, J, I;
    I = function (w) {
      function y(E, D) {
        function F(au) {
          if (P(au)) {
            z(au, H, D, 0, at);
          } else {
            if (R(au)) {
              for (G in au) {
                au.hasOwnProperty(G) && z(au[G], H, D, G, at);
              }
            }
          }
        }
        var at = !! E.test,
          ar = at ? E.yep : E.nope,
          aq = E.load || E.both,
          H = E.callback,
          G;
        F(ar), F(aq), E.complete && D.load(E.complete);
      }

      function z(E, D, ar, aq, H) {
        var G = A(E),
          F = G.autoCallback;
        if (!G.bypass) {
          D && (D = N(D) ? D : D[E] || D[aq] || D[E.split("/").pop().split("?")[0]]);
          if (G.instead) {
            return G.instead(E, D, ar, aq, H);
          }
          ar.load(G.url, G.forceCSS || !G.forceJS && /css$/.test(G.url) ? "c" : an, G.noexec), (N(D) || N(F)) && ar.load(function () {
            M(), D && D(G.origUrl, H, aq), F && F(G.origUrl, H, aq);
          });
        }
      }

      function A(E) {
        var D = E.split("!"),
          at = L.length,
          ar = D.pop(),
          aq = D.length,
          H = {
            url: ar,
            origUrl: ar,
            prefixes: D
          }, G, F;
        for (F = 0; F < aq; F++) {
          G = K[D[F]], G && (H = G(H));
        }
        for (F = 0; F < at; F++) {
          H = L[F](H);
        }
        return H;
      }
      var v, C, B = this.yepnope.loader;
      if (P(w)) {
        z(w, 0, B, 0);
      } else {
        if (T(w)) {
          for (v = 0; v < w.length; v++) {
            C = w[v], P(C) ? z(C, 0, B, 0) : T(C) ? I(C) : R(C) && y(C, B);
          }
        } else {
          R(w) && y(w, B);
        }
      }
    }, I.addPrefix = function (w, v) {
      K[w] = v;
    }, I.addFilter = function (v) {
      L.push(v);
    }, I.errorTimeout = 10000, ao.readyState == null && ao.addEventListener && (ao.readyState = "loading", ao.addEventListener("DOMContentLoaded", J = function () {
      ao.removeEventListener("DOMContentLoaded", J, 0), ao.readyState = "complete";
    }, 0)), ap.yepnope = M();
  })(this, this.document);
  var c = CVP.Utils;
  var g = function () {
    var v = "";
    if (window.console && window.console.log && l) {
      v = c.slice(arguments).join(" | ");
      window.console.log(v);
      if (c.isFunc(window.logJSAuth)) {
        window.logJSpAuth(v);
      }
    }
  };
  var m = CVP.Ajax;
  var f = (function () {
    var v = "http://aspen-qa.turner.com",
      C, D, E = false,
      A = [],
      B, z, w, y;
    D = function (F) {
      v = F;
      C = new window.CVP.easyXDM.Rpc({
        swf: "http://i.cdn.turner.com/xslo/cvp/easyxdm/swf/easyxdm.swf",
        remote: v + "/static/xdm_iframe.html"
      }, {
        remote: {
          request: {}
        }
      });
      g("[aspen]", "[easyXDM]", "init AspenComm");
      E = true;
      D = function () {
        throw new Error("already init'ed - ignored");
      };
      B();
    };
    z = function (H, F, G) {
      if (E) {
        y(H, F, G);
      } else {
        w(H, F, G);
      }
    };
    w = function () {
      A.push[arguments];
    };
    B = function () {
      var G = 0,
        F = A.length;
      for (; G < F; ++G) {
        y.apply(null, A[G]);
      }
    };
    y = function (J, G, H) {
      g("[aspen]", "[easyXDM]", "make request", J);
      var I, F, K;
      I = c.extend(c.extend({
        method: "POST"
      }, J || {}));
      F = function (L) {
        var M = L.data;
        if (typeof M === "string" && M.charAt(0).match(/[{[]/)) {
          try {
            M = JSON.parse(M);
          } catch (N) {
            g(N);
          }
        }
        g("[aspen]", "[easyXDM]", "request success", L);
        G(M, L.status, L.headers);
      };
      K = function (L) {
        var M = L.data;
        if (typeof M === "string" && M.charAt(0).match(/[{[]/)) {
          try {
            M = JSON.parse(M);
          } catch (N) {
            g(N);
          }
        }
        H(M, L.status, L.message);
      };
      C.request(I, F, K);
    };
    return ({
      init: D,
      request: z
    });
  }());
  var b = function (v) {
    window.CVP = window.CVP || {};
    yepnope({
      test: window.CVP.easyXDM != null,
      nope: "http://z.cdn.turner.com/xslo/cvp/easyxdm/js/easyXDM.ugly.js",
      complete: function () {
        if (!window.easyXDM) {
          throw new Error("failed to install easyXDM");
        } else {
          window.CVP.easyXDM = easyXDM.noConflict("CVP");
          yepnope({
            test: window.JSON != null,
            nope: "http://z.cdn.turner.com/xslo/cvp/easyxdm/js/json2.ugly.js",
            complete: function () {
              if (!window.JSON) {
                throw new Error("failed to install JSON polyfill");
              }
            },
            complete: v
          });
        }
      }
    });
  };
  var u = function () {
    this._dependencies = [];
    this._loadedCount = 0;
    this._successHandlers = [];
    this._failureHandlers = [];
    this.add = function (w) {
      this._dependencies.push({
        dependency: w,
        success: false
      });
      var v = this._dependencies.length - 1;
      w.onComplete(c.bind(this._onDependencyLoaded, this, v, true));
      w.onFailure(c.bind(this._onDependencyLoaded, this, v, false));
    };
    this.load = function () {
      for (var w = 0, v = this._dependencies.length; w < v; w++) {
        this._dependencies[w].dependency.load();
      }
    };
    this.onComplete = function (v) {
      this._successHandlers.push(v);
    };
    this.onFailure = function (v) {
      this._failureHandlers.push(v);
    };
    this._onDependencyLoaded = function (v, w) {
      ++this._loadedCount;
      this._dependencies[v].success = w;
      if (this._loadedCount === this._dependencies.length) {
        this._onAllDependenciesLoaded();
      }
    };
    this._onAllDependenciesLoaded = function () {
      this._loadedCount = 0;
      var z = true;
      for (var y = 0, v = this._dependencies.length; y < v; y++) {
        if (!this._dependencies[y].success) {
          z = false;
          break;
        }
      }
      var w = (z) ? this._successHandlers : this._failureHandlers;
      for (y = 0, v = w.length; y < v; y++) {
        w[y]();
      }
    };
  };
  var a = function (v) {
    this._func = v;
    this._successHandlers = [];
    this._failureHandlers = [];
    this.load = function () {
      this._func(c.bind(this._onSuccess, this), c.bind(this._onFailure, this));
    };
    this.onComplete = function (w) {
      this._successHandlers.push(w);
    };
    this.onFailure = function (w) {
      this._failureHandlers.push(w);
    };
    this._onSuccess = function () {
      for (var y = 0, w = this._successHandlers.length; y < w; y++) {
        this._successHandlers[y]();
      }
    };
    this._onFailure = function () {
      for (var y = 0, w = this._failureHandlers.length; y < w; y++) {
        this._failureHandlers[y]();
      }
    };
  };
  var t = "http://i.cdn.turner.com/xslo/cvp/config/";
  var h = "total";
  var q = "timer";
  var s = "none";
  var e = {};
  var k = {};
  var p = n.extend({
    init: function (v) {
      this._enabled = false;
      this._queue = [];
      this._config = v;
      this._timer;
      this._firstPostTimer;
    },
    start: function (v) {
      this._config = v;
      this._enabled = true;
      if (k.batchMode == q) {
        g("[aspen]", "start timer");
        var y = this;
        this._timer = setTimeout(function () {
          y._postTimerEvent();
        }, Number(k.batchModeAmount) * 1000);
        var w = Math.ceil(Math.random() * Number(k.batchModeAmount));
        if (w == Number(k.batchModeAmount)) {
          w--;
          if (w <= 0) {
            w = 0.5;
          }
        }
        g("[aspen]", "random time: " + w);
        this._firstPostTimer = setTimeout(function () {
          y._firstPostTimerEvent();
        }, w * 1000);
      }
    },
    add: function (v) {
      this._addToQueue(v);
      if (!this._enabled) {
        g("[aspen]", "Batch service not enabled. Queuing message.");
        return;
      }
      if (k.enabled && !this._config.batchThrottled) {
        if (k.batchMode == h) {
          if (this._queue.length == k.batchModeAmount) {
            this.post();
          }
        } else {
          if (k.batchMode == s) {
            this.post();
          } else {
            if (k.batchMode != q) {
              this.post();
            }
          }
        }
        if (this._queue.length > 0) {
          if ((v["eventType"] == "error") && (typeof k.highPriorityErrors != "undefined")) {
            this.flushByError(v["eventData"]);
          } else {
            if ((v["eventType"] != "error") && (typeof k.highPriorityEvents != "undefined")) {
              this.flushByEvent(v["eventType"]);
            }
          }
        }
      } else {
        if (k.enabled) {
          g("[aspen]", "Aspen is diabled via analyticsConfig. Message not added.");
        }
        if (this._config.batchThrottled) {
          g("[aspen]", "Batching is throttled. Message not added.");
        }
      }
    },
    _addToQueue: function (v) {
      g("[aspen]", "Adding message to batch queue.");
      this._queue.push(v);
    },
    post: function () {
      if (!this._config.postThrottled) {
        var A = {
          "sessionId": this._config.sessionId,
          "events": this._queue
        };
        g("[aspen]", "send batch string");
        if (!c.isNull(this._config.requestMethod) && (this._config.requestMethod == "easyXDM")) {
          f.request({
            url: k.batchApi,
            data: {
              aspenJson: JSON.stringify(A)
            }
          }, c.bind(this._postSuccess, this), c.bind(this._postFailure, this));
        } else {
          var z = "";
          var y = k.servicesUrl + k.batchApi;
          if (y.indexOf(".jsonp") === -1) {
            y += ".jsonp";
          }
          if (k.batchContentEncoding == "gzip") {
            var w = "?aspenJson=" + JSON.stringify(A);
            var v = encodeURIComponent(w).replace(/%20/g, "+");
            var B = v;
            z = B;
          } else {
            z = "?aspenJson=" + encodeURIComponent(JSON.stringify(A)).replace(/%20/g, "+");
          }
          m.getJSONP({
            jsonpCallback: "aspenPostBatch",
            url: y + z,
            error: c.bind(this._postFailure, this),
            success: c.bind(this._postSuccess, this)
          });
        }
        this._queue = [];
      } else {
        g("[aspen]", "Batch posting is throttled. Batch not posted.");
      }
    },
    _postTimerEvent: function () {
      g("[aspen]", "postTimer - queue.length: " + this._queue.length);
      if (this._queue.length > 0) {
        g("[aspen]", "posting " + this._queue.length + " messages");
        this.post();
      } else {
        g("[aspen]", "no messages to post");
      }
      var v = this;
      this._timer = setTimeout(function () {
        v._postTimerEvent();
      }, Number(k.batchModeAmount) * 1000);
    },
    _firstPostTimerEvent: function () {
      g("[aspen]", "firstPostTimer - queue.length: " + this._queue.length);
      if (this._queue.length > 0) {
        g("[aspen]", "posting " + this._queue.length + " messages");
        this.post();
      } else {
        g("[aspen]", "no messages to post");
      }
    },
    _postSuccess: function (v) {
      g("[aspen]", "post success: " + v);
    },
    _postFailure: function (v) {
      g("[aspen]", "post failed: " + v);
    },
    flushByError: function (F) {
      if (typeof F.errorCode != "undefined") {
        var B = F.errorCode;
        var T = B.substring(0, 2);
        var C = B.substring(2, 4);
        var Q = B.substring(4, 6);
        var E = B.substring(6);
        var y = [];
        y = k.highPriorityErrors.split(",");
        var H = "";
        var S = "";
        var z = "";
        var D = "";
        var G = [];
        var U = [];
        var A = [];
        var W = [];
        for (var R = 0, N = y.length; R < N; ++R) {
          switch (R) {
            case 0:
              H = String(y[R]);
              G = H.split("+");
              break;
            case 1:
              S = String(y[R]);
              U = S.split("+");
              break;
            case 2:
              z = String(y[R]);
              A = z.split("+");
              break;
            case 3:
              D = String(y[R]);
              W = D.split("+");
              break;
          }
        }
        for (R = 0, N = G.length; R < N; ++R) {
          var w = String(G[R]);
          if ((T == w) || (w == "*")) {
            for (var P = 0, L = U.length; P < L; ++P) {
              var I = String(U[P]);
              if ((C == I) || (I == "*")) {
                for (var O = 0, K = A.length; O < K; ++O) {
                  var v = String(A[O]);
                  if ((Q == v) || (v == "*")) {
                    for (var M = 0, J = W.length; M < J; ++M) {
                      var V = String(W[M]);
                      if ((E == V) || (V == "*")) {
                        g("[aspen", "[flushByError] found match, flushing batch");
                        this.post();
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    },
    flushByEvent: function (z) {
      var w = k.highPriorityEvents.split(",");
      for (var y = 0, v = w.length; y < v; ++y) {
        var A = String(w[y]);
        if (A == z) {
          g("[aspen]", "[flushBatchByEvent] found match, flushing batch");
          this.post();
        }
      }
    },
    setSessionId: function (v) {
      this._config.sessionId = v;
    },
    setBatchThrottled: function (v) {
      this._config.batchThrottled = v;
    },
    setPostThrottled: function (v) {
      this._config.postThrottled = v;
    },
    disableTimer: function () {
      if (k.batchMode == q) {
        clearTimeout(this._timer);
      }
    }
  });
  var r = {
    WAITING: "loadStateWaiting",
    LOADING: "loadStateLoading",
    READY: "loadStateReady",
    FAILED: "loadStateFailed"
  };
  var d = window.Aspen = {
    init: function (w) {
      var v = this;
      if (c.undef(this.initialized)) {
        this.initialized = true;
        this.ready = false;
        this.batchService;
        this.sessionObject = {};
        this.serviceUrlRoot;
        this.isThrottled = true;
        this.sessionId = -1;
        this.timeDifference = 0;
        this._retryTimer;
        this._retries = 0;
        this._retriesMade = 0;
        this._retryTime = 0;
        this._savedSession = {};
        this._timestampStr = "";
        this.sessionToken = "";
        this._appId = "";
        this._requestMethod = "jsonp";
        this._messageQueue = [];
        this._loadState = r.WAITING;
        this._configLoaded = false;
        this._dependenciesLoaded = false;
        e = this._options = w;
        e.site = e && e.site;
        e.profile = e && e.profile;
        e.context = e && e.context;
        e.contentId = e && e.contentId;
        e.containerUrl = e && e.containerUrl;
        e.configUrl = e && e.configUrl;
        e.requestMethod = e && e.requestMethod;
        e.dt = e && e.superduperdevtime;
        e.configBaseUrl = e && e.configBaseUrl;
        if (!c.undef(e.requestMethod) && !c.empty(e.requestMethod)) {
          this._requestMethod = e.requestMethod;
        }
        g("[aspen]", "requestMethod", this._requestMethod);
        if (c.empty(e.site)) {
          g("[aspen]", "Unable to start Aspen, no site provided");
        } else {
          this.batchService = new p();
          this._loadState = r.LOADING;
          CVP.Events.onReady(function () {
            var y = new u();
            y.add(new a(c.bind(v._loadConfigFile, v)));
            y.add(new a(c.bind(v._loadRequiredJS, v)));
            y.onComplete(c.bind(v._onDependenciesLoaded, v));
            y.onFailure(c.bind(v._onDependenciesLoadFailure, v));
            y.load();
          });
        }
      }
    },
    _loadConfigFile: function (y, v) {
      var z = e.configBaseUrl || t + e.site;
      g("[aspen]", "Using config base path: " + z);
      var w = z + "/aspenanalytics.json?_=" + c.now();
      m.getJSONP({
        jsonpCallback: "cvp_onAnalyticsConfigReceived",
        url: w,
        success: c.bind(this._loadConfigSuccess, this, y),
        error: c.bind(this._loadConfigFailure, this, v)
      });
    },
    _loadConfigSuccess: function (v, w) {
      g("[aspen]", "Config loaded successfully");
      k = c.extend(c.extend({}, w["default"] || {}), w[e.profile] || {});
      if (c.undef(k.batchMode)) {
        k.batchMode = "total";
      }
      if (c.undef(k.batchModeAmount)) {
        k.batchModeAmount = "10";
      }
      if (c.undef(k.helloRetryCount)) {
        k.helloRetryCount = "5";
      }
      if (c.undef(k.helloRetryTime)) {
        k.helloRetryTime = "10000";
      }
      if (c.undef(k.batchContentEncoding)) {
        k.batchContentEncoding = "json";
      }
      g("[aspen]", "batchMode: ", k.batchMode);
      g("[aspen]", "batchModeAmount: ", k.batchModeAmount);
      g("[aspen]", "helloRetryCount: ", k.helloRetryCount);
      g("[aspen]", "helloRetryTime: ", k.helloRetryTime);
      v && v();
    },
    _loadConfigFailure: function (v, w) {
      g("[aspen]", "Config failed to load", w);
      v && v();
    },
    _loadRequiredJS: function (y, w) {
      var v = this;
      if (window.JSON != null) {
        this._loadRequiredJSSuccess(y);
      } else {
        yepnope({
          load: "http://z.cdn.turner.com/xslo/cvp/easyxdm/js/json2.ugly.js",
          complete: function () {
            if (!window.JSON) {
              v._loadRequiredJSFailure(w);
              return;
            }
            v._loadRequiredJSSuccess(y);
          }
        });
      }
    },
    _loadRequiredJSSuccess: function (v) {
      g("[aspen]", "External JS dependencies loaded successfully");
      v && v();
    },
    _loadRequiredJSFailure: function (v) {
      g("[aspen]", "External JS dependencies failed to load");
      v && v();
    },
    _onDependenciesLoaded: function () {
      this._loadState = r.READY;
      g("[aspen]", "_onDependenciesLoaded - all required dependencies successfully loaded.");
      if (!c.undef(k.enabled) && k.enabled === "true") {
        g("[aspen]", "analytics enabled via config");
        if (!c.undef(k.servicesUrl)) {
          this.serviceUrlRoot = k.servicesUrl;
          if (this._requestMethod === "easyXDM") {
            b(function () {
              f.init(k.servicesUrl);
            });
          }
          this._hello();
        }
      } else {
        g("[aspen]", "analytics disabled via config");
        this._initFailure();
      }
    },
    _onDependenciesLoadFailure: function () {
      this._loadState = r.FAILED;
      g("[aspen]", "_onDependenciesLoadFailure - one or more required dependencies failed to load.");
    },
    _hello: function () {
      var w = c.getQueryParam("sessionToken");
      g("[aspen]", "check querySessionToken: ", w);
      if (!c.empty(w)) {
        this.sessionToken = w;
        this.send({}, "authSessionReload");
      } else {
        if (!c.undef(CVP)) {
          this.sessionToken = CVP.getSessionToken();
          g("[aspen]", "calling get sessionToken: ", this.sessionToken);
        }
      }
      var y = {
        propertyName: e.site,
        pageUrl: document.URL,
        context: e.context,
        protocol: "1.0"
      };
      if (!c.empty(this.sessionToken)) {
        y.sessionToken = this.sessionToken;
      }
      if (this._requestMethod === "easyXDM") {
        f.request({
          url: "/api/hello",
          data: {
            aspenJson: JSON.stringify(y)
          }
        }, c.bind(this._helloSuccess, this), c.bind(this._helloFailure, this));
      } else {
        if (this._requestMethod === "jsonp") {
          var v = k.servicesUrl + k.helloApi;
          if (v.indexOf(".jsonp") === -1) {
            v += ".jsonp";
          }
          v += "?aspenJson=" + encodeURIComponent(JSON.stringify(y)).replace(/%20/g, "+");
          m.getJSONP({
            jsonpCallback: "parseCVPServicesInitialization",
            url: v,
            error: c.bind(this._helloFailure, this),
            success: c.bind(this._helloSuccess, this)
          });
        }
      }
      this._retryTimer = setTimeout(c.bind(this._helloRetry, this), Number(k.helloRetryTime));
      this._isRetrying = true;
      this.hello = function () {};
    },
    _helloSuccess: function (w) {
      clearTimeout(this._retryTimer);
      this.isThrottled = (typeof w.throttled !== "undefined") && (w.throttled !== "no") || this.isThrottled;
      this.sessionId = (typeof w.sessionId !== "undefined") ? w.sessionId : this.sessionId;
      this._timestampStr = (typeof w.timestamp !== "undefined") ? w.timestamp : this.timeDifference;
      this.timeDifference = Number(this._timestampStr) - c.now();
      if (w.throttled === "no") {
        this.isThrottled = false;
      }
      g("[aspen]", "_helloSuccess");
      g("[aspen]", "config.throttled: " + w.throttled);
      g("[aspen]", "throttled: " + this.isThrottled);
      g("[aspen]", "sessionId: " + this.sessionId);
      this._appId = "CVP_" + c.randomString(25);
      var v = {};
      v.batchThrottled = false;
      v.postThrottled = true;
      v.sessionId = "";
      v.requestMethod = this._requestMethod;
      this.batchService.start(v);
      this.batchService.setSessionId(this.sessionId);
      this.batchService.setPostThrottled(this.isThrottled);
      this._initSuccess();
    },
    _helloFailure: function (v) {
      g("[aspen]", "_helloFailure url: " + v);
    },
    _helloRetry: function () {
      if (this._retries == k.helloRetryCount) {
        clearTimeout(this._retryTimer);
        g("[aspen]", "retries exhasted, aspen is disabled");
        this.isThrottled = true;
        this.batchService.setBatchThrottled(true);
        this.batchService.setPostThrottled(true);
        this.batchService.disableTimer();
      } else {
        this._retries++;
        this._retryTime = this._retries * Number(k.helloRetryTime);
        this._savedSession.retries = String(this._retries);
        this._savedSession.retryTime = String(this._retryTime);
        this._hello();
      }
    },
    isMessageExcluded: function (v) {
      if (k && k.messageExcludes) {
        if (k.messageExcludes.indexOf(v) >= 0) {
          return true;
        }
      }
      return false;
    },
    send: function (y, w) {
      if (!this.ready) {
        g("[aspen]", "send - Aspen's not ready, queuing message");
        this._messageQueue.push({
          message: y,
          type: w
        });
        return;
      }
      if (!this.isThrottled) {
        if (this.isMessageExcluded(w)) {
          g("[aspen]", "message excluded by config, not added to batch", w);
          return;
        }
        y["timestamp"] = c.now() + this.timeDifference;
        y["appId"] = this._appId;
        g("[aspen]", "appId: " + this._appId);
        var v = {};
        v["eventType"] = w;
        v["eventData"] = y;
        g("[aspen]", "add to batch json message: " + JSON.stringify(v));
        this.batchService.add(v);
      } else {
        g("[aspen]", "Add message to batch is throttled! Message not added.");
      }
    },
    setSessionToken: function (v) {
      this.sessionToken = v;
    },
    _initSuccess: function () {
      this.ready = true;
      for (var w = 0, v = this._messageQueue.length; w < v; w++) {
        this.send(this._messageQueue[w].message, this._messageQueue[w].type);
      }
      var y = {};
      y.screenWidth = screen.width;
      y.screenHeight = screen.height;
      y.browserName = navigator.appName;
      y.userAgent = navigator.userAgent;
      y.platform = navigator.platform;
      this.send(y, "systemInfo");
      this._initSuccess = function () {};
    },
    _initFailure: function () {}
  };
}).call(this);
var CNNVIDEO = function (r, E) {
  var ac = "0.4",
    h = window.jQuery,
    w = h.trim(r),
    g = h(w.substring(0, 1) !== "#" ? "#" + r : r),
    P = false,
    X = false,
    G = g.attr("id"),
    e = G + "-videowrapper",
    u, K, s, y, C, n, k, m, ad, ab, F, W, V, H, a, p, f, c, J, T, R, M, b, o, Y, Q, D, z, q, B, A, ae, S, l, t, N, U, v, Z, L = String.prototype.split.call("onContentMetadata onContentBegin onContentPlay onContentPause onContentEnd onContentComplete onContentBuffering onContentVolume onContentError onAdPlay onAdEnd", " "),
    d, aa, I = {}, O = h.extend({}, {
      video: "/tech/2012/01/11/ces-2012-3d-tvs.cnn",
      network: "cnn",
      profile: "desktop",
      context: "main",
      section: "",
      thumb: "http://i2.cdn.turner.com/cnn/dam/assets/120307022252-romney-gingrich-santorum-split-story-top.jpg",
      autostart: false,
      width: "640",
      height: "360",
      preset: "custom",
      diagnostics: {
        section: "default"
      }
    }, E);
  O.diagnostics.version = ac;
  O.diagnostics.adsection = E.adsection || "default";
  O.fullscreenbitrate = 1300;
  if (O.isLive) {
    y = "http://i.cdn.turner.com/cnn/.e/img/3.0/video/416_player_Click_to_watch_off.png";
    C = "http://i.cdn.turner.com/cnn/.e/img/3.0/video/416_player_click_to_watch_on.png";
    n = 145;
  } else {
    y = "http://i.cdn.turner.com/cnn/.e/img/3.0/video/416_player_Click_to_play_off.png";
    C = "http://i.cdn.turner.com/cnn/.e/img/3.0/video/416_player_click_to_play_on.png";
    n = 136;
  }
  u = E.adsection || false;
  K = ".cnnvideo_wrapper{ position: relative; }.cnnvideo_playcontainer{ position: absolute; top:0px; left: 0px; cursor: pointer; background: url(" + y + ") no-repeat; }.cnnvideo_click_standard { width:" + n + "px; height:42px;}.cnnvideo_playcontainer:hover{ background: url(" + C + ") no-repeat; }#adCountdown {background: black; color: white; font-size: 10px; height: 18px; padding: 1px 5px; position: absolute; bottom: 0; width: 406px; } #source{ color: #666666; } .vidSource{ color: #999999; } .vidSource a{ color: #6AB9D3; }.vidSource a:hover{ color: #CA0002; }";
  if (O.preset && O.preset !== "custom") {
    switch (O.preset) {
      case "homepage":
      case "sectionfront":
        O.width = "416";
        O.height = "230";
        O.profile = "desktop";
        O.context = "sectionfront";
        break;
      case "debates":
        O.width = "768";
        O.height = "432";
        O.profile = "desktop";
        O.context = "2012debates";
        break;
      case "storypage":
        O.width = "640";
        O.height = "360";
        O.profile = "desktop";
        O.context = "main";
        break;
      case "blog":
        O.width = "512";
        O.height = "288";
        break;
      case "large":
        O.width = "768";
        O.height = "432";
        break;
      case "xlarge":
        O.width = "960";
        O.height = "540";
        break;
      case "leanback":
        O.width = "1280";
        O.height = "720";
        break;
      default:
    }
  }
  d = function () {
    var af = /\b(Kindle|Fire|Silk)\b/ig.exec(window.navigator.userAgent);
    if (af) {
      return "kindle";
    }
    af = /\b(Android)\b/ig.exec(window.navigator.userAgent);
    if (af) {
      return "android";
    }
    return null;
  };
  V = function () {
    var af = h('<div class="cnnvideo_wrapper" id="' + e + '"></div>');
    g.html(af);
    return af;
  };
  H = function (ag, af) {
    X.play(ag, af || {});
  };
  a = function () {
    if (X) {
      X.pause();
    }
  };
  A = function () {
    var af = X.getDuration();
    if (!X) {
      af = 0;
    }
    return af;
  };
  ae = function () {
    var af = X.getPlayhead();
    if (!X) {
      af = 0;
    }
    return af;
  };
  Z = function () {
    var af;
    if (X) {
      af = X.getAbsolutePlayhead();
    } else {
      af = -1;
    }
    return af;
  };
  p = function () {
    if (X) {
      X.resume();
    }
  };
  z = function (ag, af, ah) {
    if (X) {
      X.resize(ag, af, ah);
    }
  };
  B = function (af) {
    if (X) {
      X.seek(af);
    }
  };
  q = function (af) {
    if (!S) {
      S = X.getContentEntry(af);
    }
    return S;
  };
  l = function (ah) {
    var ag = q(ah),
      af;
    if (ag) {
      af = h.parseJSON(ag);
      if (af && af.broadcastStartTime) {
        return af.broadcastStartTime;
      }
    }
    return 0;
  };
  t = function () {
    return O.video;
  };
  f = function (af) {
    X.setAdSection(af);
  };
  c = function (af) {
    return (af.indexOf("cvptve/") !== -1);
  };
  J = function (af) {
    return (af.indexOf("cvplive/") !== -1);
  };
  T = function (ah) {
    var ag = O.diagnostics || {}, af = ah || X.getContentId();
    ag.deliveryType = "O";
    if (c(af)) {
      ag.deliveryType = "T";
    } else {
      if (J(af)) {
        ag.deliveryType = "L";
      }
    }
    return ag;
  };
  R = function () {
    if (u !== undefined) {
      f(u);
    }
    H(O.video, {
      convivaMetadata: T()
    });
  };
  M = function (af) {
    if (X) {
      return;
    }
    var ai, ag = L.length,
      ak, aj = d(),
      al = aj ? "html5" : "flash";
    X = new window.CVP({
      id: "cvp_" + G,
      width: O.width,
      height: O.height,
      playerType: al,
      perVideoFallbacks: [{
        evaluate: function () {
          return al === "html5" && O.isLive;
        },
        filter: O.videoStreamUrl
      }],
      flashVars: {
        context: O.context,
        site: O.network,
        profile: O.profile,
        contentId: O.video
      },
      embed: {
        containerSwf: "http://z.cdn.turner.com/xslo/cvp/assets/container/2.0.4.0/cvp_main_container.swf",
        options: {
          quality: "high",
          bgcolor: "#000000",
          allowFullScreen: "true",
          allowScriptAccess: "always",
          wMode: "transparent"
        }
      },
      onCVPReady: function () {
        R();
      },
      onContentBegin: function (am, an) {
        g.triggerHandler("onContentBegin", {
          type: "onContentBegin",
          playerId: am,
          contentId: an
        });
      },
      onContentPlay: function (am, an) {
        g.triggerHandler("onContentPlay", {
          type: "onContentPlay",
          playerId: am,
          contentId: an
        });
      },
      onContentComplete: function (am, an) {
        g.triggerHandler("onContentComplete", {
          type: "onContentComplete",
          playerId: am,
          contentId: an
        });
      },
      onContentPlayhead: function (am, ap, an, ao) {
        g.triggerHandler("onContentPlayhead", {
          type: "onContentPlayhead",
          playerId: am,
          contentId: ap,
          playhead: an,
          duration: ao
        });
      },
      onAdPlay: function (ao, ap, ar, at, aq, an, am) {
        g.triggerHandler("adPlay", {
          type: "adPlay",
          playerId: ao,
          token: ap,
          mode: ar,
          id: at,
          duration: aq,
          segmentId: an,
          adType: am
        });
      },
      onAdEnd: function (ao, ap, ar, at, aq, an, am) {
        g.triggerHandler("onAdEnd", {
          type: "onAdEnd",
          playerId: ao,
          token: ap,
          mode: ar,
          id: at,
          duration: aq,
          segmentId: an,
          adType: am
        });
      },
      onContentPause: function (am, an) {
        g.triggerHandler("onContentPause", {
          type: "onContentPause",
          playerId: am,
          contentId: an
        });
      },
      onTrackingFullscreen: function (an, am) {
        g.triggerHandler("onTrackingFullscreen", {
          type: "onTrackingFullscreen",
          playerId: an,
          dataObj: am
        });
      },
      onTrackingAdCountdown: function (am, an) {
        document.getElementById("adCountdown").innerHTML = "Your video will play in  " + an.secs + " secs";
      }
    });

    function ah() {
      return g.triggerHandler("event", arguments);
    }
    for (ai = 0; ai < ag; ai += 1) {
      ak = L[ai];
      if (!(X.hasOwnProperty(ak))) {
        X[ak] = ah();
      }
    }
    if (typeof af === "function") {
      af();
    }
  };
  b = function () {
    if (h('style[title="cnnvideo"]').length > 0) {
      return;
    }
    var ag = document.getElementsByTagName("head")[0],
      ah = document.createElement("style"),
      af;
    ah.type = "text/css";
    ah.title = "cnnvideo";
    if (ah.styleSheet) {
      ah.styleSheet.cssText = K;
    } else {
      af = document.createTextNode(K);
      ah.appendChild(af);
    }
    ag.appendChild(ah);
  };
  o = function () {
    var ag = Math.ceil(O.width / 2) - 100,
      af = Math.ceil(O.height / 2) - 30;
    return '<a class="cnnvideo_clicklink" href="#" title="Click to watch this video"><div class="cnnvideo_playcontainer cnnvideo_click_standard" style="top:' + af + "px;left:" + ag + 'px;"></div></a>';
  };
  Y = function () {
    return ['<img src="', O.thumb, '" width="', O.width, '" height="', O.height, '" alt="', O.alt || "Watch this video", '" />'].join("");
  };
  N = function () {
    if (O.headline) {
      var af;
      if (O.headlineUrl) {
        af = "<a href=" + O.headlineUrl + ">" + O.headline + "</a>";
      } else {
        af = O.headline;
      }
      return '<div class="cnn_mtt1imgh videoHeadline"><div class="cnn_mtt1imghtitle"><h1><span style="padding:11px 9px">' + af + "</span></h1></div></div>";
    }
  };
  U = function () {
    h("#cnnCVP1").append('<div id="adCountdown" style="display: none;"></div>');
  };
  v = function () {
    if (O.source) {
      var af;
      if (O.sourceUrl) {
        af = "<a href=" + O.sourceUrl + ' target="_blank">' + O.source + "</a>";
      } else {
        af = O.source;
      }
      return '<div id="source">Source: <span class="vidSource">' + af + "</span></div>";
    }
  };
  Q = function () {
    h("#cnnCVP1").parent().append('<div id="adCountdown"></div>');
    g.find(".videoHeadline").remove();
    P.empty();
    X.embed(e);
  };
  D = function () {
    M(function () {
      Q();
    });
  };
  g.on("onContentBegin", function (ag, af) {
    I.META = new window._jsmd.plugin.gCNNVideoCollection();
    I.CONTENT = h.parseJSON(X.getContentEntry(af.contentId));
  });
  g.on("onContentPlay", function (ah, ag) {
    var af = "video-start";
    if (J(ag.contentId)) {
      if (O.context === "debates_homepage" || O.context === "homepage_large") {
        window.live_interval = 60;
      }
      af = "video-live";
    }
    document.getElementById("adCountdown").innerHTML = v();
    window.sendVideo2Event(I.CONTENT, af, ag.playerId);
  });
  g.on("onContentComplete", function (ag, af) {
    window.sendVideo2Event(I.CONTENT, "video-complete", af.playerId);
  });
  g.on("onContentPlayhead", function (aj, ai) {
    var ag = ai.playhead,
      ah = ai.duration,
      ak = ai.contentId,
      af = ai.playerId;
    if (I.META !== undefined && ag !== undefined && !I.META.get(ak, "hasScrubbed")) {
      if (ag > (ah * 0.75) && !I.META.get(ak, "isSeventyFive")) {
        window.sendVideo2Event(I.CONTENT, "video-seventyfive", af);
      } else {
        if (ag > (ah * 0.5) && !I.META.get(ak, "isHalf")) {
          window.sendVideo2Event(I.CONTENT, "video-fifty", af);
        } else {
          if (ag > (ah * 0.25) && !I.META.get(ak, "isTwentyFive")) {
            window.sendVideo2Event(I.CONTENT, "video-twentyfive", af);
          } else {
            if (ag > (ah * 0.1) && !I.META.get(ak, "isTen")) {
              window.sendVideo2Event(I.CONTENT, "video-ten", af);
            }
          }
        }
      }
    }
  });
  g.on("adPlay", function (ah, ag) {
    var af = ag.playerId;
    I.CONTENT.ad_duration = ag.duration;
    window.sendVideo2Event(I.CONTENT, "video-preroll", af);
  });
  g.on("onAdEnd", function (ag, af) {
    window.sendVideo2Event(I.CONTENT, "video-midroll-complete", af.playerId);
  });
  g.on("onContentPause", function (ag, af) {
    window.sendVideo2Event(I.CONTENT, "video-pause", af.playerId);
  });
  g.on("onTrackingFullscreen", function (ag, af) {
    if (af.dataObj.fullscreen) {
      X.setMaxBitrate(O.fullscreenbitrate);
    }
  });
  b();
  P = V();
  if (O.autostart) {
    D();
  }
  if (!O.autostart) {
    P.html(Y() + o());
    if (O.headline) {
      g.append(N());
    }
    P.find(".cnnvideo_playcontainer").on("click", function (af) {
      D();
      af.preventDefault();
    });
  }
  return {
    getVersion: function () {
      return ac;
    },
    resume: function () {
      p();
    },
    pause: function () {
      a();
    },
    resize: function (ag, af, ah) {
      z(ag, af, ah);
    },
    seek: function (af) {
      B(af);
    },
    getContentEntry: function (af) {
      return q(af);
    },
    getContentPlayhead: function () {
      return Z();
    },
    getDuration: function () {
      return A();
    },
    getPlayHead: function () {
      return ae();
    },
    getStartTime: function (af) {
      return l(af);
    },
    getVideoId: function () {
      return t();
    }
  };
};

function callCnnVideo(a) {
  window.CNNVIDEOS = window.CNNVIDEOS || {};
  window.CNNVIDEOS[a.key] = window.CNNVIDEO(a.markupid, {
    video: a.video,
    thumb: a.thumb,
    preset: "homepage",
    diagnostics: {
      section: "homepage",
      placement: a.placement
    },
    network: "cnn",
    adsection: a.adsection,
    headline: a.headline,
    headlineUrl: a.url,
    source: a.source,
    sourceUrl: a.sourceUrl,
    isLive: a.isLive,
    section: a.section,
    videoStreamUrl: a.videoStreamUrl
  });
}

function initializeChartbeat(a, c, b) {
  window._sf_startpt = (new Date()).getTime();
  window._sf_async_config = {};
  window._sf_async_config.uid = 37612;
  window._sf_async_config.useCanonical = true;
  window._sf_async_config.domain = a;
  window._sf_async_config.sections = c;
  window._sf_async_config.authors = b;
}

function loadChartbeat(d, b) {
  var a = location.host;
  if (a == "localhost" || a.indexOf("dev.cnn.com") >= 0) {
    a = "ref.cnn.com";
  }
  initializeChartbeat(a, d, b);
  window._sf_endpt = (new Date()).getTime();
  var c = document.createElement("script");
  c.setAttribute("src", (("https:" === document.location.protocol) ? "https://a248.e.akamai.net/chartbeat.download.akamai.com/102508/" : "http://static.chartbeat.com/") + "js/chartbeat.js");
  document.body.appendChild(c);
}
if ("undefined" === typeof window.CNNHP) {
  var CNNHP = {};
}(function (b, c) {
  function a(g, f) {
    var e, d;
    if ("undefined" !== typeof g) {
      d = "undefined" !== typeof g.length;
      if (!d) {
        g[f.name] = f.definition;
      }
      if (d) {
        for (e = g.length - 1; e >= 0; e -= 1) {
          if ("undefined" !== typeof g[e]) {
            g[e][f.name] = f.definition;
          }
        }
      }
    }
  }
  a(b, {
    "name": "UtilsModule",
    "definition": (function (f) {
      var d, e;

      function g() {
        this.keys = function (l) {
          var k, h = [];
          if (!Object.keys) {
            if ("object" !== typeof l) {
              throw new TypeError("Object.keys called on non-object");
            }
            for (k in l) {
              if (Object.prototype.hasOwnProperty.call(l, k)) {
                h.push(k);
              }
            }
          } else {
            h = Object.keys(l);
          }
          return h;
        };
        this.cnn_add_query_arg = function (F, G, D) {
          var C, B, A, w, s, q, E, p, n = [],
            t = [],
            u = typeof F,
            z = typeof G,
            r = ("object" === u),
            y = ("string" === u && "string" === z),
            o = "",
            m = "",
            h = "";
          if (y || r) {
            E = F;
            p = G;
            if (r) {
              t = d.keys(E);
            }
            if (y) {
              E = {};
              E[F] = G;
              p = D;
              t.push(F);
            }
            if ("undefined" === typeof p || "" === p) {
              p = f.location.href;
            }
            p = p.split("#");
            m = ("undefined" === typeof p[1]) ? "" : "#" + p[1];
            p = p[0].split("?");
            o = p[0];
            p = ("undefined" === typeof p[1]) ? "" : p[1];
            if ("" !== p) {
              p = p.split("&");
            }
            for (C = p.length - 1; 0 <= C; C -= 1) {
              q = p[C].split("=");
              n.push(p[C]);
              for (B = t.length - 1; 0 <= B; B -= 1) {
                A = t[B];
                if (A === q[0]) {
                  n.pop();
                  t[B] = t[t.length - 1];
                  t.pop();
                  B = -1;
                  s = E[A];
                  if ("" !== s) {
                    q[1] = s;
                    n.push(A + "=" + s);
                  }
                }
              }
            }
            if (t.length > 0) {
              for (w = t.length - 1; 0 <= w; w -= 1) {
                A = t[w];
                s = E[A];
                if ("" !== s) {
                  n.push(A + "=" + s);
                }
              }
            }
            h = (0 === n.length) ? "" : "?";
            if ("?" === h) {
              h += ((n.length > 1) ? n.join("&") : n[0]);
            }
            n = null;
            p = null;
            q = null;
          }
          return o + h + m;
        };
      }
      e = {
        "getInstance": function (h) {
          if ("undefined" === typeof d) {
            d = new g(h);
          }
          return d;
        }
      };
      return e;
    }(c))
  });
}(CNNHP, window));
(function (c, d) {
  function b(h, g) {
    var f, e;
    if ("undefined" !== typeof h) {
      e = "undefined" !== typeof h.length;
      if (!e) {
        h[g.name] = g.definition;
      }
      if (e) {
        for (f = h.length - 1; f >= 0; f -= 1) {
          if ("undefined" !== typeof h[f]) {
            h[f][g.name] = g.definition;
          }
        }
      }
    }
  }
  b(c, {
    "name": "AnnouncementBoxWidget",
    "definition": function a(l, p) {
      var n = this,
        o, q, f, m, h, g, e, k;
      q = {};
      o = "";
      m = [];
      f = null;
      g = function (t, s) {
        var r;
        o = t;
        q = d.extend({}, {
          "skin": "announcement-box-widget",
          "bannerClass": "announcement-box-banner",
          "bannerRate": 30000
        }, s);
        d(o).addClass(q.skin);
        r = d(o).find("." + q.bannerClass);
        if (0 === r.length) {
          d(o).append('<div class="' + q.bannerClass + '" style="display: none;"></div>');
        }
      };
      k = function (r, s) {
        if ("undefined" === typeof s) {
          s = {};
        }
        return d(n).triggerHandler("AnnouncementBoxWidget:" + r, s);
      };
      e = function () {
        if (null !== f) {
          m.shift();
          clearTimeout(f);
        }
        if (m.length > 0) {
          n.animateAnnouncement("show");
          f = setTimeout(e, q.bannerRate);
        }
        if (0 === m.length) {
          n.animateAnnouncement("hide");
          clearTimeout(f);
          f = null;
          k("announcementsDone");
        }
      };
      h = function (r) {
        switch (r) {
          case "show":
            d(o).find("." + q.bannerClass).eq(0).html(m[0]).fadeIn();
            break;
          case "hide":
            d(o).find("." + q.bannerClass).eq(0).fadeOut();
            break;
        }
      };
      this.updateOptions = function (s) {
        var r;
        s = d.extend({}, q, s);
        for (r in q) {
          if (q.hasOwnProperty(r)) {
            q[r] = s[r];
          }
        }
      };
      this.addAnnouncement = function (r) {
        m.push(r);
        if (1 === m.length) {
          e();
        }
      };
      this.cancelAll = function () {
        m = [];
        e();
      };
      this.cancel = function () {
        k("cancel");
        e();
      };
      this.animateAnnouncement = function (r) {
        h(r);
      };
      this.initialize = function () {
        d(o).show();
      };
      g(l, p);
    }
  });
}(window.CNNHP, $j));
(function (b, c) {
  function a(g, f) {
    var e, d;
    if ("undefined" !== typeof g) {
      d = "undefined" !== typeof g.length;
      if (!d) {
        g[f.name] = f.definition;
      }
      if (d) {
        for (e = g.length - 1; e >= 0; e -= 1) {
          if ("undefined" !== typeof g[e]) {
            g[e][f.name] = f.definition;
          }
        }
      }
    }
  }
  a(b, {
    "name": "JSONPoolModule",
    "definition": (function (g) {
      function f() {
        var l, h, k, n, m;
        l = {};
        h = {};
        k = {};
        n = function (o) {
          var p = [];
          if (l.hasOwnProperty(o)) {
            p = l[o];
          }
          return p;
        };
        m = function (o, q) {
          var p = new RegExp(q + "=[^&]+&?", "g");
          o = o.replace(p, "");
          o = o.replace(/_=[0-9]+&?/, "");
          o = o.replace(/\?$/, "");
          return o;
        };
        this.getURLbyId = function (q) {
          var o = "",
            p = h;
          if (p.hasOwnProperty(q)) {
            o = p[q];
          }
          return o;
        };
        this.register = function (r, o) {
          var p, q = 0;
          if ("" === this.getURLbyId(r) && "" !== o) {
            h[r] = o;
            if (!l.hasOwnProperty(o)) {
              l[o] = [];
            }
            l[o].push(r);
            for (p in k) {
              if (k.hasOwnProperty(p)) {
                if (k[p] > q) {
                  q = k[p];
                }
              }
            }
            q += 1;
            k[o] = q;
          }
        };
        this.deregister = function (r) {
          var o = this.getURLbyId(r),
            q, p;
          if ("" !== o) {
            delete h[r];
            if ("undefined" !== typeof h[r]) {
              h[r] = "";
            }
            if (k.hasOwnProperty(o)) {
              delete k[o];
              if ("undefined" !== typeof k[o]) {
                k[o] = "";
              }
            }
            if (l.hasOwnProperty(o)) {
              q = l[o];
              for (p = q.length - 1; p >= 0; p -= 1) {
                if (r === q[p]) {
                  q.splice(p, 1);
                  p = -1;
                }
              }
              l[o] = q;
              if (0 === q.length) {
                delete l[o];
                if ("undefined" !== typeof l[o]) {
                  l[o] = "";
                }
              }
            }
          }
        };
        this.enqueueIds = function (q) {
          var p, s, o, r = {};
          for (p = q.length - 1; p >= 0; p -= 1) {
            s = q[p];
            o = this.getURLbyId(s);
            if ("" !== o) {
              if (!r.hasOwnProperty(o)) {
                r[o] = [];
              }
              r[o].push(s);
            }
          }
          d.enqueueAll(r);
        };
        this.enqueue = function (o) {
          if (l.hasOwnProperty(o)) {
            g.ajax(o, {
              "dataType": "jsonp",
              "cache": true,
              "jsonp": "callback",
              "jsonpCallback": "jsonpool" + k[o].toString(),
              "timeout": 3000
            }).done(function (r) {
              var q, p;
              q = n(m(this.url, this.jsonp, this.jsonpCallback));
              for (p = q.length - 1; p >= 0; p -= 1) {
                g(d).triggerHandler("JSONPool:" + q[p], r);
              }
            }).fail(function (r) {
              var q, p;
              q = n(m(this.url, this.jsonp, this.jsonpCallback));
              for (p = q.length - 1; p >= 0; p -= 1) {
                g(d).triggerHandler("JSONPool:" + q[p] + "-failed", r);
              }
            });
          }
        };
        this.enqueueAll = function (q) {
          var o = "",
            r;
          r = l;
          if ("undefined" !== typeof q) {
            r = q;
          }
          for (o in r) {
            if (r.hasOwnProperty(o)) {
              d.enqueue(o);
            }
          }
        };
      }
      var d, e = {
        "getInstance": function (h) {
          if ("undefined" === typeof d) {
            d = new f(h);
          }
          return d;
        }
      };
      return e;
    }(c))
  });
}(CNNHP, $j));
(function (b, d) {
  function a(h, g) {
    var f, e;
    if ("undefined" !== typeof h) {
      e = "undefined" !== typeof h.length;
      if (!e) {
        h[g.name] = g.definition;
      }
      if (e) {
        for (f = h.length - 1; f >= 0; f -= 1) {
          if ("undefined" !== typeof h[f]) {
            h[f][g.name] = g.definition;
          }
        }
      }
    }
  }
  a(b, {
    "name": "SlideRotatorWidget",
    "definition": function c(k, r) {
      var o = this,
        q, l, n, s, f, e, m, p, h, g;
      s = {};
      l = [];
      n = -1;
      q = "";
      f = null;
      e = false;
      m = function (v, u) {
        var t, w, y = "";
        q = v;
        if ("undefined" !== typeof q && "" !== q) {
          s = d.extend({}, {
            "skinClass": "cnn-slide-rotator-widget",
            "slideClass": "slide",
            "rotationRate": 10000,
            "slideDirection": "slide-up"
          }, u);
          t = d(q);
          t.addClass(s.skinClass);
          w = t.find("." + s.slideClass);
          switch (w.length) {
            case 0:
              y = '<div class="' + s.slideClass + '"></div><div class="' + s.slideClass + '"></div>';
              break;
            case 1:
              y = '<div class="' + s.slideClass + '"></div>';
              break;
          }
          t.append(y);
          w.each(function () {
            var z = d(this).html();
            if ("" !== z) {
              l.push(z);
            }
          });
        }
      };
      p = function () {
        var t;
        if (l.length - 1 <= n) {
          t = g("updateSlides");
          n = -1;
          if ("undefined" !== typeof t && 0 !== t.length) {
            l = null;
            l = t;
          }
        }
        n += 1;
        return ("undefined" === typeof l[n]) ? "" : l[n];
      };
      h = function () {
        var t = d(q),
          u = t.find("." + s.slideClass),
          v = -1 * u.outerHeight(),
          w = 1000;
        t.attr("data-locked", "true");
        switch (s.slideDirection) {
          case "slide-up":
            u.eq(1).html(p());
            u.eq(1).addClass("sliding-bottom");
            u.eq(0).addClass("sliding-top").animate({
              "margin-top": v.toString() + "px"
            }, w, d.proxy(function () {
              this.slides.eq(1).removeClass("sliding-bottom");
              this.slides.eq(0).removeClass("sliding-top").css({
                "margin-top": "0"
              }).detach().appendTo(t);
            }, {
              "slides": u
            }));
            break;
          case "slide-down":
            u.eq(0).addClass("sliding-top");
            u.last().html(p());
            u.last().addClass("sliding-bottom").css({
              "margin-top": v.toString() + "px"
            }).detach().prependTo(t).animate({
              "margin-top": "0px"
            }, w, d.proxy(function () {
              u.eq(0).removeClass("sliding-top");
              u.last().removeClass("sliding-bottom");
            }, {
              "slides": u
            }));
            break;
        }
        if (null !== f) {
          clearTimeout(f);
        }
        f = setTimeout(o.rotate, s.rotationRate);
      };
      g = function (t, u) {
        if ("undefined" === typeof u) {
          u = {};
        }
        return d(o).triggerHandler("SlideRotatorWidget:" + t, u);
      };
      this.pause = function () {
        g("pause");
        if (null !== f) {
          clearTimeout(f);
        }
      };
      this.resume = function () {
        g("resume");
        if (null !== f) {
          clearTimeout(f);
        }
        f = setTimeout(o.rotate, s.rotationRate);
      };
      this.initialize = function () {
        var t = d(q);
        if (!e) {
          t.find("." + s.slideClass).eq(0).html(p());
          t.show("slow");
          o.resume();
          e = true;
        }
      };
      this.rotate = function () {
        h();
      };
      m(k, r);
    }
  });
}(window.CNNHP, $j));
(function (b, e, c) {
  function a(k, h) {
    var g, f;
    if ("undefined" !== typeof k) {
      f = "undefined" !== typeof k.length;
      if (!f) {
        k[h.name] = h.definition;
      }
      if (f) {
        for (g = k.length - 1; g >= 0; g -= 1) {
          if ("undefined" !== typeof k[g]) {
            k[g][h.name] = h.definition;
          }
        }
      }
    }
  }
  a(b, {
    "name": "FlipperTickerApp",
    "definition": function d(C, A) {
      var r = this,
        s, f, q, w, F, M, V, H, g, T, v, p, E, R, S, K, B, L, Q, m, O, h, G, l, z, U, P, D, I, u, n, y, k, N, J, t, o;
      V = {};
      w = "";
      H = [];
      s = [];
      q = [];
      S = [];
      g = [];
      K = -1;
      M = null;
      v = 10;
      F = {};
      T = {};
      E = true;
      R = -1;
      p = [];
      B = function (aa, Y) {
        var ab, W, ac, X, Z;
        if (b.hasOwnProperty("JSONPoolModule")) {
          V = e.extend({}, {
            "skin": "flipper-ticker-widget",
            "bannerClass": "ft-banner",
            "boardClass": "board",
            "flipperClass": "flipper",
            "linkTracking": "elec_flippertkr",
            "useLocalConfig": false,
            "config": {
              "global": {
                "host": "",
                "path": "",
                "updateInterval": -1,
                "display": true
              },
              "columns": [],
              "flipInterval": -1,
              "bop": {
                "host": "",
                "path": "",
                "updateInterval": -1,
                "display": false
              },
              "called": {
                "host": "",
                "path": "",
                "updateInterval": -1,
                "display": false,
                "displayInterval": -1
              }
            },
            "clientConfig": {
              "host": "http://data.cnn.com",
              "path": "/jsonp/ELECTION/2012/meta/clientConfig.json",
              "updateInterval": -1
            }
          }, Y);
          w = aa;
          f = b.JSONPoolModule.getInstance();
          e(w).addClass(V.skin);
          X = e(w).attr("data-clientConfig-host");
          Z = e(w).attr("data-clientConfig-path");
          if ("undefined" !== typeof X && "" !== X && "undefined" !== typeof Z && "" !== Z) {
            e(w).removeAttr("data-clientConfig-host");
            e(w).removeAttr("data-clientConfig-path");
            V.clientConfig.host = X;
            V.clientConfig.path = Z;
          }
          W = e(w).find("." + V.bannerClass);
          if (0 === W.length) {
            e(w).append('<div class="' + V.bannerClass + '" style="display: none;"></div>');
            W = e(w).find("." + V.bannerClass);
          }
          if ("undefined" !== typeof b.AnnouncementBoxWidget) {
            M = new b.AnnouncementBoxWidget(W);
          }
          ab = e(w).find("." + V.boardClass);
          if (0 === ab.length) {
            e(w).append('<div class="' + V.boardClass + '" style="display: none;"></div>');
            ab = e(w).find("." + V.boardClass);
          }
          ab.find("." + V.flipperClass).eq(0).addClass("first-column");
          e(ab).on("click", "div.race-feed", function () {
            var ad = e(this),
              af = ad.attr("data-raceid"),
              ae;
            if ("undefined" !== typeof af) {
              ae = m(af);
              if ("" !== ae) {
                c.location.assign(b.UtilsModule.getInstance().cnn_add_query_arg("hpt", V.linkTracking, ae));
              }
            }
          });
          ac = e(w).find(".collapse");
          if (0 !== ac.length) {
            e(ac).on("click", function () {
              var af = e(w),
                ad = af.find("." + V.boardClass),
                ae = e(this);
              if (ad.is(":hidden")) {
                ad.show();
                ae.addClass("collapse");
                ae.removeClass("expand");
              } else {
                ad.hide();
                M.cancelAll();
                ae.removeClass("collapse");
                ae.addClass("expand");
              }
            });
          }
          e(w).on("click", "a", function () {
            var ad = e(this).attr("href");
            if (undefined !== ad && null !== ad) {
              e(this).attr("href", b.UtilsModule.getInstance().cnn_add_query_arg("hpt", V.linkTracking, ad));
            }
          });
          f.register("clientConfig", V.clientConfig.host + V.clientConfig.path);
        }
      };
      D = function (aa) {
        var Z, Y, X = {
          "flipper": null,
          "clientConfig": null
        }, W = {
          "name": "",
          "host": "",
          "path": "",
          "updateInterval": -1,
          "display": false,
          "bopKey": ""
        };
        X.flipper = e.extend(true, {}, V.config, aa.flipper);
        Z = X.flipper.columns;
        for (Y = Z.length - 1; Y >= 0; Y -= 1) {
          if (Z[Y].display) {
            Z[Y] = e.extend({}, W, Z[Y]);
          } else {
            Z.splice(Y, 1);
          }
        }
        X.clientConfig = e.extend(true, {}, V.clientConfig, aa.clientConfig);
        return X;
      };
      m = function (ac) {
        var aa = "",
          Y = "",
          Z = "",
          X = ["/election/2012/results/state"],
          W = ["AL", "AK", "AZ", "AR", "CA", "CO", "CT", "DE", "DC", "FL", "GA", "HI", "ID", "IL", "IN", "IA", "KS", "KY", "LA", "ME", "MD", "MA", "MI", "MN", "MS", "MO", "MT", "NE", "NV", "NH", "NJ", "NM", "NY", "NC", "ND", "OH", "OK", "OR", "PA", "RI", "SC", "SD", "TN", "TX", "UT", "VT", "VA", "WA", "WV", "WI", "WY"],
          ab = new RegExp(/^[A-Z]{2}[GHIPS][0-9]{2}$/);
        if (ab.test(ac)) {
          aa = ac.slice(0, 2);
          Y = ac.slice(2, 3);
          Z = ac.slice(3);
          if (-1 !== e.inArray(aa, W)) {
            X.push("/", aa);
            switch (Y) {
              case "G":
                X.push("/governor");
                break;
              case "H":
                X.push("/house/", Z);
                break;
              case "I":
                X.push("/ballot/", Z);
                break;
              case "P":
                X.push("/president");
                break;
              case "S":
                X.push("/senate");
                break;
            }
          }
        }
        if (1 === X.length) {
          X = [];
        }
        return X.join("");
      };
      u = function (Y) {
        var X, W = false;
        for (X = p.length; X >= 0; X -= 1) {
          if (Y === p[X]) {
            W = true;
            X = -1;
          }
        }
        return W;
      };
      z = function (ab, W) {
        var Z = W.type.replace("JSONPool:flipper", ""),
          Y, aa, X = [],
          ad = "",
          ac = "undefined" === typeof S[Z] ? -1 : S[Z],
          af = "undefined" === typeof s[Z] || null === s[Z],
          ae = ab.hasOwnProperty("lts") && ab.lts > ac;
        if (af || ae) {
          S[Z] = ab.lts;
          if (ab.hasOwnProperty("races")) {
            ad = "PS";
            X = ab.races;
          } else {
            if (ab.hasOwnProperty("stateraces")) {
              ad = "H";
              X = ab.stateraces;
            } else {
              if (ab.hasOwnProperty("G") && ab.G.hasOwnProperty("races")) {
                ad = "GI";
                X = ab;
              } else {
                if (ab.hasOwnProperty("I")) {
                  ad = "GI";
                  X = ab;
                }
              }
            }
          }
          if ("undefined" === typeof q[Z] || q[Z] > X.length) {
            q[Z] = 0;
          }
          Y = Math.floor(V.config.columns[Z].updateInterval / V.config.flipInterval);
          if (Y < 0) {
            Y = 1;
          }
          Y *= v;
          if ("GI" === ad) {
            aa = ab;
          } else {
            aa = X.splice(q[Z], Y);
          }
          U(aa, ad, Z);
          if (af) {
            q[Z] += Y;
          }
        }
      };
      U = function (X, ah, aa) {
        var ae, ac, ab, Y, W = [],
          ai = "",
          af, ag, ak, aj, Z, ad;
        ai = ['<div><div id="container" class="race-feed"><p id="race" class="race-type"><span id="icon" class="race-icon"></span></p>', '<p id="state" class="race-state"><span class="percent-total">Est. <span id="totalpercent"></span>% in</span></p>', '<p id="candidate_1" class="race-candidate"><span id="winner_1" class="race-winner"></span><span class="percent-candidate"><span id="percent_1"></span>%</span></p>', '<p id="candidate_2" class="race-candidate"><span id="winner_2" class="race-winner"></span><span class="percent-candidate"><span id="percent_2"></span>%</span></p>', '<p id="candidate_3" class="race-candidate"><span id="winner_3" class="race-winner"></span><span class="percent-candidate"><span id="percent_3"></span>%</span></p>', "</div></div>"].join("");
        if ("PS" === ah) {
          for (ae = X.length - 1; ae >= 0; ae -= 1) {
            ag = e.extend({}, {
              "raceid": "",
              "race": "",
              "state": "",
              "keyrace": false,
              "pctsrep": ""
            }, X[ae]);
            aj = "";
            if (ag.keyrace) {
              aj = "keyrace";
              if ("P" === ag.rtype) {
                aj = "battleground";
              }
            }
            af = e(ai).clone();
            af.find("#container").removeAttr("id").addClass(ag.race.toLowerCase()).attr("data-raceid", ag.raceid).end().find("#race").prepend(ag.race).removeAttr("id").end().find("#icon").addClass(aj).removeAttr("id").end().find("#state").removeAttr("id").prepend(ag.state).end().find("#totalpercent").html(ag.pctsrep);
            if (ag.hasOwnProperty("candidates")) {
              for (ac = ag.candidates.length - 1, Y = 0; ac >= 0; ac -= 1, Y += 1) {
                ak = e.extend({}, {
                  "lname": "",
                  "party": "",
                  "winner": false,
                  "vpct": ""
                }, ag.candidates[Y]);
                aj = "";
                if (ak.winner) {
                  aj = "winner";
                }
                Z = '<span class="candidate-icon ' + ak.party.toLowerCase() + '"></span>';
                af.find("#candidate_" + (Y + 1)).removeAttr("id").prepend(Z, ak.lname).find("#winner_" + (Y + 1)).removeAttr("id").addClass(aj).end().find("#percent_" + (Y + 1)).removeAttr("id").html(ak.vpct);
                if (Y >= 2) {
                  ac = -1;
                }
              }
              af.find("#candidate_1").remove();
              af.find("#candidate_2").remove();
              af.find("#candidate_3").remove();
            }
            W[ae] = af.html();
          }
        }
        if ("H" === ah) {
          for (ab = X.length - 1; ab >= 0; ab -= 1) {
            if (X[ab].hasOwnProperty("races")) {
              for (ae = X[ab].races.length - 1; ae >= 0; ae -= 1) {
                ag = e.extend({}, {
                  "raceid": "",
                  "race": "",
                  "state": "",
                  "keyrace": false,
                  "pctsrep": ""
                }, X[ab].races[ae]);
                aj = "";
                if (ag.keyrace) {
                  aj = "keyrace";
                }
                af = e(ai).clone();
                af.find("#container").removeAttr("id").addClass(ag.race.toLowerCase()).attr("data-raceid", ag.raceid).end().find("#race").prepend(ag.race).removeAttr("id").end().find("#icon").addClass(aj).removeAttr("id").end().find("#state").removeAttr("id").prepend(ag.state).end().find("#totalpercent").html(ag.pctsrep);
                if (ag.hasOwnProperty("candidates")) {
                  for (ac = ag.candidates.length - 1, Y = 0; ac >= 0; ac -= 1, Y += 1) {
                    ak = e.extend({}, {
                      "lname": "",
                      "party": "",
                      "winner": false,
                      "vpct": ""
                    }, ag.candidates[Y]);
                    aj = "";
                    if (ak.winner) {
                      aj = "winner";
                    }
                    Z = '<span class="candidate-icon ' + ak.party.toLowerCase() + '"></span>';
                    af.find("#candidate_" + (Y + 1)).removeAttr("id").prepend(Z, ak.lname).find("#winner_" + (Y + 1)).removeAttr("id").addClass(aj).end().find("#percent_" + (Y + 1)).removeAttr("id").html(ak.vpct);
                    if (Y >= 2) {
                      ac = -1;
                    }
                  }
                  af.find("#candidate_1").remove();
                  af.find("#candidate_2").remove();
                  af.find("#candidate_3").remove();
                }
                W.push(af.html());
              }
            }
          }
          W.reverse();
        }
        if (X.hasOwnProperty("G") && X.G.hasOwnProperty("races")) {
          for (ae = X.G.races.length - 1; ae >= 0; ae -= 1) {
            ag = e.extend({}, {
              "raceid": "",
              "race": "",
              "state": "",
              "keyrace": false,
              "pctsrep": ""
            }, X.G.races[ae]);
            aj = "";
            if (ag.keyrace) {
              aj = "keyrace";
            }
            af = e(ai).clone();
            af.find("#container").removeAttr("id").addClass(ag.race.toLowerCase()).attr("data-raceid", ag.raceid).end().find("#race").prepend(ag.race).removeAttr("id").end().find("#icon").addClass(aj).removeAttr("id").end().find("#state").removeAttr("id").prepend(ag.state).end().find("#totalpercent").html(ag.pctsrep);
            if (ag.hasOwnProperty("candidates")) {
              for (ac = ag.candidates.length - 1, Y = 0; ac >= 0; ac -= 1, Y += 1) {
                ak = e.extend({}, {
                  "lname": "",
                  "party": "",
                  "winner": false,
                  "vpct": ""
                }, ag.candidates[Y]);
                aj = "";
                if (ak.winner) {
                  aj = "winner";
                }
                Z = '<span class="candidate-icon ' + ak.party.toLowerCase() + '"></span>';
                af.find("#candidate_" + (Y + 1)).removeAttr("id").prepend(Z, ak.lname).find("#winner_" + (Y + 1)).removeAttr("id").addClass(aj).end().find("#percent_" + (Y + 1)).removeAttr("id").html(ak.vpct);
                if (Y >= 2) {
                  ac = -1;
                }
              }
              af.find("#candidate_1").remove();
              af.find("#candidate_2").remove();
              af.find("#candidate_3").remove();
            }
            W[ae] = af.html();
          }
        }
        if (X.hasOwnProperty("I") && X.I.hasOwnProperty("races")) {
          for (ae = X.I.races.length - 1; ae >= 0; ae -= 1) {
            ag = e.extend({}, {
              "raceid": "",
              "race": "",
              "state": "",
              "keyrace": false,
              "pctsrep": ""
            }, X.I.races[ae]);
            aj = "";
            if (ag.keyrace) {
              aj = "keyrace";
            }
            af = e(ai).clone();
            af.find("#container").removeAttr("id").addClass(ag.race.toLowerCase()).attr("data-raceid", ag.raceid).end().find("#race").prepend(ag.race).removeAttr("id").end().find("#icon").addClass(aj).removeAttr("id").end().find("#state").removeAttr("id").prepend(ag.state).end().find("#totalpercent").html(ag.pctsrep);
            if (ag.hasOwnProperty("candidates")) {
              for (ac = ag.candidates.length - 1, Y = 0; ac >= 0; ac -= 1, Y += 1) {
                ak = e.extend({}, {
                  "lname": "",
                  "party": "",
                  "winner": false,
                  "vpct": ""
                }, ag.candidates[Y]);
                aj = "";
                if (ak.winner) {
                  aj = "winner";
                }
                af.find("#candidate_" + (Y + 1)).removeAttr("id").prepend(ak.lname).find("#winner_" + (Y + 1)).removeAttr("id").addClass(aj).end().find("#percent_" + (Y + 1)).removeAttr("id").html(ak.vpct);
                if (Y >= 2) {
                  ac = -1;
                }
              }
              af.find("#candidate_1").remove();
              af.find("#candidate_2").remove();
              af.find("#candidate_3").remove();
            }
            ad = 0;
            if (X.hasOwnProperty("G") && X.G.hasOwnProperty("races")) {
              ad = X.G.races.length;
            }
            W[ae + ad] = af.html();
          }
        }
        s[aa] = null;
        s[aa] = W;
        if (W.length > 0) {
          H[aa].initialize();
        }
      };
      I = function (ae) {
        var aj = ['<div id="container"><div class="banner">', '<p class="called-title">Called races <span class="called-count">(<span id="current"></span> of <span id="total"></span>)</span></p>', '<p class="called-body"><span id="party-icon" class="party-icon"></span><a id="party" class="party" href="#">CNN projects <span id="fullname"></span> will win <span id="state"></span>', '<span id="electoral"> (<span id="evotes"></span> electoral votes)</span>.</a></p>', "</div></div>"].join(""),
          Y = 0,
          ac = [],
          af, ad, ab, ah, X, ag, aa, am, al, ak, ai, Z, W;
        if (ae.hasOwnProperty("ts") && ae.ts > R) {
          for (ai in ae) {
            if (ae.hasOwnProperty(ai)) {
              switch (ai) {
                case "P":
                case "S":
                case "G":
                case "H":
                  if (ae[ai].hasOwnProperty("races")) {
                    X = ae[ai].races;
                    for (af = X.length - 1; af >= 0; af -= 1) {
                      ah = e.extend({}, {
                        "raceid": "",
                        "state": "",
                        "keyrace": false,
                        "ts": -1,
                        "candidates": []
                      }, X[af]);
                      if (!u(ah.raceid)) {
                        p.push(ah.raceid);
                        if ("P" === ai || ("P" !== ai && ah.keyrace)) {
                          al = null;
                          for (ad = ah.candidates.length - 1; ad >= 0; ad -= 1) {
                            al = e.extend({}, {
                              "fname": "",
                              "lname": "",
                              "suffix": "",
                              "usesuffix": false,
                              "winner": false,
                              "evotes": -1,
                              "party": ""
                            }, ah.candidates[ad]);
                            if (al.winner) {
                              ad = -1;
                            }
                          }
                          if (null !== al) {
                            aa = m(ah.raceid);
                            ak = "party-" + al.party.toLowerCase();
                            am = al.fname + " " + al.lname;
                            if (al.usesuffix) {
                              am += ", " + al.suffix;
                            }
                            if ("" === aa) {
                              aa = "#";
                            }
                            ag = e(aj).clone();
                            ag.find("#current").removeAttr("id").html(Y + 1).end().find("#party-icon").removeAttr("id").addClass(ak).end().find("#party").removeAttr("id").addClass(ak).attr("href", aa).end().find("#fullname").removeAttr("id").html(am).end().find("#state").removeAttr("id").html(ah.state);
                            if (-1 === al.evotes) {
                              ag.find("#electoral").remove();
                            } else {
                              ag.find("#electoral").removeAttr("id").end().find("#evotes").removeAttr("id").html(al.evotes);
                            }
                            ac[Y] = ag;
                            Y += 1;
                          }
                        }
                      }
                    }
                  }
                  break;
              }
            }
          }
          Z = ac.length;
          for (ab = Z - 1, Y = 0; ab >= 0; ab -= 1, Y += 1) {
            M.addAnnouncement(ac[Y].find("#total").removeAttr("id").html(Z).end().html());
          }
          if (Z > 0) {
            W = e(w).find(".close");
            W.on("click", function () {
              M.cancelAll();
            });
            W.show();
          }
          R = ae.ts;
        }
      };
      G = function (ar) {
        var ab, af, W = "",
          ao, ag, ad, an, Z, aa, aq, Y, ah, ak, aj, ai, at, ae, X, ap, ac, al = 270,
          am;
        if (ar.hasOwnProperty("lts") && ar.lts > K) {
          K = ar.lts;
          if (ar.hasOwnProperty("races")) {
            ag = V.config.columns;
            for (ao = ag.length - 1; ao >= 0; ao -= 1) {
              Z = ag[ao].bopKey;
              if ("" !== Z && ar.races.hasOwnProperty(Z)) {
                g[ao] = "";
                if ("USP" === Z) {
                  ad = ['<div id="container"><div class="bop bop-pres flipper-cf">', '<p class="bop-title">President <em>270 for win</em></p>', '<p class="candidates flipper-cf"><span class="left">Barack Obama</span><span class="right">Mitt Romney</span></p>', '<div class="tug-of-war"><div id="tugOfWarD" class="tug-d"></div><div class="divider"></div><div id="tugOfWarR" class="tug-r"></div></div>', '<p class="seats-won flipper-cf"><span id="D" class="seats party-d"></span><span id="R" class="seats party-r"></span></p>', "</div></div>"].join("");
                  an = e.extend({}, {
                    "D": 0,
                    "R": 0,
                    "I": 0,
                    "U": 0
                  }, ar.races[Z]);
                  am = an.D + an.R + an.I + an.U;
                  ae = '<span class="small-party-icon"></span>';
                  aa = "";
                  aq = "";
                  if (an.D >= al) {
                    aa = '<span class="winner"></span>';
                    aq = "";
                  }
                  if (an.R >= al) {
                    aa = "";
                    aq = '<span class="winner"></span>';
                  }
                  W = e(ad).clone();
                  W.find("#tugOfWarD").removeAttr("id").css("width", Math.floor(an.D / am * 100) + "%").end().find("#tugOfWarR").removeAttr("id").css("width", Math.floor(an.R / am * 100) + "%").end().find("#D").removeAttr("id").append(ae, an.D, aa).end().find("#R").removeAttr("id").append(aq, an.R, ae);
                  g[ao] = W.html();
                }
                if ("USH" === Z) {
                  ad = ['<div id="container"><div class="bop bop-house flipper-cf">', '<p class="bop-title">U.S. House <em>218 for control</em></p>', '<p class="candidates flipper-cf"><span class="left">DEM</span><span class="right">GOP</span></p>', '<div class="tug-of-war"><div id="tugOfWarD" class="tug-d"></div><div class="divider"></div>', '<div id="tugOfWarR" class="tug-r"></div></div>', '<p class="seats-won flipper-cf"><span id="D" class="seats party-d"></span><span id="I" class="seats party-i"></span>', '<span id="R" class="seats party-r"></span></p>', "</div></div>"].join("");
                  if (ar.hasOwnProperty("H")) {
                    an = e.extend({}, {
                      "D": 0,
                      "R": 0,
                      "I": 0,
                      "U": 0
                    }, ar.races[Z]);
                    af = e.extend({}, {
                      "rcontrol": 0,
                      "dcontrol": 0
                    }, ar.H);
                    X = an.D + an.R + an.I + an.U;
                    ae = '<span class="small-party-icon"></span>';
                    aa = "";
                    aq = "";
                    Y = "";
                    if (an.R >= af.rcontrol) {
                      aa = "";
                      aq = '<span class="winner"></span>';
                      Y = "";
                    }
                    if (an.D >= af.dcontrol) {
                      aa = '<span class="winner"></span>';
                      aq = "";
                      Y = "";
                    }
                    if (an.I >= af.dcontrol) {
                      Y = '<span class="winner"></span>';
                      aq = "";
                      aa = "";
                    }
                    W = e(ad).clone();
                    W.find("#tugOfWarD").removeAttr("id").css("width", Math.floor(an.D / X * 100) + "%").end().find("#tugOfWarR").removeAttr("id").css("width", Math.floor(an.R / X * 100) + "%").end().find("#D").removeAttr("id").append(ae, an.D, aa).end().find("#I").removeAttr("id").append(ae, an.I, Y).end().find("#R").removeAttr("id").append(aq, an.R, ae);
                    g[ao] = W.html();
                  }
                }
                if ("USS" === Z) {
                  ad = ['<div id="container"><div class="bop bop-senate">', '<p class="bop-title">Senate <em>51 for control</em></p>', '<p class="candidates flipper-cf"><span class="left">DEM</span><span class="right">GOP</span></p>', '<div class="tug-of-war"><div class="divider"></div><div id="tugOfWarD" class="tug-d"></div>', '<div id="tugOfWarOpen" class="open-seats"></div>', '<div id="tugOfWarR" class="tug-r"></div></div>', '<p class="seats-won flipper-cf"><span id="D" class="seats party-d"></span><span id="I" class="seats party-i"></span>', '<span id="R" class="seats party-r"></span></p>', "</div></div>"].join("");
                  if (ar.hasOwnProperty("S")) {
                    ab = e.extend({}, {
                      "dgains": 0,
                      "dnot": 0,
                      "rgains": 0,
                      "rnot": 0,
                      "igains": 0,
                      "dcontrol": 0,
                      "rcontrol": 0
                    }, ar.S);
                    an = e.extend({}, {
                      "D": 0,
                      "R": 0,
                      "I": 0,
                      "U": 0
                    }, ar.races[Z]);
                    ap = an.D + an.R + an.I + an.U;
                    ae = '<span class="small-party-icon"></span>';
                    aa = "";
                    aq = "";
                    Y = "";
                    if (an.R >= ab.rcontrol) {
                      aa = "";
                      aq = '<span class="winner"></span>';
                      Y = "";
                    }
                    if (an.D >= ab.dcontrol) {
                      aa = '<span class="winner"></span>';
                      aq = "";
                      Y = "";
                    }
                    if (an.I >= ab.dcontrol) {
                      Y = '<span class="winner"></span>';
                      aq = "";
                      aa = "";
                    }
                    at = ap - (ab.dnot + ab.rnot);
                    ac = Math.floor(ab.dnot / ap * 100);
                    W = e(ad).clone();
                    if (ab.dgains > 0) {
                      ak = Math.round(ab.dgains / at * 100) + "%";
                      if ("0%" === ak) {
                        ak = "1px";
                      }
                      W.find("#tugOfWarOpen").append('<div class="gains gains-d party-d" style="width:' + ak + '"></div>');
                    }
                    if (ab.igains > 0) {
                      aj = Math.round(ab.igains / at * 100) + "%";
                      if ("0%" === aj) {
                        aj = "1px";
                      }
                      W.find("#tugOfWarOpen").append('<div class="gains gains-i party-i" style="width:' + aj + '"></div>');
                    }
                    if (an.U > 0) {
                      ai = Math.round(an.U / at * 100) + "%";
                      if ("0%" === ai) {
                        ai = "1px";
                      }
                      W.find("#tugOfWarOpen").append('<div class="gains gains-u" style="width:' + ai + '"></div>');
                    }
                    if (ab.rgains > 0) {
                      ah = Math.round(ab.rgains / at * 100) + "%";
                      if ("0%" === ah) {
                        ah = "1px";
                      }
                      W.find("#tugOfWarOpen").append('<div class="gains gains-r party-r" style="width:' + ah + '"></div>');
                    }
                    W.find("#tugOfWarD").removeAttr("id").css("width", ac + "%").end().find("#tugOfWarR").removeAttr("id").css("width", (100 - ac) + "%").end().find("#tugOfWarOpen").removeAttr("id").css({
                      "width": at + "%",
                      "left": ac + "%"
                    }).end().find("#D").removeAttr("id").append(ae, an.D, aa).end().find("#I").removeAttr("id").append(ae, an.I, Y).end().find("#R").removeAttr("id").append(aq, an.R, ae);
                    g[ao] = W.html();
                  }
                }
                if ("" !== g[ao]) {
                  H[ao].initialize();
                }
              }
            }
          }
        }
      };
      P = function (ab) {
        var Y, ac, ad = {}, X = V.config,
          aa, W = function (ae) {
            return z(ae, {
              "type": "JSONPool:flipper" + this.column
            });
          }, Z = function (ae) {
            var af = "";
            if ("string" === typeof ae) {
              af = ae.replace("jsonp/", "");
            }
            return af;
          };
        ad[X.bop.host + Z(V.config.bop.path)] = G;
        ad[X.called.host + Z(V.config.called.path)] = I;
        for (Y = X.columns.length - 1; Y >= 0; Y -= 1) {
          aa = X.columns[Y].host + Z(X.columns[Y].path);
          if ("" !== aa) {
            ad[aa] = e.proxy(W, {
              "column": Y
            });
          }
        }
        if (ab.hasOwnProperty("data")) {
          ac = ab.data;
          if (e.isArray(ac)) {
            t(ac, ad);
          } else {
            if ("object" === typeof ab) {
              o(ac, ad);
            }
          }
        }
      };
      t = function (Y, Z) {
        var X, W;
        for (X = Y.length - 1; X >= 0; X -= 1) {
          W = Y[X];
          if (Z.hasOwnProperty(W.url)) {
            Z[W.url](W);
          }
        }
      };
      o = function (X, Y) {
        var W;
        for (W in X) {
          if (X.hasOwnProperty(W) && Y.hasOwnProperty(W)) {
            Y[W](X[W]);
          }
        }
      };
      N = function () {
        var aa, ac, ab, Y, ad, X, W, Z = function () {
          var ag = function () {
            return;
          }, ae = ("undefined" === typeof this.cache[this.columnId] || null === this.cache[this.columnId]) ? [] : this.cache[this.columnId],
            af = this.bop[this.columnId];
          if ("undefined" !== typeof af && "" !== af) {
            if (0 !== ae.length) {
              ae.splice(ae.length, 0, af);
            } else {
              ae.push(af);
            }
          }
          if (0 === ae.length) {
            ae = ag;
          }
          this.cache[this.columnId] = null;
          return ae;
        };
        W = [];
        Y = V.config;
        if (Y.columns.length > 0) {
          X = e(w);
          ad = X.find("." + V.flipperClass);
          ac = X.find("." + V.boardClass);
          for (aa = (Y.columns.length - ad.length - 1); aa >= 0; aa -= 1) {
            ac.append('<div class="' + V.flipperClass + '"></div>');
          }
          ad = X.find("." + V.flipperClass);
          for (aa = Y.columns.length - 1; aa >= 0; aa -= 1) {
            ab = Y.columns[aa];
            H[aa] = new b.SlideRotatorWidget(ad.eq(aa), {
              "rotationRate": Y.flipInterval + (aa * 250)
            });
            e(H[aa]).on("SlideRotatorWidget:updateSlides", e.proxy(Z, {
              "columnId": aa,
              "cache": s,
              "bop": g
            }));
          }
        }
      };
      y = function () {
        if (null !== M) {
          e(M).on("AnnouncementBoxWidget:announcementsDone", function () {
            var W = e(w).find(".close");
            W.off("click");
            W.hide();
          });
        }
      };
      n = function () {
        var X, ab, aa = V.config,
          Y = aa.global,
          Z = ("" === Y.host && "" === Y.path) ? true : false,
          W = function () {
            return V.config.columns[this.columnId];
          };
        for (ab in T) {
          if (T.hasOwnProperty(ab) && "clientConfig" !== ab) {
            Q(ab);
          }
        }
        if (Z) {
          J("flipperCalled", function () {
            return V.config.called;
          }, I);
          J("flipperBOP", function () {
            return V.config.bop;
          }, G);
          for (X = aa.columns.length - 1; X >= 0; X -= 1) {
            J("flipper" + X, e.proxy(W, {
              "columnId": X
            }), z);
          }
        } else {
          J("flipperTickerOnePoll", function () {
            return e.extend({}, {
              "display": true
            }, V.config.global);
          }, P);
        }
      };
      J = function (ac, Z, aa, Y, X) {
        var ab = e.extend({}, {
          "host": "",
          "path": "",
          "updateInterval": -1,
          "display": false
        }, Z()),
          W = ("undefined" === typeof Y) ? false : Y;
        if (ab.display) {
          f.register(ac, ab.host + ab.path);
          e(f).on("JSONPool:" + ac, e.proxy(function (ad, ae) {
            var af, ag;
            this.processor(ae, ad);
            ag = e.extend({}, {
              "host": "",
              "path": "",
              "updateInterval": -1,
              "display": false
            }, this.configurations());
            if (-1 !== ag.updateInterval) {
              l(this.id);
              af = ag.host + ag.path;
              if ("" !== af && f.getURLbyId(this.id) !== af) {
                f.deregister(this.id);
                f.register(this.id, af);
              }
              if (undefined === X || false === X) {
                O(this.id, setTimeout(e.proxy(function () {
                  f.enqueueIds([this.id]);
                }, {
                  "id": this.id
                }), ag.updateInterval));
              }
            }
          }, {
            "id": ac,
            "configurations": Z,
            "processor": aa
          }));
          e(f).on("JSONPool:" + ac + "-failed", e.proxy(function () {
            var ad = L(this.id),
              ae = e.extend({}, {
                "host": "",
                "path": "",
                "updateInterval": -1,
                "display": false
              }, this.configurations());
            if (!E) {
              if (F[ac] < v) {
                if (undefined === X || false === X) {
                  O(this.id, e.proxy(setTimeout(function () {
                    f.enqueueIds([this.id]);
                  }, {
                    "id": this.id
                  }), ae.updateInterval * ad));
                }
              }
            }
          }, {
            "id": ac,
            "configurations": Z
          }));
          if (W && -1 !== ab.updateInterval) {
            if (undefined === X || false === X) {
              O(this.id, setTimeout(e.proxy(function () {
                f.enqueueIds([this.id]);
              }, {
                "id": ac
              }), ab.updateInterval));
            }
          } else {
            if (undefined === X || false === X) {
              f.enqueueIds([ac]);
            }
          }
        }
      };
      Q = function (X) {
        var W;
        f.deregister(X);
        e(f).off("JSONPool:" + X);
        e(f).off("JSONPool:" + X + "-failed");
        if (!T.hasOwnProperty(X)) {
          clearTimeout(T[X]);
          W = delete T[X];
          if (!W) {
            T[X] = null;
          }
        }
      };
      h = function (W, X) {
        if ("undefined" === typeof X) {
          X = {};
        }
        return e(r).triggerHandler("FlipperTickerApp:" + W, X);
      };
      L = function (W) {
        if (!F.hasOwnProperty(W)) {
          F[W] = 0;
        }
        F[W] += 1;
        return F[W] * 1.5;
      };
      l = function (W) {
        if (!F.hasOwnProperty(W)) {
          F[W] = 0;
        }
        F[W] = 0;
      };
      O = function (X, W) {
        if (!T.hasOwnProperty(X)) {
          clearTimeout(T[X]);
          T[X] = null;
        }
        T[X] = W;
      };
      k = function (Y) {
        var X = D(Y),
          W = (V.config.called.displayInterval !== X.flipper.called.displayInterval),
          Z = (E || V.config.global.host !== X.flipper.global.host || V.config.global.path !== X.flipper.global.path) ? true : false;
        V.config = X.flipper;
        V.clientConfig = X.clientConfig;
        if (W) {
          M.updateOptions({
            "bannerRate": X.flipper.called.displayInterval
          });
        }
        if (E) {
          E = false;
          N();
          y();
          if (X.flipper.columns.length > 0 || X.flipper.bop.display || X.flipper.called.display) {
            e(w).find("." + V.boardClass).addClass("columns-" + X.flipper.columns.length);
            e(w).show();
          }
        }
        if (Z) {
          n();
        }
      };
      this.initialize = function (W) {
        var X = (undefined !== W);
        if (e(w).length > 0) {
          J("clientConfig", function () {
            return e.extend({}, {
              "display": true
            }, V.clientConfig);
          }, k, V.useLocalConfig, X);
          if (X) {
            k(W);
          }
        }
      };
      B(C, A);
    }
  });
}(window.CNNHP, $j, window));